<?php

return array(

/*
|--------------------------------------------------------------------------
| Password Reminder Language Lines
|--------------------------------------------------------------------------
|
| The following language lines are the default lines which match reasons
| that are given by the password broker for a password update attempt
| has failed, such as for an invalid token or invalid new password.
|
*/

"password" => "As palavras-passe devem conter no mínimo seis caracteres e devem ser iguais.",

"user" => "Não foi encontrado um utilizador com o endereço de email indicado.",

"token" => "Este token de redefinição de palavra-passe é inválido.",

"sent" => "Lembrete de palavra-passe enviado!",

);
