<?php

return array(

    /*
    |--------------------------------------------------------------------------
    | Password Reminder Language Lines
    |--------------------------------------------------------------------------
    |
    | The following language lines are the default lines which match reasons
    | that are given by the password broker for a password update attempt
    | has failed, such as for an invalid token or invalid new password.
    |
    */

    "password" => "パスワードは６文字以上必要です。またパスワードの確認と一致している必要があります。",

    "user" => "そのEメールアドレスのユーザは存在しません。",

    "token" => "このパスワード・リセット・トークンは正しくありません。",

    "sent" => "パスワードリマインダーが送信されました！",

);
