<?php

return array(

    /*
    |--------------------------------------------------------------------------
    | Password Reminder Language Lines
    |--------------------------------------------------------------------------
    |
    | The following language lines are the default lines which match reasons
    | that are given by the password broker for a password update attempt
    | has failed, such as for an invalid token or invalid new password.
    |
    */

    "password" => "Hasło musi mieć conajmniej sześć znaków i być takie samo jak potwierdzające.",

    "user" => "Użytkownik o podanym adresie e-mail nie istnieje.",

    "token" => "Wprowadzony token jest nieprawidłowy.",

    "sent" => "Przypomnienie hasła zostało wysłane!",

);