<?php

return [

    /*
    |--------------------------------------------------------------------------
    | Password Reminder Language Lines
    |--------------------------------------------------------------------------
    |
    | The following language lines are the default lines which match reasons
    | that are given by the password broker for a password update attempt
    | has failed, such as for an invalid token or invalid new password.
    |
    */

    'password' => 'Geslo mora biti dolgo vsaj šest znakov in se mora ujemati z potrditvenim geslom.',
    'reset'    => 'Geslo je bilo spremenjeno!',
    'sent'     => 'Opomnik za geslo poslano!',
    'token'    => 'Ponastavitveni žeton je neveljaven.',
    'user'     => 'Ne moremo najti uporabnika s tem e-poštnim naslovom.',

];
