<?php

return array(

    /*
    |--------------------------------------------------------------------------
    | Password Reminder Language Lines
    |--------------------------------------------------------------------------
    |
    | The following language lines are the default lines which match reasons
    | that are given by the password broker for a password update attempt
    | has failed, such as for an invalid token or invalid new password.
    |
    */

    "password" => "Las contraseñas deben contener al menos 6 caracteres y coincidir.",

    "user"     => "No podemos encontrar a un usuario con ese correo electrónico.",

    "token"    => "Este token de recuperación de contraseña es inválido.",

    "sent"     => "¡Recordatorio de contraseña enviado!",

);
