<?php

return array(

    /*
    |--------------------------------------------------------------------------
    | Password Reminder Language Lines
    |--------------------------------------------------------------------------
    |
    | The following language lines are the default lines which match reasons
    | that are given by the password broker for a password update attempt
    | has failed, such as for an invalid token or invalid new password.
    |
    */

    "password" => "Passwörter müssen 6 Zeichen lang sein und korrekt bestätigt werden.",

    "user"     => "Wir konnten leider keinen Nutzer mit dieser E-Mail Adresse finden.",

    "token"    => "Der Passwort-Wiederherstellungs-Schlüssel ist ungültig.",

    "sent"     => "Passworterinnerung wurde versendet!",

);
