<?php

return [
    /*
    |--------------------------------------------------------------------------
    | Password Reminder Language Lines
    |--------------------------------------------------------------------------
    |
    | The following language lines are the default lines which match reasons
    | that are given by the password broker for a password update attempt
    | has failed, such as for an invalid token or invalid new password.
    |
    */

    'password' => 'Паролата трябва да бъде поне шест знака и да съвпада.',
    'reset'    => 'Паролата е нулирана!',
    'sent'     => 'Изпратено е напомняне за вашата парола!',
    'token'    => 'Този токен за нулиране на парола е невалиден.',
    'user'     => 'Потребител с такъв e-mail адрес не може да бъде открит.',
];
