<?php

return [

    /*
    |--------------------------------------------------------------------------
    | Password Reminder Language Lines
    |--------------------------------------------------------------------------
    |
    | The following language lines are the default lines which match reasons
    | that are given by the password broker for a password update attempt
    | has failed, such as for an invalid token or invalid new password.
    |
    */

    "password" => "A palavra-passe deve conter pelo menos seis caracteres e combinar com a confirmação.",
    "user" => "Utilizador não encontrado.",
    "token" => "Token inválido.",
    "sent" => "Link para reposição da palavra-passe enviado por email!",
    "reset" => "Palavra-passe reposta!",

];
