<?php

return [

    /*
    |--------------------------------------------------------------------------
    | Password Reminder Language Lines
    |--------------------------------------------------------------------------
    |
    | The following language lines are the default lines which match reasons
    | that are given by the password broker for a password update attempt
    | has failed, such as for an invalid token or invalid new password.
    |
    */

    'password' => 'รหัสผ่านต้องมีความยาวอย่างน้อยหกตัวอักษรและต้องตรงกับช่องยืนยันรหัสผ่าน',
    'reset'    => 'ทำการตั้งค่ารหัสผ่านใหม่แล้ว',
    'sent'     => 'ส่งเครื่องช่วยเตือนความจำรหัสผ่านแล้ว!',
    'token'    => 'ชุดรหัสสำหรับการเปลี่ยนรหัสผ่านไม่ถูกต้อง',
    'user'     => 'ไม่พบผู้ใช้งานที่ตรงกับอีเมล์นี้',

];
