<?php

return [
    /*
    |--------------------------------------------------------------------------
    | Password Reminder Language Lines
    |--------------------------------------------------------------------------
    |
    | The following language lines are the default lines which match reasons
    | that are given by the password broker for a password update attempt
    | has failed, such as for an invalid token or invalid new password.
    |
    */

    'password' => 'Лозинката треба да биде најмалку шест карактери и да совпаѓа со потврдната лозинка.',
    'reset'    => 'Password has been reset!',
    'sent'     => 'Испратен емаил со инструкции за ресетирање на лозинка!',
    'token'    => 'Невалиден токен за ресетирање на лозинката.',
    'user'     => 'Не може да се пронајде корисник со таква емаил адреса.',
];
