<?php

return [

    /*
    |--------------------------------------------------------------------------
    | Password Reminder Language Lines
    |--------------------------------------------------------------------------
    |
    | The following language lines are the default lines which match reasons
    | that are given by the password broker for a password update attempt
    | has failed, such as for an invalid token or invalid new password.
    |
    */

    'password' => 'Fjalëkalimet duhet të jenë gjashtë karaktere dhe të përputhen me konfirmimin.',
    'reset'    => 'Fjalëkalimi u ndryshua!',
    'sent'     => 'Adresa për ndryshimin e fjalëkalimit u dërgua!',
    'token'    => 'Ky tallon për ndryshimin e fjalëkalimit është i pasaktë.',
    'user'     => 'Nuk mund të gjejmë një përdorues me atë adres email-i.',

];
