<?php

return array(

    /*
    |--------------------------------------------------------------------------
    | Password Reminder Language Lines
    |--------------------------------------------------------------------------
    |
    | The following language lines are the default lines which match reasons
    | that are given by the password broker for a password update attempt
    | has failed, such as for an invalid token or invalid new password.
    |
    */

    "password" => "Les mots de passe doivent avoir au moins six caractères et doivent être identiques.",

    "user"     => "Nous ne pouvons trouver cet utilisateur avec cette adresse e-mail.",

    "token"    => "Ce jeton de réinitialisation du mot de passe n'est pas valide.",

    "sent"     => "Rappel du mot de passe envoyé !",

);
