<?php

$lang = [
    'client_dashboard' => 'Message to be displayed on clients dashboard',
    'client_currency' => 'The client currency.',
    'client_language' => 'The client language.',
    'client_payment_terms' => 'The client payment terms.',
    'client_paid_invoice' => 'Message to be displayed on a clients paid invoice screen',
    'client_unpaid_invoice' => 'Message to be displayed on a clients unpaid invoice screen',
    'client_unapproved_quote' => 'Message to be displayed on a clients unapproved quote screen',
];

return $lang;
