    <div class="row">
<div class="plans-table col-md-12">
  <div class="col-md-4 desc hide-phone">
    <div class="cell"></div>
    <div class="cell">{{ trans('texts.plans.number_clients') }}</div>
    <div class="cell">{{ trans('texts.plans.unlimited_invoices') }}</div>
    <div class="cell">{{ trans('texts.plans.company_logo') }}</div>
    <div class="cell">{{ trans('texts.plans.live_pdf') }}</div>
    <div class="cell">{{ trans('texts.plans.four_templates') }}</div>
    <div class="cell">{{ trans('texts.plans.payments') }}</div>
    <div class="cell">{{ trans('texts.plans.additional_templates') }}</div>
    <div class="cell">{{ trans('texts.plans.multi_user') }}</div>
    <div class="cell">{{ trans('texts.plans.quotes') }}</div>
    <div class="cell">{{ trans('texts.plans.advanced_settings') }}</div>
    <div class="cell">{{ trans('texts.plans.data_vizualizations') }}</div>
    <div class="cell">{{ trans('texts.plans.email_support') }}</div>
    <div class="cell">{{ trans('texts.plans.remove_created_by') }}</div>
    <div class="cell">{{ trans('texts.plans.latest_features') }}</div>
    <div class="cell">{{ trans('texts.plans.pricing') }}</div>

  </div>
  <div class="free col-md-4">
    <div class="cell">{{ trans('texts.plans.free') }}</div>
    <div class="cell"><div class="hide-desktop">{{ trans('texts.plans.number_clients') }}</div><span>500</span></div>
    <div class="cell"><div class="hide-desktop">{{ trans('texts.plans.unlimited_invoices') }}</div><span class="glyphicon glyphicon-ok"></div>
    <div class="cell"><div class="hide-desktop">{{ trans('texts.plans.company_logo') }}</div><span class="glyphicon glyphicon-ok"></div>
    <div class="cell"><div class="hide-desktop">{{ trans('texts.plans.live_pdf') }}</div><span class="glyphicon glyphicon-ok"></div>
    <div class="cell"><div class="hide-desktop">{{ trans('texts.plans.four_templates') }}</div><span class="glyphicon glyphicon-ok"></div>
    <div class="cell"><div class="hide-desktop">{{ trans('texts.plans.payments') }}</div><span class="glyphicon glyphicon-ok"></div>
    <div class="cell"><div class="hide-desktop">{{ trans('texts.plans.additional_templates') }}</div><span class="glyphicon glyphicon-remove"></div>
    <div class="cell"><div class="hide-desktop">{{ trans('texts.plans.multi_user') }}</div><span class="glyphicon glyphicon-remove"></div>
    <div class="cell"><div class="hide-desktop">{{ trans('texts.plans.quotes') }}</div><span class="glyphicon glyphicon-remove"></div>
    <div class="cell"><div class="hide-desktop">{{ trans('texts.plans.advanced_settings') }}</div><span class="glyphicon glyphicon-remove"></div>
    <div class="cell"><div class="hide-desktop">{{ trans('texts.plans.data_vizualizations') }}</div><span class="glyphicon glyphicon-remove"></div>
    <div class="cell"><div class="hide-desktop">{{ trans('texts.plans.email_support') }}</div><span class="glyphicon glyphicon-remove"></div>
    <div class="cell"><div class="hide-desktop">{{ trans('texts.plans.remove_created_by') }}</div><span class="glyphicon glyphicon-remove"></div>
    <div class="cell"><div class="hide-desktop">{{ trans('texts.plans.latest_features') }}</div><span class="glyphicon glyphicon-remove"></div>
    <div class="cell price"><div class="hide-desktop">{!! trans('texts.plans.pricing') !!}</div><p>{!! trans('texts.plans.free_always') !!}</p></div>
  </div>
  <div class="pro col-md-4">

    <div class="cell">{{ trans('texts.plans.pro_plan') }}</div>
    <div class="cell"><div class="hide-desktop">{{ trans('texts.plans.number_clients') }}</div><span style="color: #2299c0; font-size: 16px;">{{ trans('texts.plans.unlimited') }}</span></div>
    <div class="cell"><div class="hide-desktop">{{ trans('texts.plans.unlimited_invoices') }}</div><span class="glyphicon glyphicon-ok"></div>
    <div class="cell"><div class="hide-desktop">{{ trans('texts.plans.company_logo') }}</div><span class="glyphicon glyphicon-ok"></div>
    <div class="cell"><div class="hide-desktop">{{ trans('texts.plans.live_pdf') }}</div><span class="glyphicon glyphicon-ok"></div>
    <div class="cell"><div class="hide-desktop">{{ trans('texts.plans.four_templates') }}</div><span class="glyphicon glyphicon-ok"></div>
    <div class="cell"><div class="hide-desktop">{{ trans('texts.plans.payments') }}</div><span class="glyphicon glyphicon-ok"></div>
    <div class="cell"><div class="hide-desktop">{{ trans('texts.plans.additional_templates') }}</div><span class="glyphicon glyphicon-ok"></div>
    <div class="cell"><div class="hide-desktop">{{ trans('texts.plans.multi_user') }}</div><span class="glyphicon glyphicon-ok"></div>
    <div class="cell"><div class="hide-desktop">{{ trans('texts.plans.quotes') }}</div><span class="glyphicon glyphicon-ok"></div>
    <div class="cell"><div class="hide-desktop">{{ trans('texts.plans.advanced_settings') }}</div><span class="glyphicon glyphicon-ok"></div>
    <div class="cell"><div class="hide-desktop">{{ trans('texts.plans.data_vizualizations') }}</div><span class="glyphicon glyphicon-ok"></div>
    <div class="cell"><div class="hide-desktop">{{ trans('texts.plans.email_support') }}</div><span class="glyphicon glyphicon-ok"></div>
    <div class="cell"><div class="hide-desktop">{{ trans('texts.plans.remove_created_by') }}</div><span class="glyphicon glyphicon-ok"></div>
    <div class="cell"><div class="hide-desktop">{{ trans('texts.plans.latest_features') }}</div><span class="glyphicon glyphicon-ok"></div>
    <div class="cell price"><div class="hide-desktop">{!! trans('texts.plans.pricing') !!}</div><p>{!! trans('texts.plans.year_price') !!}</p></div>

    <!-- <div class="cell"><a href="#"><div class="cta"><h2 onclick="return getStarted()">GO PRO <span>+</span></h2></div>    </a>-->
  </div>
</div>
</div>