<?php

return [
    /*
    |--------------------------------------------------------------------------
    | Password Reminder Language Lines
    |--------------------------------------------------------------------------
    |
    | The following language lines are the default lines which match reasons
    | that are given by the password broker for a password update attempt
    | has failed, such as for an invalid token or invalid new password.
    |
    */

    'password' => 'Lozinka mora imati najmanje 6 karaktera i da odgovara potvrdi.',
    'reset'    => 'Lozinka je resetovana!',
    'sent'     => 'Poslali smo reset link za vašu lozinku!',
    'token'    => 'Ukucana oznaka za resetovanje lozinke nije važeća.',
    'user'     => 'Nismo uspeli pronaći korisnika sa email adresom.',
];
