<?php

return [

    /*
    |--------------------------------------------------------------------------
    | Password Reminder Language Lines
    |--------------------------------------------------------------------------
    |
    | The following language lines are the default lines which match reasons
    | that are given by the password broker for a password update attempt
    | has failed, such as for an invalid token or invalid new password.
    |
    */

    'password' => 'Les contrasenyes han de contenir almenys 6 caràcters i coincidir.',
    'reset'    => "La contrasenya s'ha restablert!",
    'sent'     => 'Recordatori de contrasenya enviat!',
    'token'    => 'Aquest token de recuperació de contrasenya és invàlid.',
    'user'     => 'No podem trobar a un usuari amb aquest correu electrònic.',

];
