<?php

return [

    /*
    |--------------------------------------------------------------------------
    | Slaptažodžio priminimo kalbos eilutės
    |--------------------------------------------------------------------------
    |
    | Sekančios kalbos eilutės yra numatytos elutės, atitinkančios priežastims,
    | pateikiamoms slatažodžių tarpininko, kai nepavyksta slaptažodžio atnaujinimo
    | bandymas, tokioms kaip negaliojanti žymė ar neteisingas naujas slaptažodis..
    |
    */

    "password" => "Slaptažodis turi būti bent šešių simbolių ir sutapti su patvirtinimu.",
    "user" => "Vartotojas su tokiu el. pašu nerastas.",
    "token" => "Šis slaptažodžio raktas yra neteisingas.",
    "sent" => "Naujo slaptažodžio nustatymo nuoroda išsiųsta",
    "reset" => "Nustatytas naujas slaptažodis!",
];
