.customContainer{
	padding: 40px 0;
	margin: 0px 0 !important;
	background: -webkit-linear-gradient(rgb(245, 245, 245), white);
}	
.customFontHead{
	font-size: 20px;
	text-align: center;
}	
.customTextBorder{
	border-bottom: 1px solid rgb(195, 193, 193);
	padding-bottom: 5%;
	margin-bottom: 5%;
}
.customSubMenu{
	margin-left: 2%;
}
.customMenuOne{
	padding-left: 5px;
	padding-right: 5px;
}
.shiftLeft{
	float: left;
}
.customMenuDiv{
	padding-bottom: 30px;
	float: left;
	width: 100%;
}