<?php

return [

    /*
    |--------------------------------------------------------------------------
    | Password Reminder Language Lines
    |--------------------------------------------------------------------------
    |
    | The following language lines are the default lines which match reasons
    | that are given by the password broker for a password update attempt
    | has failed, such as for an invalid token or invalid new password.
    |
    */

    'password' => 'Heslo musí obsahovat alespoň 6 znaků a musí odpovídat.',
    'reset'    => 'Heslo bylo obnoveno!',
    'sent'     => 'Upomínka ke změně hesla byla odeslána!',
    'token'    => 'Klíč pro obnovu hesla je nesprávný.',
    'user'     => 'Nepodařilo se najít uživatele s touto e-mailovou adresou.',

];
