<?php

return array(

    /*
    |--------------------------------------------------------------------------
    | Password Reminder Language Lines
    |--------------------------------------------------------------------------
    |
    | The following language lines are the default lines which match reasons
    | that are given by the password broker for a password update attempt
    | has failed, such as for an invalid token or invalid new password.
    |
    */

    "password" => "Wachtwoord moet minimaal zes tekens lang zijn en de wachtwoorden moeten overeenkomen.",

    "user"     => "Geen gebruiker bekend met dat e-mailadres.",

    "token"    => "Dit wachtwoord reset token is niet geldig.",

    "sent"     => "Wachtwoord herinnering verzonden!",

);
