<?php

return [

    /*
    |--------------------------------------------------------------------------
    | Password Reminder Language Lines
    |--------------------------------------------------------------------------
    |
    | The following language lines are the default lines which match reasons
    | that are given by the password broker for a password update attempt
    | has failed, such as for an invalid token or invalid new password.
    |
    */

    'password' => 'Parola trebuie să fie de cel puțin șase caractere și să se potrivească cu cea de confirmare.',
    'reset'    => 'Parola a fost resetată!',
    'sent'     => 'Am trimis un e-mail cu link-ul de resetare a parolei!',
    'token'    => 'Codul de resetare a parolei este greșit.',
    'user'     => 'Nu există niciun utilizator cu această adresă de e-mail.',

];
