<?php

return [

    /*
    |--------------------------------------------------------------------------
    | Password Reminder Language Lines
    |--------------------------------------------------------------------------
    |
    | The following language lines are the default lines which match reasons
    | that are given by the password broker for a password update attempt
    | has failed, such as for an invalid token or invalid new password.
    |
    */

    "password" => "Lösenord måste innehålla minst sex tecken och matcha varandra.",

    "user"     => "Vi kan inte hitta en användare med den e-postadressen.",

    "token"    => "Koden för lösenordsåterställning är ogiltig.",

    "sent"     => "Lösenordspåminnelse skickad!",

    "reset"    => "Lösenordet har blivit återställt!",

];
