<?php

return [

    /*
    |--------------------------------------------------------------------------
    | Password Reminder Language Lines
    |--------------------------------------------------------------------------
    |
    | The following language lines are the default lines which match reasons
    | that are given by the password broker for a password update attempt
    | has failed, such as for an invalid token or invalid new password.
    |
    */

    'password' => 'Το συνθηματικό πρέπει να έχει τουλάχιστον έξι χαρακτήρες και να ταιριάζει με την επαλήθευση.',
    'reset'    => 'Έχει γίνει επαναφορά του συνθηματικού!',
    'sent'     => 'Η υπενθύμιση του συνθηματικού εστάλη!',
    'token'    => 'Το κλειδί αρχικοποίησης του συνθηματικού δεν είναι έγκυρο.',
    'user'     => 'Δεν βρέθηκε χρήστης με το συγκεκριμένο email.',

];
