<?php

return array(

    /*
    |--------------------------------------------------------------------------
    | Password Reminder Language Lines
    |--------------------------------------------------------------------------
    |
    | The following language lines are the default lines which match reasons
    | that are given by the password broker for a password update attempt
    | has failed, such as for an invalid token or invalid new password.
    |
    */

    "password" => "Passord m&#229; v&#230;re minst seks tegn og samsvare med bekreftelsen.",

    "user" => "Vi kan ikke finne en bruker med den e-postadressen.",

    "token" => "Denne tilbakestillingsn&#248;kkelen er ugyldig.",

    "sent" => "Passord p&#229;minnelse sendt!",

);
