<?php

return [

    /*
    |--------------------------------------------------------------------------
    | Password Reminder Language Lines
    |--------------------------------------------------------------------------
    |
    | The following language lines are the default lines which match reasons
    | that are given by the password broker for a password update attempt
    | has failed, such as for an invalid token or invalid new password.
    |
    */

    "password" => "Beide Passwörter müssen übereinstimmen und mindestens 6 Zeichen lang sein.",
    "user" => "Wir können keinen Nutzer mit dieser E-Mail Adresse finden.",
    "token" => "Der Code zum Zurücksetzen des Passworts ist ungültig oder abgelaufen.",
    "sent" => "Es wurde soeben eine E-Mail verschickt, die einen Link zum Zurücksetzen des Passworts enthält!",
    "reset" => "Das Passwort wurde zurückgesetzt!",

];
