<?php

return [

    /*
    |--------------------------------------------------------------------------
    | Password Reminder Language Lines
    |--------------------------------------------------------------------------
    |
    | The following language lines are the default lines which match reasons
    | that are given by the password broker for a password update attempt
    | has failed, such as for an invalid token or invalid new password.
    |
    */

    "password" => "Het wachtwoord moet minimaal zes tekens lang zijn en moet overeenkomen met de bevestiging.",
    "user" => "We kunnen geen gebruiker vinden met het opgegeven e-mailadres.",
    "token" => "Het wachtwoord reset token is ongeldig.",
    "sent" => "We hebben u een wachtwoord reset link gemaild!",
    "reset" => "Je wachtwoord is opnieuw ingesteld!",

];
