<?php

return array(

    /*
    |--------------------------------------------------------------------------
    | Password Reminder Language Lines
    |--------------------------------------------------------------------------
    |
    | The following language lines are the default lines which match reasons
    | that are given by the password broker for a password update attempt
    | has failed, such as for an invalid token or invalid new password.
    |
    */

    "password" => "Le password devono essere di almeno 6 caratteri e devono coincidere.",

    "user"     => "Non esiste un utente associato a questo indirizzo e-mail.",

    "token"    => "Questo token per la reimpostazione della password non è valido.",

    "sent"     => "Promemoria della password inviato!",

);
