<?php

return [

    /*
    |--------------------------------------------------------------------------
    | Password Reminder Language Lines
    |--------------------------------------------------------------------------
    |
    | The following language lines are the default lines which match reasons
    | that are given by the password broker for a password update attempt
    | has failed, such as for an invalid token or invalid new password.
    |
    */

    'password' => 'Lozinke moraju biti duge barem 6 znakova i moraju odgovarati potvrdi.',
    'reset'    => 'Lozinka je postavljena!',
    'sent'     => 'Poveznica za ponovono postavljanje lozinke je poslana!',
    'token'    => 'Oznaka za ponovno postavljanje lozinke više nije važeća.',
    'user'     => 'Korisnik nije pronađen.',

];
