<?php

$LANG = array(
    'organization' => 'Οργανισμός',
    'name' => 'Επωνυμία',
    'website' => 'Ιστοσελίδα',
    'work_phone' => 'Τηλέφωνο',
    'address' => 'Διεύθυνση',
    'address1' => 'Οδός',
    'address2' => 'Διαμέρισμα',
    'city' => 'Πόλη',
    'state' => 'Νομός',
    'postal_code' => 'Ταχ. Κώδικας',
    'country_id' => 'Χώρα',
    'contacts' => 'Επαφές',
    'first_name' => 'Όνομα',
    'last_name' => 'Επώνυμο',
    'phone' => 'Τηλέφωνο',
    'email' => 'Email',
    'additional_info' => 'Επιπλέον Πληροφορίες',
    'payment_terms' => 'Όροι Πληρωμής',
    'currency_id' => 'Νόμισμα',
    'size_id' => 'Μέγεθος Εταιρείας',
    'industry_id' => 'Βιομηχανία',
    'private_notes' => 'Προσωπικές Σημειώσεις',
    'invoice' => 'Τιμολόγιο',
    'client' => 'Πελάτης',
    'invoice_date' => 'Ημερομηνία Τιμολογίου',
    'due_date' => 'Ημερομηνία Ολοκλήρωσης',
    'invoice_number' => 'Αριθμός Τιμολογίου',
    'invoice_number_short' => 'Τιμολόγιο #',
    'po_number' => 'Αριθμός Παραγγελίας',
    'po_number_short' => 'Παραγγελία #',
    'frequency_id' => 'Πόσο Συχνά',
    'discount' => 'Έκπτωση',
    'taxes' => 'Φόροι',
    'tax' => 'Φόρος',
    'item' => 'Προϊόν',
    'description' => 'Περιγραφή',
    'unit_cost' => 'Τιμή Μονάδας',
    'quantity' => 'Ποσότητα',
    'line_total' => 'Αξία',
    'subtotal' => 'Μερικό Σύνολο',
    'paid_to_date' => 'Εξοφλημένο Ποσό',
    'balance_due' => 'Ολικό Σύνολο',
    'invoice_design_id' => 'Σχέδιο',
    'terms' => 'Όροι',
    'your_invoice' => 'Το τιμολόγιό σας',
    'remove_contact' => 'Διαγραφή επαφής',
    'add_contact' => 'Προσθήκη επαφής',
    'create_new_client' => 'Δημιουργία νέου πελάτη',
    'edit_client_details' => 'Επεξεργασία στοιχείων πελάτη',
    'enable' => 'Ενεργοποίηση',
    'learn_more' => 'Μάθετε περισσότερα',
    'manage_rates' => 'Διαχείριση ποσοστών',
    'note_to_client' => 'Σημείωση προς Πελάτη',
    'invoice_terms' => 'Όροι Τιμολογίου',
    'save_as_default_terms' => 'Αποθήκευση ως προεπιλογή',
    'download_pdf' => 'Κατέβασμα PDF',
    'pay_now' => 'Πληρώστε Τώρα',
    'save_invoice' => 'Αποθήκευση Τιμολογίου',
    'clone_invoice' => 'Κλωνοποίηση σε Τιμολόγιο',
    'archive_invoice' => 'Αρχειοθέτηση Τιμολογίου',
    'delete_invoice' => 'Διαγραφή Τιμολογίου',
    'email_invoice' => 'Αποστολή Τιμολογίου με email',
    'enter_payment' => 'Καταχώρηση πληρωμής',
    'tax_rates' => 'Ποσοστά Φόρων',
    'rate' => 'Ποσοστό',
    'settings' => 'Ρυθμίσεις',
    'enable_invoice_tax' => 'Ενεργοποίηση καθορισμού <b>ενιαίου φόρου τιμολογίου</b>',
    'enable_line_item_tax' => 'Ενεργοποίηση καθορισμού <b>φόρου ανά προϊόν</b>',
    'dashboard' => 'Πίνακας ελέγχου',
    'dashboard_totals_in_all_currencies_help' => 'Σημείωση: Προσθέστε ένα :link με το όνομα ":name" για να εμφανίσετε τα σύνολα χρησιμοποιώντας ένα μόνο νόμισμα βάσης.',
    'clients' => 'Πελάτες',
    'invoices' => 'Τιμολόγια',
    'payments' => 'Πληρωμές',
    'credits' => 'Πιστώσεις',
    'history' => 'Ιστορικό',
    'search' => 'Αναζήτηση',
    'sign_up' => 'Εγγραφή',
    'guest' => 'Επισκέπτης',
    'company_details' => 'Στοιχεία Εταιρείας',
    'online_payments' => 'Πληρωμές Online',
    'notifications' => 'Ειδοποιήσεις',
    'import_export' => 'Εισαγωγή | Εξαγωγή',
    'done' => 'Έτοιμο',
    'save' => 'Αποθήκευση',
    'create' => 'Δημιουργία',
    'upload' => 'Ανέβασμα',
    'import' => 'Εισαγωγή',
    'download' => 'Κατέβασμα',
    'cancel' => 'Άκυρο',
    'close' => 'Κλείσιμο',
    'provide_email' => 'Παρακαλώ συμπληρώστε μια έγκυρη διεύθυνση email',
    'powered_by' => 'Λειτουργεί με',
    'no_items' => 'Δεν υπάρχουν προϊόντα',
    'recurring_invoices' => 'Επαναλαμβανόμενα Τιμολόγια',
    'recurring_help' => '<p>Αυτόματη αποστολή ίδιων τιμολογίων στους πελάτες ανά εβδομάδα, δύο εβδομάδες, μήνα, τρίμηνο ή έτος. </p>
<p>Χρησιμοποιήστε τα :MONTH, :QUARTER ή :YEAR για δυναμικές ημερομηνίες. Λειτουργούν και απλές αριθμητικές πράξεις, όπως για παράδειγμα :MONTH-1. </p>
<p>Παραδείγματα δυναμικών μεταβλητών σε τιμολόγια:</p>
<ul>
<li>"Συνδρομή γυμναστηρίου μήνας :MONTH" >> "Συνδρομή γυμναστηρίου μήνας Ιούλιος"</li>
<li>":YEAR+1 ετήσια συνδρομή" >> "2015 ετήσια συνδρομή"</li>
<li>"Προκαταβολή πληρωμής για το :QUARTER+1" >> "Προκαταβολή πληρωμής για το Τρίμηνο 2"</li>
</ul>',
    'recurring_quotes' => 'Επαναλαμβανόμενες Προσφορές',
    'in_total_revenue' => 'στα συνολικά έσοδα',
    'billed_client' => 'τιμολογημένος πελάτης',
    'billed_clients' => 'τιμολογημένοι πελάτες',
    'active_client' => 'ενεργός πελάτης',
    'active_clients' => 'ενεργοί πελάτες',
    'invoices_past_due' => 'Ληγμένα Τιμολόγια',
    'upcoming_invoices' => 'Προσεχή Τιμολόγια',
    'average_invoice' => 'Μέσος Όρος Τιμολογίων',
    'archive' => 'Αρχειοθέτηση',
    'delete' => 'Διαγραφή',
    'archive_client' => 'Αρχειοθέτηση Πελάτη',
    'delete_client' => 'Διαγραφή Πελάτη',
    'archive_payment' => 'Αρχειοθέτηση Πληρωμής',
    'delete_payment' => 'Διαγραφή Πληρωμής',
    'archive_credit' => 'Αρχειοθέτηση Πίστωσης',
    'delete_credit' => 'Διαγραφή Πίστωσης',
    'show_archived_deleted' => 'Προβολή αρχειοθετημένων/διεγραμμένων',
    'filter' => 'Φίλτρο',
    'new_client' => 'Νέος Πελάτης',
    'new_invoice' => 'Νέο Τιμολόγιο',
    'new_payment' => 'Εισάγετε πληρωμή',
    'new_credit' => 'Εισάγετε Πίστωση',
    'contact' => 'Επαφή',
    'date_created' => 'Ημ/νία Δημιουργίας',
    'last_login' => 'Τελευταία Είσοδος',
    'balance' => 'Υπόλοιπο',
    'action' => 'Ενέργεια',
    'status' => 'Κατάσταση',
    'invoice_total' => 'Σύνολο Τιμολογίου',
    'frequency' => 'Συχνότητα',
    'range' => 'Εύρος',
    'start_date' => 'Ημ/νία Έναρξης',
    'end_date' => 'Ημ/νία Λήξης',
    'transaction_reference' => 'Κωδικός Συναλλαγής',
    'method' => 'Μέθοδος',
    'payment_amount' => 'Ποσό Πληρωμής',
    'payment_date' => 'Ημ/νία Πληρωμής',
    'credit_amount' => 'Ποσό Πίστωσης',
    'credit_balance' => 'Υπόλοιπο Πίστωσης',
    'credit_date' => 'Ημ/νία Πίστωσης',
    'empty_table' => 'Δεν υπάρχουν διαθέσιμα δεδομένα',
    'select' => 'Επιλογή',
    'edit_client' => 'Επεξεργασία Πελάτη',
    'edit_invoice' => 'Επεξεργασία Τιμολογίου',
    'create_invoice' => 'Δημιουργία Τιμολογίου',
    'enter_credit' => 'Καταχώρηση Πίστωσης',
    'last_logged_in' => 'Τελευταία είσοδος',
    'details' => 'Στοιχεία',
    'standing' => 'Θέση',
    'credit' => 'Πίστωση',
    'activity' => 'Δραστηριότητα',
    'date' => 'Ημερομηνία',
    'message' => 'Μήνυμα',
    'adjustment' => 'Προσδιορισμός',
    'are_you_sure' => 'Είστε σίγουροι;',
    'payment_type_id' => 'Τύπος Πληρωμής',
    'amount' => 'Ποσό',
    'work_email' => 'Email',
    'language_id' => 'Γλώσσα',
    'timezone_id' => 'Ζώνη ώρας',
    'date_format_id' => 'Μορφή Ημερομηνίας',
    'datetime_format_id' => 'Μορφή Ημερομηνίας/Ώρας',
    'users' => 'Χρήστες',
    'localization' => 'Τοπικές Ρυθμίσεις',
    'remove_logo' => 'Διαγραφή λογότυπου',
    'logo_help' => 'Υποστηρίζονται: JPEG, GIF και PNG',
    'payment_gateway' => 'Πύλη Πληρωμών (Gateway)',
    'gateway_id' => 'Πύλη Πληρωμής (Gateway)',
    'email_notifications' => 'Ειδοποιήσεις Email',
    'email_sent' => 'Αποστολή email όταν το τιμολόγιο <b>σταλεί</b>',
    'email_viewed' => 'Αποστολή email όταν το τιμολόγιο <b>προβληθεί</b>',
    'email_paid' => 'Αποστολή email όταν το τιμολόγιο <b>πληρωθεί</b>',
    'site_updates' => 'Ενημερώσεις Ιστοσελίδας',
    'custom_messages' => 'Προσαρμοσμένα Μηνύματα',
    'default_email_footer' => 'Ορισμός προεπιλεγμένης <b>υπογραφής email</b>',
    'select_file' => 'Παρακαλώ επιλέξτε ένα αρχείο',
    'first_row_headers' => 'Χρήση της πρώτης σειράς ως επικεφαλίδες',
    'column' => 'Κολόνα',
    'sample' => 'Παράδειγμα',
    'import_to' => 'Εισαγωγή σε',
    'client_will_create' => 'πελάτης θα δημιουργηθεί',
    'clients_will_create' => 'πελάτες θα δημιουργηθούν',
    'email_settings' => 'Ρυθμίσεις Email',
    'client_view_styling' => 'Στυλ Προβολής Πελάτη',
    'pdf_email_attachment' => 'Επισύναψε PDF',
    'custom_css' => 'Προσαρμοσμένο CSS',
    'import_clients' => 'Εισαγωγή Δεδομένων Πελάτη',
    'csv_file' => 'Αρχείο CSV',
    'export_clients' => 'Εξαγωγή Δεδομένων Πελάτη',
    'created_client' => 'Επιτυχής δημιουργία πελάτη',
    'created_clients' => 'Επιτυχής δημιουργία :count πελατών',
    'updated_settings' => 'Επιτυχής ενημέρωση ρυθμίσεων',
    'removed_logo' => 'Επιτυχής διαγραφή λογότυπου',
    'sent_message' => 'Επιτυχής αποστολή μηνύματος',
    'invoice_error' => 'Παρακαλώ σιγουρευτείτε ότι επιλέξατε ένα πελάτη και διορθώσατε τυχόν σφάλματα',
    'limit_clients' => 'Λυπάμαι, αυτό υπερβαίνει το όριο των :count πελατών',
    'payment_error' => 'Προέκυψε ένα σφάλμα κατά τη διαδικασία της πληρωμής. Παρακαλώ, δοκιμάστε ξανά σε λίγο.',
    'registration_required' => 'Παρακαλώ, εγγραφείτε για να αποστείλετε ένα τιμολόγιο',
    'confirmation_required' => 'Παρακαλώ επιβεβαιώστε τη διεύθυνση email, :link για να ξαναστείλετε το email επιβεβαίωσης.',
    'updated_client' => 'Επιτυχής ενημέρωση πελάτη',
    'archived_client' => 'Επιτυχής αρχειοθέτηση πελάτη',
    'archived_clients' => 'Επιτυχής αρχειοθέτηση :count πελατών',
    'deleted_client' => 'Επιτυχής διαγραφή πελάτη',
    'deleted_clients' => 'Επιτυχής διαγραφή :count πελατών',
    'updated_invoice' => 'Επιτυχής ενημέρωση τιμολογίου',
    'created_invoice' => 'Επιτυχής δημιουργία τιμολογίου',
    'cloned_invoice' => 'Επιτυχής κλωνοποίηση τιμολογίου',
    'emailed_invoice' => 'Επιτυχής αποστολή τιμολογίου',
    'and_created_client' => 'και δημιουργήθηκε ο πελάτης',
    'archived_invoice' => 'Επιτυχής αρχειοθέτηση τιμολογίου',
    'archived_invoices' => 'Επιτυχής αρχειοθέτηση :count τιμολογίων',
    'deleted_invoice' => 'Επιτυχής διαγραφή τιμολογίου',
    'deleted_invoices' => 'Επιτυχής διαγραφή :count τιμολογίων',
    'created_payment' => 'Επιτυχής δημιουργία πληρωμής',
    'created_payments' => 'Επιτυχής δημιουργία :count πληρωμών',
    'archived_payment' => 'Επιτυχής αρχειοθέτηση πληρωμής',
    'archived_payments' => 'Επιτυχής αρχειοθέτηση :count πληρωμών',
    'deleted_payment' => 'Επιτυχής διαγραφή πληρωμής',
    'deleted_payments' => 'Επιτυχής διαγραφή :count πληρωμών',
    'applied_payment' => 'Επιτυχής εφαρμογή πληρωμής',
    'created_credit' => 'Επιτυχής δημιουργία πίστωσης',
    'archived_credit' => 'Επιτυχής αρχειοθέτηση πίστωσης',
    'archived_credits' => 'Επιτυχής αρχειοθέτηση :count πιστώσεων',
    'deleted_credit' => 'Επιτυχής διαγραφή πίστωσης',
    'deleted_credits' => 'Επιτυχής διαγραφή :count πιστώσεων',
    'imported_file' => 'Επιτυχής εισαγωγή αρχείου',
    'updated_vendor' => 'Επιτυχής ενημέρωση προμηθευτή',
    'created_vendor' => 'Επιτυχής δημιουργία προμηθευτή',
    'archived_vendor' => 'Επιτυχής αρχειοθέτηση προμηθευτή',
    'archived_vendors' => 'Επιτυχής αρχειοθέτηση :count προμηθευτών',
    'deleted_vendor' => 'Επιτυχής διαγραφή προμηθευτή',
    'deleted_vendors' => 'Επιτυχής διαγραφή :count προμηθευτών',
    'confirmation_subject' => 'Επιβεβαίωση Λογαριασμού Invoice Ninja',
    'confirmation_header' => 'Επιβεβαίωση Λογαριασμού',
    'confirmation_message' => 'Παρακαλω, πατήστε τον παρακάτω σύνδεσμο για να επιβεβαιώσετε το λογαριασμό σας.',
    'invoice_subject' => 'Νέο τιμολόγιο :number από :account',
    'invoice_message' => 'Για να δείτε το τιμολόγιο των :amount, πατήστε τον παρακάτω σύνδεσμο.',
    'payment_subject' => 'Λήψη Πληρωμής',
    'payment_message' => 'Ευχαριστούμε για την πληρωμή των :amount.',
    'email_salutation' => 'Αγαπητέ(-ή) :name,',
    'email_signature' => 'Με εκτίμηση,',
    'email_from' => 'Η Ομάδα του Invoice Ninja',
    'invoice_link_message' => 'Για να δείτε το τιμολόγιο πατήστε τον παρακάτω σύνδεσμο:',
    'notification_invoice_paid_subject' => 'Το τιμολόγιο :invoice πληρώθηκε από :client',
    'notification_invoice_sent_subject' => 'Το τιμολόγιο :invoice απεστάλη σε :client',
    'notification_invoice_viewed_subject' => 'Το τιμολόγιο :invoice προβλήθηκε σε :client',
    'notification_invoice_paid' => 'Πληρωμή ποσού :amount έγινε από τον πελάτη :client για το Τιμολόγιο :invoice',
    'notification_invoice_sent' => 'Στον πελάτη :client απεστάλη το Τιμολόγιο :invoice ποσού :amount.',
    'notification_invoice_viewed' => 'Ο πελάτης :client είδε το Τιμολόγιο :invoice ποσού :amount.',
    'reset_password' => 'Μπορείτε να επαναφέρετε τον κωδικό του λογαριασμού σας πατώντας τον παρακάτω σύνδεσμο:',
    'secure_payment' => 'Ασφαλής Πληρωμή',
    'card_number' => 'Αριθμός Κάρτας',
    'expiration_month' => 'Μήνας Λήξης',
    'expiration_year' => 'Έτος Λήξης',
    'cvv' => 'CVV',
    'logout' => 'Αποσύνδεση',
    'sign_up_to_save' => 'Εγγραφείτε για να σώσετε την εργασία σας',
    'agree_to_terms' => 'Συμφωνώ με τους όρους',
    'terms_of_service' => 'Όροι της Υπηρεσίας',
    'email_taken' => 'Η διεύθυνση email έχει ήδη καταχωρηθεί',
    'working' => 'Σε εξέλιξη',
    'success' => 'Επιτυχία',
    'success_message' => 'Εγγραφήκατε επιτυχώς! Παρακαλώ, επισκευθείτε το σύνδεσμο στο email επιβεβαίωσης για να επικυρώσετε τη διεύθυνση email.',
    'erase_data' => 'Ο λογαριασμός σας δεν είναι εγγεγραμμένος, αυτό θα διαγράψει οριστικά τα δεδομένα σας.',
    'password' => 'Κωδικός Πρόσβασης',
    'pro_plan_product' => 'Επαγγελματικό Πλάνο',
    'pro_plan_success' => 'Ευχαριστούμε που επιλέξατε το Invoice Ninja\'s Pro plan!<p/>&nbsp;<br/>
<b>Επόμενα Βήματα</b><p/>Ένα τιμολόγιο προς πληρωμή έχει αποσταλεί στη διεύθυνση
email που είναι συνδεδεμένη με το λογαριασμό σας. Για να ξεκλειδώσετε όλα τα
εντυπωσιακά χαρακτηριστικά του Pro Plan, παρακαλώ ακολουθήστε τις οδηγίες
στο τιμολόγιο για να πληρώσετε για ένα χρόνο τιμολόγησης επιπέδου Pro.<p/>
Δε βρίσκετε το τιμολόγιο; Χρειάζεστε περισσότερη βοήθεια; Είμαστε ευτυχείς
να σας βοηθήσουμε. Στείλτε μας email στο contact@invoiceninja.com\',',
    'unsaved_changes' => 'Έχετε μη αποθηκευμένες αλλαγές',
    'custom_fields' => 'Προσαρμοσμένα Πεδία',
    'company_fields' => 'Πεδία Εταιρείας',
    'client_fields' => 'Πεδία Πελάτη',
    'field_label' => 'Ετικέτα Πεδίου',
    'field_value' => 'Τιμή Πεδίου',
    'edit' => 'Επεξεργασία',
    'set_name' => 'Ορίστε την επωνυμία της εταιρείας',
    'view_as_recipient' => 'Προβολή ως παραλήπτης',
    'product_library' => 'Βιβλιοθήκη Προϊόντων',
    'product' => 'Προϊόν',
    'products' => 'Προϊόντα',
    'fill_products' => 'Αυτόματη συμπλήρωση προϊόντων',
    'fill_products_help' => 'Επιλέγοντας ένα προϊόν, αυτόματα <b>θα συμπληρωθεί η περιγραφή και η αξία</b>',
    'update_products' => 'Αυτόματη ενημέρωση προϊόντων',
    'update_products_help' => 'Ενημερώνοντας ένα τιμολόγιο, αυτόματα <b>θα ενημερωθεί και η βιβλιοθήκη προϊόντων</b>',
    'create_product' => 'Προσθήκη Προϊόντος',
    'edit_product' => 'Επεξεργασία Προϊόντος',
    'archive_product' => 'Αρχειοθέτηση Προϊόντος',
    'updated_product' => 'Επιτυχής ενημέρωση προϊόντος',
    'created_product' => 'Επιτυχής δημιουργία προϊόντος',
    'archived_product' => 'Επιτυχής αρχειοθέτηση προϊόντος',
    'pro_plan_custom_fields' => ':link για να ενεργοποιήσετε τα προσαρμοσμένα πεδία προσχωρώντας στο Pro Plan',
    'advanced_settings' => 'Ρυθμίσεις για Προχωρημένους',
    'pro_plan_advanced_settings' => ':link για να ενεργοποιήσετε τις ρυθμίσεις για προχωρημένους προσχωρώντας στο Pro Plan',
    'invoice_design' => 'ΣχέδιοΤιμολογίου',
    'specify_colors' => 'Προσδιορισμός χρωμάτων',
    'specify_colors_label' => 'Επιλέξτε τα χρώματα που χρησιμοποιούνται στο τιμολόγιο',
    'chart_builder' => 'Κατασκευή Γραφήματος',
    'ninja_email_footer' => 'Δημιουργήθηκε με :site | Δημιουργήστε. Αποστείλετε. Εξοφληθείτε.',
    'go_pro' => 'Πήγαινε στην Επαγγελματική έκδοση',
    'quote' => 'Προσφορά',
    'quotes' => 'Προσφορές',
    'quote_number' => 'Αριθμός Προσφοράς',
    'quote_number_short' => 'Προσφορά #',
    'quote_date' => 'Ημ/νία Προσφοράς',
    'quote_total' => 'Σύνολο Προσφοράς',
    'your_quote' => 'Η Προσφορά σας',
    'total' => 'Σύνολο',
    'clone' => 'Κλωνοποίηση',
    'new_quote' => 'Νέα Προσφορά',
    'create_quote' => 'Δημιουργία Προσφοράς',
    'edit_quote' => 'Επεξεργασία Προσφοράς',
    'archive_quote' => 'Αρχειοθέτηση Προσφοράς',
    'delete_quote' => 'Διαγραφή Προσφοράς',
    'save_quote' => 'Αποθήκευση Προσφοράς',
    'email_quote' => 'Αποστολή Προσφοράς',
    'clone_quote' => 'Κλωνοποίηση σε Προσφορά',
    'convert_to_invoice' => 'Μετατροπή σε Τιμολόγιο',
    'view_invoice' => 'Προβολή Τιμολογίου',
    'view_client' => 'Προβολή Πελάτη',
    'view_quote' => 'Προβολή Προσφοράς',
    'updated_quote' => 'Επιτυχής ενημέρωση προσφοράς',
    'created_quote' => 'Επιτυχής δημιουργία προσφοράς',
    'cloned_quote' => 'Επιτυχής κλωνοποίηση προσφοράς',
    'emailed_quote' => 'Επιτυχής αποστολή προσφοράς',
    'archived_quote' => 'Επιτυχής αρχειοθέτηση προσφοράς',
    'archived_quotes' => 'Επιτυχής αρχειοθέτηση :count προσφορών',
    'deleted_quote' => 'Επιτυχής διαγραφή προσφοράς',
    'deleted_quotes' => 'Επιτυχής διαγραφή :count προσφορών',
    'converted_to_invoice' => 'Επιτυχής μετατροπή προσφοράς σε τιμολόγιο',
    'quote_subject' => 'Νέα προσφορά :number από :account',
    'quote_message' => 'Για να δείτε την προσφορά ποσού :amount, πατήστε τον παρακάτω σύνδεσμο.',
    'quote_link_message' => 'Για να δείτε την προσφορά του πελάτη σας, πατήστε τον παρακάτω σύνδεσμο:',
    'notification_quote_sent_subject' => 'Η προσφορά :invoice απεστάλη στον πελάτη :client',
    'notification_quote_viewed_subject' => 'Η προσφορά :invoice προβλήθηκε στον πελάτη :client',
    'notification_quote_sent' => 'Απεστάλη Προσφορά :invoice αξίας :amount στον πελάτη :client.',
    'notification_quote_viewed' => 'Ο πελάτης :client είδε την Προσφορά :invoice αξίας :amount.',
    'session_expired' => 'Η συνεδρία σας έληξε',
    'invoice_fields' => 'Πεδία Τιμολογίου',
    'invoice_options' => 'Επιλογές Τιμολογίου',
    'hide_paid_to_date' => 'Απόκρυψη Εξοφλημένου Ποσού',
    'hide_paid_to_date_help' => 'Εμφάνιση πεδίου "Εξοφλημένο Ποσό" μόνο στο παραστατικό όταν ληφθεί μια πληρωμή.',
    'charge_taxes' => 'Χρέωση φόρων',
    'user_management' => 'Διαχειριση Χρηστών',
    'add_user' => 'Προσθήκη Χρήστη',
    'send_invite' => 'Αποστολή Πρόσκλησης',
    'sent_invite' => 'Επιτυχής αποστολή πρόσκλησης',
    'updated_user' => 'Επιτυχής ενημέρωση χρήστη',
    'invitation_message' => 'Έχετε προσκληθεί από :invitor.',
    'register_to_add_user' => 'Παρακαλώ, εγραφείτε για να προσθέσετε χρήστη',
    'user_state' => 'Κατάσταση',
    'edit_user' => 'Επεξεργασία Χρήστη',
    'delete_user' => 'Διαγραφή Χρήστη',
    'active' => 'Ενεργός',
    'pending' => 'Εκκρεμής',
    'deleted_user' => 'Επιτυχής διαγραφή χρήστη',
    'confirm_email_invoice' => 'Είστε σίγουροι ότι θέλετε να αποστείλετε αυτό το τιμολόγιο;',
    'confirm_email_quote' => 'Είστε σίγουροι ότι θέλετε να αποστείλετε αυτή την προσφορά;',
    'confirm_recurring_email_invoice' => 'Είστε σίγουροι ότι θέλετε να αποστέλλεται αυτό το παραστατικό;',
    'confirm_recurring_email_invoice_not_sent' => 'Είστε σίγουροι ότι θέλετε να ξεκινήσετε την επανάληψη ;',
    'cancel_account' => 'Διαγραφή Λογαριασμού',
    'cancel_account_message' => 'Προσοχή: Αυτό θα σβήσει το λογαριασμό σας, χωρίς δυνατότητα αναίρεσης.',
    'go_back' => 'Επιστροφή',
    'data_visualizations' => 'Απεικονίσεις Δεδομένων',
    'sample_data' => 'Εμφάνιση δείγματος δεδομένων',
    'hide' => 'Απόκρυψη',
    'new_version_available' => 'Μια νέα έκδοση του :releases_link είναι διαθέσιμη. Έχετε τη v:user_version, η τελευταία είναι η v:latest_version',
    'invoice_settings' => 'Ρυθμίσεις Τιμολογίου',
    'invoice_number_prefix' => 'Σειρά Τιμολογίου',
    'invoice_number_counter' => 'Αρίθμηση Τιμολογίου',
    'quote_number_prefix' => 'Σειρά Προσφοράς',
    'quote_number_counter' => 'Αρίθμηση Προσφοράς',
    'share_invoice_counter' => 'Μοιραστείτε τον μετρητή τιμολογίου',
    'invoice_issued_to' => 'Έκδοση τιμολογίου προς',
    'invalid_counter' => 'Για να αποφείγετε πιθανή σύγχυση, παρακαλώ ορίστε σειρά σε τιμολόγιο ή προσφορά',
    'mark_sent' => 'Σήμανση ως Απεσταλμένο',
    'gateway_help_1' => ':link για εγγραφή στο Authorize.net.',
    'gateway_help_2' => ':link για εγγραφή στο Authorize.net.',
    'gateway_help_17' => ':link για να πάρετε υπογραφή για το API του PayPal.',
    'gateway_help_27' => ':link για να εγγραφείτε στο 2Checkout.com. Για να βεβαιωθείτε ότι οι πληρωμές παρακολουθούνται ορίστε το :complete_link ως τη διέυθυνση ανακατεύθυνσης στο Λογαριασμός > Διαχείρισης Ιστοσελίδας στην ιστοσελίδα του 2Checkout.',
    'gateway_help_60' => ':link για δημιουργία λογαριασμού WePay.',
    'more_designs' => 'Περισσότερα σχέδια',
    'more_designs_title' => 'Επιπλέον Σχέδια Τιμολογίων',
    'more_designs_cloud_header' => 'Αποκτήστε την Επαγγελματική έκδοση για επιπλέον σχέδια τιμολογίων',
    'more_designs_cloud_text' => '',
    'more_designs_self_host_text' => '',
    'buy' => 'Αγορά',
    'bought_designs' => 'Επιπλέον σχέδια τιμολογίων προστέθηκαν με επιτυχία',
    'sent' => 'Απεσταλμένα',
    'vat_number' => 'ΑΦΜ',
    'timesheets' => 'Φύλλα χρονοχρέωσης',
    'payment_title' => 'Κατσχωρήστε τη Διεύθυνση Τιμολόγησης και τα στοιχεία της Πιστωτικής Κάρτας',
    'payment_cvv' => 'Αυτός είναι ο αριθμός με 3-4 ψηφία στην πίσω μεριά της κάρτας σας',
    'payment_footer1' => 'Η διεύθυνση τημολόγησης πρέπει να ταιριάζει με τη διεύθυνση που έχει δηλωθεί στην πιστωτική κάρτα.',
    'payment_footer2' => 'Παρακαλώ πατήστε "ΠΛΗΡΩΜΗ ΤΩΡΑ" μόνο μία φορά. Η συναλλαγή ενδέχεται να διαρκέσει ως και ένα λεπτό.',
    'id_number' => 'Αριθμός ID',
    'white_label_link' => 'Λευκή Ετικέτα',
    'white_label_header' => 'Λευκή Ετικέτα',
    'bought_white_label' => 'Επιτυχής ενεργοποίηση άδειας χρήσης λευκής ετικέτας',
    'white_labeled' => 'Εφαρμόσθηκε η λευκή ετικέτα',
    'restore' => 'Ανάκτηση',
    'restore_invoice' => 'Ανάκτηση Τιμολογίου',
    'restore_quote' => 'Ανάκτηση Προσφοράς',
    'restore_client' => 'Ανάκτηση Πελάτη',
    'restore_credit' => 'Ανάκτηση Πίστωσης',
    'restore_payment' => 'Ανάκτηση Πληρωμής',
    'restored_invoice' => 'Επιτυχής ανάκτηση τιμολογίου',
    'restored_quote' => 'Επιτυχής ανάκτηση προσφοράς',
    'restored_client' => 'Επιτυχής ανάκτηση πελάτη',
    'restored_payment' => 'Επιτυχής ανάκτηση πληρωμής',
    'restored_credit' => 'Επιτυχής ανάκτηση πίστωσης',
    'reason_for_canceling' => 'Βοηθήστε μας να βελτιώσουμε την ιστοσελίδα μας λέγοντάς μας γιατί φεύγετε.',
    'discount_percent' => 'Ποσοστό',
    'discount_amount' => 'Ποσό',
    'invoice_history' => 'Ιστορικό Τιμολογίου',
    'quote_history' => 'Ιστορικό Προσφοράς',
    'current_version' => 'Τρέχουσα έκδοση',
    'select_version' => 'Επιλογή έκδοσης',
    'view_history' => 'Προβολή Ιστορικού',
    'edit_payment' => 'Επεξεργασία Πληρωμής',
    'updated_payment' => 'Επιτυχής ενημέρωση πληρωμής',
    'deleted' => 'Διεγραμμένο',
    'restore_user' => 'Ανάκτηση Χρήστη',
    'restored_user' => 'Επιτυχής ανάκτηση χρήστη',
    'show_deleted_users' => 'Προβολή διεγραμμένων χρηστών',
    'email_templates' => 'Πρότυπα email',
    'invoice_email' => 'Email Τιμολογίων',
    'payment_email' => 'Email Πληρωμών',
    'quote_email' => 'Email Προσφορών',
    'reset_all' => 'Επαναφορά Όλων',
    'approve' => 'Αποδοχή',
    'token_billing_type_id' => 'Χρέωση Διακριτικού',
    'token_billing_help' => 'Στοιχεία πληρωμής με WePay, Stripe, Braintree ή GoCardless.',
    'token_billing_1' => 'Απενεργοποιημένο',
    'token_billing_2' => 'Opt-in - το checkbox εμφανίζεται αλλά όχι επιλεγμένο',
    'token_billing_3' => 'Opt-out - το checkbox εμφανίζεται και είναι επιλεγμένο',
    'token_billing_4' => 'Πάντα',
    'token_billing_checkbox' => 'Αποθήκευση στοιχείων πιστωτικής κάρτας',
    'view_in_gateway' => 'Προβολή σε :gateway',
    'use_card_on_file' => 'Χρήση του Card on File',
    'edit_payment_details' => 'Επεξεργασία στοιχείων πληρωμής',
    'token_billing' => 'Αποθήκευση στοιχείων κάρτας',
    'token_billing_secure' => 'Η κάρτα αποθηκεύεται με ασφάλεια με :link',
    'support' => 'Υποστήριξη',
    'contact_information' => 'Στοιχεία Επικοινωνίας',
    '256_encryption' => 'Κωδικοποίηση 256-Bit',
    'amount_due' => 'Οφειλόμενο ποσό προς πληρωμή',
    'billing_address' => 'Διεύθυνση Τιμολόγησης',
    'billing_method' => 'Μέθοδος Τιμολόγησης',
    'order_overview' => 'Επισκόπηση Παραγγελίας',
    'match_address' => '*Η διεύθυνση πρέπει να ταιριάζει με αυτή της πιστωτικής κάρτας.',
    'click_once' => '*Παρακαλώ πατήστε το "ΠΛΗΡΩΜΗ ΤΩΡΑ" μόνο μία φορά. Η διαδικασία της συναλλαγής μπορεί να διαρκέσαι ως και 1 λεπτό.',
    'invoice_footer' => 'Υποσέλιδο Τιμολογίου',
    'save_as_default_footer' => 'Αποθήκευση ως προεπιλεγμένο υποσέλιδο',
    'token_management' => 'Διαχείριση Διακριτικών',
    'tokens' => 'Διακριτικά',
    'add_token' => 'Προσθήκη Διακριτικού',
    'show_deleted_tokens' => 'Προβολή διεγραμμένων διακριτικών',
    'deleted_token' => 'Επιτυχής διαγραφή διακριτικού',
    'created_token' => 'Επιτυχής δημιουργία διακριτικού',
    'updated_token' => 'Επιτυχής ενημέρωση διακριτικού',
    'edit_token' => 'Επεξεργασία Διακριτικού',
    'delete_token' => 'Διαγραφή Διακριτικού',
    'token' => 'Διακριτικό',
    'add_gateway' => 'Προσθήκη Πύλης Πληρωμών (Gateway)',
    'delete_gateway' => 'Διαγραφή Πύλης Πληρωμών (Gateway)',
    'edit_gateway' => 'Επεξεργασία Πύλης Πληρωμών (Gateway)',
    'updated_gateway' => 'Επιτυχής ενημέρωση πύλης πληρωμών (Gateway)',
    'created_gateway' => 'Επιτυχής δημιουργία πύλης πληρωμών (Gateway)',
    'deleted_gateway' => 'Επιτυχής διαγραφή πύλης πληρωμών (Gateway)',
    'pay_with_paypal' => 'PayPal',
    'pay_with_card' => 'Πιστωτική Κάρτα',
    'change_password' => 'Αλλαγή κωδικού πρόσβασης',
    'current_password' => 'Τρέχων κωδικός  Πρόσβασης',
    'new_password' => 'Νέος κωδικός Πρόσβασης',
    'confirm_password' => 'Επιβεβαίωση κωδικού πρόσβασης',
    'password_error_incorrect' => 'Ο τρέχων κωδικός  πρόσβασης είναι λανθασμένος.',
    'password_error_invalid' => 'Ο νέος κωδικός  πρόσβασης δεν είναι έγκυρος.',
    'updated_password' => 'Επιτυχής ενημέρωση κωδικού πρόσβασης',
    'api_tokens' => 'Διακριτικά API',
    'users_and_tokens' => 'Χρήστες & Διακριτικά',
    'account_login' => 'Είσοδος στο Λογαριασμό',
    'recover_password' => 'Ανάκτηση του κωδικού  πρόσβασής σας',
    'forgot_password' => 'Ξεχάσατε τον κωδικό  πρόσβασής σας;',
    'email_address' => 'Διεύθυνση email',
    'lets_go' => 'Πάμε',
    'password_recovery' => 'Ανάκτηση Κωδικού Πρόσβασης',
    'send_email' => 'Αποστολή Email',
    'set_password' => 'Ορισμός Κωδικού Πρόσβασης',
    'converted' => 'Μετατράπηκε',
    'email_approved' => 'Αποστολή email μόλις η προσφορά είναι  <b>αποδεκτή</b>',
    'notification_quote_approved_subject' => 'Η προσφορά :invoice έγινε αποδεκτή από :client',
    'notification_quote_approved' => 'Ο πελάτης :client αποδέχτηκε την Προσφορά :invoice ποσού :amount.',
    'resend_confirmation' => 'Νέα αποστολή email επιβεβαίωσης',
    'confirmation_resent' => 'Το email επιβεβαίωσης εστάλη ξανά',
    'gateway_help_42' => ':link για να εγγραφείτε στο BitPay.<br/>Σημείωση: χρησιμοποιήστε ένα παλαιού τύπου κλειδί API, όχι ένα διακριτικό API.',
    'payment_type_credit_card' => 'Πιστωτική Κάρτα',
    'payment_type_paypal' => 'PayPal',
    'payment_type_bitcoin' => 'Bitcoin',
    'payment_type_gocardless' => 'GoCardless',
    'knowledge_base' => 'Γνωσιακή Βάση',
    'partial' => 'Μερικό/Κατάθεση',
    'partial_remaining' => ':partial από :balance',
    'more_fields' => 'Περισσότερα Πεδία',
    'less_fields' => 'Λιγότερα Πεδία',
    'client_name' => 'Όνομα Πελάτη',
    'pdf_settings' => 'Ρυθμίσεις PDF',
    'product_settings' => 'Ρυθμίσεις Προϊόντων',
    'auto_wrap' => 'Αυτόματη Αναδίπλωση Γραμμής',
    'duplicate_post' => 'Προειδοποίηση: Η προηγούμενη σελίδα υποβλήθηκε δύο φορές. Η δεύτερη υποβολή αγνοήθηκε.',
    'view_documentation' => 'Προβολή Τεκμηρίωσης',
    'app_title' => 'Δωρεάν Ανοιχτού-Κώδικα Online Τιμολόγηση',
    'app_description' => 'Το Invoice Ninja είναι μια δωρεάν, ανοιχτού-κώδικα λύση για τιμολόγηση πελατών. Με το Invoice Ninja μπορείτε να εύκολα δημιουργήσετε και να στείλετε όμορφα τιμολόγια από οποιαδήποτε συσκευή που έχει πρόσβαση στο internet. Οι πελάτες σας μπορούν να τυπώνουν τα τιμολόγιά σας, να τα κατεβάζουν σε pdf ή ακόμα και να πληρώνουν online μέσα από το σύστημα.',
    'rows' => 'γραμμές',
    'www' => 'www',
    'logo' => 'Λογότυπο',
    'subdomain' => 'Υποτομέας',
    'provide_name_or_email' => 'Παρακαλώ συμπληρώστε ένα όνομα ή email',
    'charts_and_reports' => 'Διαγράμματα & Αναφορές',
    'chart' => 'Διάγραμμα',
    'report' => 'Αναφορά',
    'group_by' => 'Ομαδοποίηση με',
    'paid' => 'Πληρωμένα',
    'enable_report' => 'Αναφορά',
    'enable_chart' => 'Διάγραμμα',
    'totals' => 'Σύνολα',
    'run' => 'Εκτέλεση',
    'export' => 'Εξαγωγή',
    'documentation' => 'Τεκμηρίωση',
    'zapier' => 'Zapier',
    'recurring' => 'Επαναλαμβανόμενο',
    'last_invoice_sent' => 'Το τελευταίο τιμολόγιο εστάλη στις :date',
    'processed_updates' => 'Επιτυχής ολοκλήρωση της ενημέρωσης',
    'tasks' => 'Εργασίες',
    'new_task' => 'Νέα Εργασία',
    'start_time' => 'Ώρα Έναρξης',
    'created_task' => 'Επιτυχής δημιουργία εργασίας',
    'updated_task' => 'Επιτυχής ενημέρωση εργασίας',
    'edit_task' => 'Επεξεργασία Εργασίας',
    'clone_task' => 'Κλωνοποίηση Εργασίας',
    'archive_task' => 'Αρχειοθέτηση Εργασίας',
    'restore_task' => 'Ανάκτηση Εργασίας',
    'delete_task' => 'Διαγραφή Εργασίας',
    'stop_task' => 'Διακοπή Εργασίας',
    'time' => 'Ώρα',
    'start' => 'Έναρξη',
    'stop' => 'Λήξη',
    'now' => 'Τώρα',
    'timer' => 'Μετρητής',
    'manual' => 'Χειροκίνητο',
    'date_and_time' => 'Ημερομηνία & Ώρα',
    'second' => 'Δευτερόλεπτο',
    'seconds' => 'Δευτερόλεπτα',
    'minute' => 'Λεπτό',
    'minutes' => 'Λεπτά',
    'hour' => 'Ώρα',
    'hours' => 'Ώρες',
    'task_details' => 'Στοιχεία Εργασίας',
    'duration' => 'Διάρκεια',
    'time_log' => 'Αρχείο Καταγραφής Χρόνου',
    'end_time' => 'Ώρα Λήξης',
    'end' => 'Λήξη',
    'invoiced' => 'Τιμολογημένα',
    'logged' => 'Εισηγμένο',
    'running' => 'Εκτελείται',
    'task_error_multiple_clients' => 'Οι εργασίες δε μπορούν να ανήκουν σε διαφορετικούς πελάτες',
    'task_error_running' => 'Παρακαλώ διακόψτε την εκτέλεση εργασιών πρώτα',
    'task_error_invoiced' => 'Οι εργασίες έχουν ήδη τιμολογηθεί',
    'restored_task' => 'Επιτυχής ανάκτηση εργασίας',
    'archived_task' => 'Επιτυχής αρχειοθέτηση εργασίας',
    'archived_tasks' => 'Επιτυχής αρχειοθέτηση :count εργασιών',
    'deleted_task' => 'Επιτυχής διαγραφή εργασίας',
    'deleted_tasks' => 'Επιτυχής διαγραφή :count εργασιών',
    'create_task' => 'Δημιουργία Εργασίας',
    'stopped_task' => 'Επιτυχής διακοπή εργασίας',
    'invoice_task' => 'Τιμολόγηση Εργασίας',
    'invoice_labels' => 'Ετικέτες Τιμολογίων',
    'prefix' => 'Πρόθεμα',
    'counter' => 'Μετρητής',
    'payment_type_dwolla' => 'Dwolla',
    'gateway_help_43' => ':link για εγγραφή στο Dwolla',
    'partial_value' => 'Πρέπει να είναι μεγαλύτερο του μηδενός και μικρότερο από το σύνολο.',
    'more_actions' => 'Περισσότερες Ενέργειες',
    'pro_plan_title' => 'NINJA PRO',
    'pro_plan_call_to_action' => 'Αναβαθμίστε Τώρα!',
    'pro_plan_feature1' => 'Δημιουργία Απεριόριστων Πελατών',
    'pro_plan_feature2' => 'Πρόσβαση σε 10 Όμορφα Σχέδια Τιμολογίων',
    'pro_plan_feature3' => 'Προσαρμοσμένες διευθύνσεις URL - "YourBrand.InvoiceNinja.com"',
    'pro_plan_feature4' => 'Αφαίρεση του "Created by Invoice Ninja"',
    'pro_plan_feature5' => 'Πρόσβαση Πολλαπλών Χρηστών & Καταγραφή Δραστηριότητας',
    'pro_plan_feature6' => 'Δημιουργία Προσφορών & Προτιμολογίων',
    'pro_plan_feature7' => 'Προσαρμογή Τίτλων Πεδίων & Αριθμήσεων',
    'pro_plan_feature8' => 'Επιλογές στην την Επισύναψη αρχείων PDF στα Emails πελατών',
    'resume' => 'Συνέχισε',
    'break_duration' => 'Διέκοψε',
    'edit_details' => 'Επεξεργασία Στοιχείων',
    'work' => 'Εργασία',
    'timezone_unset' => 'Παρακαλώ :link για να ορίσετε τη ζώνη ώρας',
    'click_here' => 'πατήστε εδώ',
    'email_receipt' => 'Αποστολή απόδειξης πληρωμής στον πελάτη',
    'created_payment_emailed_client' => 'Επιτυχής δημιουργία πληρωμής και αποστολής της στον πελάτη',
    'add_company' => 'Προσθήκη Εταιρείας',
    'untitled' => 'Ανώνυμο',
    'new_company' => 'Νέα Εταιρεία',
    'associated_accounts' => 'Επιτυχής σύνδεση λογαριασμών',
    'unlinked_account' => 'Επιτυχής αποσύνδεση λογαριασμών',
    'login' => 'Είσοδος',
    'or' => 'ή',
    'email_error' => 'Προέκυψε πρόβλημα κατά την αποστολή του email',
    'confirm_recurring_timing' => 'Σημείωση: τα email στέλνονται στην αρχή κάθε ώρας',
    'confirm_recurring_timing_not_sent' => 'Σημείωση: τα τιμολόγια δημιουργούνται στην έναρξη της ώρας.',
    'payment_terms_help' => 'Ορίζει την προεπιλεγμένη <b>ημερομηνία ολοκλήρωσης<b> των τιμολογίων',
    'unlink_account' => 'Αποδύνδεση Λογαριασμού',
    'unlink' => 'Αποσύνδεση',
    'show_address' => 'Προβολή Διεύθυνσης',
    'show_address_help' => 'Απαίτηση από τον πελάτη να συμπληρώσει τη διεύθυνση τιμολόγησης',
    'update_address' => 'Ενημέρωση Διεύθυνσης',
    'update_address_help' => 'Ενημέρωση της διεύθυνσης του πελάτη με τα παρεχόμενα στοιχεία',
    'times' => 'Φορές',
    'set_now' => 'Όρισε το στο τώρα',
    'dark_mode' => 'Σκοτεινό Περιβάλλον',
    'dark_mode_help' => 'Χρήση σκούρου υπόβαθρου για τις πλαϊνές μπάρες',
    'add_to_invoice' => 'Προσθήκη στο Τιμολόγιο :Invoice',
    'create_new_invoice' => 'Δημιουργία νέου τιμολογίου',
    'task_errors' => 'Παρακαλώ διορθώστε τυχόν επικαλυπτόμενες ώρες',
    'from' => 'Από',
    'to' => 'Προς',
    'font_size' => 'Μέγεθος Γραμμάτων',
    'primary_color' => 'Κύριο Χρώμα',
    'secondary_color' => 'Δευτερεύον Χρώμα',
    'customize_design' => 'Προσαρμογή Σχεδίου',
    'content' => 'Περιεχόμενο',
    'styles' => 'Στυλ',
    'defaults' => 'Προεπιλογές',
    'margins' => 'Περιθώρια',
    'header' => 'Επικεφαλίδα',
    'footer' => 'Υποσέλιδο',
    'custom' => 'Προσαρμοσμένο',
    'invoice_to' => 'Τιμολόγιο προς',
    'invoice_no' => 'Αρ. Τιμολογίου',
    'quote_no' => 'Προσφορά Αρ.',
    'recent_payments' => 'Πρόσφατες Πληρωμές',
    'outstanding' => 'Εκκρεμή',
    'manage_companies' => 'Διαχείριση Εταιρειών',
    'total_revenue' => 'Συνολικά Έσοδα',
    'current_user' => 'Τρέχων Χρήστης',
    'new_recurring_invoice' => 'Νέο Επαναλαμβανόμενο Τιμολόγιο',
    'recurring_invoice' => 'Επαναλαμβανόμενο Τιμολόγιο',
    'new_recurring_quote' => 'Νέα Επαναλαμβανόμενη Προσφορά',
    'recurring_quote' => 'Επαναλαμβανόμενη Προσφορά',
    'recurring_too_soon' => 'Είναι πολύ νωρίς για να δημιουργήσετε το επόμενο επαναλαμβανόμενο τιμολόγιο. Είναι προγραμματισμένο για την :date',
    'created_by_invoice' => 'Δημιουργήθηκε από :invoice',
    'primary_user' => 'Κύριος Χρήστης',
    'help' => 'Βοήθεια',
    'customize_help' => '<p>Χρησιμοποιούμε το :pdfmake_link για να ορίσουμε τα σχέδια των τιμολογίων. Το pdfmake :playground_link προσφέρει ένα υπέροχο τρόπο για να δείτε τη βιβλιοθήκη στην πράξη.</p>
                        <p>Εάν χρειάζεστε βοήθεια στην κατανόηση κάποιου θέματος μπορείτε να υποβάλετε μία ερώτηση στο :forum_link με την εμφάνιση που χρησιμοποιείτε.</p>',
    'playground' => 'παιδότοπος',
    'support_forum' => 'φόρουμ υποστήριξης',
    'invoice_due_date' => 'Ημερομηνία Ολοκλήρωσης',
    'quote_due_date' => 'Έγκυρο Έως',
    'valid_until' => 'Έγκυρο Έως',
    'reset_terms' => 'Επαναφορά όρων',
    'reset_footer' => 'Επαναφορά υποσέλιδου',
    'invoice_sent' => ':count τιμολόγιο στάλθηκε',
    'invoices_sent' => ':count τιμολόγια στάλθηκαν',
    'status_draft' => 'Πρόχειρο',
    'status_sent' => 'Απεσταλμένα',
    'status_viewed' => 'Εμφανισμένα',
    'status_partial' => 'Μερικό',
    'status_paid' => 'Πληρωμένα',
    'status_unpaid' => 'Μη εξοφλημένη',
    'status_all' => 'Όλα',
    'show_line_item_tax' => 'Εμφάνιση <b>φόρου ανά προϊόν σε κάθε γραμμή</b>',
    'iframe_url' => 'Ιστοσελίδα',
    'iframe_url_help1' => 'Αντιγράψτε τον παρακάτω κώδικα στη σελίδα του site σας.',
    'iframe_url_help2' => 'Μπορείτε να δοκιμάσετε το χαρακτιριστικό πατώντας \'Προβολή ως παραλήπτης\' για ένα τιμολόγιο.',
    'auto_bill' => 'Αυτόματη Χρέωση',
    'military_time' => '24ωρη εμφάνιση Ώρας',
    'last_sent' => 'Τελευταία Αποστολή',
    'reminder_emails' => 'Μηνύματα Υπενθύμισης',
    'quote_reminder_emails' => 'Μηνύματα Υπενθύμισης Προσφοράς',
    'templates_and_reminders' => 'Πρότυπα & Υπενθυμίσεις',
    'subject' => 'Θέμα',
    'body' => 'Κείμενο',
    'first_reminder' => 'Πρώτη Υπενθύμιση',
    'second_reminder' => 'Δεύτερη Υπενθύμιση',
    'third_reminder' => 'Τρίτη Υπενθύμιση',
    'num_days_reminder' => 'Ημέρες μετά την ημερομηνία ολοκλήρωσης',
    'reminder_subject' => 'Υπενθύμιση: Τιμολόγιο :invoice από :account',
    'reset' => 'Επαναφορά',
    'invoice_not_found' => 'Το ζητούμενο τιμολόγιο δεν είναι διαθέσιμο',
    'referral_program' => 'Πρόγραμμα Παραπομπής',
    'referral_code' => 'URL Παραπομπής',
    'last_sent_on' => 'Τελευταία Αποστολή: :date',
    'page_expire' => 'Αυτή η σελίδα θα λήξει σύντομα, :click_here για να συνεχίσετε τη λειτουργία της',
    'upcoming_quotes' => 'Προσεχείς Προσφορές',
    'expired_quotes' => 'Προσφορές που έληξαν',
    'sign_up_using' => 'Εγγραφείτε με',
    'invalid_credentials' => 'Αυτά τα στοιχεία εισόδου δεν ταιριάζουν με τα αρχεία μας',
    'show_all_options' => 'Προβολή όλων των επιλογών',
    'user_details' => 'Στοιχεία Χρήστη',
    'oneclick_login' => 'Συνδεδεμένος Λογαριασμός',
    'disable' => 'Απενεργοποίηση',
    'invoice_quote_number' => 'Αριθμήσεις Τιμολογίων και Προσφορών',
    'invoice_charges' => 'Επιβαρύνσεις Τιμολογίου',
    'notification_invoice_bounced' => 'Μας ήταν αδύνατο να παραδώσουμε το Τιμολόγιο:invoice στο :contact.',
    'notification_invoice_bounced_subject' => 'Αδυναμία παράδοσης Τιμολογίου :invoice',
    'notification_quote_bounced' => 'Μας ήταν αδύνατο να παραδώσουμε την Προσφορά :invoice στο :contact.',
    'notification_quote_bounced_subject' => 'Αδυναμία παράδοσης Προσφοράς :invoice',
    'custom_invoice_link' => 'Προσαρμοσμένος Σύνδεσμος Τιμολογίου',
    'total_invoiced' => 'Σύνολο Τιμολογημένων',
    'open_balance' => 'Ανοιχτό Υπόλοιπο',
    'verify_email' => 'Παρακαλώ επισκεφθείτε το σύνδεσμο στο email επιβεβαίωσης λογαριασμού για να επικυρώσετε την email διεύθυνσή σας.',
    'basic_settings' => 'Βασικές Ρυθμίσεις',
    'pro' => 'Επαγγελματική',
    'gateways' => 'Πύλες Πληρωμών (Gateways)',
    'next_send_on' => 'Επόμενη Αποστολή: :date',
    'no_longer_running' => 'Αυτό το τιμολόγιο δεν είναι προγραμματισμένο να τρέξει',
    'general_settings' => 'Γενικές Ρυθμίσεις',
    'customize' => 'Προσαρμογή',
    'oneclick_login_help' => 'Συνδέστε ένα λογαριασμό για εισαγωγή χωρίς τη χρήση κωδικού πρόσβασης',
    'referral_code_help' => 'Κερδίστε χρήματα μοιράζοντας τη χρήση της εφαρμογής μας online.',
    'enable_with_stripe' => 'Ενεροποίησε | Απαιτείται το Stripe',
    'tax_settings' => 'Ρυθμίσεις Φόρων',
    'create_tax_rate' => 'Προσθήκη Ποσοστού Φόρου',
    'updated_tax_rate' => 'Επιτυχής ενημέρωση ποσοστού φόρου',
    'created_tax_rate' => 'Επιτυχής δημιουργία ποσοστού φόρου',
    'edit_tax_rate' => 'Επεξεργασία ποσοστού φόρου',
    'archive_tax_rate' => 'Αρχειοθέτηση Ποσοστού Φόρου',
    'archived_tax_rate' => 'Επιτυχής αρχειοθέτηση ποσοστού φόρου',
    'default_tax_rate_id' => 'Προεπιλεγμένο Ποσοστό Φόρου',
    'tax_rate' => 'Ποσοστό Φόρου',
    'recurring_hour' => 'Επαναλαμβανόμενη Ώρα',
    'pattern' => 'Μοτίβο',
    'pattern_help_title' => 'Βοήθεια Μοτίβων',
    'pattern_help_1' => 'Δημιουργείστε προσαρμοσμένους αριθμούς καθορίζοντας ένα πρότυπο',
    'pattern_help_2' => 'Διαθέσιμες μεταβλητές:',
    'pattern_help_3' => 'Για παράδειγμα, το :example θα μετατραπεί σε :value',
    'see_options' => 'Προβολή επιλογών',
    'invoice_counter' => 'Μετρητής Τιμολογίων',
    'quote_counter' => 'Μετρητής Προσφορών',
    'type' => 'Τύπος',
    'activity_1' => 'Ο χρήστης :user δημιούργησε τον πελάτη :client',
    'activity_2' => 'Ο χρήστης :user αρχειοθέτησε τον πελάτη :client',
    'activity_3' => 'Ο χρήστης :user διέγραψε τον πελάτη :client',
    'activity_4' => 'Ο χρήστης :user δημιούργησε το τιμολόγιο :invoice',
    'activity_5' => 'Ο χρήστης :user ενημέρωσε το τιμολόγιο :invoice',
    'activity_6' => 'Ο χρήστης :user έστειλε με email το τιμολόγιο :invoice για τον πελάτη :client στην επαφή :contact',
    'activity_7' => 'Η επαφή :contact είδε το τιμολόγιο :invoice για τον πελάτη :client',
    'activity_8' => 'Ο χρήστης :user αρχειοθέτησε το τιμολόγιο :invoice',
    'activity_9' => 'Ο χρήστης :user διέγραψε το τιμολόγιο :invoice',
    'activity_10' => 'Η επαφή :contact καταχώρησε την πληρωμή ποσού :payment_amount για το τιμολόγιο :invoice για τον πελάτη :client',
    'activity_11' => 'Ο χρήστης :user ενημέρωσε την πληρωμή :payment',
    'activity_12' => 'Ο χρήστης :user αρχειοθέτησε την πληρωμή :payment',
    'activity_13' => 'Ο χρήστης :user διέγραψε την πληρωμή :payment',
    'activity_14' => 'Ο χρήστης :user καταχώρησε την πίστωση :credit',
    'activity_15' => 'Ο χρήστης :user ενημέρωσε την πίστωση :credit',
    'activity_16' => 'Ο χρήστης :user αρχειοθέτησε την πίστωση :credit',
    'activity_17' => 'Ο χρήστης :user διέγραψε την πίστωση :credit',
    'activity_18' => 'Ο χρήστης :user δημιουργησε την προσφορά :quote',
    'activity_19' => 'Ο χρήστης :user ενημέρωσε την προσφορά :quote',
    'activity_20' => 'Ο χρήστης :user έστειλε με email την προσφορά :quote για τον πελάτη :client στην επαφή :contact',
    'activity_21' => 'Η επαφή :contact είδε την προσφορά :quote',
    'activity_22' => 'Ο χρήστης :user αρχειοθέτησε την προσφορά :quote',
    'activity_23' => 'Ο χρήστης :user διέγραψε την προσφορά :quote',
    'activity_24' => 'Ο χρήστης :user επανέφερε την προσφορά :quote',
    'activity_25' => 'Ο χρήστης :user επανέφερε το τιμολόγιο :invoice',
    'activity_26' => 'Ο χρήστης :user επανέφερε τον πελάτη :client',
    'activity_27' => 'Ο χρήστης :user επανέφερε την πληρωμή :payment',
    'activity_28' => 'Ο χρήστης :user επανέφερε την πίστωση :credit',
    'activity_29' => 'Η επαφή :contact αποδέχτηκε την προσφορά :quote για τον πελάτη :client',
    'activity_30' => 'Ο χρήστης :user δημιούργησε τον προμηθευτή :vendor',
    'activity_31' => 'Ο χρήστης :user αρχειοθέτησε τον προμηθευτή :vendor',
    'activity_32' => 'Ο χρήστης :user διέγραψε τον προμηθευτή :vendor',
    'activity_33' => 'Ο χρήστης :user επανέφερε τον προμηθευτή :vendor',
    'activity_34' => 'Ο χρήστης :user δημιούργησε τη δαπάνη :expense',
    'activity_35' => 'Ο χρήστης :user αρχειοθέτησε τη δαπάνη :expense',
    'activity_36' => 'Ο χρήστης :user διέγραψε τη δαπάνη :expense',
    'activity_37' => 'Ο χρήστης :user επανέφερε τη δαπάνη :expense',
    'activity_42' => 'Ο χρήστης :user δημιούργησε την εργασία :task',
    'activity_43' => 'Ο χρήστης :user ενημέρωσε την εργασία :task',
    'activity_44' => 'Ο χρήστης :user αρχειοθέτησε την εργασία :task',
    'activity_45' => 'Ο χρήστης :user διέγραψε την εργασία :task',
    'activity_46' => 'Ο χρήστης :user επανέφερε την εργασία :task',
    'activity_47' => 'Ο χρήστης :user ενημέρωσε τη δαπάνη :expense',
    'activity_48' => 'Ο χρήστης :user ενημέρωσε το αίτημα υποστήριξης :ticket',
    'activity_49' => 'Ο χρήστης :user έκλεισε το αίτημα υποστήριξης :ticket',
    'activity_50' => 'Ο χρήστης :user συνένωσε το αίτημα υποστήριξης :ticket',
    'activity_51' => 'Ο χρήστης :user διαίρεσε στα δύο το αίτημα υποστήριξης :ticket',
    'activity_52' => 'Η επαφή :contact δημιούργησε το αίτημα υποστήριξης :ticket',
    'activity_53' => 'Η επαφή :contact επαναδημιούργησε το αίτημα υποστήριξης :ticket',
    'activity_54' => 'Ο χρήστης :user επαναδημιούργησε το αίτημα υποστήριξης :ticket',
    'activity_55' => 'Η επαφή :contact απάντησε στο αίτημα υποστήριξης :ticket',
    'activity_56' => 'Ο χρήστης :user είδε το αίτημα υποστήριξης :ticket',

    'payment' => 'Πληρωμή',
    'system' => 'Σύστημα',
    'signature' => 'Υπογραφή Email',
    'default_messages' => 'Προεπιλεγμένα Μηνύματα',
    'quote_terms' => 'Όροι Προσφοράς',
    'default_quote_terms' => 'Προεπιλεγμένοι Όροι Προσφορών',
    'default_invoice_terms' => 'Προεπιλεγμένοι Όροι Τιμολογίων',
    'default_invoice_footer' => 'Προεπιλεγμένο Υποσέλιδο Τιμολογίων',
    'quote_footer' => 'Υποσέλιδο Προσφοράς',
    'free' => 'Δωρεάν',
    'quote_is_approved' => 'Επιτυχής αποδοχή',
    'apply_credit' => 'Εφαρμογή Πίστωσης',
    'system_settings' => 'Ρυθμίσεις Συστήματος',
    'archive_token' => 'Αρχειοθέτηση Διακριτικού',
    'archived_token' => 'Επιτυχής αρχειοθέτηση διακριτικού',
    'archive_user' => 'Αρχειοθέτηση Χρήστη',
    'archived_user' => 'Επιτυχής αρχειοθέτηση χρήστη',
    'archive_account_gateway' => 'Διαγραφή Πύλης Πληρωμών (Gateway)',
    'archived_account_gateway' => 'Επιτυχής αρχειοθέτηση πύλης πληρωμών (Gateway)',
    'archive_recurring_invoice' => 'Αρχειοθέτηση Επαναλαμβανόμενου Τιμολογίου',
    'archived_recurring_invoice' => 'Επιτυχής αρχειοθέτηση επαναλαμβανόμενου τιμολογίου',
    'delete_recurring_invoice' => 'Διαγραφή Επαναλαμβανόμενου Τιμολογίου',
    'deleted_recurring_invoice' => 'Επιτυχής διαγραφή επαναλαμβανόμενου τιμολογίου',
    'restore_recurring_invoice' => 'Επαναφορά Επαναλαμβανόμενου Τιμολογίου',
    'restored_recurring_invoice' => 'Επιτυχής επαναφορά επαναλαμβανόμενου τιμολογίου',
    'archive_recurring_quote' => 'Αρχειοθέτηση Επαναλαμβανόμενης Προσφοράς',
    'archived_recurring_quote' => 'Επιτυχής αρχειοθέτηση επαναλαμβανόμενης προσφοράς',
    'delete_recurring_quote' => 'Διαγραφή Επαναλαμβανόμενης Προσφοράς',
    'deleted_recurring_quote' => 'Επιτυχής διαγραφή επαναλαμβανόμενης προσφοράς',
    'restore_recurring_quote' => 'Επαναφορά Επαναλαμβανόμενης Προσφοράς',
    'restored_recurring_quote' => 'Επιτυχής επαναφορά επαναλαμβανόμενης προσφοράς',
    'archived' => 'Αρχειοθετημένο',
    'untitled_account' => 'Ανώνυμη Εταιρία',
    'before' => 'Πριν',
    'after' => 'Μετά',
    'reset_terms_help' => 'Επαναφορά στους προεπιλεγμένους όρους του λογαριασμού',
    'reset_footer_help' => 'Επαναφορά στο προεπιλεγμένο υποσέλιδο του λογαριασμού',
    'export_data' => 'Εξαγωγή Δεδομένων',
    'user' => 'Χρήστης',
    'country' => 'Χώρα',
    'include' => 'Περιλεμβάνει',
    'logo_too_large' => 'Το λογότυπό σας είναι :size, για καλύτερη απόδοση του PDF προτείνουμε να ανεβάσετε ένα αρχείο εικόνας μικρότερο από 200KB',
    'import_freshbooks' => 'Εισαγωγή από FreshBooks',
    'import_data' => 'Εισαγωγή Δεδομένων',
    'source' => 'Πηγή',
    'csv' => 'CSV',
    'client_file' => 'Αρχείο Πελάτη',
    'invoice_file' => 'Αρχείο Τιμολογίου',
    'task_file' => 'Αρχείο Εργασίας',
    'no_mapper' => 'Μη έγκυρη χαρτογράφηση αρχείου',
    'invalid_csv_header' => 'Μη έγκυρη κεφαλίδα CSV',
    'client_portal' => 'Portal Πελάτη',
    'admin' => 'Διαχειριστής',
    'disabled' => 'Απενεργοποιημένο',
    'show_archived_users' => 'Προβολή αρχειοθετημένων χρηστών',
    'notes' => 'Σημειώσεις',
    'invoice_will_create' => 'Το τιμολόγιο θα δημιουργηθεί',
    'invoices_will_create' => 'τιμολόγια θα δημιουργηθούν',
    'failed_to_import' => 'Οι παρακάτω εγγραφές απέτυχαν να εισαχθούν. Υπάρχουν ήδη ή λείπουν απαραίτητα πεδία.',
    'publishable_key' => 'Δημοσιοποιήσιμο Κλειδί',
    'secret_key' => 'Κρυφό Κλειδί',
    'missing_publishable_key' => 'Ορίστε το δημοσιοποιήσιμο κλειδί Stripe για βελτιωμένη διαδικασία ολοκλήρωσης αγοράς',
    'email_design' => 'Σχεδίαση Email',
    'due_by' => 'Πληρωτέο μέχρι :date',
    'enable_email_markup' => 'Ενεργοποίηση Σημανσης',
    'enable_email_markup_help' => 'Κάντε τη διαδικασία πληρωμής πιο εύκολη για τους πελάτες σας προσθέτοντας σήμανση από το schema.org στα emails σας.',
    'template_help_title' => 'Βοήθεια Προτύπων',
    'template_help_1' => 'Διαθέσιμες μεταβλητές:',
    'email_design_id' => 'Στυλ Email',
    'email_design_help' => 'Κάντε τα emails σας να δείχνουν πιο επαγγελματικά με τη διάταξη HTML.',
    'plain' => 'Απλό',
    'light' => 'Ανοιχτό',
    'dark' => 'Σκούρο',
    'industry_help' => 'Χρησιμοποιείται για να παρέχει συγκρίσεις μέσων όρων εταιριών ίδιου μεγέθους στους ίδιους επαγγελματικούς τομείς.',
    'subdomain_help' => 'Ορίστε τον υποτομέα ή εμφάνιστε το τιμολόγιο στη δική σας ιστοσελίδα',
    'website_help' => 'Εμφανίστε το τιμολόγιο σε ένα iFrame στη δική σας ιστοσελίδα',
    'invoice_number_help' => 'Ορίστε ένα πρόθεμα ή χρησιμοποιήστε ένα προσαρμοσμένο μοτίβο για να καθορίζετε δυναμικά τον αριθμό τιμολογίου.',
    'quote_number_help' => 'Ορίστε ένα πρόθεμα ή χρησιμοποιήστε ένα προσαρμοσμένο μοτίβο για να καθορίζετε δυναμικά τον αριθμό προσφοράς.',
    'custom_client_fields_helps' => 'Προσθέστε ένα πεδίο όταν δημιουργείτε ένα πελάτη και επιλέξτε δυνητικά την εμφάνισή της ετικέτας και της τιμής στο αρχείο PDF.',
    'custom_account_fields_helps' => 'Προσθέστε μία ετικέτα και μία τιμή στο σημείο που αφορά τις λεπτομέρειες της εταιρίας στο αρχείο PDF.',
    'custom_invoice_fields_helps' => 'Προσθέστε ένα πεδίο όταν δημιουργείτε ένα τιμολόγιο και επιλέξτε δυνητικά την εμφάνισή της ετικέτας και της τιμής στο αρχείο PDF.',
    'custom_invoice_charges_helps' => 'Προσθέστε ένα πεδίο όταν δημιουργείτε ένα τιμολόγιο και συμπεριλάβετε την χρέωση στα υποσύνολα του τιμολογίου.',
    'token_expired' => 'Το διακριτικό πιστοποίησης έχει λήξει. Παρακαλώ δοκιμάστε ξανά.',
    'invoice_link' => 'Σύνδεσμος Τιμολογίου',
    'button_confirmation_message' => 'Κάντε κλικ για να επιβεβαιώσετε τη διεύθυνση email σας.',
    'confirm' => 'Επιβεβαίωση',
    'email_preferences' => 'Προτιμήσεις Email',
    'created_invoices' => 'Δημιουργήθηκαν επιτυχώς :count τιμολόγιο(α)',
    'next_invoice_number' => 'Ο επόμενος αριθμός τιμολογίου είναι :number.',
    'next_quote_number' => 'Ο επόμενος αριθμός προσφοράς είναι :number.',
    'days_before' => 'ημέρες πριν από',
    'days_after' => 'ημέρες μετά από',
    'field_due_date' => 'ημερομηνία ολοκλήρωσης',
    'field_invoice_date' => 'ημερομηνία τιμολογίου',
    'schedule' => 'Προγραμμάτισε',
    'email_designs' => 'Σχέδια Email',
    'assigned_when_sent' => 'Ανάθεση όταν αποσταλεί',
    'white_label_purchase_link' => 'Προμηθευτείτε μια άδεια χρήσης λευκής ετικέτας',
    'expense' => 'Δαπάνη',
    'expenses' => 'Δαπάνες',
    'new_expense' => 'Καταχώρηση Δαπάνης',
    'enter_expense' => 'Καταχώρηση Δαπάνης',
    'vendors' => 'Προμηθευτές',
    'new_vendor' => 'Νέος Προμηθευτής',
    'payment_terms_net' => 'Καθαρό',
    'vendor' => 'Προμηθευτής',
    'edit_vendor' => 'Επεξεργασία Προμηθευτή',
    'archive_vendor' => 'Αρχειοθέτηση προμηθευτή',
    'delete_vendor' => 'Διαγραφή Προμηθευτή',
    'view_vendor' => 'Εμφάνιση Προμηθευτή',
    'deleted_expense' => 'Επιτυχής διαγραφή δαπάνης',
    'archived_expense' => 'Επιτυχής αρχειοθέτηση δαπάνης',
    'deleted_expenses' => 'Επιτυχής διαγραφή δαπανών',
    'archived_expenses' => 'Επιτυχής αρχειοθέτηση δαπανών',
    'expense_amount' => 'Ποσό Δαπάνης',
    'expense_balance' => 'Υπόλοιπο Δαπάνης',
    'expense_date' => 'Ημερομηνία Δαπάνης',
    'expense_should_be_invoiced' => 'Θέλετε να τιμολογηθεί αυτό το έξοδο',
    'public_notes' => 'Δημόσιες Σημειώσεις',
    'invoice_amount' => 'Ποσό Τιμολογίου',
    'exchange_rate' => 'Ισοτιμία Ανταλλαγής',
    'yes' => 'Ναι',
    'no' => 'Όχι',
    'should_be_invoiced' => 'Πρέπει να τιμολογηθεί',
    'view_expense' => 'Εμφάνιση δαπάνης # :expense',
    'edit_expense' => 'Επεξεργασία Δαπάνης',
    'archive_expense' => 'Αρχειοθέτηση Δαπάνης',
    'delete_expense' => 'Διαγραφή Δαπάνης',
    'view_expense_num' => 'Δαπάνη # :expense',
    'updated_expense' => 'Επιτυχής ενημέρωση δαπάνης',
    'created_expense' => 'Επιτυχής δημιουργία δαπάνης',
    'enter_expense' => 'Καταχώρηση Δαπάνης',
    'view' => 'Προβολή',
    'restore_expense' => 'Ανάκτηση Δαπάνης',
    'invoice_expense' => 'Τιμολόγηση Δαπάνης',
    'expense_error_multiple_clients' => 'Οι δαπάνες δε μπορούν να ανήκουν σε διαφορετικούς πελάτες',
    'expense_error_invoiced' => 'Οι δαπάνες έχουν ήδη τιμολογηθεί',
    'convert_currency' => 'Μετατροπή νομίσματος',
    'num_days' => 'Αριθμός Hμερών',
    'create_payment_term' => 'Δημιουργία Όρου Πληρωμής',
    'edit_payment_terms' => 'Επεξεργασία Όρου Πληρωμής',
    'edit_payment_term' => 'Επεξεργασία Όρου Πληρωμής',
    'archive_payment_term' => 'Αρχειοθέτηση Όρου Πληρωμής',
    'recurring_due_dates' => 'Ημερομηνίες Πληρωμής Επαναλαμβανόμενων Τιμολογίων',
    'recurring_due_date_help' => '<p>Ορίστε αυτόματα ημερομηνία πληρωμής για το τιμολόγιο.</p>
        <p>Τιμολόγια μηνιαίου ή ετήσιου κύκλου που έχουν οριστεί πληρωτέα την ίδια η προηγούμενη ημερομηνία από αυτή που έχουν δημιουργηθεί θα είναι πληρωτέα τον επόμενο μήνα. Τιμολόγια που θα είναι πληρωτέα την 29η ή 30η μηνών που δεν διαθέτουν αυτές τις ημερομηνίες θα ορίζονται πληρωτέα την τελευταία ημέρα του επόμενου μήνα.</p>
        <p>Τιμολόγια εβδομαδιαίας χρέωσης που έχουν οριστεί πληρωτέα την ημέρα της εβδομάδας που έχουν δημιουργηθεί θα είναι πληρωτέα την επόμενη εβδομάδα.</p>
        <p>Για παράδειγμα:</p>
        <ul>
          <li>Σήμερα ο μήνας έχει 15 και έχει οριστεί ημέρα πληρωμής η 1η του μήνα. Τότε η ημέρα πληρωμής θα είναι η 1η του επόμενου μήνα.</li>
          <li>Σήμερα ο μήνας έχει 15 και έχει οριστεί ημέρα πληρωμής η τελευταία μέρα του μήνα. Τότε η ημέρα πληρωμής θα είναι η τελευταία μέρα του τρέχοντος  μήνα.
</li>
          <li>Σήμερα ο μήνας έχει 15 και έχει οριστεί ημέρα πληρωμής η 15η του μήνα. Τότε η ημέρα πληρωμής θα είναι η 15η του <strong>επόμενου</strong> μήνα.
</li>
          <li>Σήμερα είναι Παρασκευή και έχει οριστεί ημέρα πληρωμής η πρώτη επόμενη Παρασκευή. Τότε η ημέρα πληρωμής θα είναι η επόμενη Παρασκευή, όχι σήμερα.
</li>
        </ul>',
    'due' => 'Πληρωτέο',
    'next_due_on' => 'Επόμενη πληρωμή: :date',
    'use_client_terms' => 'Χρήση όρων πελατών',
    'day_of_month' => ':ordinal ημέρα του μήνα',
    'last_day_of_month' => 'Τελευταία ημέρα του μήνα',
    'day_of_week_after' => ':ordinal :day μετά',
    'sunday' => 'Κυριακή',
    'monday' => 'Δευτέρα',
    'tuesday' => 'Τρίτη',
    'wednesday' => 'Τετάρτη',
    'thursday' => 'Πέμπτη',
    'friday' => 'Παρασκευή',
    'saturday' => 'Σάββατο',
    'header_font_id' => 'Γραμματοσειρά Επικεφαλίδας',
    'body_font_id' => 'Γραμματοσειρά Κειμένου',
    'color_font_help' => 'Σημείωση: το πρωτεύων χρώμα και γραμματοσειρά χρησιμοποιούνται επίσης στο portal του πελάτη και στα  προσαρμοσμένα σχέδια email.',
    'live_preview' => 'Ζωντανή Προεπισκόπηση',
    'invalid_mail_config' => 'Αδυναμία αποστολής email, παρακαλώ ελέγξτε ότι οι ρυθμίσεις email είναι σωστές.',
    'invoice_message_button' => 'Για να δείτε το τιμολόγιο των :amount, πατήστε το παρακάτω κουμπί.',
    'quote_message_button' => 'Για να δείτε την προσφορά του ποσού :amount, πατήστε το παρακάτω κουμπί.',
    'payment_message_button' => 'Ευχαριστούμε για την πληρωμή των :amount.',
    'payment_type_direct_debit' => 'Απευθείας Χρέωση',
    'bank_accounts' => 'Πιστωτικές Κάρτες & Τράπεζες',
    'add_bank_account' => 'Προσθήκη Τραπεζικού Λογαριασμού',
    'setup_account' => 'Καθορισμός Λογαριασμού',
    'import_expenses' => 'Εισαγωγή Δαπανών',
    'bank_id' => 'Τράπεζα',
    'integration_type' => 'Τύπος Ενσωμάτωσης',
    'updated_bank_account' => 'Επιτυχής ενημέρωση τραπεζικού λογαριασμού',
    'edit_bank_account' => 'Επεξεργασία Τραπεζικού Λογαριασμού',
    'archive_bank_account' => 'Αρχειοθέτηση Τραπεζικού Λογαριασμού',
    'archived_bank_account' => 'Επιτυχής αρχειοθέτηση τραπεζικού λογαριασμού',
    'created_bank_account' => 'Επιτυχής δημιουργία τραπεζικού λογαριασμού',
    'validate_bank_account' => 'Επικύρωση Τραπεζικού Λογαριασμού',
    'bank_password_help' => 'Σημείωση: ο κωδικός πρόσβασής σας μεταδόθηκε με ασφαλή τρόπο και δεν θα αποθηκευτεί ποτέ στους server μας.',
    'bank_password_warning' => 'Προειδοποίηση: ο κωδικός πρόσβασής σας μπορεί να μεταδοθεί σε απλό κείμενο, σκεφτείτε την ενεργοποίηση του HTTPS.',
    'username' => 'Όνομα Χρήστη',
    'account_number' => 'Αριθμός Λογαριασμού',
    'account_name' => 'Όνομασία Λογαριασμού',
    'bank_account_error' => 'Αδυναμία ανάσυρσης λεπτομερειών του λογαριασμού, παρακαλώ ελέγξτε τα στοιχεία σας. ',
    'status_approved' => 'Αποδεκτή',
    'quote_settings' => 'Ρυθμίσεις Προσφορών',
    'auto_convert_quote' => 'Αυτόματη Μετατροπή',
    'auto_convert_quote_help' => 'Αυτόματη μετατροπή της προσφοράς σε τιμολόγιο μόλις γίνει αποδεκτή από τον πελάτη.',
    'validate' => 'Επικύρωση',
    'info' => 'Πληροφορίες',
    'imported_expenses' => 'Επιτυχής δημιουργία :count_vendors προμηθευτή(ών) και :count_expenses δαπάνης(ών)',
    'iframe_url_help3' => 'Σημείωση: Εάν προγραμματίζετε να δέχεστε πιστωτικές κάρτες σας προτείνουμε να χρησιμοποιήσετε HTTPS στην ιστοσελίδα σας.',
    'expense_error_multiple_currencies' => 'Οι δαπάνες δε μπορούν να είναι σε διαφορετικά νομίσματα.',
    'expense_error_mismatch_currencies' => 'Το νόμισμα του πελάτη δεν είναι το ίδιο με το νόμισμα της δαπάνης.',
    'trello_roadmap' => 'Πλάνο Ανάπτυξης στο Trello',
    'header_footer' => 'Επικεφαλίδα/Υποσέλιδο',
    'first_page' => 'Πρώτη σελίδα',
    'all_pages' => 'Προσθήκη Σελίδας',
    'last_page' => 'Τελευταία σελίδα',
    'all_pages_header' => 'Εμφάνιση Κεφαλίδας',
    'all_pages_footer' => 'Εμφάνιση Υποσέλιδου',
    'invoice_currency' => 'Νόμισμα Τιμολογίου',
    'enable_https' => 'Σας προτείνουμε να χρησιμοποιήσετε HTTPS για να δέχεστε πιστωτικές κάρτες online.',
    'quote_issued_to' => 'Έκδοση προσφοράς προς',
    'show_currency_code' => 'Κωδικός Νομίσματος',
    'free_year_message' => 'Ο λογαριασμός σας αναβαθμίστηκε στο επαγγελματικό πακέτο για ένα χρόνο χωρίς κόστος.',
    'trial_message' => 'Ο λογαριασμός σας θα δεχθεί μια δωρεάν δοκιμαστική περίοδο δύο εβδομάδων στο επαγγελματικό μας πλάνο.',
    'trial_footer' => 'Η δωρεάν δοκιμαστική περίοδο ισχύει για :count ακόμα ημέρες, :link για να αναβαθμίσετε τώρα.',
    'trial_footer_last_day' => 'Αυτή είναι η τελευταία ημέρα της δωρεάν δοκιμαστικής περιόδου, :link για να αναβαθμίσετε τώρα.',
    'trial_call_to_action' => 'Έναρξη Δωρεάν Δοκιμής',
    'trial_success' => 'Επιτυχής ενεργοποίηση δωρεάν δοκιμαστικής περιόδου δύο εβδομάδων στο επαγγελματικό πλάνο.',
    'overdue' => 'Εκπρόθεσμος',


    'white_label_text' => 'Προμηθευτείτε μια ΕΤΗΣΙΑ άδεια χρήσης λευκής ετικέτας με $:price για να αφαιρέσετε το λογότυπο Ninja από το τιμολόγιο και το portal του πελάτη.',
    'user_email_footer' => 'Για να προσαρμόσετε τις ρυθμίσεις ειδοποίησης μέσω email, παρακαλώ κάντε κλικ εδώ :link',
    'reset_password_footer' => 'Αν δεν αιτηθήκατε αυτή την επαναφορά κωδικού πρόσβασης, παρακαλώ ενημερώστε την υποστήριξη στο :email',
    'limit_users' => 'Λυπάμαι, αυτό υπερβαίνει το όριο των :limit  χρηστών',
    'more_designs_self_host_header' => 'Λάβετε 6 επιπλέον σχέδια τιμολογίων με μόνο $:price',
    'old_browser' => 'Παρακαλώ χρησιμοποιήστε ένα :link',
    'newer_browser' => 'νεότερος browser',
    'white_label_custom_css' => ':link για $:price για να ενεργοποιήσετε την προσαρμοσμένη εμφάνιση και να υποστηρίξετε το project μας.',
    'bank_accounts_help' => 'Συνδέστε ένα τραπεζικό λογαριασμό για αυτόματη εισαγωγή δαπανών και δημιουργία προμηθευτών. Υποστηρίζεται η American Express και :link.',
    'us_banks' => '400+ τράπεζες ΗΠΑ',

    'pro_plan_remove_logo' => ':link για να αφαιρέσετε το λογότυπο Invoice Ninja και να συμμετέχετε στο Επαγγελματικό Πλάνο',
    'pro_plan_remove_logo_link' => 'Πατήστε εδώ',
    'invitation_status_sent' => 'Απεστάλη',
    'invitation_status_opened' => 'Ανοιχτό',
    'invitation_status_viewed' => 'Εμφανισμένα',
    'email_error_inactive_client' => 'Δεν μπορούν να αποσταλούν emails σε ανενεργούς πελάτες',
    'email_error_inactive_contact' => 'Δεν μπορούν να αποσταλούν emails σε ανενεργές επαφές',
    'email_error_inactive_invoice' => 'Δεν μπορούν να αποσταλούν emails σε ανενεργά τιμολόγια',
    'email_error_inactive_proposal' => 'Δεν μπορούν να αποσταλούν emails σε ανενεργές προτάσεις',
    'email_error_user_unregistered' => 'Παρακαλούμε εγγραφείτε στο λογαριασμό σας για να στείλετε emails',
    'email_error_user_unconfirmed' => 'Παρακαλούμε επιβεβαιώστε το λογαριασμό σας για να στείλετε emails',
    'email_error_invalid_contact_email' => 'Λανθασμένο email επικοινωνίας',

    'navigation' => 'Πλοήγηση',
    'list_invoices' => 'Λίστα Τιμολογίων',
    'list_clients' => 'Λίστα Πελατών',
    'list_quotes' => 'Λίστα Προσφορών',
    'list_tasks' => 'Λίστα Εργασιών',
    'list_expenses' => 'Λίστα Δαπανών',
    'list_recurring_invoices' => 'Λίστα Επαναλαμβανόμενων Τιμολογίων',
    'list_payments' => 'Λίστα Πληρωμών',
    'list_credits' => 'Λίστα Πιστώσεων',
    'tax_name' => 'Ονομασία Φόρου',
    'report_settings' => 'Ρυθμίσεις Αναφορών',
    'search_hotkey' => 'συντόμευση είναι /',

    'new_user' => 'Νέος Χρήστης',
    'new_product' => 'Νέο Προϊόν',
    'new_tax_rate' => 'Νέο Ποσοστό Φόρου',
    'invoiced_amount' => 'Τιμολογημένο Ποσό',
    'invoice_item_fields' => 'Πεδία Προϊόντων Τιμολογίου',
    'custom_invoice_item_fields_help' => 'Προσθέστε ένα πεδίο όταν δημιουργείτε ένα προϊόν τιμολογίου και εμφανίστε την ετικέτα και την τιμή στο αρχείο PDF.',
    'recurring_invoice_number' => 'Επαναλαμβανόμενος Αριθμός',
    'recurring_invoice_number_prefix_help' => 'Ορίστε ένα πρόθεμα που να περιλαμβάνεται στον αριθμό τιμολογίου των επαναλαμβανόμενων τιμολογίων.',

    // Client Passwords
    'enable_portal_password' => 'Προστασία Τιμολογίων με Κωδικό Πρόσβασης',
    'enable_portal_password_help' => 'Επιτρέπει τον καθορισμό κωδικού πρόσβασης για κάθε επαφή. Αν έχει καθοριστεί κωδικός, η επαφή θα υποχρεούται να καταχωρήσει κωδικό πριν την προβολή των τιμολογίων.',
    'send_portal_password' => 'Αυτόματη Δημιουργία',
    'send_portal_password_help' => 'Εάν δεν έχει οριστεί κωδικό πρόσβασης, θα δημιουργηθεί ένα αυτόματα και θα αποσταλεί με το πρώτο τιμολόγιο.',

    'expired' => 'Ληγμένα',
    'invalid_card_number' => 'Η πιστωτική κάρτα δεν είναι έγκυρη.',
    'invalid_expiry' => 'Η ημερομηνία λήξης δεν είναι έγκυρη.',
    'invalid_cvv' => 'Το CVV δεν είναι έγκυρο.',
    'cost' => 'Κόστος',
    'create_invoice_for_sample' => 'Σημείωση: δημιουργήστε το πρώτο σας τιμολόγιο για να δείτε την προεπισκόπηση εδώ.',

    // User Permissions
    'owner' => 'Ιδιοκτήτης',
    'administrator' => 'Διαχειριστής',
    'administrator_help' => 'Επιτρέψτε στο χρήστη να διαχειρίζεται χρήστες, να αλλάζει ρυθμίσεις και να τροποποιεί όλες τις εγγραφές',
    'user_create_all' => 'Δημιουργία πελατών, τιμολογίων κλπ.',
    'user_view_all' => 'Προβολή πελατών, τιμολογίων κλπ.',
    'user_edit_all' => 'Επεξεργασία πελατών, τιμολογίων κλπ.',
    'gateway_help_20' => ':link για εγγραφή στο Sage Pay.',
    'gateway_help_21' => ':link για εγγραφή στο Sage Pay.',
    'partial_due' => 'Μερική Πληρωμή',
    'restore_vendor' => 'Ανάκτηση Προμηθευτή',
    'restored_vendor' => 'Ο Προμηθευτής ανακτήθηκε με επιτυχία',
    'restored_expense' => 'Επιτυχής επαναφορά δαπάνης',
    'permissions' => 'Δικαιώματα',
    'create_all_help' => 'Επιτρέψτε στο χρήστη να δημιουργεί και να τροποποιεί εγγραφές',
    'view_all_help' => 'Επιτρέψτε στο χρήστη να βλέπει εγγραφές που δεν έχει δημιουργήσει',
    'edit_all_help' => 'Επιτρέψτε στο χρήστη να τροποποιεί εγγραφές που δεν έχει δημιουργήσει',
    'view_payment' => 'Εμφάνιση Πληρωμής',

    'january' => 'Ιανουάριος',
    'february' => 'Φεβρουάριος',
    'march' => 'Μάρτιος',
    'april' => 'Απρίλιος',
    'may' => 'Μάιος',
    'june' => 'Ιούνιος',
    'july' => 'Ιούλιος',
    'august' => 'Αύγουστος',
    'september' => 'Σεπτέμβριος',
    'october' => 'Οκτώβριος',
    'november' => 'Νοέμβριος',
    'december' => 'Δεκέμβριος',

    // Documents
    'documents_header' => 'Έγγραφα:',
    'email_documents_header' => 'Έγγραφα:',
    'email_documents_example_1' => 'Widgets Receipt.pdf',
    'email_documents_example_2' => 'Final Deliverable.zip',
    'quote_documents' => 'Έγγραφα Προσφοράς',
    'invoice_documents' => 'Έγγραφα Τιμολογίου',
    'expense_documents' => 'Έγγραφα Δαπάνης',
    'invoice_embed_documents' => 'Ενσωματωμένα Έγγραφα',
    'invoice_embed_documents_help' => 'Συμπεριλάβετε τις συνημμένες εικόνες στο τιμολόγιο',
    'document_email_attachment' => 'Επισύναψη Εγγράφων',
    'ubl_email_attachment' => 'Επισύναψε UBL',
    'download_documents' => 'Κατέβασμα Εγγράφων (:size)',
    'documents_from_expenses' => 'Από Δαπάνες:',
    'dropzone_default_message' => 'Σύρετε τα αρχεία ή κάντε κλικ για μεταφόρτωση',
    'dropzone_default_message_disabled' => 'Οι μεταφορτώσεις είναι απενεργοποιημένες',
    'dropzone_fallback_message' => 'Ο browser σας δεν υποστηρίζει τη μεταφόρτωση αρχείων με σύρσιμο.',
    'dropzone_fallback_text' => 'Παρακαλώ χρησιμοποιήστε την παρακάτω αναδρομική φόρμα για να μεταφορτώσετε αρχεία με τον παλιό τρόπο.',
    'dropzone_file_too_big' => 'Το αρχείο είναι πολύ μεγάλο ({{filesize}}MiB). Μέγιστο μέγρθος: {{maxFilesize}}MiB.',
    'dropzone_invalid_file_type' => 'Δε μπορείτε να ανεβάσετε αρχεία αυτού του τύπου.',
    'dropzone_response_error' => 'Ο διακομιστής αποκρίθηκε με τον κωδικό {{statusCode}}.',
    'dropzone_cancel_upload' => 'Ακύρωση ανεβάσματος',
    'dropzone_cancel_upload_confirmation' => 'Είστε σίγουροι ότι θέλετε να ακυρώσετε αυτό το ανέβασμα;',
    'dropzone_remove_file' => 'Διαγραφή αρχείου',
    'documents' => 'Έγγραφα',
    'document_date' => 'Ημερομηνία Εγγράφου',
    'document_size' => 'Μέγεθος',

    'enable_client_portal' => 'Portal Πελάτη',
    'enable_client_portal_help' => 'Εμφάνιση/απόκρυψη portal πελάτη',
    'enable_client_portal_dashboard' => 'Πίνακας ελέγχου',
    'enable_client_portal_dashboard_help' => 'Εμφάνιση/απόκρυψη του πίνακα ελέγχου στο portal πελάτη.',

    // Plans
    'account_management' => 'Διαχείριση Λογαριασμού',
    'plan_status' => 'Κατάσταση Πλάνου',

    'plan_upgrade' => 'Αναβάθμιση',
    'plan_change' => 'Αλλαγή Πλάνου',
    'pending_change_to' => 'Αλλαγή Σε',
    'plan_changes_to' => ':plan σε :date',
    'plan_term_changes_to' => ':plan (:term) σε :date',
    'cancel_plan_change' => 'Ακύρωση Αλλαγής',
    'plan' => 'Πλάνο',
    'expires' => 'Λήγει',
    'renews' => 'Ανανεώσεις',
    'plan_expired' => ':plan Πλάνο Έληξε',
    'trial_expired' => ':plan Πλάνο Δοκιμαστική Περίοδος Έληξε',
    'never' => 'Ποτέ',
    'plan_free' => 'Δωρεάν',
    'plan_pro' => 'Επαγγελματική',
    'plan_enterprise' => 'Εταιρικό',
    'plan_white_label' => 'Προσωπική Φιλοξενία (Λευκή Ετικέτα)',
    'plan_free_self_hosted' => 'Προσωπική Φιλοξενία (Δωρεάν)',
    'plan_trial' => 'Δοκιμαστικό',
    'plan_term' => 'Όρος',
    'plan_term_monthly' => 'Μήνας',
    'plan_term_yearly' => 'Ετήσιο',
    'plan_term_month' => 'Μήνας',
    'plan_term_year' => 'Έτος',
    'plan_price_monthly' => '$:price/Μήνα',
    'plan_price_yearly' => '$:price/Έτος',
    'updated_plan' => 'Ενημερωμένες ρυθμίσεις πλάνου',
    'plan_paid' => 'Έναρξη Περιόδου',
    'plan_started' => 'Έναρξη Πλάνου',
    'plan_expires' => 'Λήξη Πλάνου',

    'white_label_button' => 'Λευκή Ετικέτα',

    'pro_plan_year_description' => 'Ένα έτος εγγραφή στο Επαγγελματικό Πλάνο του Invoice Ninja.',
    'pro_plan_month_description' => 'Ένας μήνας εγγραφή στο Επαγγελματικό Πλάνο του Invoice Ninja.',
    'enterprise_plan_product' => 'Πλάνο Enterprise',
    'enterprise_plan_year_description' => 'Ένα έτος εγγραφή στο Εταιρικό Πλάνο του Invoice Ninja.',
    'enterprise_plan_month_description' => 'Ένας μήνας εγγραφή στο Εταιρικό Πλάνο του Invoice Ninja.',
    'plan_credit_product' => 'Πίστωση',
    'plan_credit_description' => 'Πίστωση για μη χρησιμοποιημένο διάστημα',
    'plan_pending_monthly' => 'Θα αλλάξει σε μηνιαίο στις :date',
    'plan_refunded' => 'Έχει εκδοθεί επιστροφή χρημάτων.',

    'live_preview' => 'Ζωντανή Προεπισκόπηση',
    'page_size' => 'Μέγεθος Σελίδας',
    'live_preview_disabled' => 'Η ζωντανή προεπισκόπηση έχει απενεργοποιηθεί για να μπορεί να εμφανιστεί αυτή η γραμματοσειρά',
    'invoice_number_padding' => 'Περιθώριο',
    'preview' => 'Προεπισκόπηση',
    'list_vendors' => 'Λίστα Προμηθευτών',
    'add_users_not_supported' => 'Αναβαθμίστε στο Εταιρικό πλάνο για να προσθέσετε επιπλέον χρήστες στο λογαριασμό σας.',
    'enterprise_plan_features' => 'Το Εταιρικό πλάνο προσθέτει υποστήριξη για πολλαπλούς χρήστες και συνημμένα αρχεία, :link για να δείτε  την πλήρη λίστα με τα χαρακτηριστικά.',
    'return_to_app' => 'Επιστροφή στην Εφαρμοφή',


    // Payment updates
    'refund_payment' => 'Επιστροφή Πληρωμής',
    'refund_max' => 'Μέγιστο:',
    'refund' => 'Επιστροφή χρημάτων',
    'are_you_sure_refund' => 'Επιστροφή επιλεγμένων πληρωμών:',
    'status_pending' => 'Σε εξέλιξη',
    'status_completed' => 'Ολοκληρώθηκε',
    'status_failed' => 'Απέτυχε',
    'status_partially_refunded' => 'Μερική επιστροφή χρημάτων',
    'status_partially_refunded_amount' => ':amount χρήματα επεστραφησαν',
    'status_refunded' => 'Επιστροφή χρημάτων',
    'status_voided' => 'Ακυρωμένη',
    'refunded_payment' => 'Επεστραμένη Πληρωμή',
    'activity_39' => ':user ακύρωσε :payment_amount πληρωμής :payment',
    'activity_40' => ':user επέστρεψε :adjustment μιας :payment_amount πληρωμής :payment',
    'card_expiration' => 'Λήξη:&nbsp:expires',

    'card_creditcardother' => 'Άγνωστο',
    'card_americanexpress' => 'American Express',
    'card_carteblanche' => 'Carte Blanche',
    'card_unionpay' => 'UnionPay',
    'card_diners' => 'Diners Club',
    'card_discover' => 'Discover',
    'card_jcb' => 'JCB',
    'card_laser' => 'Laser',
    'card_maestro' => 'Maestro',
    'card_mastercard' => 'MasterCard',
    'card_solo' => 'Solo',
    'card_switch' => 'Εναλλαγή',
    'card_visacard' => 'Visa',
    'card_ach' => 'ACH',

    'payment_type_stripe' => 'Stripe',
    'ach' => 'ACH',
    'enable_ach' => 'Αποδοχή τραπεζικών εμβασμάτων από τράπεζες των Ηνωμένων Πολιτειών',
    'stripe_ach_help' => 'Η υποστήριξη στην ACH πρέπει επίσης να ενεργοποιηθεί στο :link.',
    'ach_disabled' => 'Μια άλλη πύλη πληρωμών (Gateway) έχει ήδη παραμετροποιηθεί για άμεση πίστωση',

    'plaid' => 'Plaid',
    'client_id' => 'Id Πελάτη',
    'secret' => 'Κρυφό',
    'public_key' => 'Δημόσιο Κλειδί',
    'plaid_optional' => '(προαιρετικό)',
    'plaid_environment_help' => 'Όταν δοθεί ένα δοκιμαστικό κλειδί από το Stripe, θα χρησιμοποιηθεί το περιβάλλον ανάπτυξης (tartan) Plaid.',
    'other_providers' => 'Άλλοι Providers',
    'country_not_supported' => 'Αυτή η χώρα δεν υποστηρίζεται.',
    'invalid_routing_number' => 'Ο αριθμός δρομολόγησης δεν είναι έγκυρος.',
    'invalid_account_number' => 'Ο αριθμός λογαριασμού δεν είναι έγκυρος.',
    'account_number_mismatch' => 'Οι αριθμοί λογαριασμών δεν ταιριάζουν.',
    'missing_account_holder_type' => 'Παρακαλώ επιλέξτε ένα προσωπικό ή εταιρικό λογαριασμό.',
    'missing_account_holder_name' => 'Παρακαλώ καταχωρήστε το όνομα κατόχου του λογαριασμού.',
    'routing_number' => 'Αριθμός δρομολόγησης',
    'confirm_account_number' => 'Επιβεβαίωση Αριθμού Λογαριασμού',
    'individual_account' => 'Προσωπικός Λογαριασμός',
    'company_account' => 'Εταιρικός Λογαριασμός',
    'account_holder_name' => 'Όνομα Κατόχου Λογαριασμού',
    'add_account' => 'Προσθήκη Λογαριασμού',
    'payment_methods' => 'Τρόποι Πληρωμής',
    'complete_verification' => 'Ολοκλήρωση Πιστοποίησης',
    'verification_amount1' => 'Ποσό 1',
    'verification_amount2' => 'Ποσό 2',
    'payment_method_verified' => 'Πιστοποίηση ολοκληρώθηκε επιτυχώς',
    'verification_failed' => 'Αποτυχία Πιστοποίησης',
    'remove_payment_method' => 'Αφαίρεση Μεθόδου Πληρωμής',
    'confirm_remove_payment_method' => 'Είστε σίγουροι ότι θέλετε να διαγράψετε αυτό τον τρόπο πληρωμής;',
    'remove' => 'Διαγραφή',
    'payment_method_removed' => 'Η μέθοδος πληρωμής αφαιρέθηκε.',
    'bank_account_verification_help' => 'Κάναμε δύο καταθέσεις στο λογαριασμό σας με την περιγραφή "VERIFICATION". Αυτές οι καταθέσεις θα χρειαστεί 1-2 εργάσιμες ημέρες για να φανούν στην αναλυτική κατάσταση λογαριασμού. Παρακαλώ εισάγετε τα ποσά παρακάτω.',
    'bank_account_verification_next_steps' => 'Κάναμε δύο καταθέσεις στο λογαριασμό σας με την περιγραφή "VERIFICATION". Αυτές οι καταθέσεις θα χρειαστεί 1-2 εργάσιμες ημέρες για να φανούν στην αναλυτική κατάσταση λογαριασμού.
        Όταν διαθέτετε τα ποσά, επιστρέψτε στην παρούσα σελίδα μεθόδου πληρωμών και πιέστε "Ολοκλήρωση Πιστοποίησης" δίπλα στο λογαριασμό.',
    'unknown_bank' => 'Άγνωστη Τράπεζα',
    'ach_verification_delay_help' => 'Θα μπορείτε να χρησιμοποιήσετε το λογαριασμό μετά την ολοκλήρωση της πιστοποίησης. Η πιστοποίηση απαιτεί συνήθως 1-2 εργάσιμες ημέρες.',
    'add_credit_card' => 'Προσθήκη Πιστωτικής Κάρτας',
    'payment_method_added' => 'Ο τρόπος πληρωμής προστέθηκε.',
    'use_for_auto_bill' => 'Χρήση για το Autobill',
    'used_for_auto_bill' => 'Τρόπος Πληρωμής Autobill',
    'payment_method_set_as_default' => 'Ορισμός τρόπου πληρωμής Autobill.',
    'activity_41' => ':payment_amount πληρωμής (:payment) απέτυχε',
    'webhook_url' => 'Διεύθυνση URL του Webhook ',
    'stripe_webhook_help' => 'Πρέπει να :link.',
    'stripe_webhook_help_link_text' => 'προσθέσετε αυτό το URL σαν σημείο τερματισμού στο Stripe',
    'gocardless_webhook_help_link_text' => 'προσθέστε αυτή τη διεύθυνση internet στο τέλος της διεύθυνσης internet στο GoCardless',
    'payment_method_error' => 'Προέκυψε ένα σφάλμα κατά τη διαδικασία προσθήκης της μεθόδου πληρωμής. Παρακαλώ, δοκιμάστε ξανά σε λίγο.',
    'notification_invoice_payment_failed_subject' => 'Η πληρωμή για το τιμολόγιο :invoice απέτυχε',
    'notification_invoice_payment_failed' => 'Μια πληρωμή που έγινε από τον πελάτη :client που αφορούσε το Τιμολόγιο :invoice απέτυχε. Η πληρωμή έχει μαρκαριστεί ως αποτυχημένη και ποσό :amount προστέθηκε στο υπόλοιπο του πελάτη.',
    'link_with_plaid' => 'Συνδέστε άμεσα το λογαριασμό σας με το Plaid',
    'link_manually' => 'Χειροκίνητη Σύνδεση',
    'secured_by_plaid' => 'Ασφαλισμένο με το Plaid',
    'plaid_linked_status' => 'Ο Τραπεζικός Λογαριασμός σας στην :bank',
    'add_payment_method' => 'Προσθήκη Τρόπου Πληρωμής',
    'account_holder_type' => 'Τύπος Κατόχου Λογαριασμού',
    'ach_authorization' => 'Εξουσιοδοτώ την :company να χρησιμοποιήσει τον τραπεζικό μου λογαριασμό για μελλοντικές πληρωμές και, εάν είναι απαραίτητο, να πιστώσει ηλεκτρονικά το λογαριασμό μου για να διορθώσει εσφαλμένες χρεώσεις. Κατανοώ ότι μπορώ να ακυρώσω αυτή την εξουσιοδότησε οποιαδήποτε στιγμή αφαιρώντας αυτή τη μέθοδο πληρωμής ή επικοινωνώντας στο :email.',
    'ach_authorization_required' => 'Πρέπει να συναινέσετε σε συναλλαγές ACH',
    'off' => 'Κλειστό',
    'opt_in' => 'Συμμετοχή',
    'opt_out' => 'Μη συμμετοχή',
    'always' => 'Πάντα',
    'opted_out' => 'Επιλέξατε μη συμμετοχή',
    'opted_in' => 'Επιλέξατε συμμετοχή',
    'manage_auto_bill' => 'Διαχείριση Auto-bill',
    'enabled' => 'Ενεργοποίηση',
    'paypal' => 'PayPal',
    'braintree_enable_paypal' => 'Ενεργοποίηση πληρωμών PayPal μέσω του BrainTree',
    'braintree_paypal_disabled_help' => 'Η πύλη πληρωμών (Gateway) PayPal επεξεργάζεται πληρωμές PayPal',
    'braintree_paypal_help' => 'Πρέπει επίσης να :link.',
    'braintree_paypal_help_link_text' => 'Συνδέστε το PayPal με το λογαριασμό σας στο BrainTree',
    'token_billing_braintree_paypal' => 'Αποθήκευση στοιχείων πληρωμής',
    'add_paypal_account' => 'Προσθήκη Λογαριασμού PayPal',


    'no_payment_method_specified' => 'Δεν έχει οριστεί τρόπος πληρωμής',
    'chart_type' => 'Τύπος Διαγράμματος',
    'format' => 'Μορφή',
    'import_ofx' => 'Εισαγωγή OFX',
    'ofx_file' => 'Αρχείο OFX',
    'ofx_parse_failed' => 'Αποτυχία ανάλυσης του αρχείου OFX',

    // WePay
    'wepay' => 'WePay',
    'sign_up_with_wepay' => 'Εγγραφείτε στο WePay',
    'use_another_provider' => 'Χρησιμοποιήστε ένα άλλο provider',
    'company_name' => 'Όνομα Εταιρείας',
    'wepay_company_name_help' => 'Αυτό θα εμφανιστεί στην ανάλυση λογαριασμού της πιστωτικής κάρτας του πελάτη.',
    'wepay_description_help' => 'Ο σκοπός αυτού του λογαριασμού.',
    'wepay_tos_agree' => 'Συμφωνώ με το :link',
    'wepay_tos_link_text' => 'Όροι της Υπηρεσίας WePay',
    'resend_confirmation_email' => 'Νέα αποστολή Email Επιβεβαίωσης',
    'manage_account' => 'Διαχείριση Λογαριασμού',
    'action_required' => 'Απαιτείται Ενέργεια',
    'finish_setup' => 'Ολοκλήρωση Εγκατάστασης',
    'created_wepay_confirmation_required' => 'Παρακαλώ ελέγξτε το email σας και επιβεβαιώστε τη διεύθυνση email σας στο WePay.',
    'switch_to_wepay' => 'Εναλλαγή στο WePay',
    'switch' => 'Εναλλαγή',
    'restore_account_gateway' => 'Επαναφορά Πύλης Πληρωμών (Gateway)',
    'restored_account_gateway' => 'Επιτυχής επαναφορά πύλης πληρωμών (Gateway)',
    'united_states' => 'Ηνωμένες Πολιτείες',
    'canada' => 'Καναδάς',
    'accept_debit_cards' => 'Αποδοχή Χρεωστικών Καρτών',
    'debit_cards' => 'Χρεωστικές Κάρτες',

    'warn_start_date_changed' => 'Το επόμενο τιμολόγιο θα αποσταλεί την επόμενη ημερομηνία έναρξης.',
    'warn_start_date_changed_not_sent' => 'Το επόμενο τιμολόγιο θα δημιουργηθεί την επόμενη ημερομηνία έναρξης.',
    'original_start_date' => 'Αρχική ημερομηνία έναρξης',
    'new_start_date' => 'Νέα ημερομηνία έναρξης',
    'security' => 'Ασφάλεια',
    'see_whats_new' => 'Δείτε τι νέο υπάρχει στην έκδοση v:version',
    'wait_for_upload' => 'Παρακαλώ αναμείνατε να ολοκληρωθεί η μεταφόρτωση του εγγράφου',
    'upgrade_for_permissions' => 'Αναβαθμίστε στο Εταιρικό πλάνο για να ενεργοποιήσετε τα δικαιώματα.',
    'enable_second_tax_rate' => 'Ενεργοποίηση καθορισμού ενός <b>δεύτερου ποσοστού φόρου</b>',
    'payment_file' => 'Αρχείο Πληρωμής',
    'expense_file' => 'Αρχείο Δαπάνης',
    'product_file' => 'Αρχείο Προϊόντος',
    'import_products' => 'Εισαγωγή Προϊόντων',
    'products_will_create' => 'προϊόντα θα δημιουργηθούν',
    'product_key' => 'Προϊόν',
    'created_products' => 'Επιτυχής δημιουργία/ενημέρωση :count προϊόν(των)',
    'export_help' => 'Χρησιμοποιήστε JSON εάν σχεδιάζετε να εισάγετε δεδομένα στο Invoice Ninja.<br/>Το αρχείο περιλαμβάνει πελάτες, προϊόντα, τιμολόγια, προσφορές και πληρωμές.',
    'selfhost_export_help' => 'Προτείνουμε να χρησιμοποιήσετε το mysqldump για να δημιουργήσετε ένα πλήρες αντίγραφο.',
    'JSON_file' => 'Αρχείο JSON',

    'view_dashboard' => 'Εμφάνιση Πίνακα ελέγχου',
    'client_session_expired' => 'Η συνεδρία έληξε',
    'client_session_expired_message' => 'Η συνεδρία σας έληξε. Παρακαλώ κάντε κλικ ξανά στο σύνδεσμο που έχετε λάβει με email.',

    'auto_bill_notification' => 'Αυτό το τιμολόγιο θα χρεωθεί αυτόματα με τη μέθοδο :payment_method στο αρχείο την :due_date. ',
    'auto_bill_payment_method_bank_transfer' => 'τραπεζικός λογαριασμός',
    'auto_bill_payment_method_credit_card' => 'πιστωτική κάρτα',
    'auto_bill_payment_method_paypal' => 'Λογαριασμός PayPal',
    'auto_bill_notification_placeholder' => 'Αυτό το τιμολόγιο θα χρεωθεί αυτόματα στην πιστωτική σας κάρτα την ημερομηνία λήξης της. ',
    'payment_settings' => 'Ρυθμίσεις Πληρωμής',

    'on_send_date' => 'Στην ημερομηνία αποστολής',
    'on_due_date' => 'Στην ημερομηνία πληρωμής',
    'auto_bill_ach_date_help' => 'Το ACH θα χρεώνει αυτόματα στην ημερομηνία πληρωμής.',
    'warn_change_auto_bill' => 'Λόγω των κανόνων NACHA οι χρεώσεις σε αυτό το τιμολόγιο μπορεί να αποτρέψουν την αυτόματη χρέωση ACH',

    'bank_account' => 'Τραπεζικός Λογαριασμός',
    'payment_processed_through_wepay' => 'Οι πληρωμές ACH θα επεξεργαστούν με χρήση του WePay.',
    'wepay_payment_tos_agree' => 'Συμφωνώ με τους όρους :terms και την πολιτική απορρήτου :privacy_policy του WePay.',
    'privacy_policy' => 'Πολιτική Απορρήτου',
    'wepay_payment_tos_agree_required' => 'Πρέπει να συμφωνήσετε με τους Όρους Χρήσης και την Πολιτική Απορρήτου του WePay.',
    'ach_email_prompt' => 'Παρακαλώ καταχωρήστε την email διεύθυνσή σας:',
    'verification_pending' => 'Αναμονή Πιστοποίησης',

    'update_font_cache' => 'Παρακαλώ ανανεώστε τη σελίδα για να ενημερωθεί η γραμματοσειρά.',
    'more_options' => 'Περισσότερες επιλογές',
    'credit_card' => 'Πιστωτική Κάρτα',
    'bank_transfer' => 'Τραπεζικό Έμβασμα',
    'no_transaction_reference' => 'Δεν λάβαμε κάποιο αποδεικτικό συναλλαγής πληρωμής από αυτή την πύλη πληρωμών (Gateway).',
    'use_bank_on_file' => 'Χρήση του Bank on File',
    'auto_bill_email_message' => 'Αυτό το τιμολόγιο θα χρεωθεί αυτόματα στη μέθοδο πληρωμής την ημερομηνία λήξης του. ',
    'bitcoin' => 'Bitcoin',
    'gocardless' => 'GoCardless',
    'added_on' => 'Προστέθηκε :date',
    'failed_remove_payment_method' => 'Αποτυχία αφαίρεσης της μεθόδου πληρωμής',
    'gateway_exists' => 'Αυτή η πύλη πληρωμών (Gateway) υπάρχει ήδη',
    'manual_entry' => 'Χειροκίνητη εισαγωγή',
    'start_of_week' => 'Πρώτη Μέρα της Εβδομάδας',

    // Frequencies
    'freq_inactive' => 'Ανενεργό',
    'freq_daily' => 'Ημερήσιο',
    'freq_weekly' => 'Εβδομάδα',
    'freq_biweekly' => 'Ανά δύο εβδομάδες',
    'freq_two_weeks' => 'Δύο εβδομάδες',
    'freq_four_weeks' => 'Τέσσερις εβδομάδες',
    'freq_monthly' => 'Μήνας',
    'freq_three_months' => 'Τρεις μήνες',
    'freq_four_months' => 'Τέσσερις μήνες',
    'freq_six_months' => 'Έξι μήνες',
    'freq_annually' => 'Έτος',
    'freq_two_years' => 'Δύο χρόνια',

    // Payment types
    'payment_type_Apply Credit' => 'Εφαρμογή Πίστωσης',
    'payment_type_Bank Transfer' => 'Τραπεζικό Έμβασμα',
    'payment_type_Cash' => 'Μετρητά',
    'payment_type_Debit' => 'Χρέωση',
    'payment_type_ACH' => 'ACH',
    'payment_type_Visa Card' => 'Visa Card',
    'payment_type_MasterCard' => 'MasterCard',
    'payment_type_American Express' => 'American Express',
    'payment_type_Discover Card' => 'Discover Card',
    'payment_type_Diners Card' => 'Diners Card',
    'payment_type_EuroCard' => 'EuroCard',
    'payment_type_Nova' => 'Nova',
    'payment_type_Credit Card Other' => 'Άλλη πιστωτική κάρτα',
    'payment_type_PayPal' => 'PayPal',
    'payment_type_Google Wallet' => 'Google Wallet',
    'payment_type_Check' => 'Επιταγή',
    'payment_type_Carte Blanche' => 'Carte Blanche',
    'payment_type_UnionPay' => 'UnionPay',
    'payment_type_JCB' => 'JCB',
    'payment_type_Laser' => 'Laser',
    'payment_type_Maestro' => 'Maestro',
    'payment_type_Solo' => 'Solo',
    'payment_type_Switch' => 'Εναλλαγή',
    'payment_type_iZettle' => 'iZettle',
    'payment_type_Swish' => 'Swish',
    'payment_type_Alipay' => 'Alipay',
    'payment_type_Sofort' => 'Sofort',
    'payment_type_SEPA' => 'Απευθείας πίστωση SEPA',
    'payment_type_Bitcoin' => 'Bitcoin',
    'payment_type_GoCardless' => 'GoCardless',
    'payment_type_Zelle' => 'Zelle',

    // Industries
    'industry_Accounting & Legal' => 'Λογιστικά & Νομικά',
    'industry_Advertising' => 'Διαφημίσεις',
    'industry_Aerospace' => 'Αεροπορία',
    'industry_Agriculture' => 'Γεωργία',
    'industry_Automotive' => 'Αυτοκίνητα',
    'industry_Banking & Finance' => 'Τραπεζική & Οικονομικά',
    'industry_Biotechnology' => 'Βιοτεχνολογία',
    'industry_Broadcasting' => 'Ραδιοτηλεόραση',
    'industry_Business Services' => 'Υπηρεσίες Επιχειρήσεων',
    'industry_Commodities & Chemicals' => 'Εμπορεύματα & Χημικά',
    'industry_Communications' => 'Τηλεπικοινωνίες',
    'industry_Computers & Hightech' => 'Υπολογιστές & Τεχνολογία',
    'industry_Defense' => 'Άμυνα',
    'industry_Energy' => 'Ενέργεια',
    'industry_Entertainment' => 'Διασκέδαση',
    'industry_Government' => 'Κυβερνηση',
    'industry_Healthcare & Life Sciences' => 'Περίθαλψη & Επιστήμες Υγείας',
    'industry_Insurance' => 'Ασφάλειες',
    'industry_Manufacturing' => 'Βιομηχανία',
    'industry_Marketing' => 'Marketing',
    'industry_Media' => 'Μέσα Ενημέρωσης',
    'industry_Nonprofit & Higher Ed' => 'Μη Κερδοσκοπική',
    'industry_Pharmaceuticals' => 'Φάρμακα',
    'industry_Professional Services & Consulting' => 'Υπηρεσίες & Συμβουλευτική',
    'industry_Real Estate' => 'Κτηματομεσιτικά',
    'industry_Restaurant & Catering' => 'Εστιατόριο & Catering',
    'industry_Retail & Wholesale' => 'Λιανικό & Χονδρικό Εμπόριο',
    'industry_Sports' => 'Αθλητισμός',
    'industry_Transportation' => 'Μεταφορά',
    'industry_Travel & Luxury' => 'Ταξίδια & Ανέσεις',
    'industry_Other' => 'Άλλο',
    'industry_Photography' => 'Φωτογραφία',

    // Countries
    'country_Afghanistan' => 'Αφγανιστάν',
    'country_Albania' => 'Αλβανία',
    'country_Antarctica' => 'Ανταρκτική',
    'country_Algeria' => 'Αλγερία',
    'country_American Samoa' => 'Αμερικανική Σαμόα',
    'country_Andorra' => 'Ανδόρα',
    'country_Angola' => 'Αγκόλα',
    'country_Antigua and Barbuda' => 'Antigua and Barbuda',
    'country_Azerbaijan' => 'Αζερμπαϊτζάν',
    'country_Argentina' => 'Αργεντινή',
    'country_Australia' => 'Αυστραλία',
    'country_Austria' => 'Αυστρία',
    'country_Bahamas' => 'Μπαχάμες',
    'country_Bahrain' => 'Μπαχρέιν',
    'country_Bangladesh' => 'Μπαγκλαντές',
    'country_Armenia' => 'Αρμενία',
    'country_Barbados' => 'Μπαρμπάντος ',
    'country_Belgium' => 'Βέλγιο',
    'country_Bermuda' => 'Βερμούδες',
    'country_Bhutan' => 'Μπρουτάν',
    'country_Bolivia, Plurinational State of' => 'Βολιβία',
    'country_Bosnia and Herzegovina' => 'Βοσνία - Ερζεγοβίνη',
    'country_Botswana' => 'Μποτσουάνα',
    'country_Bouvet Island' => 'Νησί Μπουβέτ',
    'country_Brazil' => 'Βραζιλία',
    'country_Belize' => 'Μπελίζ',
    'country_British Indian Ocean Territory' => 'Βρετανική Ινδία',
    'country_Solomon Islands' => 'Νησιά του Σολομώντα',
    'country_Virgin Islands, British' => 'Βρετανικοί Παρθένοι Νήσοι',
    'country_Brunei Darussalam' => 'Μπρουνέι',
    'country_Bulgaria' => 'Βουλγαρία',
    'country_Myanmar' => 'Νιαμάρ',
    'country_Burundi' => 'Μπουρουντί',
    'country_Belarus' => 'Λευκορωσία',
    'country_Cambodia' => 'Καμπότζη',
    'country_Cameroon' => 'Καμερούν',
    'country_Canada' => 'Καναδάς',
    'country_Cape Verde' => 'Πράσινο Ακρωτήρι',
    'country_Cayman Islands' => 'Νησιά Cayman',
    'country_Central African Republic' => 'Κεντρική Αφρικανική Δημοκρατία',
    'country_Sri Lanka' => 'Σρι Λάνκα',
    'country_Chad' => 'Τσαντ',
    'country_Chile' => 'Χιλή',
    'country_China' => 'Κίνα',
    'country_Taiwan, Province of China' => 'Ταϊβάν',
    'country_Christmas Island' => 'Νησί Χριστουγέννων',
    'country_Cocos (Keeling) Islands' => 'Νησιά Cocos (Keeling)',
    'country_Colombia' => 'Κολομβία',
    'country_Comoros' => 'Κομόρος',
    'country_Mayotte' => 'Μαγιότ',
    'country_Congo' => 'Κονγκό',
    'country_Congo, the Democratic Republic of the' => 'Δημοκρατία του Κονγκό',
    'country_Cook Islands' => 'Νησία Cook',
    'country_Costa Rica' => 'Κόστα Ρίκα',
    'country_Croatia' => 'Κροατία',
    'country_Cuba' => 'Κούβα',
    'country_Cyprus' => 'Κύπρος',
    'country_Czech Republic' => 'Τσεχία',
    'country_Benin' => 'Μπενίν',
    'country_Denmark' => 'Δανία',
    'country_Dominica' => 'Δομίνικος',
    'country_Dominican Republic' => 'Δομινικανή Δημοκρατία',
    'country_Ecuador' => 'Εκουαδόρ',
    'country_El Salvador' => 'El Salvador',
    'country_Equatorial Guinea' => 'Γουινέα',
    'country_Ethiopia' => 'Αιθιοπία',
    'country_Eritrea' => 'Εριθρεά',
    'country_Estonia' => 'Εστονία',
    'country_Faroe Islands' => 'Νησία Faroe',
    'country_Falkland Islands (Malvinas)' => 'Νησιά Φόκλαντ',
    'country_South Georgia and the South Sandwich Islands' => 'Βόρεια Γεωργία',
    'country_Fiji' => 'Φίτζι',
    'country_Finland' => 'Φιλανδία',
    'country_Åland Islands' => 'Νησιά Αλάντ',
    'country_France' => 'Γαλλία',
    'country_French Guiana' => 'Γαλλική Γουιάνα',
    'country_French Polynesia' => 'Γαλλική Πολυνησία',
    'country_French Southern Territories' => 'Γαλλικές Βόρειες περιοχές',
    'country_Djibouti' => 'Τζιμπουτί',
    'country_Gabon' => 'Γκαμπόν',
    'country_Georgia' => 'Γεωργία',
    'country_Gambia' => 'Γκάμπια',
    'country_Palestinian Territory, Occupied' => 'Παλαιστίνη',
    'country_Germany' => 'Γερμανία',
    'country_Ghana' => 'Γκάνα',
    'country_Gibraltar' => 'Γιβλαρτάρ',
    'country_Kiribati' => 'Κιριμπάτι',
    'country_Greece' => 'Ελλάδα',
    'country_Greenland' => 'Γροιλανδία',
    'country_Grenada' => 'Γκρενάδα',
    'country_Guadeloupe' => 'Γουαδελούπη',
    'country_Guam' => 'Γκουάμ',
    'country_Guatemala' => 'Γουατεμάλα',
    'country_Guinea' => 'Γουινέα',
    'country_Guyana' => 'Γουιάνα',
    'country_Haiti' => 'Αϊτή',
    'country_Heard Island and McDonald Islands' => 'Νησιά McDonalds',
    'country_Holy See (Vatican City State)' => 'Βατικάνό',
    'country_Honduras' => 'Ονδούρα',
    'country_Hong Kong' => 'Χονκ Κονκ',
    'country_Hungary' => 'Ουγκαρία',
    'country_Iceland' => 'Ισλανδία',
    'country_India' => 'Ινδία',
    'country_Indonesia' => 'Ινδονησία',
    'country_Iran, Islamic Republic of' => 'Ιράν',
    'country_Iraq' => 'Ιράκ',
    'country_Ireland' => 'Ιρλανδία',
    'country_Israel' => 'Ισραήλ',
    'country_Italy' => 'Ιταλία',
    'country_Côte d\'Ivoire' => 'Ακτή Ελεφαντοστού',
    'country_Jamaica' => 'Τζαμάικα',
    'country_Japan' => 'Ιαπωνία',
    'country_Kazakhstan' => 'Καζακστάν',
    'country_Jordan' => 'Ιορδανία',
    'country_Kenya' => 'Κένυα',
    'country_Korea, Democratic People\'s Republic of' => 'Βόρεια Κορέα',
    'country_Korea, Republic of' => 'Νότια Κορέα',
    'country_Kuwait' => 'Κουβέιτ',
    'country_Kyrgyzstan' => 'Κιργιστάν',
    'country_Lao People\'s Democratic Republic' => 'Λάος',
    'country_Lebanon' => 'Λίβανος',
    'country_Lesotho' => 'Λεσόθο',
    'country_Latvia' => 'Λετονία',
    'country_Liberia' => 'Λιβερία',
    'country_Libya' => 'Λιβύη',
    'country_Liechtenstein' => 'Λιχνεστάιν',
    'country_Lithuania' => 'Λιθουανία',
    'country_Luxembourg' => 'Λουξεμβούργο',
    'country_Macao' => 'Μακάο',
    'country_Madagascar' => 'Μαδαγασκάρη',
    'country_Malawi' => 'Μαλάουι',
    'country_Malaysia' => 'Μαλαισία',
    'country_Maldives' => 'Μαλδίβες',
    'country_Mali' => 'Μάλι',
    'country_Malta' => 'Μάλτα',
    'country_Martinique' => 'Μαρτινίκα',
    'country_Mauritania' => 'Μαβριτανία',
    'country_Mauritius' => 'Μαυρίκιος',
    'country_Mexico' => 'Μεξικό',
    'country_Monaco' => 'Μονακό',
    'country_Mongolia' => 'Μογκολία',
    'country_Moldova, Republic of' => 'Μολδαβία',
    'country_Montenegro' => 'Μαυροβούνιο',
    'country_Montserrat' => 'Μονσεράτ',
    'country_Morocco' => 'Μαρόκο',
    'country_Mozambique' => 'Μοζαμβίκη',
    'country_Oman' => 'Ομάν',
    'country_Namibia' => 'Ναμίμπια',
    'country_Nauru' => 'Ναουρού',
    'country_Nepal' => 'Νεπάλ',
    'country_Netherlands' => 'Ολλανδία',
    'country_Curaçao' => 'Κουρακάο',
    'country_Aruba' => 'Αρούμπα',
    'country_Sint Maarten (Dutch part)' => 'Άριος Μαρτίνος (Ολλανδία)',
    'country_Bonaire, Sint Eustatius and Saba' => 'Άγιος Ευστάθιος',
    'country_New Caledonia' => 'Νέα Καλιδονία',
    'country_Vanuatu' => 'Βατουάτου',
    'country_New Zealand' => 'Νέα Ζηλανδία',
    'country_Nicaragua' => 'Νικαράγουα',
    'country_Niger' => 'Νίγρας',
    'country_Nigeria' => 'Νιγηρία',
    'country_Niue' => 'Νίου',
    'country_Norfolk Island' => 'Νησία Norfolk',
    'country_Norway' => 'Νορβηγία',
    'country_Northern Mariana Islands' => 'Νησιά Βόρειας Μαριάννας',
    'country_United States Minor Outlying Islands' => 'Νησιά Ηνωμένων Πολιτειών',
    'country_Micronesia, Federated States of' => 'Μικρονησία',
    'country_Marshall Islands' => 'Νησιά Marshall',
    'country_Palau' => 'Παλάου',
    'country_Pakistan' => 'Πακιστάν',
    'country_Panama' => 'Παναμάς',
    'country_Papua New Guinea' => 'Παπούα',
    'country_Paraguay' => 'Παραγουάη',
    'country_Peru' => 'Περού',
    'country_Philippines' => 'Φιλιπίνες',
    'country_Pitcairn' => 'Πιτκέρν',
    'country_Poland' => 'Πολωνία',
    'country_Portugal' => 'Πορτογαλία',
    'country_Guinea-Bissau' => 'Μπισάου',
    'country_Timor-Leste' => 'Τιμόρ',
    'country_Puerto Rico' => 'Πόρτο Ρίκο',
    'country_Qatar' => 'Κατάρ',
    'country_Réunion' => 'Ρεγιούνιον',
    'country_Romania' => 'Ρουμανία',
    'country_Russian Federation' => 'Ρωσία',
    'country_Rwanda' => 'Ρουάντα',
    'country_Saint Barthélemy' => 'Άγιος Βαρθολομαίος',
    'country_Saint Helena, Ascension and Tristan da Cunha' => 'Τριστάν',
    'country_Saint Kitts and Nevis' => 'Νέβις',
    'country_Anguilla' => 'Ανγκουίλα',
    'country_Saint Lucia' => 'Αγία Λουκία',
    'country_Saint Martin (French part)' => 'Άγιος Μαρτίνος (Γαλλία)',
    'country_Saint Pierre and Miquelon' => 'Άγιος Πέτρος',
    'country_Saint Vincent and the Grenadines' => 'Γρεναδίνη',
    'country_San Marino' => 'Σαν Μαρίνο',
    'country_Sao Tome and Principe' => 'Άγιος Θωμάς',
    'country_Saudi Arabia' => 'Σαουδική Αραβία',
    'country_Senegal' => 'Σενεγάλη',
    'country_Serbia' => 'Σερβία',
    'country_Seychelles' => 'Σευχέλες',
    'country_Sierra Leone' => 'Σιέρρα Λεόνε',
    'country_Singapore' => 'Σινγκαπούρη',
    'country_Slovakia' => 'Σλοβακία',
    'country_Viet Nam' => 'Βιετνάμ',
    'country_Slovenia' => 'Σλοβενία',
    'country_Somalia' => 'Σομαλία',
    'country_South Africa' => 'Νότια Αφρική',
    'country_Zimbabwe' => 'Σιμπάμπουε',
    'country_Spain' => 'Ισπανία',
    'country_South Sudan' => 'Νότιο Σουδάν',
    'country_Sudan' => 'Σουδάν',
    'country_Western Sahara' => 'Δυτική Σαχάρα',
    'country_Suriname' => 'Σουρινάμ',
    'country_Svalbard and Jan Mayen' => 'Σβαλμπάντ',
    'country_Swaziland' => 'Σουαζουάλη',
    'country_Sweden' => 'Σουηδία',
    'country_Switzerland' => 'Ελβετία',
    'country_Syrian Arab Republic' => 'Συρία',
    'country_Tajikistan' => 'Τατζικιστάν',
    'country_Thailand' => 'ταιλάνδη',
    'country_Togo' => 'Τογκό',
    'country_Tokelau' => 'Τοκελάου',
    'country_Tonga' => 'Τόνγκα',
    'country_Trinidad and Tobago' => 'Τρινιντάντ Τομπάκο',
    'country_United Arab Emirates' => 'Αραβικά Εμιράτα',
    'country_Tunisia' => 'Τηνυσία',
    'country_Turkey' => 'Τουρκία',
    'country_Turkmenistan' => 'Τουρμπεκιστάν',
    'country_Turks and Caicos Islands' => 'Νησιά Caicos',
    'country_Tuvalu' => 'Τουβαλού',
    'country_Uganda' => 'Ουγκάντα',
    'country_Ukraine' => 'Ουκρανία',
    'country_Macedonia, the former Yugoslav Republic of' => 'Σκόπια',
    'country_Egypt' => 'Αίγυπτος',
    'country_United Kingdom' => 'Αγγλία',
    'country_Guernsey' => 'Γουερνσέυ',
    'country_Jersey' => 'Τζέρσεϊ',
    'country_Isle of Man' => 'Νησί του Πάσχα',
    'country_Tanzania, United Republic of' => 'Ταζμανία',
    'country_United States' => 'Ηνωμένες Πολιτείες',
    'country_Virgin Islands, U.S.' => 'Παρθένοι Νήσοι',
    'country_Burkina Faso' => 'Μπουργκίνα Φάσο',
    'country_Uruguay' => 'Ουρουγουάη',
    'country_Uzbekistan' => 'Ουζμπεκιστάν',
    'country_Venezuela, Bolivarian Republic of' => 'Βενεζουέλα',
    'country_Wallis and Futuna' => 'Ουάλις',
    'country_Samoa' => 'Σαμόα',
    'country_Yemen' => 'Υεμένη',
    'country_Zambia' => 'Ζάμπια',

    // Languages
    'lang_Brazilian Portuguese' => 'Πορτογαλικά Βραζιλίας',
    'lang_Croatian' => 'Κροατικά',
    'lang_Czech' => 'Τσέχικα',
    'lang_Danish' => 'Δανικά',
    'lang_Dutch' => 'Ολλανδικά',
    'lang_English' => 'Αγγλικά',
    'lang_French' => 'Γαλλικά',
    'lang_French - Canada' => 'Γαλλικά Καναδά',
    'lang_German' => 'Γερμανικά',
    'lang_Italian' => 'Ιταλικά',
    'lang_Japanese' => 'Ιαπωνικά',
    'lang_Lithuanian' => 'Λιθουανικά',
    'lang_Norwegian' => 'Νορβηγικά',
    'lang_Polish' => 'Πολωνικά',
    'lang_Spanish' => 'Ισπανικά',
    'lang_Spanish - Spain' => 'Ισπανικά Ισπανίας',
    'lang_Swedish' => 'Σουηδικά',
    'lang_Albanian' => 'Αλβανικά',
    'lang_Greek' => 'Ελληνικά',
    'lang_English - United Kingdom' => 'Αγγλικά - Ηνωμένο Βασίλειο',
    'lang_English - Australia' => 'Αγγλικά - Αυστραλία',
    'lang_Slovenian' => 'Σλοβένικά',
    'lang_Finnish' => 'Φινλανδικά',
    'lang_Romanian' => 'Ρουμάνικα',
    'lang_Turkish - Turkey' => 'Τουρκικά - Τουρκία',
    'lang_Portuguese - Brazilian' => 'Πορτογαλικά - Βραζιλία',
    'lang_Portuguese - Portugal' => 'Πορτογαλικά - Πορτογαλία',
    'lang_Thai' => 'Ταϊλανδέζικα',
    'lang_Macedonian' => 'Μακεδονικά',
    'lang_Chinese - Taiwan' => 'Κινέζικα Ταϊβάν',
    'lang_Serbian' => 'Σέρβικα',
    'lang_Bulgarian' => 'Βουλγάρικα',
    'lang_Russian' => 'Russian',

    // Industries
    'industry_Accounting & Legal' => 'Λογιστικά & Νομικά',
    'industry_Advertising' => 'Διαφημίσεις',
    'industry_Aerospace' => 'Αεροπορία',
    'industry_Agriculture' => 'Γεωργία',
    'industry_Automotive' => 'Αυτοκίνητα',
    'industry_Banking & Finance' => 'Τραπεζική & Οικονομικά',
    'industry_Biotechnology' => 'Βιοτεχνολογία',
    'industry_Broadcasting' => 'Ραδιοτηλεόραση',
    'industry_Business Services' => 'Υπηρεσίες Επιχειρήσεων',
    'industry_Commodities & Chemicals' => 'Εμπορεύματα & Χημικά',
    'industry_Communications' => 'Τηλεπικοινωνίες',
    'industry_Computers & Hightech' => 'Υπολογιστές & Τεχνολογία',
    'industry_Defense' => 'Άμυνα',
    'industry_Energy' => 'Ενέργεια',
    'industry_Entertainment' => 'Διασκέδαση',
    'industry_Government' => 'Κυβερνηση',
    'industry_Healthcare & Life Sciences' => 'Περίθαλψη & Επιστήμες Υγείας',
    'industry_Insurance' => 'Ασφάλειες',
    'industry_Manufacturing' => 'Βιομηχανία',
    'industry_Marketing' => 'Marketing',
    'industry_Media' => 'Μέσα Ενημέρωσης',
    'industry_Nonprofit & Higher Ed' => 'Μη Κερδοσκοπική',
    'industry_Pharmaceuticals' => 'Φάρμακα',
    'industry_Professional Services & Consulting' => 'Υπηρεσίες & Συμβουλευτική',
    'industry_Real Estate' => 'Κτηματομεσιτικά',
    'industry_Retail & Wholesale' => 'Λιανικό & Χονδρικό Εμπόριο',
    'industry_Sports' => 'Αθλητισμός',
    'industry_Transportation' => 'Μεταφορά',
    'industry_Travel & Luxury' => 'Ταξίδια & Ανέσεις',
    'industry_Other' => 'Άλλο',
    'industry_Photography' => 'Φωτογραφία',

    'view_client_portal' => 'Προβολή portal πελάτη',
    'view_portal' => 'Προβολή portal',
    'vendor_contacts' => 'Επαφές Προμηθευτών',
    'all' => 'Όλα',
    'selected' => 'Επιλεγμένο',
    'category' => 'Κατηγορία',
    'categories' => 'Κατηγορίες',
    'new_expense_category' => 'Νέα Κατηγορία Δαπανών',
    'edit_category' => 'Επεξεργα',
    'archive_expense_category' => 'Αρχειοθέτηση Κατηγορίας',
    'expense_categories' => 'Κατηγορίες Δαπάνης',
    'list_expense_categories' => 'Λίστα Κατηγοριών Δαπάνης',
    'updated_expense_category' => 'Επιτυχής ενημέρωση κατηγορίας δαπανών',
    'created_expense_category' => 'Επιτυχής δημιουργία κατηγορίας δαπανών',
    'archived_expense_category' => 'Επιτυχής αρχειοθέτηση κατηγορίας δαπανών',
    'archived_expense_categories' => 'Επιτυχής αρχειοθέτηση :count κατηγορίας δαπανών',
    'restore_expense_category' => 'Επαναφορά κατηγορίας δαπανών',
    'restored_expense_category' => 'Επιτυχής επαναφορά κατηγορίας δαπανών',
    'apply_taxes' => 'Εφαρμογή φόρων',
    'min_to_max_users' => ':min έως :max χρήστες',
    'max_users_reached' => 'Έχετε φτάσει το μέγιστο αριθμό χρηστών.',
    'buy_now_buttons' => 'Κουμπιά Αγορά Τώρα',
    'landing_page' => 'Σελίδα Εισόδου',
    'payment_type' => 'Τύπος Πληρωμής',
    'form' => 'Φόρμα',
    'link' => 'Σύνδεσμος',
    'fields' => 'Πεδία',
    'dwolla' => 'Dwolla',
    'buy_now_buttons_warning' => 'Σημείωση: εγγραφές πελατών και τιμολογίων δημιουργούνται ακόμα και αν η συναλλαγή δεν ολοκληρωθεί.',
    'buy_now_buttons_disabled' => 'Αυτό το χαρακτηριστικό προϋποθέτει ότι το προϊόν έχει ήδη δημιουργηθεί και ότι έχει ρυθμιστεί η πύλη πληρωμών (Gateway).',
    'enable_buy_now_buttons_help' => 'Ενεργοποίηση υποστήριξης για τα κουμπιά Αγορά Τώρα',
    'changes_take_effect_immediately' => 'Σημείωση: οι αλλαγές ενεργοποιούνται άμεσα',
    'wepay_account_description' => 'Πύλη Πληρωμών (Gateway) για το Invoice Ninja',
    'payment_error_code' => 'Προέκυψε ένα σφάλμα κατά τη διαδικασία της πληρωμής [:code]. Παρακαλώ, δοκιμάστε ξανά σε λίγο.',
    'standard_fees_apply' => 'Τέλος: 2.9%/1.2% [Πιστωτική Κάρτα/Τραπεζικό Λογαριασμό] + $0.30 ανά επιτυχημένη χρέωση.',
    'limit_import_rows' => 'Τα δεδομένα πρέπει να εισαχθούν σε ομάδες των :count ή λιγότερων σειρών',
    'error_title' => 'Κάτι πήγε στραβά',
    'error_contact_text' => 'Αν θα θέλατε βοήθεια, παρακαλώ στείλτε μας email στη διεύθυνση :mailaddress',
    'no_undo' => 'Προειδοποίηση: αυτό δε μπορεί να αναιρεθεί.',
    'no_contact_selected' => 'Παρακαλώ επιλέξτε επαφή',
    'no_client_selected' => 'Παρακαλώ επιλέξτε πελάτη',

    'gateway_config_error' => 'Μπορεί να βοηθήσει εάν ορίσετε νέους κωδικούς πρόσβασης ή δημιουργήσετε νέα κλειδιά API.',
    'payment_type_on_file' => ':type σε αρχείο',
    'invoice_for_client' => 'Τιμολόγιο :invoice για :client',
    'intent_not_found' => 'Λυπάμαι, αλλά δεν καταλαβαίνω τι ρωτάτε.',
    'intent_not_supported' => 'Λυπάμαι, αλλά δεν μπορώ να το κάνω αυτό.',
    'client_not_found' => 'Δεν μπόρεσα να βρω τον πελάτη',
    'not_allowed' => 'Λυπάμαι, δεν έχετε την απαραίτητη πρόσβαση',
    'bot_emailed_invoice' => 'Το τιμολόγιό σας έχει αποσταλεί,',
    'bot_emailed_notify_viewed' => 'Θα σας στείλω email μόλις εμφανιστεί.',
    'bot_emailed_notify_paid' => 'Θα σας στείλω email μόλις πληρωθεί.',
    'add_product_to_invoice' => 'Προσθήκη 1 :product',
    'not_authorized' => 'Δεν είστε εξουσιοδοτημένος.',
    'bot_get_email' => 'Γειά! (wave)<br/>Ευχαριστώ που δοκιμάσατε τον αυτοματισμό του Invoice Ninja.<br/>Θα πρέπει να δημιουργήσετε ένα δωρεάν λογαριασμό για να χρησιμοποιήσετε αυτό τον αυτοματισμό.<br/>Στείλτε μου την διεύθυνση email σας για να ξεκινήσετε.',
    'bot_get_code' => 'Ευχαριστούμε! Σας στείλαμε ένα email με τον κωδικό ασφαλείας.',
    'bot_welcome' => 'Δηλαδή, ο λογαριασμός σας είναι επικυρωμένος.<br/>',
    'email_not_found' => 'Δεν μπόρεσα να βρω ένα διαθέσιμο λογαριασμό για :email',
    'invalid_code' => 'Ο κωδικός δεν είναι σωστός',
    'security_code_email_subject' => 'Κωδικός ασφαλείας για τον αυτοματισμό Invoice Ninja',
    'security_code_email_line1' => 'Αυτός είναι ο κωδικός ασφαλείας για τον αυτοματισμό Invoice Ninja',
    'security_code_email_line2' => 'Σημείωση: θα λήξει σε 10 λεπτά.',
    'bot_help_message' => 'Αυτή τη στιγμή υποστηρίζεται:<br/>• Δημιουργία\ενημέρωση\αποστολή με email ενός τιμολογίου<br/>• Λίστα προϊόντων<br/>Για παράδειγμα:<br/><i>τιμολογήστε τον Μπομπ για 2 εισιτήρια, ορίστε την ημερομηνία λήξης την επόμενη Τρίτη και την έκπτωση σε 10 τοις εκατό</i>',
    'list_products' => 'Λίστα Προϊόντων',

    'include_item_taxes_inline' => 'Περιέλαβε <b>φόρο ανά προϊόν σε κάθε γραμμή</b>',
    'created_quotes' => 'Επιτυχής δημιουργία :count προσφοράς(ών)',
    'limited_gateways' => 'Σημείωση: υποστηρίζουμε μία πύλη πληρωμών (Gateway) πιστωτικών καρτών ανά εταιρεία.',

    'warning' => 'Ειδοποίηση',
    'self-update' => 'Ενημέρωση',
    'update_invoiceninja_title' => 'Ενημέρωση Invoice Ninja',
    'update_invoiceninja_warning' => 'Πριν αρχίσετε την αναβάθμιση του Invoice Ninja, δημιουργήστε ένα αντίγραφο ασφαλείας της βάσης δεδομένων και των αρχείων!',
    'update_invoiceninja_available' => 'Υπάρχει διαθέσιμη νεότερη έκδοση του Invoice Ninja.',
    'update_invoiceninja_unavailable' => 'Δεν υπάρχει νεότερη έκδοση του Invoice Ninja διαθέσιμη.',
    'update_invoiceninja_instructions' => 'Παρακαλώ εγκαταστήστε τη νέα έκδοση <strong>:version</strong> κάνοντας κλικ στο κουμπί  <em>Αναβαθμίστε τώρα</em> παρακάτω. Μετά θα μεταφερθείτε στον πίνακα ελέγχου.',
    'update_invoiceninja_update_start' => 'Ενημέρωση Τώρα',
    'update_invoiceninja_download_start' => 'Κατέβασμα :version',
    'create_new' => 'Δημιουργία Νέου',

    'toggle_navigation' => 'Εναλλαγή Πλοήγησης',
    'toggle_history' => 'Εναλλαγή Ιστορικού',
    'unassigned' => 'Δεν έχει ανατεθεί',
    'task' => 'Εργασία',
    'contact_name' => 'Όνομα Επαφής',
    'city_state_postal' => 'Πόλη/Νομός/Τ.Κ.',
    'custom_field' => 'Προσαρμοσμένο Πεδίο',
    'account_fields' => 'Πεδία Εταιρείας',
    'facebook_and_twitter' => 'Facebook και Twitter',
    'facebook_and_twitter_help' => 'Ακολουθήστε τη ροή μας για να υποστηρίξετε το project μας',
    'reseller_text' => 'Σημείωση: Η άδεια χρήσης λευκής ετικέτας αφορά προσωπική χρήση, παρακαλώ στείλτε μας email στο :email εάν θέλετε να μεταπωλήσετε την εφαρμογή μας.',
    'unnamed_client' => 'Ανώνυμος Πελάτης',

    'day' => 'Ημέρα',
    'week' => 'Εβδομάδα',
    'month' => 'Μήνας',
    'inactive_logout' => 'Έχετε αποσυνδεθεί λόγω αδράνειας',
    'reports' => 'Αναφορές',
    'total_profit' => 'Συνολικά Κέρδη',
    'total_expenses' => 'Συνολικές Δαπάνες',
    'quote_to' => 'Προσφορά προς',

    // Limits
    'limit' => 'Όριο',
    'min_limit' => 'Ελάχιστο: :min',
    'max_limit' => 'Μέγιστο: :max',
    'no_limit' => 'Χωρίς Όριο',
    'set_limits' => 'Καθορισμός Ορίων :gateway_type',
    'enable_min' => 'Ενεργοποίηση ελάχιστου',
    'enable_max' => 'Ενεργοποίηση μέγιστου',
    'min' => 'Ελάχιστο',
    'max' => 'Μέγιστο',
    'limits_not_met' => 'Αυτό το τιμολόγιο δεν συμφωνεί με τα όριο αυτού του τύπου πληρωμών',

    'date_range' => 'Εύρος Ημερομηνιών',
    'raw' => 'Ακατέργαστο',
    'raw_html' => 'Ακατέργαστη HTML',
    'update' => 'Ενημέρωση',
    'invoice_fields_help' => 'Σύρετε και εναποθέστε πεδία για να αλλάξετε την σειρά και την θέση τους',
    'new_category' => 'Νέα Κατηγορία',
    'restore_product' => 'Ανάκτηση Προϊόντος',
    'blank' => 'Κενό',
    'invoice_save_error' => 'Προέκυψε ένα σφάλμα κατά τη διαδικασία αποθήκευσης του τιμολογίου σας',
    'enable_recurring' => 'Ενεργοποίηση επαναλαμβανόμενου',
    'disable_recurring' => 'Απενεργοποίηση επαναλαμβανόμενου',
    'text' => 'Κείμενο',
    'expense_will_create' => 'δαπάνη θα δημιουργηθεί',
    'expenses_will_create' => 'δαπάνες θα δημιουργηθούν',
    'created_expenses' => 'Επιτυχής δημιουργία :count δαπάνης(ών)',

    'translate_app' => 'Βοηθήστε να βελτιώσουμε τις μεταφράσεις μας με το :link',
    'expense_category' => 'Κατηγορία Δαπάνης',

    'go_ninja_pro' => 'Πήγαινε στην Επαγγελματική έκδοση Ninja',
    'go_enterprise' => 'Πηγαίντε στο Εταιρικό!',
    'upgrade_for_features' => 'Αναβαθμίστε Για Περισσότερα Χαρακτηριστικά',
    'pay_annually_discount' => 'Πληρώστε ανά έτος για 10 μήνες + 2 μήνες δωρεάν!',
    'pro_upgrade_title' => 'Επαγγελματική έκδοση Ninja',
    'pro_upgrade_feature1' => 'YourBrand.InvoiceNinja.com',
    'pro_upgrade_feature2' => 'Προσαρμόστε κάθε παράμετρο του Τιμολογίου σας!',
    'enterprise_upgrade_feature1' => 'Ορίστε δικαιώματα για πολλαπλούς χρήστες',
    'enterprise_upgrade_feature2' => 'Επισυνάψτε αρχεία τρίτων στα τιμολόγια και τις δαπάνες',
    'much_more' => 'Πολύ Περισσότερα!',
    'all_pro_fetaures' => 'Με επιπλέον όλα τα επαγγελματικά χαρακτηριστικά',

    'currency_symbol' => 'Σύμβολο',
    'currency_code' => 'Κωδικός',

    'buy_license' => 'Αγορά Άδειας Χρήσης',
    'apply_license' => 'Εφαρμογή Άδειας Χρήσης',
    'submit' => 'Υποβολή',
    'white_label_license_key' => 'Κλειδί Άδειας Χρήσης',
    'invalid_white_label_license' => 'Η άδεια χρήσης λευκής ετικέτας δεν είναι έγκυρη',
    'created_by' => 'Δημιουργήθηκε από :name',
    'modules' => 'Ενότητες',
    'financial_year_start' => 'Πρώτος Μήνας του Έτους',
    'authentication' => 'Πιστοποίηση',
    'checkbox' => 'Κουτάκι',
    'invoice_signature' => 'Υπογραφή',
    'show_accept_invoice_terms' => 'Κουτάκι Όρων Τιμολογίου',
    'show_accept_invoice_terms_help' => 'Απαίτηση από τον πελάτη να αποδεχθεί τους όρους του τιμολογίου',
    'show_accept_quote_terms' => 'Κουτάκι Όρων Προσφοράς',
    'show_accept_quote_terms_help' => 'Απαίτηση από τον πελάτη να αποδεχθεί τους όρους της προσφοράς',
    'require_invoice_signature' => 'Υπογραφή Τιμολογίου',
    'require_invoice_signature_help' => 'Απαίτηση από τον πελάτη να συμπληρώσει την υπογραφή του.',
    'require_quote_signature' => 'Υπογραφή Προσφοράς',
    'require_quote_signature_help' => 'Απαίτηση από τον πελάτη να συμπληρώσει την υπογραφή του.',
    'i_agree' => 'Συμφωνώ με τους Όρους',
    'sign_here' => 'Παρακαλώ υπογράψτε εδώ:',
    'authorization' => 'Εξουσιοδότηση',
    'signed' => 'Υπογεγραμμένο',

    // BlueVine
    'bluevine_promo' => 'Δεχθείτε ευέλικτες πιστωτικές λύσεις και factoring τιμολογίων με χρήση της BlueVine.',
    'bluevine_modal_label' => 'Εγγραφείτε στη BlueVine',
    'bluevine_modal_text' => '<h3>Γρήγορη χρηματοδότηση της εταιρίας σας χωρίς γραφειοκρατία.</h3>
<ul><li>Ευέλικτες πιστωτικές λύσεις και factoring τιμολογίων.</li></ul>',
    'bluevine_create_account' => 'Δημιουργήστε λογαριασμό',
    'quote_types' => 'Λάβετε προσφορά για',
    'invoice_factoring' => 'Factoring τιμολογίων',
    'line_of_credit' => 'Πιστωτικές λύσεις',
    'fico_score' => 'Το FICO σκορ σας',
    'business_inception' => 'Ημερομηνία Έναρξης Επιχείρησης',
    'average_bank_balance' => 'Μέσο υπόλοιπο τραπεζικού λογαριασμού',
    'annual_revenue' => 'Ετήσια έσοδα',
    'desired_credit_limit_factoring' => 'Επιθυμητό όριο factoring τιμολογίων',
    'desired_credit_limit_loc' => 'Επιθυμητό όριο πιστωτικων λύσεων',
    'desired_credit_limit' => 'Επιθυμητό όριο πίστωσης',
    'bluevine_credit_line_type_required' => 'Πρέπει να επιλέξετε τουλάχιστον ένα',
    'bluevine_field_required' => 'Αυτό το πεδίο είναι απαραίτητο',
    'bluevine_unexpected_error' => 'Εμφανίστηκε μη αναμενόμενο σφάλμα.',
    'bluevine_no_conditional_offer' => 'Απαιτούνται περισσότερες πληροφορίες πριν τη λήψη προσφοράς. Πατήστε συνέχεια παρακάτω.',
    'bluevine_invoice_factoring' => 'Factoring Τιμολογίων',
    'bluevine_conditional_offer' => 'Προσφορά υπό όρους',
    'bluevine_credit_line_amount' => 'Πιστωτική Λύση',
    'bluevine_advance_rate' => 'Ποσοστό Επόμενου Βήματος',
    'bluevine_weekly_discount_rate' => 'Εβδομαδιαίο Ποσοστό Έκπτωσης',
    'bluevine_minimum_fee_rate' => 'Ελάχιστο Τέλος',
    'bluevine_line_of_credit' => 'Πιστωτικές Λύσεις',
    'bluevine_interest_rate' => 'Επιτόκιο',
    'bluevine_weekly_draw_rate' => 'Εβδομαδιαίο Ποσοστό Εξισορρόπησης',
    'bluevine_continue' => 'Συνεχίστε στη BlueVine',
    'bluevine_completed' => 'Η εγγραφή στη BlueVine ολοκληρώθηκε',

    'vendor_name' => 'Προμηθευτής',
    'entity_state' => 'Περιοχή',
    'client_created_at' => 'Ημ/νία Δημιουργίας',
    'postmark_error' => 'Προέκυψε πρόβλημα κατά την αποστολή του email μέσω Postmark: :link',
    'project' => 'Project',
    'projects' => 'Projects',
    'new_project' => 'Νέο Project',
    'edit_project' => 'Επεξεργασία Project',
    'archive_project' => 'Αρχειοθέτηση Project',
    'list_projects' => 'Λίστα Projects',
    'updated_project' => 'Επιτυχής ενημέρωση project',
    'created_project' => 'Επιτυχής δημιουργία project',
    'archived_project' => 'Επιτυχής αρχειοθέτηση project',
    'archived_projects' => 'Επιτυχής αρχειοθέτηση :count projects',
    'restore_project' => 'Επαναφορά Project',
    'restored_project' => 'Επιτυχής ανάκτηση project',
    'delete_project' => 'Διαγραφή Project',
    'deleted_project' => 'Επιτυχής διαγραφή project',
    'deleted_projects' => 'Επιτυχής διαγραφή :count projects',
    'delete_expense_category' => 'Διαγραφή κατηγορίας',
    'deleted_expense_category' => 'Επιτυχής διαγραφή κατηγορίας',
    'delete_product' => 'Διαγραφή Προϊόντος',
    'deleted_product' => 'Επιτυχής διαγραφή προϊόντος',
    'deleted_products' => 'Επιτυχής διαγραφή :count προϊόντων',
    'restored_product' => 'Επιτυχής ανάκτηση προϊόντος',
    'update_credit' => 'Ενημέρωση Πίστωσης',
    'updated_credit' => 'Επιτυχής ενημέρωση πίστωσης',
    'edit_credit' => 'Επεξεργασία Πίστωσης',
    'realtime_preview' => 'Προεπισκόπηση Πραγματικού Χρόνου',
    'realtime_preview_help' => 'Εμφάνιση μιας προεπισκόπησης πραγματικού χρόνου του PDF του τιμολογίου κατά την επεξεργασία του τιμολογίου.<br/>Απενεργοποιήστε αυτή την επιλογή για βελτίωση της ταχύτητας επεξεργασίας τιμολογίων.',
    'live_preview_help' => 'Εμφάνιση μιας ζωντανής προεπισκόπησης του PDF της σελίδας του τιμολογίου.',
    'force_pdfjs_help' => 'Αντικαταστήστε τον ενσωματωμένο παρουσιαστή PDF στο :chrome_link και :firefox_link.<br/>Ενεργοποιήστε αυτή την επιλογή εάν ο browser σας κατεβάζει αυτόματα το PDF.',
    'force_pdfjs' => 'Παρεμπόδιση Κατεβάσματος',
    'redirect_url' => 'URL Ανακατεύθυνσης',
    'redirect_url_help' => 'Εναλλακτικά ορίστε ένα URL για ανακατεύθυνση μετά την πραγματοποίηση μιας πληρωμής.',
    'save_draft' => 'Αποθήκευση Πρόχειρου',
    'refunded_credit_payment' => 'Επιστροφή πιστωτικών πληρωμών',
    'keyboard_shortcuts' => 'Συντομεύσεις Πληκτρολογίου',
    'toggle_menu' => 'Εναλλαγή Μενού',
    'new_...' => 'Νέο ...',
    'list_...' => 'Εμφάνιση ...',
    'created_at' => 'Ημ/νία Δημιουργίας',
    'contact_us' => 'Επικοινωνήστε μαζί μας',
    'user_guide' => 'Οδηγός Χρήσης',
    'promo_message' => 'Αναβαθμίστε πριν από :expires και πάρτε έκπτωση :amount στα Επαγγελματικά και Εταιρικά μας πακέτα.',
    'discount_message' => ':amount λήγουν :expires',
    'mark_paid' => 'Όρισε ως Πληρωμένα',
    'marked_sent_invoice' => 'Επιτυχής ορισμός τιμολογίου ως απεσταλμένο',
    'marked_sent_invoices' => 'Επιτυχής ορισμός τιμολογίων ως απεσταλμένα',
    'invoice_name' => 'Τιμολόγιο',
    'product_will_create' => 'προϊόν θα δημιουργηθεί',
    'contact_us_response' => 'Ευχαριστούμε για το μήνυμά σας! Θα προσπαθήσουμε να σας απαντήσουμε το συντομότερο δυνατό.',
    'last_7_days' => 'Τελευταίες 7 Ημέρες',
    'last_30_days' => 'Τελευταίες 30 Ημέρες',
    'this_month' => 'Αυτός ο Μήνας',
    'last_month' => 'Προηγούμενος Μήνας',
    'current_quarter' => 'Τρέχων Τετράμηνο',
    'last_quarter' => 'Τελευταίο Τετράμηνο',
    'last_year' => 'Προηγούμενος Χρόνος',
    'custom_range' => 'Προσαρμοσμένο Εύρος',
    'url' => 'URL',
    'debug' => 'Αποσφαλμάτωση',
    'https' => 'HTTPS',
    'require' => 'Απαιτεί',
    'license_expiring' => 'Σημείωση: Η άδεια χρήσης σας θα λήξει σε :count ημέρες, :link για ανανέωση.',
    'security_confirmation' => 'Η διεύθυνση email σας έχει επιβεβαιωθεί.',
    'white_label_expired' => 'Η άδεια χρήσης λευκής ετικέτας σας έχει λήξει, παρακαλώ σκεφτείτε την ανανέωσή της για να υποστηρίξετε το project μας.',
    'renew_license' => 'Ανανέωση Άδειας Χρήσης',
    'iphone_app_message' => 'Σκεφτείτε να κατεβάσετε το :link',
    'iphone_app' => 'Εφαρμογή iPhone',
    'android_app' => 'Εφαρμογή Android',
    'logged_in' => 'Εισηγμένος',
    'switch_to_primary' => 'Αλλάξτε στην πρωτεύουσα επιχείρηση (:name) για να διαχειριστείτε το πλάνο σας.',
    'inclusive' => 'Συμπεριλαμβάνεται',
    'exclusive' => 'Δεν συμπεριλαμβάνεται',
    'postal_city_state' => 'ΤΚ/Πόλη/Περιοχή',
    'phantomjs_help' => 'Σε συγκεκριμένες περιπτώσεις η εφαρμογή χρησιμοποιεί το :link_phantom για να δημιουργήσει το PDF, εγκαταστήστε το :link_docs για να το δημιουργήσετε τοπικά.',
    'phantomjs_local' => 'Χρήση του τοπικού PhantomJS',
    'client_number' => 'Αριθμός Πελάτη',
    'client_number_help' => 'Ορίστε ένα πρόθεμα ή χρησιμοποιήστε ένα προσαρμοσμένο μοτίβο για να καθορίζετε δυναμικά τον αριθμό πελάτη.',
    'next_client_number' => 'Ο επόμενος αριθμός πελάτη είναι :number.',
    'generated_numbers' => 'Δημιουργημένοι Αριθμοί',
    'notes_reminder1' => 'Πρώτη Υπενθύμιση',
    'notes_reminder2' => 'Δεύτερη Υπενθύμιση',
    'notes_reminder3' => 'Τρίτη Υπενθύμιση',
    'notes_reminder4' => 'Υπενθύμιση',
    'bcc_email' => 'Email ιδιαίτερης κοινοποίησης',
    'tax_quote' => 'Προσφορά Φόρου',
    'tax_invoice' => 'Τιμολόγιο Φόρου',
    'emailed_invoices' => 'Επιτυχής αποστολή τιμολογίων',
    'emailed_quotes' => 'Επιτυχής αποστολή προσφορών',
    'website_url' => 'Διεύθυνση ιστοσελίδας',
    'domain' => 'Domain',
    'domain_help' => 'Χρησιμοποιημένο στο portal του πελάτη όταν στέλνετε emails.',
    'domain_help_website' => 'Χρησιμοποιημένο όταν στέλνετε emails.',
    'import_invoices' => 'Εισαγωγή Τιμολογίων',
    'new_report' => 'Νέα Αναφορά',
    'edit_report' => 'Επεξεργασία Αναφοράς',
    'columns' => 'Στήλες',
    'filters' => 'Φίλτρα',
    'sort_by' => 'Ταξινόμηση Κατά',
    'draft' => 'Πρόχειρο',
    'unpaid' => 'Μη εξοφλημένη',
    'aging' => 'Γήρανση',
    'age' => 'Ηλικία',
    'days' => 'Ημέρες',
    'age_group_0' => '0 - 30 Ημέρες',
    'age_group_30' => '30 - 60 Ημέρες',
    'age_group_60' => '60 - 90 Ημέρες',
    'age_group_90' => '90 - 120 Ημέρες',
    'age_group_120' => '120+ Ημέρες',
    'invoice_details' => 'Στοιχεία Τιμολογίου',
    'qty' => 'Ποσότητα',
    'profit_and_loss' => 'Κέρδος και Ζημιά',
    'revenue' => 'Έσοδα',
    'profit' => 'Κέρδος',
    'group_when_sorted' => 'Ομαδική Ταξινόμηση',
    'group_dates_by' => 'Ομαδοποίηση Ημερομηνιών Κατά',
    'year' => 'Έτος',
    'view_statement' => 'Εμφάνιση Δήλωσης',
    'statement' => 'Δήλωση',
    'statement_date' => 'Ημ/νία Δήλωσης',
    'mark_active' => 'Σήμανση ως Ενεργό',
    'send_automatically' => 'Αυτόματη Αποστολή',
    'initial_email' => 'Αρχικό Email',
    'invoice_not_emailed' => 'Το τιμολόγιο δεν έχει αποσταλεί με email.',
    'quote_not_emailed' => 'Η προσφορά δεν έχει αποσταλεί με email.',
    'sent_by' => 'Απεστάλη από :user',
    'recipients' => 'Παραλήπτες',
    'save_as_default' => 'Αποθήκευση ως προεπιλογή',
    'start_of_week_help' => 'Χρησιμοποιήθηκε από <b>date</b> επιλογείς',
    'financial_year_start_help' => 'Χρησιμοποιήθηκε από <b>date range</b> επιλογείς',
    'reports_help' => 'Shift + Click για να γίνει ταξινόμηση με βάση πολλές στήλες, Ctrl + Click για εκκαθάριση της ομαδοποίησης.',
    'this_year' => 'Τρέχον Χρόνος',

    // Updated login screen
    'ninja_tagline' => 'Δημιουργήστε. Αποστείλετε. Εξοφληθείτε.',
    'login_or_existing' => 'Ή συνδεθείτε με ένα συνδεδεμένο λογαριασμό.',
    'sign_up_now' => 'Εγγραφή Τώρα',
    'not_a_member_yet' => 'Δεν είστε ακόμη μέλη;',
    'login_create_an_account' => 'Δημιουργία Λογαριασμού',

    // New Client Portal styling
    'invoice_from' => 'Τιμολόγια Από:',
    'email_alias_message' => 'Απαιτείται από τον κάθε εταιρία να έχει μία μοναδική διεύθυνση email.<br/>Σκεφτείτε τη χρήση ενός ψευδώνυμου. Πχ, email+label@example.com',
    'full_name' => 'Πλήρες Όνομα',
    'month_year' => 'ΜΗΝΑΣ/ΕΤΟΣ',
    'valid_thru' => 'Ισχύει\nthru',

    'product_fields' => 'Πεδία Προϊόντος',
    'custom_product_fields_help' => 'Προσθέστε ένα πεδίο όταν δημιουργείτε ένα προϊόν ή ένα τιμολόγιο και εμφανίστε την ετικέτα και την τιμή στο αρχείο PDF',
    'freq_two_months' => 'Δύο μήνες',
    'freq_yearly' => 'Ετήσιο',
    'profile' => 'Προφίλ',
    'payment_type_help' => 'Ορίζει τον προεπιλεγμένο <b>τρόπο χειροκίνητης πληρωμής</b>.',
    'industry_Construction' => 'Κατασκευή',
    'your_statement' => 'Η Δήλωσή σας',
    'statement_issued_to' => 'Η δήλωση εκδόθηκε προς',
    'statement_to' => 'Δήλωση προς',
    'customize_options' => 'Προσαρμογή επιλογών',
    'created_payment_term' => 'Επιτυχής δημιουργία όρων πληρωμής',
    'updated_payment_term' => 'Επιτυχής επικαιροποίηση όρων πληρωμής',
    'archived_payment_term' => 'Επιτυχής αποθήκευση όρου πληρωμής',
    'resend_invite' => 'Επαναποστολή Πρόσκλησης',
    'credit_created_by' => 'Πίστωση δημιουργήθηκε από την πληρωμή :transaction_reference',
    'created_payment_and_credit' => 'Επιτυχής δημιουργία πληρωμής και πίστωση',
    'created_payment_and_credit_emailed_client' => 'Επιτυχής δημιουργία πληρωμής και πίστωσης, και αποστολής email στον πελάτη',
    'create_project' => 'Δημιουργία project',
    'create_vendor' => 'Δημιουργία προμηθευτή',
    'create_expense_category' => 'Δημιουργία κατηγορίας',
    'pro_plan_reports' => ':link για την ενεργοποίηση των εκθέσεων με τη συμμετοχή στο Επαγγελματικό Πλάνο',
    'mark_ready' => 'Σήμανση ως Έτοιμο',

    'limits' => 'Όρια',
    'fees' => 'Τέλη',
    'fee' => 'Τέλος',
    'set_limits_fees' => 'Όρίστε :gateway_type Όρια/Τέλη',
    'fees_tax_help' => 'Ενεργοποιήστε τους φόρους ανά γραμμή για να ορίσετε τα τέλη φόρου για τις αμοιβές.',
    'fees_sample' => 'Το τέλος για ένα τιμολόγιο ποσού :amount θα είναι :total.',
    'discount_sample' => 'Η έκπτωση για ένα τιμολόγιο ποσού :amount θα είναι :total.',
    'no_fees' => 'Χωρίς Αμοιβές',
    'gateway_fees_disclaimer' => 'Προειδοποίηση: δεν επιτρέπουν όλες οι πολιτείες και πύλες πληρωμής να προσθέτετε τέλη, παρακαλούμε δείτε τους κατά τόπους νόμους / όρους παροχής υπηρειών',
    'percent' => 'Ποσοστό',
    'location' => 'Τοποθεσία',
    'line_item' => 'Προϊόν Γραμμής',
    'surcharge' => 'Επιβάρυνση',
    'location_first_surcharge' => 'Ενεργοποιημένο - Πρώτη επιβάρυνση',
    'location_second_surcharge' => 'Ενεργοποιημένο - Δεύτερη επιβάρυνση',
    'location_line_item' => 'Ενεργοποιημένο - Προϊόν γραμμής',
    'online_payment_surcharge' => 'Επιβάρυνση Πληρωμών Online',
    'gateway_fees' => 'Τέλη Πύλης Πληρωμής',
    'fees_disabled' => 'Τα τέλη είναι απενεργοποιημένα',
    'gateway_fees_help' => 'Προσθέστε αυτόματα μία επιβάρυνση/έκπτωση online πληρωμής.',
    'gateway' => 'Πύλη πληρωμής (Gateway)',
    'gateway_fee_change_warning' => 'Εάν υπάρχουν απλήρωτα τιμολόγια με τέλη πρέπει να ενημερωθούν χειροκίνητα.',
    'fees_surcharge_help' => 'Προσαρμογή επιβάρυνσης :link.',
    'label_and_taxes' => 'ετικέτες και φόρους',
    'billable' => 'Χρεώσιμο',
    'logo_warning_too_large' => 'Το αρχείο εικόνας είναι πολύ μεγάλο.',
    'logo_warning_fileinfo' => 'Προειδοποίηση: Για την υποστήριξη αρχείων gif πρέπει να έχει ενεργοποιηθεί η PHP επέκταση fileinfo',
    'logo_warning_invalid' => 'Υπήρξε ένα πρόβλημα ανάγνωσης του αρχείου εικόνας, παρακαλώ δοκιμάστε ένα διαφορετικό τύπο αρχείου.',

    'error_refresh_page' => 'Εμφανίστηκε ένα λάθος, παρακαλώ ανανεω΄στε αυτή τη σελίδα και προσπαθήστε ξανά.',
    'data' => 'Δεδομένα',
    'imported_settings' => 'Επιτυχής εισαγωγή ρυθμίσεων',
    'reset_counter' => 'Επανεκκίνηση Μετρητή',
    'next_reset' => 'Επόμενη επανεκκίνηση',
    'reset_counter_help' => 'Αυτόματη επανεκκίνηση των μετρητών τιμολογίου και προσφοράς.',
    'auto_bill_failed' => 'Αυτόματη τιμολόγηση για το τιμολόγιο :invoice_number failed',
    'online_payment_discount' => 'Έκπτωση Online Πληρωμής',
    'created_new_company' => 'Επιτυχής δημιουργία νέας εταιρίας',
    'fees_disabled_for_gateway' => 'Τα τέλη είναι απενεργοποιημένα γι\' αυτή την πύλη πληρωμής.',
    'logout_and_delete' => 'Έξοδος/Διαγραφή λογαριασμού',
    'tax_rate_type_help' => 'Οι συμπεριλαμβανόμενοι φόροι προσαρμόζουν το κόστος προϊόντος ανά γραμμή όταν επιλεχθούν.<br/>Μόνο οι μη συμπεριλαμβανόμενοι φόροι μπορούν να χρησιμοποιηθούν ως προεπιλεγμένοι.',
    'invoice_footer_help' => 'Χρησιμοποιήστε το $pageNumber και το $pageCount για να εμφανίσετε τις πληροφορίες σελίδας.',
    'credit_note' => 'Πιστωτικό Σημείωμα',
    'credit_issued_to' => 'Πίστωση εκδόθηκε προς',
    'credit_to' => 'Πίστωση προς',
    'your_credit' => 'Η Πίστωσή σας',
    'credit_number' => 'Αριθμός Πίστωσης',
    'create_credit_note' => 'Δημιουργία Πιστωτικού Σημειώματος',
    'menu' => 'Μενού',
    'error_incorrect_gateway_ids' => 'Σφάλμα: Ο πίνακας των πυλών πληρωμής (gateways) έχει λάθος αριθμούς.',
    'purge_data' => 'Εκκαθάριση Δεδομένων',
    'delete_data' => 'Διαγραφή Δεδομένων',
    'purge_data_help' => 'Οριστική διαγραφή όλων των δεδομένων αλλά διατήρηση λογαριασμού και ρυθμίσεων.',
    'cancel_account_help' => 'Οριστική διαγραφή του λογαριασμού με όλα τα δεδομένα και τις ρυθμίσεις.',
    'purge_successful' => 'Επιτυχής εκκαθάριση δεδομένων επιχείρησης',
    'forbidden' => 'Απαγορευμένο',
    'purge_data_message' => 'Προσοχή: Αυτό θα σβήσει όλα σας τα δεδομένα, χωρίς δυνατότητα αναίρεσης.',
    'contact_phone' => 'Τηλέφωνο Επικοινωνίας',
    'contact_email' => 'Email Επικοινωνίας',
    'reply_to_email' => 'Email Απάντησης',
    'reply_to_email_help' => 'Ορίστε τη διεύθυνση απάντησης για τα emails που απευθύνονται στους πελάτες.',
    'bcc_email_help' => 'Ορίστε τη διεύθυνση κρυφής αποστολής για τα emails που απευθύνονται στους πελάτες.',
    'import_complete' => 'Επιτυχής ολοκλήρωση της εισαγωγής',
    'confirm_account_to_import' => 'Παρακαλώ επιβεβαιώστε το λογαριασμό σας για εισαγωγή δεδομένων',
    'import_started' => 'Η εισαγωγή δεδομένων ξεκίνησε, θα σας αποσταλεί email με την ολοκλήρωση.',
    'listening' => 'Ηχητική καταγραφή...',
    'microphone_help' => 'Πείτε "νέο τιμολόγιο για [client]" ή "εμφάνισέ μου τις αρχειοθετημένες πληρωμές του [client]"',
    'voice_commands' => 'Ηχητικές Εντολές',
    'sample_commands' => 'Δείγματα εντολών',
    'voice_commands_feedback' => 'Εργαζόμαστε για να βελτιώσουμε αυτό το χαρακτηριστικό, εάν υπάρχει μία εντολή που θέλετε να υποστηρίζουμε παρακαλούμε στείλτε μας email στο :email.',
    'payment_type_Venmo' => 'Venmo',
    'payment_type_Money Order' => 'Έμβασμα',
    'archived_products' => 'Επιτυχής αρχειοθέτηση :count προϊόντων',
    'recommend_on' => 'Προτείνουμε την <b>ενεργοποίηση</b> αυτής της ρύθμισης.',
    'recommend_off' => 'Προτείνουμε την <b>απενεργοποίηση</b> αυτής της ρύθμισης.',
    'notes_auto_billed' => 'Αυτόματη χρέωση',
    'surcharge_label' => 'Ετικέτα Επιβάρυνσης',
    'contact_fields' => 'Πεδία Επαφής',
    'custom_contact_fields_help' => 'Προσθέστε ένα πεδίο όταν δημιουργείτε μία επαφή και επιλέξτε δυνητικά την εμφάνισή της ετικέτας και της τιμής στο αρχείο PDF.',
    'datatable_info' => 'Εμφάνιση :start έως :end από :total εγγραφές',
    'credit_total' => 'Συνολική Πίστωση',
    'mark_billable' => 'Σήμανση ως χρεώσιμο',
    'billed' => 'Τιμολογήθηκαν',
    'company_variables' => 'Μεταβλητές Εταιρίας',
    'client_variables' => 'Μεταβλητές Πελάτη',
    'invoice_variables' => 'Μεταβλητές Τιμολογίου',
    'navigation_variables' => 'Μεταβλητές Πλοήγησης',
    'custom_variables' => 'Προσαρμοσμένες Μεταβλητές',
    'invalid_file' => 'Μη έγκυρος τύπος αρχείου',
    'add_documents_to_invoice' => 'Προσθέστε έγγραφα στο τιμολόγιο',
    'mark_expense_paid' => 'Σήμανση ως εξοφλημένο',
    'white_label_license_error' => 'Αδυναμία επικύρωσης της άδειας, ελέγξτε το αρχείο storage/logs/laravel-error.log για περισσότερες λεπτομέρειες.',
    'plan_price' => 'Τιμή Πλάνου',
    'wrong_confirmation' => 'Λανθασμένος κωδικός επιβεβαίωσης',
    'oauth_taken' => 'Ο λογαριασμός χρήστη έχει ήδη καταχωρηθεί',
    'emailed_payment' => 'Επιτυχής αποστολή πληρωμής με Email',
    'email_payment' => 'Αποστολή πληρωμής με Email',
    'invoiceplane_import' => 'Χρησιμοποιήστε το :link για να μεταφέρετε τα δεδομένα σας από το InvoicePlane.',
    'duplicate_expense_warning' => 'Προειδοποίηση: Το :link μπορεί να είναι διπλή εγγραφή',
    'expense_link' => 'έξοδο',
    'resume_task' => 'Επανέναρξη Εργασίας',
    'resumed_task' => 'Επιτυχής επανέναρξη εργασίας',
    'quote_design' => 'Σχεδιασμός Προσφοράς',
    'default_design' => 'Προεπιλεγμένος Σχεδιασμός',
    'custom_design1' => 'Προσαρμοσμένος Σχεδιασμός 1',
    'custom_design2' => 'Προσαρμοσμένος Σχεδιασμός 2',
    'custom_design3' => 'Προσαρμοσμένος Σχεδιασμός 3',
    'empty' => 'Κενό',
    'load_design' => 'Φόρτωση Σχεδιασμού',
    'accepted_card_logos' => 'Λογότυπα Αποδεκτών Καρτών',
    'phantomjs_local_and_cloud' => 'Χρησιμοποιείτε το τοπικό PhantomJS, επιστροφή πίσω στο phantomjscloud.com',
    'google_analytics' => 'Google Analytics',
    'analytics_key' => 'Κλειδί Analytics',
    'analytics_key_help' => 'Ιχνηλατήστε τις πληρωμές σας χρησιμοποιώντας :link',
    'start_date_required' => 'Απαιτείται η ημερομηνία έναρξης',
    'application_settings' => 'Ρυθμίσεις Εφαρμογής',
    'database_connection' => 'Σύνδεση Βάσης Δεδομένων',
    'driver' => 'Οδηγός',
    'host' => 'Εξυπηρετητής',
    'database' => 'Βάση Δεδομένων',
    'test_connection' => 'Έλεγχος σύνδεσης',
    'from_name' => 'Από Όνομα',
    'from_address' => 'Από Διεύθυνση',
    'port' => 'Πόρτα',
    'encryption' => 'Κρυπτογράφηση',
    'mailgun_domain' => 'Όνομα χώρου Mailgun',
    'mailgun_private_key' => 'Ιδιωτικό Κλειδί Mailgun',
    'send_test_email' => 'Αποστολή δοκιμαστικού email',
    'select_label' => 'Επιλογή Ετικέτας',
    'label' => 'Ετικέτα',
    'service' => 'Υπηρεσία',
    'update_payment_details' => 'Ανανέωση στοιχείων πληρωμής',
    'updated_payment_details' => 'Επιτυχής ανανέωση στοιχείων πληρωμής',
    'update_credit_card' => 'Ανανέωση Πιστωτικής Κάρτας',
    'recurring_expenses' => 'Επαναλαμβανόμενες Δαπάνες',
    'recurring_expense' => 'Επαναλαμβανόμενη Δαπάνη',
    'new_recurring_expense' => 'Νέα Επαναλαμβανόμενη Δαπάνη',
    'edit_recurring_expense' => 'Επεξεργασία Επαναλαμβανόμενης Δαπάνης',
    'archive_recurring_expense' => 'Αρχειοθέτηση Επαναλαμβανόμενης Δαπάνης',
    'list_recurring_expense' => 'Εμφάνιση Επαναλαμβανόμενων Δαπανών',
    'updated_recurring_expense' => 'Επιτυχής ενημέρωση επαναλαμβανόμενης δαπάνης',
    'created_recurring_expense' => 'Επιτυχής δημιουργία επαναλαμβανόμενης δαπάνης',
    'archived_recurring_expense' => 'Επιτυχής αρχειοθέτηση επαναλαμβανόμενης δαπάνης',
    'restore_recurring_expense' => 'Επαναφορά Επαναλαμβανόμενης Δαπάνης',
    'restored_recurring_expense' => 'Επιτυχής επαναφορά επαναλαμβανόμενης δαπάνης',
    'delete_recurring_expense' => 'Διαγραφή Επαναλαμβανόμενης Δαπάνης',
    'deleted_recurring_expense' => 'Επιτυχής διαγραφή project',
    'view_recurring_expense' => 'Εμφάνιση Επαναλαμβανόμενης Δαπάνης',
    'taxes_and_fees' => 'Φόροι και τέλη',
    'import_failed' => 'Εισαγωγή Απέτυχε',
    'recurring_prefix' => 'Επαναλαμβανόμενο Πρόθεμα',
    'options' => 'Επιλογές',
    'credit_number_help' => 'Ορίστε ένα πρόθεμα ή χρησιμοποιήστε ένα προσαρμοσμένο μοτίβο για να καθορίζετε δυναμικά τον αριθμό πίστωσης για αρνητικά τιμολόγια.',
    'next_credit_number' => 'Ο επόμενος αριθμός πίστωσης είναι :number.',
    'padding_help' => 'Το πλήθος των μηδενικών για τη δημιουργία του αριθμού.',
    'import_warning_invalid_date' => 'Προειδοποίηση: Η μορφή της ημερομηνίας μοιάζει να είναι μη έγκυρη.',
    'product_notes' => 'Σημειώσεις Προϊόντος',
    'app_version' => 'Έκδοση Εφαρμογής',
    'ofx_version' => 'Έκδοση OFX',
    'gateway_help_23' => ':link για να λάβετε τα κλειδιά του Stripe API.',
    'error_app_key_set_to_default' => 'Σφάλμα: Το APP_KEY έχει οριστεί στην προκαθορισμένη τιμή, για να το ενημερώσετε κάντε αντίγραφο ασφαλείας από τη βάση δεδομένων και εκτελέστε το <code>php artisan ninja:update-key</code>',
    'charge_late_fee' => 'Τέλη Καθυστερημένης Εξόφλησης',
    'late_fee_amount' => 'Ποσό Τέλους Καθυστερημένης Εξόφλησης',
    'late_fee_percent' => 'Ποσοστό Τέλους Καθυστερημένης Εξόφλησης',
    'late_fee_added' => 'Τέλος καθυστερημένης εξόφλησης προστέθηκε την :date',
    'download_invoice' => 'Κατέβασμα Τιμολογίου',
    'download_quote' => 'Κατέβασμα Προσφοράς',
    'invoices_are_attached' => 'Τα αρχεία PDF έχουν επισυναφθεί.',
    'downloaded_invoice' => 'Θα αποσταλεί email με το τιμολόγιο σε αρχείο PDF',
    'downloaded_quote' => 'Θα αποσταλεί email με την προσφορά σε αρχείο PDF',
    'downloaded_invoices' => 'Θα αποσταλεί email με τα τιμολόγια σε αρχεία PDF',
    'downloaded_quotes' => 'Θα αποσταλεί email με τις προσφορές σε αρχεία PDF',
    'clone_expense' => 'Κλωνοποίηση Δαπάνης',
    'default_documents' => 'Προεπιλεγμένα Κείμενα',
    'send_email_to_client' => 'Αποστολή email στον πελάτη',
    'refund_subject' => 'Επιστροφή Χρημάτων Επεξεργάσθηκε',
    'refund_body' => 'Έχετε επιστροφή χρημάτων ποσού :amount για το τιμολόγιο :invoice_number.',

    'currency_us_dollar' => 'Δολάριο Ηνωμένων Πολιτειών',
    'currency_british_pound' => 'Βρετανική Λίρα',
    'currency_euro' => 'Ευρώ',
    'currency_south_african_rand' => 'Ραντ Νότιας Αφρικής',
    'currency_danish_krone' => 'Δανική Κορώνα',
    'currency_israeli_shekel' => 'Σέκελ Ισραήλ',
    'currency_swedish_krona' => 'Κορώνα Σουηδίας',
    'currency_kenyan_shilling' => 'Σελίνι Κένυας',
    'currency_canadian_dollar' => 'Δολάριο Καναδά',
    'currency_philippine_peso' => 'Πέσο Φιλιπίνων',
    'currency_indian_rupee' => 'Ρουπία Ινδίας',
    'currency_australian_dollar' => 'Δολάριο Αυστραλίας',
    'currency_singapore_dollar' => 'Δολάριο Σιγκαπούρης',
    'currency_norske_kroner' => 'Κορώνα Νορβηγίας',
    'currency_new_zealand_dollar' => 'Δολάριο Νέας Ζηλανδίας',
    'currency_vietnamese_dong' => 'Ντονγκ Βιετνάμ',
    'currency_swiss_franc' => 'Φράγκο Σουηδίας',
    'currency_guatemalan_quetzal' => 'Κουετσάλ Γουατεμάλας',
    'currency_malaysian_ringgit' => 'Ρινγκίτ Μαλαισίας',
    'currency_brazilian_real' => 'Ρεάλ Βραζιλίας',
    'currency_thai_baht' => 'Μπατ Ταϊλάνδης',
    'currency_nigerian_naira' => 'Νάιρα Νιγηρίας',
    'currency_argentine_peso' => 'Πέσο Αργεντινής',
    'currency_bangladeshi_taka' => 'Τάκα Μπαγκλαντές',
    'currency_united_arab_emirates_dirham' => 'Ντιρχάμ Ηνωμένων Αραβικών Εμιράτων',
    'currency_hong_kong_dollar' => 'Δολάριο Χονγκ Κονγκ',
    'currency_indonesian_rupiah' => 'Ρουπία Ινδονησίας',
    'currency_mexican_peso' => 'Πέσο Μεξικού',
    'currency_egyptian_pound' => 'Λίρα Αιγύπτου',
    'currency_colombian_peso' => 'Πέσο Κολομβίας',
    'currency_west_african_franc' => 'Φράγκο Δυτικής Αφρικής',
    'currency_chinese_renminbi' => 'Ρενμίνμπι Κίνας',
    'currency_rwandan_franc' => 'Φράγκο Ρουάντα',
    'currency_tanzanian_shilling' => 'Σελίνι Τανζανίας',
    'currency_netherlands_antillean_guilder' => 'Γκίλντα Ολλανδικών Αντιλλών',
    'currency_trinidad_and_tobago_dollar' => 'Δολάριο Τρινιντάντ και Ταμπάκο',
    'currency_east_caribbean_dollar' => 'Δολάριο Ανατολικής Καραϊβικής',
    'currency_ghanaian_cedi' => 'Σέντι Γκάνας',
    'currency_bulgarian_lev' => 'Λέβαβ Βουλγαρίας',
    'currency_aruban_florin' => 'Φιορίνι Αρούμπα',
    'currency_turkish_lira' => 'Λίρα Τουρκίας',
    'currency_romanian_new_leu' => 'Νέο Λέβα Ρουμανίας',
    'currency_croatian_kuna' => 'Κούνα Κροατίας',
    'currency_saudi_riyal' => 'Ριάλ Σαουδικής Αραβίας',
    'currency_japanese_yen' => 'Γιεν Ιαπωνίας',
    'currency_maldivian_rufiyaa' => 'Ρουφίγια Μαλδίβων',
    'currency_costa_rican_colon' => 'Κολόν Κόστα Ρίκας',
    'currency_pakistani_rupee' => 'Ρουπία Πακιστάν',
    'currency_polish_zloty' => 'Ζλότυ Πολωνίας',
    'currency_sri_lankan_rupee' => 'Ρουπία Σρι Λάνκα',
    'currency_czech_koruna' => 'Κορώνα Τσεχίας',
    'currency_uruguayan_peso' => 'Πέσο Ουρουγουάης',
    'currency_namibian_dollar' => 'Δολάριο Ναμίμπια',
    'currency_tunisian_dinar' => 'Δηνάριο Τυνησίας',
    'currency_russian_ruble' => 'Ρούβλι Ρωσίας',
    'currency_mozambican_metical' => 'Μετικάλ Μοζαμβίκης',
    'currency_omani_rial' => 'Ριάλ Ομάν',
    'currency_ukrainian_hryvnia' => 'Γρίβνα Ουκρανίας',
    'currency_macanese_pataca' => 'Πατάκα Μακάο',
    'currency_taiwan_new_dollar' => 'Νέο Δολάριο Ταϊβάν',
    'currency_dominican_peso' => 'Πέσο Αγίου Δομίνικου',
    'currency_chilean_peso' => 'Πέσο χιλής',
    'currency_icelandic_krona' => 'Κορώνα Ισλανδίας',
    'currency_papua_new_guinean_kina' => 'Κίνα Παπούα και Νέα Γουινέα',
    'currency_jordanian_dinar' => 'Δηνάριο Ιορδανίας',
    'currency_myanmar_kyat' => 'Κιάτ Νιανμάρ',
    'currency_peruvian_sol' => 'Σολ Περού',
    'currency_botswana_pula' => 'Πούλα Μποτσουάνας',
    'currency_hungarian_forint' => 'Ουγγρικό Φιορίνι',
    'currency_ugandan_shilling' => 'Σελίνι Ουγκάντας ',
    'currency_barbadian_dollar' => 'Δολάριο Μπαρμπέιντος',
    'currency_brunei_dollar' => 'Δολάριο Μπρουνέι',
    'currency_georgian_lari' => 'Λάρι Γεωργίας',
    'currency_qatari_riyal' => 'Ριγιάλ Κατάρ',
    'currency_honduran_lempira' => 'Λεμπίρα Ονδούρας',
    'currency_surinamese_dollar' => 'Δολάριο Σουρινάμ',
    'currency_bahraini_dinar' => 'Δηνάριο Μπαχρέιν',
    'currency_venezuelan_bolivars' => 'Μπολιβάρ Βενεζουέλας',
    'currency_south_korean_won' => 'Γουόν Νότιας Κορέας',
    'currency_moroccan_dirham' => 'Ντιρχάμ Μαρόκου',
    'currency_jamaican_dollar' => 'Δολλάριο Τζαμάικας',
    'currency_angolan_kwanza' => 'Κουάνζα Αγκόλας',
    'currency_haitian_gourde' => 'Γκούρντε Αϊτής',
    'currency_zambian_kwacha' => 'Κβάτσα Ζάμπιας',
    'currency_nepalese_rupee' => 'Ρουπία Νεπάλ',
    'currency_cfp_franc' => 'CFP Franc',
    'currency_mauritian_rupee' => 'Ρουπία Μαυρίκιου',
    'currency_cape_verdean_escudo' => 'Εσκούδο Πράσινου Ακρωτηρίου',
    'currency_kuwaiti_dinar' => 'Δινάριο Κουβέιτ',
    'currency_algerian_dinar' => 'Δηνάριο Αλγερίας',
    'currency_macedonian_denar' => 'Δηνάριο Βόρειας Μακεδονίας',
    'currency_fijian_dollar' => 'Δολάριο Νησιών Φίτζι',
    'currency_bolivian_boliviano' => 'Βολιβιάνο Βολιβίας',
    'currency_albanian_lek' => 'Λεκ Αλβανίας',
    'currency_serbian_dinar' => 'Δηνάριο Σερβίας',
    'currency_lebanese_pound' => 'Λίρα Λιβάνου',
    'currency_armenian_dram' => 'Ντραμ Αρμενίας',
    'currency_azerbaijan_manat' => 'Μανάτ Αζερμπαϊτζάν',
    'currency_bosnia_and_herzegovina_convertible_mark' => 'Μάρκο Βοσνίας - Ερζεγοβίνης',
    'currency_belarusian_ruble' => 'Ρούβλι Λευκορωσίας',
    'currency_moldovan_leu' => 'Λεβ Μολδαβίας',
    'currency_kazakhstani_tenge' => 'Τάνγκε Καζακστάν',
    'currency_gibraltar_pound' => 'Λίρα Γιβλαρτάρ',

    'review_app_help' => 'Ελπίζουμε να απολαμβάνετε τη χρήση της εφαρμογής.<br/> Εάν θα θέλατε να γράψετε μια κριτική :link θα το εκτιμούσαμε ιδιαίτερα!',
    'writing_a_review' => 'συγγραφή κριτικής',

    'use_english_version' => 'Σιγουρευτείτε ότι χρησιμοποιείτε την Αγγλική έκδοση των αρχείων.<br/>Χρησιμοποιούμε τις κεφαλίδες των στηλών για να ταιριάξουμε τα πεδία.',
    'tax1' => 'Πρώτο; Φόρος',
    'tax2' => 'Δεύτερος Φόρος',
    'fee_help' => 'Τέλη της πύλης πληρωμής (Gateway) είναι τα κόστη για την πρόσβαση στα δίκτυα που αναλαμβάνουν την επεξεργασία των online πληρωμών',
    'format_export' => 'Μορφή εξαγωγής',
    'custom1' => 'Πρώτη Προσαρμογή',
    'custom2' => 'Δεύτερη Προσαρμογή',
    'contact_first_name' => 'Όνομα Επαφής',
    'contact_last_name' => 'Επώνυμο Επαφής',
    'contact_custom1' => 'Πρώτη Προσαρμογή Επαφής',
    'contact_custom2' => 'Δεύτερη Προσαρμογή Επαφής',
    'currency' => 'Νόμισμα',
    'ofx_help' => 'Για αποσφαλμάτωση  ελέγξτε για σχόλια στο :ofxhome_link και τεστάρετε με :ofxget_link.',
    'comments' => 'σχόλια',

    'item_product' => 'Προϊόν',
    'item_notes' => 'Σημειώσεις Προϊόντος',
    'item_cost' => 'Κόστος Προϊόντος',
    'item_quantity' => 'Ποσότητα Προϊόντος',
    'item_tax_rate' => 'Ποσοστό Φόρου Προϊόντος',
    'item_tax_name' => 'Όνομα Φόρου Προϊόντος',
    'item_tax1' => 'Φόρος1 Προϊόντος',
    'item_tax2' => 'Φόρος2 Προϊόντος',

    'delete_company' => 'Διαγραφή Επιχείρησης',
    'delete_company_help' => 'Οριστική διαγραφή της επιχείρησης μαζί με όλα τα δεδομένα και τις ρυθμίσεις.',
    'delete_company_message' => 'Προειδοποίηση: Αυτό θα διαγράψει οριστικά την επιχείρηση, χωρίς αναίρεση.',

    'applied_discount' => 'Το κουπόνι έχει εφαρμοσθεί, το κόστος του πλάνου έχει μειωθεί κατά :discount%.',
    'applied_free_year' => 'Το κουπόνι έχει εφαρμοσθεί, ο λογαριασμός σας έχει αναβαθμιστεί σε επαγγελματικό για ένα χρόνο.',

    'contact_us_help' => 'Εάν αναφέρετε ένα λάθος παρακαλούμε να συμπεριλάβετε οποιοδήποτε σχετικά logs από τη θέση storage/logs/laravel-error.log',
    'include_errors' => 'Συμπερίληψη Λαθών',
    'include_errors_help' => 'Συμπεριλάβετε το :link από τη θέση storage/logs/laravel-error.log',
    'recent_errors' => 'πρόσφατα σφάλματα',
    'customer' => 'Πελάτης',
    'customers' => 'Πελάτες',
    'created_customer' => 'Επιτυχής δημιουργία πελάτη',
    'created_customers' => 'Επιτυχής δημιουργία :count πελατών',

    'purge_details' => 'Τα δεδομένα στην επιχείρησή σας (:account) έχουν εκκαθαριστεί επιτυχώς.',
    'deleted_company' => 'Επιτυχής διαγραφή επιχείρησης',
    'deleted_account' => 'Επιτυχής ακύρωση λογαριασμού',
    'deleted_company_details' => 'Η επιχείρησή σας (:account) έχει διαγραφεί επιτυχώς.',
    'deleted_account_details' => 'Ο λογαριασμός σας (:account) έχει διαγραφεί επιτυχώς.',

    'alipay' => 'Alipay',
    'sofort' => 'Sofort',
    'sepa' => 'Απευθείας πίστωση SEPA',
    'enable_alipay' => 'Αποδοχή Alipay',
    'enable_sofort' => 'Αποδοχή τραπεζικών εμβασμάτων από τράπεζες της Ευρώπης',
    'stripe_alipay_help' => 'Αυτές οι πύλες πληρωμών πρέπει επίσης να ενεργοποιηθούν στο :link.',
    'calendar' => 'Ημερολόγιο',
    'pro_plan_calendar' => ':link για να ενεργοποιήσετε το ημερολόγιο συμμετέχοντας στο Επαγγελματικό Πλάνο',

    'what_are_you_working_on' => 'Σε τι εργάζεστε;',
    'time_tracker' => 'Παρακολούθηση Χρόνου',
    'refresh' => 'Ανανέωση',
    'filter_sort' => 'Φιλτράρισμα/Ταξινόμηση',
    'no_description' => 'Καμία Περιγραφή',
    'time_tracker_login' => 'Εισαγωγή στην Παρακολούθηση Χρόνου',
    'save_or_discard' => 'Αποθήκευση ή απόρριψη των αλλαγών σας',
    'discard_changes' => 'Απόρριψη Αλλαγών',
    'tasks_not_enabled' => 'Οι εργασίες δεν έχουν ενεργοποιηθεί.',
    'started_task' => 'Επιτυχής έναρξη εργασίας',
    'create_client' => 'Δημιουργία Πελάτη',

    'download_desktop_app' => 'Λήψη της εφαρμογής για Desktop',
    'download_iphone_app' => 'Λήψη της εφαρμογής για IPhone',
    'download_android_app' => 'Λήψη της εφαρμογής για Android',
    'time_tracker_mobile_help' => 'κάντε διπλό κλικ στην εργασία για να την επιλέξετε',
    'stopped' => 'Διακόπηκε',
    'ascending' => 'Αύξουσα σειρά',
    'descending' => 'Φθίνουσα σειρά',
    'sort_field' => 'Ταξινόμηση κατά',
    'sort_direction' => 'Κατεύθυνση',
    'discard' => 'Απόρριψη',
    'time_am' => 'πμ',
    'time_pm' => 'μμ',
    'time_mins' => 'λ',
    'time_hr' => 'ω',
    'time_hrs' => 'ω',
    'clear' => 'Καθαρισμός',
    'warn_payment_gateway' => 'Σημείωση: η αποδοχή online πληρωμών απαιτεί μία πύλη πληρωμών, :link για να προσθέσετε μία.',
    'task_rate' => 'Κόστος Εργασίας',
    'task_rate_help' => 'Ορίστε το προκαθορισμένο ποσοστό για τις τιμολογημένες εργασίες.',
    'past_due' => 'Ληγμένα',
    'document' => 'Έγγραφο',
    'invoice_or_expense' => 'Τιμολόγιο/Δαπάνη',
    'invoice_pdfs' => 'Αρχεία PDF Τιμολογίου',
    'enable_sepa' => 'Αποδοχή SEPA',
    'enable_bitcoin' => 'Αποδοχή Bitcoin',
    'iban' => 'IBAN',
    'sepa_authorization' => 'Παρέχοντας το IBAN και επιβεβαιώνοντας αυτή την πληρωμή, εξουσιοδοτείτε την :company και το Stripe, τον πάροχο υπηρεσιών πληρωμών μας, να στείλει οδηγίες στην τράπεζά σας πως να πιστώσει τον λογαριασμό και να πιστώσει το λογαριασμό σε συμφωνία με αυτές τις οδηγίες. Δικαιούστε επιστροφή χρημάτων από την τράπεζά σας βάσει των όρων της σύμβασής σας με την τράπεζά σας. Η επιστροφή των χρημάτων πρέπει να γίνει απαιτητή μέσα σε 8 εβδομάδες από την ημερομηνία που πιστώθηκε ο λογαριασμός σας.',
    'recover_license' => 'Επαναφορά Άδειας Χρήσης',
    'purchase' => 'Αγορά',
    'recover' => 'Επαναφορά',
    'apply' => 'Εφαρμογή',
    'recover_white_label_header' => 'Επαναφορά Άδειας Χρήσης Λευκής Ετικέτας',
    'apply_white_label_header' => 'Εφαρμογή Άδειας Χρήσης Λευκής Ετικέτας',
    'videos' => 'Βίντεο',
    'video' => 'Βίντεο',
    'return_to_invoice' => 'Επιστροφή στο Τιμολόγιο',
    'gateway_help_13' => 'Για να χρησιμοποιήσετε το ITN αφήστε κενό το πεδίο για το κλειδί PDT.',
    'partial_due_date' => 'Ημερομηνία Μερικής Πληρωμής',
    'task_fields' => 'Πεδία Εργασίας',
    'product_fields_help' => 'Μεταφέρετε και αποθέστε πεδία για να αλλάξετε τη σειρά τους',
    'custom_value1' => 'Προσαρμοσμένη Τιμή',
    'custom_value2' => 'Προσαρμοσμένη Τιμή',
    'enable_two_factor' => 'Αυθεντικοποίηση δύο σημείων',
    'enable_two_factor_help' => 'Χρησιμοποιήστε του τηλέφωνό σας για να επιβεβαιώσετε την ταυτότητά σας όταν πραγματοποιείτε είσοδο στο σύστημα',
    'two_factor_setup' => 'Εγκατάσταση δύο σημείων',
    'two_factor_setup_help' => 'Σκανάρετε το barcode με μία :link συμβατή εφαρμογή.',
    'one_time_password' => 'Κωδικός Πρόσβασης μίας Φοράς',
    'set_phone_for_two_factor' => 'Ορίστε τον αριθμό του κινητού τηλεφώνου σας ως αντίγραφο ασφαλείας για ενεργοποίηση.',
    'enabled_two_factor' => 'Επιτυχής ενεργοποίηση Αυθεντικοποίησης Δύο Σημείων',
    'add_product' => 'Προσθήκη Προϊόντος',
    'email_will_be_sent_on' => 'Σημείωση: το email θα αποσταλεί την :date.',
    'invoice_product' => 'Τιμολόγηση Προϊόντος',
    'self_host_login' => 'Στοιχεία εισόδου Ιδίας Φιλοξενίας',
    'set_self_hoat_url' => 'URL Ιδίας Φιλοξενίας',
    'local_storage_required' => 'Σφάλμα: η τοπική αποθήκευση δεν είναι διαθέσιμη.',
    'your_password_reset_link' => 'Ο σύνδεσμος για την επαναφορά του κωδικού πρόσβασής σας',
    'subdomain_taken' => 'Το subdomain χρησιμοποιείται ήδη',
    'client_login' => 'Εισαγωγή Πελάτη',
    'converted_amount' => 'Μετατρεπόμενο Ποσό',
    'default' => 'Προεπιλογή',
    'shipping_address' => 'Διεύθυνση Αποστολής',
    'bllling_address' => 'Διεύθυνση Χρέωσης',
    'billing_address1' => 'Οδός Χρέωσης',
    'billing_address2' => 'Διαμέρισμα Χρέωσης',
    'billing_city' => 'Πόλη Χρέωσης',
    'billing_state' => 'Περιφέρεια Χρέωσης',
    'billing_postal_code' => 'Ταχυδρομικός Κωδικός Χρέωσης',
    'billing_country' => 'Χώρα Χρέωσης',
    'shipping_address1' => 'Οδός Αποστολής',
    'shipping_address2' => 'Διαμέρισμα Αποστολής',
    'shipping_city' => 'Πόλη Αποστολής',
    'shipping_state' => 'Περιφέρεια Αποστολής',
    'shipping_postal_code' => 'Ταχυδρομικός Κώδικας Αποστολής',
    'shipping_country' => 'Χώρα Αποστολής',
    'classify' => 'Κατατάξτε',
    'show_shipping_address_help' => 'Απαιτήστε από τον πελάτη να εισάγει την διεύθυνση αποστολής του',
    'ship_to_billing_address' => 'Αποστολή στη διεύθυνση χρέωσης',
    'delivery_note' => 'Σημείωση Παράδοσης',
    'show_tasks_in_portal' => 'Εμφάνιση εργασιών στο portal του πελάτη',
    'cancel_schedule' => 'Ακύρωση Προγραμματισμού',
    'scheduled_report' => 'Προγραμματισμός Αναφοράς',
    'scheduled_report_help' => 'Στείλτε email με την αναφορά :report ως :format στο :email',
    'created_scheduled_report' => 'Επιτυχής προγραμματισμός αναφοράς',
    'deleted_scheduled_report' => 'Επιτυχής ακύρωση προγραμματισμού αναφοράς',
    'scheduled_report_attached' => 'Η προγραμματισμένη αναφορά τύπου :type είναι συνημμένη.',
    'scheduled_report_error' => 'Αποτυχία δημιουργίας προγραμματισμένης αναφοράς',
    'invalid_one_time_password' => 'Μη έγκυρος κωδικός πρόσβασης μιας φοράς',
    'apple_pay' => 'Apple/Google Πληρωμή',
    'enable_apple_pay' => 'Αποδοχή Πληρωμής Apple και Πληρωμή με Google',
    'requires_subdomain' => 'Αυτός ο τύπος πληρωμής απαιτεί να :link.',
    'subdomain_is_set' => 'subdomain έχει οριστεί',
    'verification_file' => 'Αρχείο Επαλήθευσης',
    'verification_file_missing' => 'Το αρχείο επαλήθευσης είναι απαραίτητο για την αποδοχή πληρωμών.',
    'apple_pay_domain' => 'Χρησιμοποιήστε <code>:domain</code> ως το domain στο :link.',
    'apple_pay_not_supported' => 'Συγνώμη αλλά τα Apple Pay / Google Pay δεν υποστηρίζονται από τον browser σας',
    'optional_payment_methods' => 'Προαιρετικές Μέθοδοι Πληρωμής',
    'add_subscription' => 'Προσθήκη Συνδρομής',
    'target_url' => 'Στόχος',
    'target_url_help' => 'Όταν το επιλεγμένο γεγονός εμφανιστεί η εφαρμογή θα στείλει την οντότητα στο στοχευμένο URL.',
    'event' => 'Γεγονός',
    'subscription_event_1' => 'Δημιουργήθηκε Πελάτης',
    'subscription_event_2' => 'Δημιουργήθηκε Τιμολόγιο',
    'subscription_event_3' => 'Δημιουργήθηκε Προσφορά',
    'subscription_event_4' => 'Δημιουργήθηκε Πληρωμή',
    'subscription_event_5' => 'Δημιουργήθηκε Προμηθευτής',
    'subscription_event_6' => 'Ενημερώθηκε Προσφορά',
    'subscription_event_7' => 'Διαγράφηκε Προσφορά',
    'subscription_event_8' => 'Ενημερώθηκε Τιμολόγιο',
    'subscription_event_9' => 'Διαγράφηκε Τιμολόγιο',
    'subscription_event_10' => 'Ενημερώθηκε ο Πελάτης',
    'subscription_event_11' => 'Διαγράφηκε ο Πελάτης',
    'subscription_event_12' => 'Διαγράφηκε η Πληρωμή',
    'subscription_event_13' => 'Ενημερώθηκε ο Προμηθευτής',
    'subscription_event_14' => 'Διαγράφηκε ο Προμηθευτής',
    'subscription_event_15' => 'Δημιουργήθηκε η Δαπάνη',
    'subscription_event_16' => 'Ενημερώθηκε η Δαπάνη',
    'subscription_event_17' => 'Διαγράφηκε η Δαπάνη',
    'subscription_event_18' => 'Δημιουργήθηκε η Εργασία',
    'subscription_event_19' => 'Ενημερώθηκε η Εργασία',
    'subscription_event_20' => 'Διαγράφηκε η Εργασία',
    'subscription_event_21' => 'Αποδεκτή Προσφορά',
    'subscriptions' => 'Εγγραφές',
    'updated_subscription' => 'Επιτυχής ενημέρωση συνδρομής',
    'created_subscription' => 'Επιτυχής δημιουργία συνδρομής',
    'edit_subscription' => 'Επεξεργασία Συνδρομής',
    'archive_subscription' => 'Αρχειοθέτηση Συνδρομής',
    'archived_subscription' => 'Επιτυχής αρχειοθέτηση συνδρομής',
    'project_error_multiple_clients' => 'Τα projects δεν μπορούν να ανήκουν σε διαφορετικούς πελάτες',
    'invoice_project' => 'Τιμολόγηση Project',
    'module_recurring_invoice' => 'Επαναλαμβανόμενα Τιμολόγια',
    'module_credit' => 'Πιστώσεις',
    'module_quote' => 'Προσφορές & Προτάσεις',
    'module_task' => 'Εργασίες & Projects',
    'module_expense' => 'Δαπάνες & Προμηθευτές',
    'module_ticket' => 'Αιτήματα υποστήριξης',
    'reminders' => 'Υπενθυμίσεις',
    'send_client_reminders' => 'Αποστολή υπενθυμίσεων με email',
    'can_view_tasks' => 'Οι εργασίες εμφανίζονται στο portal',
    'is_not_sent_reminders' => 'Οι υπενθυμίσεις δεν έχουν αποσταλεί',
    'promotion_footer' => 'Η προωθητική ενέργειά σας θα λήξει σύντομα, :link για να αναβαθμίσετε τώρα.',
    'unable_to_delete_primary' => 'Σημείωση: για να διαγράψετε αυτή την επιχείρηση διαγράψτε πρώτα όλες τις συνδεδεμένες επιχειρήσεις.',
    'please_register' => 'Παρακαλούμε καταχωρίστε το λογαριασμό σας',
    'processing_request' => 'Επεξεργασία αιτήματος',
    'mcrypt_warning' => 'Προειδοποίηση: Το Mcrypt βρίσκεται στη διαδικασία απόσυρσης, εκτελέστε το :command για να ενημερώσετε την κρυπτογράφησή σας',
    'edit_times' => 'Επεξεργασία Επαναλήψεων',
    'inclusive_taxes_help' => 'Συμπεριλάβετε <b>φόρους στο κόστος</b>',
    'inclusive_taxes_notice' => 'Αυτή η ρύθμιση δεν μπορεί να αλλάξει όταν ένα τιμολόγιο έχει δημιουργηθεί.',
    'inclusive_taxes_warning' => 'Προειδοποίηση: τα υπάρχοντα τιμολόγια θα χρειαστούν επαναποθήκευση',
    'copy_shipping' => 'Αντιγραφή Αποστολής',
    'copy_billing' => 'Αντιγραφή Χρέωσης',
    'quote_has_expired' => 'Η προσφορά έχει λήξει, παρακαλούμε επικοινωνήστε με τον έμπορο.',
    'empty_table_footer' => 'Εμφάνιση 0 έως 0 από 0 εγγραφές',
    'do_not_trust' => 'Μην θυμηθείς αυτή τη συσκευή',
    'trust_for_30_days' => 'Εμπιστευτείτε για 30 μέρες',
    'trust_forever' => 'Εμπιστευτείτε για πάντα',
    'kanban' => 'Kanban',
    'backlog' => 'Αναμονή',
    'ready_to_do' => 'Έτοιμο',
    'in_progress' => 'Σε εξέλιξη',
    'add_status' => 'Προσθήκη κατάστασης',
    'archive_status' => 'Αρχειοθέτηση Κατάστασης',
    'new_status' => 'Νέα Κατάσταση',
    'convert_products' => 'Μετατροπή Τιμών Προϊόντων',
    'convert_products_help' => 'Αυτόματη μετατροπή τιμών προϊόντων στο νόμισμα συναλλαγών του πελάτη',
    'improve_client_portal_link' => 'Ορίστε ένα subdomain για να μειώσετε το μήκος του συνδέσμου του portal του πελάτη.',
    'budgeted_hours' => 'Χρεώσιμες Ώρες',
    'progress' => 'Πρόοδος',
    'view_project' => 'Εμφάνιση Project',
    'summary' => 'Περίληψη',
    'endless_reminder' => 'Συνεχής Υπενθύμιση',
    'signature_on_invoice_help' => 'Προσθέστε τον ακόλουθο κώδικα για να εμφανίζεται η υπογραφή του πελάτη σας στο PDF.',
    'signature_on_pdf' => 'Εμφάνισε στο PDF',
    'signature_on_pdf_help' => 'Εμφάνισε την υπογραφή του πελάτη στο PDF του τιμολογίου/προσφοράς.',
    'expired_white_label' => 'Η άδεια λευκής ετικέτας έληξε',
    'return_to_login' => 'Επιστροφή στην Είσοδο',
    'convert_products_tip' => 'Σημείωση: προσθέστε ένα :link με την ονομασία ":name" για να δείτε την ισοτιμία.',
    'amount_greater_than_balance' => 'Το ποσό είναι μεγαλύτερο από το υπόλοιπο του τιμολογίου, θα δημιουργηθεί μια πίστωση με το εναπομείναν ποσό.',
    'custom_fields_tip' => 'χρησιμοποιήστε το <code>Label|Option1,Option2</code> για να εμφανίσετε ένα κουτί επιλογών.',
    'client_information' => 'Πληροφορίες Πελάτη',
    'updated_client_details' => 'Επιτυχής ενημέρωση των στοιχείων πελάτη',
    'auto' => 'Αυτόματο',
    'tax_amount' => 'Ποσό Φόρου',
    'tax_paid' => 'Πληρωμένος Φόρος',
    'none' => 'Κανένα',
    'proposal_message_button' => 'Για να δείτε την πρόταση ποσού :amount, πατήστε το παρακάτω κουμπί.',
    'proposal' => 'Πρόταση',
    'proposals' => 'Προτάσεις',
    'list_proposals' => 'Λίστα Προτάσεων',
    'new_proposal' => 'Νέα Πρόταση',
    'edit_proposal' => 'Επεξεργασία Πρότασης',
    'archive_proposal' => 'Αρχειοθέτηση Πρότασης',
    'delete_proposal' => 'Διαγραφή Πρότασης',
    'created_proposal' => 'Επιτυχής δημιουργία πρότασης',
    'updated_proposal' => 'Επιτυχής ενημέρωση πρότασης',
    'archived_proposal' => 'Επιτυχής αρχειοθέτηση πρότασης',
    'deleted_proposal' => 'Επιτυχής αρχειοθέτηση πρότασης',
    'archived_proposals' => 'Επιτυχής αρχειοθέτηση :count προτάσεων',
    'deleted_proposals' => 'Επιτυχής αρχειοθέτηση :count προτάσεων',
    'restored_proposal' => 'Επιτυχής ανάκτηση πρότασης',
    'restore_proposal' => 'Ανάκτηση Πρότασης',
    'snippet' => 'Απόσπασμα',
    'snippets' => 'Αποσπάσματα',
    'proposal_snippet' => 'Απόσπασμα',
    'proposal_snippets' => 'Αποσπάσματα',
    'new_proposal_snippet' => 'Νέο Απόσπασμα',
    'edit_proposal_snippet' => 'Επεξεργασία Αποσπάσματος',
    'archive_proposal_snippet' => 'Αρχειοθέτηση Αποσπάσματος',
    'delete_proposal_snippet' => 'Διαγραφή Αποσπάσματος',
    'created_proposal_snippet' => 'Επιτυχής δημιουργία αποσπάσματος',
    'updated_proposal_snippet' => 'Επιτυχής ενημέρωση αποσπάσματος',
    'archived_proposal_snippet' => 'Επιτυχής αρχειοθέτηση αποσπάσματος',
    'deleted_proposal_snippet' => 'Επιτυχής αρχειοθέτηση αποσπάσματος',
    'archived_proposal_snippets' => 'Επιτυχής αρχειοθέτηση :count αποσπασμάτων',
    'deleted_proposal_snippets' => 'Επιτυχής αρχειοθέτηση :count αποσπασμάτων',
    'restored_proposal_snippet' => 'Επιτυχής ανάκτηση αποσπάσματος',
    'restore_proposal_snippet' => 'Ανάκτηση Αποσπάσματος',
    'template' => 'Πρότυπο',
    'templates' => 'Πρότυπα',
    'proposal_template' => 'Πρότυπο',
    'proposal_templates' => 'Πρότυπα',
    'new_proposal_template' => 'Νέο Πρότυπο',
    'edit_proposal_template' => 'Επεξεργασία Προτύπου',
    'archive_proposal_template' => 'Αρχειοθέτηση Προτύπου',
    'delete_proposal_template' => 'Διαγραφή Προτύπου',
    'created_proposal_template' => 'Επιτυχής δημιουργία προτύπου',
    'updated_proposal_template' => 'Επιτυχής ενημέρωση προτύπου',
    'archived_proposal_template' => 'Επιτυχής αρχειοθέτηση προτύπου',
    'deleted_proposal_template' => 'Επιτυχής αρχειοθέτηση προτύπου',
    'archived_proposal_templates' => 'Επιτυχής αρχειοθέτηση :count προτύπων',
    'deleted_proposal_templates' => 'Επιτυχής αρχειοθέτηση :count προτύπων',
    'restored_proposal_template' => 'Επιτυχής ανάκτηση προτύπου',
    'restore_proposal_template' => 'Ανάκτηση Προτύπου',
    'proposal_category' => 'Κατηγορία',
    'proposal_categories' => 'Κατηγορίες',
    'new_proposal_category' => 'Νέα Κατηγορία',
    'edit_proposal_category' => 'Επεξεργασία Κατηγορίας',
    'archive_proposal_category' => 'Αρχειοθέτηση Κατηγορίας',
    'delete_proposal_category' => 'Διαγραφή Κατηγορίας',
    'created_proposal_category' => 'Επιτυχής δημιουργία κατηγορίας',
    'updated_proposal_category' => 'Επιτυχής ενημέρωση κατηγορίας',
    'archived_proposal_category' => 'Επιτυχής αρχειοθέτηση κατηγορίας',
    'deleted_proposal_category' => 'Επιτυχής αρχειοθέτηση κατηγορίας',
    'archived_proposal_categories' => 'Επιτυχής αρχειοθέτηση :count κατηγοριών',
    'deleted_proposal_categories' => 'Επιτυχής αρχειοθέτηση :count κατηγοριών',
    'restored_proposal_category' => 'Επιτυχής ανάκτηση κατηγορίας',
    'restore_proposal_category' => 'Ανάκτηση Κατηγορίας',
    'delete_status' => 'Διαγραφή Κατάστασης',
    'standard' => 'Στάνταρ',
    'icon' => 'Εικονίδιο',
    'proposal_not_found' => 'Η ζητούμενη πρόταση τιμολόγιο δεν είναι διαθέσιμη',
    'create_proposal_category' => 'Δημιουργία κατηγορίας',
    'clone_proposal_template' => 'Κλωνοποίηση Προτύπου',
    'proposal_email' => 'Email πρότασης',
    'proposal_subject' => 'Νέα πρόταση :number από :account',
    'proposal_message' => 'Για να δείτε την πρόταση ποσού :amount, πατήστε τον παρακάτω σύνδεσμο.',
    'emailed_proposal' => 'Επιτυχής αποστολή πρότασης',
    'load_template' => 'Φόρτωση Προτύπου',
    'no_assets' => 'Δεν υπάρχουν εικόνες, σύρατε για μεταφόρτωση',
    'add_image' => 'Προσθήκη εικόνας',
    'select_image' => 'Επιλογή εικόνας',
    'upgrade_to_upload_images' => 'Αναβαθμίστε στο Εταιρικό πλάνο για να μεταφορτώσετε εικόνες',
    'delete_image' => 'Διαγραφή εικόνας',
    'delete_image_help' => 'Ειδοποίηση: διαγράφοντας την εικόνα θα την αφαιρέσει από όλες τις προτάσεις.',
    'amount_variable_help' => 'Σημείωση: το πεδίο $amount του τιμολογίου θα χρησιμοποιήσει το πεδίο μερική προκαταβολή εάν οριστεί διαφορετικά θα χρησιμοποιήσει το υπόλοιπο του τιμολογίου.',
    'taxes_are_included_help' => 'Σημείωση: Οι περιλαμβανόμενοι φόροι έχουν ενεργοποιηθεί.',
    'taxes_are_not_included_help' => 'Σημείωση: Οι περιλαμβανόμενοι φόροι δεν έχουν ενεργοποιηθεί.',
    'change_requires_purge' => 'Η αλλαγή αυτών των ρυθμίσεων απαιτεί :link τα δεδομένα του λογαριασμού.',
    'purging' => 'καθαρισμός',
    'warning_local_refund' => 'Η επιστροφή χρημάτων θα καταγραφεί στην εφαρμογή αλλά ΔΕΝ θα εκτελεστεί από την πύλη πληρωμών (gateway).',
    'email_address_changed' => 'Η διεύθυνση email έχει αλλάξει.',
    'email_address_changed_message' => 'Η διεύθυνση email του λογαριασμού σας άλλαξε από :old_email σε :new_email.',
    'test' => 'Τεστ',
    'beta' => 'Beta',
    'gmp_required' => 'Η εξαγωγή σε ZIP απαιτεί την επέκταση GMP',
    'email_history' => 'Ιστορικό Email',
    'loading' => 'Φόρτωση',
    'no_messages_found' => 'Δεν βρέθηκαν μηνύματα',
    'processing' => 'Επεξεργασία',
    'reactivate' => 'Επανενεργοποίηση',
    'reactivated_email' => 'Η διεύθυνση email έχει επανενεργοποιηθεί.',
    'emails' => 'Emails',
    'opened' => 'Ανοίχθηκε',
    'bounced' => 'Επεστράφη',
    'total_sent' => 'Στάλθηκαν Συνολικά',
    'total_opened' => 'Ανοίχθηκαν Συνολικά',
    'total_bounced' => 'Επεστράφησαν Συνολικά',
    'total_spam' => 'Χαρακτηρίστηκαν Spam Συνολικά',
    'platforms' => 'Πλατφόρμες',
    'email_clients' => 'Πρόγραμμα Email',
    'mobile' => 'Κινητό',
    'desktop' => 'Σταθερός υπολογιστής',
    'webmail' => 'Webmail',
    'group' => 'Ομάδα',
    'subgroup' => 'Υποομάδα',
    'unset' => 'Αναίρεση ορισμού',
    'received_new_payment' => 'Δεχθήκατε μία καινούργια πληρωμή.',
    'slack_webhook_help' => 'Δεχθείτε ενημερώσεις πληρωμών χρησιμοποιώντας το :link.',
    'slack_incoming_webhooks' => 'Εισερχόμενα webhooks από το Slack',
    'accept' => 'Αποδοχή',
    'accepted_terms' => 'Επιτυχής αποδοχή των τελευταίων όρων χρήσης',
    'invalid_url' => 'Εσφαλμένο URL',
    'workflow_settings' => 'Ρυθμίσεις Ροής Εργασιών',
    'auto_email_invoice' => 'Αυτόματο Email',
    'auto_email_invoice_help' => 'Αυτόματη αποστολή επαναλαμβανόμενων τιμολογίων με email όταν δημιουργηθούν.',
    'auto_archive_invoice' => 'Αυτόματη Αρχειοθέτηση',
    'auto_archive_invoice_help' => 'Αυτόματη αρχειοθέτηση τιμολογίων όταν εξοφληθούν.',
    'auto_archive_quote' => 'Αυτόματη Αρχειοθέτηση',
    'auto_archive_quote_help' => 'Αυτόματη αρχειοθέτηση προσφορών όταν μετατραπούν.',
    'require_approve_quote' => 'Απαίτηση για αποδοχή της προσφοράς',
    'require_approve_quote_help' => 'Απαίτηση από τον πελάτη να αποδεχθεί την προσφορά.',
    'allow_approve_expired_quote' => 'Επιτρέψτε την αποδοχή προσφοράς που έχει λήξει.',
    'allow_approve_expired_quote_help' => 'Επιτρέψτε στους πελάτες την αποδοχή προσφορών που έχουν λήξει.',
    'invoice_workflow' => 'Τιμολόγηση Ροής Εργασιών',
    'quote_workflow' => 'Προσφορά  Ροής Εργασιών',
    'client_must_be_active' => 'Σφάλμα: ο πελάτης πρέπει να είναι ενεργός',
    'purge_client' => 'Εκκαθάριση Πελάτη',
    'purged_client' => 'Επιτυχής εκκαθάριση πελάτη',
    'purge_client_warning' => 'Όλες οι σχετικές εγγραφές (τιμολόγια, εργασίες, δαπάνες, αρχεία, κλπ) θα διαγραφούν επίσης.',
    'clone_product' => 'Κλωνοποίηση Προϊόντος',
    'item_details' => 'Στοιχεία Προϊόντος',
    'send_item_details_help' => 'Αποστείλετε τα στοιχεία ανά γραμμή στην πύλη πληρωμών.',
    'view_proposal' => 'Προβολή Πρότασης',
    'view_in_portal' => 'Προβολή στο Portal',
    'cookie_message' => 'Αυτός ο ιστότοπος χρησιμοποιεί cookies για να βεβαιωθεί ότι απολαμβάνετε τη βέλτιστη δυνατή εμπειρία πλοήγησης.',
    'got_it' => 'Το κατάλαβα!',
    'vendor_will_create' => 'προμηθευτής θα δημιουργηθεί',
    'vendors_will_create' => 'προμηθευτές θα δημιουργηθούν',
    'created_vendors' => 'Επιτυχής δημιουργία :count προμηθευτών',
    'import_vendors' => 'Εισαγωγή Προμηθευτών',
    'company' => 'Εταιρεία',
    'client_field' => 'Πεδίο Πελάτη',
    'contact_field' => 'Πεδίο Επαφής',
    'product_field' => 'Πεδίο Προϊόντος',
    'task_field' => 'Πεδίο Εργασίας',
    'project_field' => 'Πεδίο Project',
    'expense_field' => 'Πεδίο Δαπάνης',
    'vendor_field' => 'Πεδίο Προμηθευτή',
    'company_field' => 'Πεδίο Εταιρείας',
    'invoice_field' => 'Πεδίο Τιμολογίου',
    'invoice_surcharge' => 'Επιβάρυνση Τιμολογίου',
    'custom_task_fields_help' => 'Προσθήκη πεδίου όταν δημιουργείται μία εργασία.',
    'custom_project_fields_help' => 'Προσθήκη πεδίου όταν δημιουργείται ένα project.',
    'custom_expense_fields_help' => 'Προσθήκη πεδίου όταν δημιουργείται μία δαπάνη.',
    'custom_vendor_fields_help' => 'Προσθήκη πεδίου όταν δημιουργείται ένας προμηθευτής.',
    'messages' => 'Μηνύματα',
    'unpaid_invoice' => 'Μη Εξοφλημένο Τιμολόγιο',
    'paid_invoice' => 'Εξοφλημένο Τιμολόγιο',
    'unapproved_quote' => 'Μη Εγκεκριμένη Προσφορά',
    'unapproved_proposal' => 'Μη Εγκεκριμένη Πρόταση',
    'autofills_city_state' => 'Αυτόματη συμπλήρωση πόλης/περιφέρειας',
    'no_match_found' => 'Δεν βρέθηκε αντιστοιχία',
    'password_strength' => 'Πολυπλοκότητα Κωδικού Πρόσβασης',
    'strength_weak' => 'Χαμηλή',
    'strength_good' => 'Καλή',
    'strength_strong' => 'Υψηλή',
    'mark' => 'Σήμανση',
    'updated_task_status' => 'Επιτυχής ενημέρωση κατάστασης εργασίας',
    'background_image' => 'Εικόνα φόντου',
    'background_image_help' => 'Χρησιμοποιήστε το :link για να διαχειριστείτε τις εικόνες σας, προτείνουμε να χρησιμοποιήσετε ένα μικρότερο αρχείο.',
    'proposal_editor' => 'επεξεργαστής πρότασης',
    'background' => 'Φόντο',
    'guide' => 'Οδηγός',
    'gateway_fee_item' => 'Τέλη Πύλης Πληρωμής για το προϊόν',
    'gateway_fee_description' => 'Τέλος Προμήθειας Πύλης Πληρωμής',
    'gateway_fee_discount_description' => 'Έκπτωση Τέλους Πύλης Πληρωμής',
    'show_payments' => 'Εμφάνιση Πληρωμών',
    'show_aging' => 'Εμφάνιση Γήρανσης',
    'reference' => 'Αναφορά',
    'amount_paid' => 'Εξοφλημένο Ποσό',
    'send_notifications_for' => 'Αποστολή Ειδοποιήσεων Για',
    'all_invoices' => 'Όλα τα Τιμολόγια',
    'my_invoices' => 'Τα δικά μου Τιμολόγια',
    'payment_reference' => 'Κωδικός Πληρωμής',
    'maximum' => 'Μέγιστο',
    'sort' => 'Ταξινόμηση',
    'refresh_complete' => 'Ανανέωση Ολοκληρώθηκε',
    'please_enter_your_email' => 'Παρακαλώ εισάγετε το email σας',
    'please_enter_your_password' => 'Παρακαλώ εισάγετε τον κωδικό πρόσβασής σας',
    'please_enter_your_url' => 'Παρακαλώ εισάγετε το URL σας',
    'please_enter_a_product_key' => 'Παρακαλώ εισάγετε το κλειδί προϊόντος σας',
    'an_error_occurred' => 'Εμφανίστηκε ένα σφάλμα.',
    'overview' => 'Επισκόπηση',
    'copied_to_clipboard' => 'Αντιγράφτηκε :value στο πρόχειρο',
    'error' => 'Σφάλμα',
    'could_not_launch' => 'Αδύνατη η εκτέλεση',
    'additional' => 'Επιπρόσθετο',
    'ok' => 'Ok',
    'email_is_invalid' => 'Το Email είναι εσφαλμένο',
    'items' => 'Προϊόντα',
    'partial_deposit' => 'Μερικό/Κατάθεση',
    'add_item' => 'Προσθήκη Προϊόντος',
    'total_amount' => 'Συνολικό Ποσό',
    'pdf' => 'PDF',
    'invoice_status_id' => 'Κατάσταση Τιμολογίου',
    'click_plus_to_add_item' => 'Πιέστε το + για την προσθήκη ενός προϊόντος',
    'count_selected' => ':count επιλέχθηκε',
    'dismiss' => 'Απέρριψε',
    'please_select_a_date' => 'Παρακαλώ επιλέξτε ημερομηνία',
    'please_select_a_client' => 'Παρακαλώ επιλέξτε πελάτη',
    'language' => 'Γλώσσα',
    'updated_at' => 'Ενημερώθηκε',
    'please_enter_an_invoice_number' => 'Παρακαλώ εισάγετε ένα αριθμό τιμολογίου',
    'please_enter_a_quote_number' => 'Παρακαλώ εισάγετε ένα αριθμό προσφοράς',
    'clients_invoices' => 'τιμολόγια του πελάτη :client',
    'viewed' => 'Εμφανισμένα',
    'approved' => 'Αποδεκτή',
    'invoice_status_1' => 'Πρόχειρο',
    'invoice_status_2' => 'Απεσταλμένα',
    'invoice_status_3' => 'Εμφανισμένα',
    'invoice_status_4' => 'Αποδεκτή',
    'invoice_status_5' => 'Μερικό',
    'invoice_status_6' => 'Πληρωμένα',
    'marked_invoice_as_sent' => 'Επιτυχής ορισμός τιμολογίου ως απεσταλμένο',
    'please_enter_a_client_or_contact_name' => 'Παρακαλώ εισάγετε ένα πελάτη ή το όνομα μίας επαφής',
    'restart_app_to_apply_change' => 'Επανεκκινήστε την εφαρμογή για να εφαρμόσετε την αλλαγή',
    'refresh_data' => 'Ανανέωση Δεδομένων',
    'blank_contact' => 'Κενή Επαφή',
    'no_records_found' => 'Δεν βρέθηκαν εγγραφές',
    'industry' => 'Βιομηχανία',
    'size' => 'Μέγεθος',
    'net' => 'Καθαρό',
    'show_tasks' => 'Εμφάνιση εργασιών',
    'email_reminders' => 'Email Υπενθύμίσεις',
    'reminder1' => 'Πρώτη Υπενθύμιση',
    'reminder2' => 'Δεύτερη Υπενθύμιση',
    'reminder3' => 'Τρίτη Υπενθύμιση',
    'send' => 'Αποστολή',
    'auto_billing' => 'Αυτόματη Χρέωση',
    'button' => 'Κουμπί',
    'more' => 'Περισσότερα',
    'edit_recurring_invoice' => 'Επεξεργασία Επαναλαμβανόμενων Τιμολογίων',
    'edit_recurring_quote' => 'Επεξεργασία Επαναλαμβανόμενων Προσφορών',
    'quote_status' => 'Κατάσταση Προσφοράς',
    'please_select_an_invoice' => 'Παρακαλώ επιλέξτε ένα τιμολόγιο',
    'filtered_by' => 'Φιλτράρισμα με',
    'payment_status' => 'Κατάσταση Πληρωμής',
    'payment_status_1' => 'Εκκρεμής',
    'payment_status_2' => 'Σε λήξη',
    'payment_status_3' => 'Απέτυχε',
    'payment_status_4' => 'Ολοκληρώθηκε',
    'payment_status_5' => 'Μερική επιστροφή χρημάτων',
    'payment_status_6' => 'Επιστροφή χρημάτων',
    'send_receipt_to_client' => 'Αποστολή απόδειξης στον πελάτη',
    'refunded' => 'Επιστροφή χρημάτων',
    'marked_quote_as_sent' => 'Επιτυχής ορισμός προσφοράς ως απεσταλμένη',
    'custom_module_settings' => 'Ρυθμίσεις Προσαρμοσμένης Μονάδας',
    'ticket' => 'Αίτημα υποστήριξης',
    'tickets' => 'Αιτήματα υποστήριξης',
    'ticket_number' => 'Αίτημα υποστήριξης #',
    'new_ticket' => 'Νέο Αίτημα υποστήριξης',
    'edit_ticket' => 'Επεξεργασία Αιτήματος υποστήριξης',
    'view_ticket' => 'Προβολή Αιτήματος υποστήριξης',
    'archive_ticket' => 'Αρχειοθέτηση Αιτήματος υποστήριξης',
    'restore_ticket' => 'Ανάκτηση Αιτήματος υποστήριξης',
    'delete_ticket' => 'Διαγραφή Αιτήματος υποστήριξης',
    'archived_ticket' => 'Επιτυχής αρχειοθέτηση αιτήματος υποστήριξης',
    'archived_tickets' => 'Επιτυχής αρχειοθέτηση αιτήματος υποστήριξης',
    'restored_ticket' => 'Επιτυχής ανάκτηση αιτήματος υποστήριξης',
    'deleted_ticket' => 'Επιτυχής διαγραφή αιτήματος υποστήριξης',
    'open' => 'Ανοιχτό',
    'new' => 'Νέο',
    'closed' => 'Κλειστό',
    'reopened' => 'Επανανοίχθηκε',
    'priority' => 'Προτεραιότητα',
    'last_updated' => 'Τελευταία ενημέρωση',
    'comment' => 'Σχόλια',
    'tags' => 'Ετικέτες',
    'linked_objects' => 'Συσχετισμένα Αντικείμενα',
    'low' => 'Χαμηλό',
    'medium' => 'Μεσαίο',
    'high' => 'Υψηλό',
    'no_due_date' => 'Δεν ορίστηκε ημερομηνία πληρωμής',
    'assigned_to' => 'Ανατέθηκε σε',
    'reply' => 'Απάντηση',
    'awaiting_reply' => 'Αναμονή απάντησης',
    'ticket_close' => 'Κλείσιμο Αιτήματος υποστήριξης',
    'ticket_reopen' => 'Επανάνοιγμα Αιτήματος υποστήριξης',
    'ticket_open' => 'Άνοιγμα Αιτήματος υποστήριξης',
    'ticket_split' => 'Διχοτόμηση Αιτήματος υποστήριξης',
    'ticket_merge' => 'Συνένωση Αιτήματος υποστήριξης',
    'ticket_update' => 'Ενημέρωση Αιτήματος υποστήριξης',
    'ticket_settings' => 'Ρυθμίσεις Αιτήματος υποστήριξης',
    'updated_ticket' => 'Ενημερώθηκε το Αίτημα υποστήριξης',
    'mark_spam' => 'Σήμανση ως ανεπιθύμητο',
    'local_part' => 'Τοπικό Τμήμα',
    'local_part_unavailable' => 'Το όνομα είναι δεσμευμένο',
    'local_part_available' => 'Το όνομα είναι ελεύθερο',
    'local_part_invalid' => 'Μη επιτρεπόμενο όνομα (μόνο αλφαβητικοί χαρακτήρες, χωρίς κενά)',
    'local_part_help' => 'Προσαρμόστε το τοπικό τμήμα από τα εισερχόμενα αιτήματα υποστήριξης πχ. YOUR_NAME@support.invoiceninja.com',
    'from_name_help' => 'Αναγνωρίζεται ο αποστολέας και πλέον εμφανίζεται το όνομά του αντί για τη διεύθυνση email του, πχ. Κέντρο Υποστήριξης',
    'local_part_placeholder' => 'YOUR_NAME',
    'from_name_placeholder' => 'Κέντρο Υποστήριξης',
    'attachments' => 'Συνημμένα',
    'client_upload' => 'Μεταφορτώσεις Πελάτη',
    'enable_client_upload_help' => 'Επιτρέψτε στους πελάτες να μεταφορτώνουν αρχεία/συνημμένα',
    'max_file_size_help' => 'Το μέγιστο μέγεθος αρχείων (KB) περιορίζεται από τις μεταβλητές post_max_size και upload_max_filesize που ορίζονται στο αρχείο PHP.INI',
    'max_file_size' => 'Μέγιστο μέγεθος αρχείου',
    'mime_types' => 'Τύποι αρχείων',
    'mime_types_placeholder' => '.pdf , .docx, .jpg',
    'mime_types_help' => 'Λίστα χωριζόμενων με κόμμα τύπων αρχείων, αφήστε το κενό για όλους',
    'ticket_number_start_help' => 'Ο αριθμός του αιτήματος υποστήριξης πρέπει να είναι μεγαλύτερος από τον τρέχοντα αριθμό αιτήματος βοήθειας',
    'new_ticket_template_id' => 'Νέο αίτημα υποστήριξης',
    'new_ticket_autoresponder_help' => 'Η επιλογή ενός προτύπου θα στείλει μία αυτόματη ειδοποίηση στον πελάτη/επαφή όταν δημιουργηθεί ένα νέο αίτημα υποστήριξης.',
    'update_ticket_template_id' => 'Ενημερωμένο Αιτήματος υποστήριξης',
    'update_ticket_autoresponder_help' => 'Η επιλογή ενός προτύπου θα στείλει μία αυτόματη ειδοποίηση στον πελάτη/επαφή όταν ανανεωθεί ένα αίτημα υποστήριξης.',
    'close_ticket_template_id' => 'Κλεισμένο Αίτημα υποστήριξης',
    'close_ticket_autoresponder_help' => 'Η επιλογή ενός προτύπου θα στείλει μία αυτόματη ειδοποίηση στον πελάτη/επαφή όταν κλείσει ένα αίτημα υποστήριξης.',
    'default_priority' => 'Προεπιλεγμένη προτεραιότητα',
    'alert_new_comment_id' => 'Νέο σχόλιο',
    'alert_comment_ticket_help' => 'Η επιλογή ενός προτύπου θα στείλει μία ειδοποίηση (στον εκπρόσωπο) όταν προστεθεί ένα σχόλιο.',
    'alert_comment_ticket_email_help' => 'Διαχωρίστε με κόμμα τα emails για να σταλεί μια κρυφή κοινοποίηση σε κάθε νέο σχόλιο',
    'new_ticket_notification_list' => 'Επιπλέον ειδοποιήσεις νέου αιτήματος υποστήριξης',
    'update_ticket_notification_list' => 'Επιπλέον ειδοποιήσεις νέου σχολίου',
    'comma_separated_values' => 'admin@example.com, supervisor@example.com',
    'alert_ticket_assign_agent_id' => 'Ανάθεση αιτήματος υποστήριξης',
    'alert_ticket_assign_agent_id_hel' => 'Η επιλογή ενός προτύπου θα στείλει μία ειδοποίηση (στον εκπρόσωπο) όταν ανατεθεί ένα αίτημα υποστήριξης.',
    'alert_ticket_assign_agent_id_notifications' => 'Επιπλέον ειδοποιήσεις ανάθεσης αιτήματος υποστήριξης',
    'alert_ticket_assign_agent_id_help' => 'Διαχωρίστε με κόμμα τα emails για να σταλεί μια κρυφή κοινοποίηση όταν ανατεθεί το αίτημα υποστήριξης',
    'alert_ticket_transfer_email_help' => 'Διαχωρίστε με κόμμα τα emails για να σταλεί μια κρυφή κοινοποίηση όταν μεταφερθεί το αίτημα υποστήριξης',
    'alert_ticket_overdue_agent_id' => 'Αίτημα υποστήριξης σε καθυστέρηση',
    'alert_ticket_overdue_email' => 'Επιπλέον ειδοποιήσεις καθυστερούμενου αιτήματος υποστήριξης',
    'alert_ticket_overdue_email_help' => 'Διαχωρίστε με κόμμα τα emails για να σταλεί μια κρυφή κοινοποίηση όταν το αίτημα υποστήριξης τεθεί σε καθυστέρηση',
    'alert_ticket_overdue_agent_id_help' => 'Η επιλογή ενός προτύπου θα στείλει μία ειδοποίηση (στον εκπρόσωπο) όταν ένα αίτημα υποστήριξης γίνει εκπρόθεσμο.',
    'ticket_master' => 'Αρχηγός Αιτημάτων Βοήθειας',
    'ticket_master_help' => 'Έχει τη δυνατότητα να αναθέτει και να μεταφέρει αιτήματα υποστήριξης. Ορίζεται ως προεπιλεγμένος εκπρόσωπος σε όλα τα αιτήματα υποστήριξης.',
    'default_agent' => 'Προεπιλεγμένος Εκπρόσωπος',
    'default_agent_help' => 'Εάν επιλεγεί θα του ανατεθούν όλα τα εισερχόμενα αιτήματα υποστήριξης',
    'show_agent_details' => 'Εμφάνιση λεπτομερειών εκπροσώπου στις απαντήσεις',
    'avatar' => 'Avatar',
    'remove_avatar' => 'Διαγραφή avatar',
    'ticket_not_found' => 'Δεν βρέθηκε το αίτημα υποστήριξης',
    'add_template' => 'Προσθήκη Προτύπου',
    'ticket_template' => 'Πρότυπο αιτήματος υποστήριξης',
    'ticket_templates' => 'Πρότυπα αιτήματος υποστήριξης',
    'updated_ticket_template' => 'Ενημερώθηκε το πρότυπο αιτήματος υποστήριξης',
    'created_ticket_template' => 'Δημιουργήθηκε το πρότυπο αιτήματος υποστήριξης',
    'archive_ticket_template' => 'Αρχειοθέτηση Προτύπου',
    'restore_ticket_template' => 'Ανάκτηση Προτύπου',
    'archived_ticket_template' => 'Επιτυχής αρχειοθέτηση προτύπου',
    'restored_ticket_template' => 'Επιτυχής ανάκτηση προτύπου',
    'close_reason' => 'Ενημερώστε μας γιατί κλείνετε αυτό το αίτημα υποστήριξης',
    'reopen_reason' => 'Ενημερώστε μας γιατί ξανά ανοίγετε αυτό το αίτημα υποστήριξης',
    'enter_ticket_message' => 'Παρακαλώ εισάγετε ένα μήνυμα για να ενημερώσετε το αίτημα υποστήριξης',
    'show_hide_all' => 'Εμφάνιση / Απόκρυψη όλων',
    'subject_required' => 'Απαιτείται Θέμα',
    'mobile_refresh_warning' => 'Εάν χρησιμοποιείτε την εφαρμογή κινητού ίσως χρειαστεί να κάνετε μία πλήρη ανανέωση.',
    'enable_proposals_for_background' => 'Για να ανεβάσετε μια εικόνα φόντου :link για να ενεργοποιήσετε τη λειτουργική μονάδα προτάσεων.',
    'ticket_assignment' => 'Το αίτημα υποστήριξης :ticket_number έχει ανατεθεί στον :agent',
    'ticket_contact_reply' => 'Το αίτημα υποστήριξης :ticket_number έχει ενημερωθεί από τον πελάτη :contact',
    'ticket_new_template_subject' => 'Το αίτημα υποστήριξης :ticket_number έχει δημιουργηθεί.',
    'ticket_updated_template_subject' => 'Το αίτημα υποστήριξης :ticket_number έχει ανανεωθεί.',
    'ticket_closed_template_subject' => 'Το αίτημα υποστήριξης :ticket_number έχει κλείσει.',
    'ticket_overdue_template_subject' => 'Το αίτημα υποστήριξης :ticket_number βρίσκεται πλέον σε καθυστέρηση',
    'merge' => 'Συνένωση',
    'merged' => 'Συνενώθηκε',
    'agent' => 'Εκπρόσωπος',
    'parent_ticket' => 'Πατρικό Αίτημα υποστήριξης',
    'linked_tickets' => 'Συνδεδεμένα Αιτήματα υποστήριξης',
    'merge_prompt' => 'Επιλέξτε αριθμό αιτήματος υποστήριξης στο οποίο να γίνει η συνένωση',
    'merge_from_to' => 'Το αίτημα υποστήριξης #:old_ticket συνενώθηκε στο αίτημα υποστήριξης #:new_ticket',
    'merge_closed_ticket_text' => 'Το αίτημα υποστήριξης #:old_ticket έκλεισε και συνενώθηκε στο αίτημα υποστήριξης #:new_ticket',
    'merge_updated_ticket_text' => 'Το αίτημα υποστήριξης #:old_ticket έκλεισε και συνενώθηκε στο παρόν αίτημα υποστήριξης',
    'merge_placeholder' => 'Συνενώστε το αίτημα υποστήριξης #:ticket στο ακόλουθο αίτημα υποστήριξης',
    'select_ticket' => 'Επιλέξτε Αίτημα υποστήριξης',
    'new_internal_ticket' => 'Νέο εσωτερικό αίτημα υποστήριξης',
    'internal_ticket' => 'Εσωτερικό αίτημα υποστήριξης',
    'create_ticket' => 'Δημιουργήστε αίτημα υποστήριξης',
    'allow_inbound_email_tickets_external' => 'Νέα Αιτήματα υποστήριξης ανά email (Πελάτη)',
    'allow_inbound_email_tickets_external_help' => 'Επιτρέψτε στους πελάτες να δημιουργούν αιτήματα υποστήριξης μέσω email',
    'include_in_filter' => 'Συμπεριλάβετε στο φίλτρο',
    'custom_client1' => ':VALUE',
    'custom_client2' => ':VALUE',
    'compare' => 'Σύγκρινε',
    'hosted_login' => 'Εισαγωγή σε φιλοξενούμενη έκδοση',
    'selfhost_login' => 'Εισαγωγή σε αυτο-φιλοξενούμενη έκδοση',
    'google_login' => 'Εισαγωγή μέσω Google',
    'thanks_for_patience' => 'Ευχαριστούμε για την υπομονή σας καθώς εργαζόμαστε για την ενσωμάτωση αυτών των χαρακτηριστικών.\n\nΕλπίζουμε να τα έχουμε ολοκληρώσει μέσα στους επόμενους μήνες.\n\nΜέχρι τότε θα συνεχίσουμε να υποστηρίζουμε την ',
    'legacy_mobile_app' => 'Εφαρμογή προηγούμενης γενιάς για κινητά',
    'today' => 'Σήμερα',
    'current' => 'Τωρινή',
    'previous' => 'Προηγούμενη',
    'current_period' => 'Τωρινή Περίοδος',
    'comparison_period' => 'Περίοδος Σύγκρισης',
    'previous_period' => 'Προηγούμενη Περίοδος',
    'previous_year' => 'Προηγούμενος Χρόνος',
    'compare_to' => 'Σύγκριση με',
    'last_week' => 'Προηγούμενη Εβδομάδα',
    'clone_to_invoice' => 'Κλωνοποίηση σε Τιμολόγιο',
    'clone_to_quote' => 'Κλωνοποίηση σε Προσφορά',
    'convert' => 'Μετατροπή',
    'last7_days' => 'Προηγούμενες 7 ημέρες',
    'last30_days' => 'Τελευταίες 30 Ημέρες',
    'custom_js' => 'Προσαρμοσμένη JS',
    'adjust_fee_percent_help' => 'Τροποποίηση του ποσοστού του λογαριασμού για τέλος',
    'show_product_notes' => 'Εμφάνιση λεπτομερειών προϊόντος',
    'show_product_notes_help' => 'Συμπεριλάβετε την <b>περιγραφή και κόστος</b> στην ανάλυση του προϊόντος',
    'important' => 'Σημαντικό',
    'thank_you_for_using_our_app' => 'Ευχαριστούμε που χρησιμοποιήσατε την εφαρμογή μας!',
    'if_you_like_it' => 'Εάν σας αρέσει παρακαλούμε',
    'to_rate_it' => 'για να το αξιολογήσετε.',
    'average' => 'Μέσος όρος',
    'unapproved' => 'Μη εγκεκριμένη',
    'authenticate_to_change_setting' => 'Παρακαλούμε αυθεντικοποιήστε για να αλλάξετε αυτή τη ρύθμιση',
    'locked' => 'Κλειδωμένη',
    'authenticate' => 'Αυθεντικοποιήστε',
    'please_authenticate' => 'Παρακαλούμε αυθεντικοποιήστε',
    'biometric_authentication' => 'Βιομετρικη αυθεντικοποίηση',
    'auto_start_tasks' => 'Αυτόματη Έναρξη Εργασιών',
    'budgeted' => 'Προϋπολογισμένο',
    'please_enter_a_name' => 'Παρακαλούμε εισάγετε ένα όνομα',
    'click_plus_to_add_time' => 'Πιέστε το + για να προσθέσετε χρόνο',
    'design' => 'Σχεδίαση',
    'password_is_too_short' => 'Ο κωδικός πρόσβασης είναι πολύ μικρός',
    'failed_to_find_record' => 'Αποτυχία ανεύρεσης εγγραφής',
    'valid_until_days' => 'Έγκυρο Έως',
    'valid_until_days_help' => 'Ορίστε αυτόματα την τιμή <b>Έγκυρο Έως</b> στις προσφορές τόσες μέρες στο μέλλον. Αφήστε κενό για απενεργοποίηση.',
    'usually_pays_in_days' => 'Ημέρες',
    'requires_an_enterprise_plan' => 'Απαιτεί ένα επαγγελματικό πλάνο',
    'take_picture' => 'Λήψη Φωτογραφίας',
    'upload_file' => 'Μεταφόρτωση Αρχείου',
    'new_document' => 'Νέο έγγραφο',
    'edit_document' => 'Επεξεργασία Εγγράφου',
    'uploaded_document' => 'Επιτυχής μεταφόρτωση αρχείου',
    'updated_document' => 'Επιτυχής ενημέρωση αρχείου',
    'archived_document' => 'Επιτυχής αρχειοθέτηση αρχείου',
    'deleted_document' => 'Επιτυχής διαγραφή αρχείου',
    'restored_document' => 'Επιτυχής επαναφορά αρχείου',
    'no_history' => 'Δεν υπάρχει ιστορικό',
    'expense_status_1' => 'Καταγεγραμμένο',
    'expense_status_2' => 'Σε αναμονή',
    'expense_status_3' => 'Τιμολογημένο',
    'no_record_selected' => 'Δεν έχουν επιλεγεί πεδία.',
    'error_unsaved_changes' => 'Παρακαλούμε σώστε ή ακυρώστε τις αλλαγές σας.',
    'thank_you_for_your_purchase' => 'Ευχαριστούμε για την αγορά σας!',
    'redeem' => 'Εξαργύρωσε',
    'back' => 'Πίσω',
    'past_purchases' => 'Παρελθόντες Αγορές',
    'annual_subscription' => 'Ετη΄σια Συνδρομή',
    'pro_plan' => 'Επαγγελματικό Πλάνο',
    'enterprise_plan' => 'Εταιρικό Πλάνο',
    'count_users' => ':count χρήστες',
    'upgrade' => 'Αναβάθμιση',
    'please_enter_a_first_name' => 'Παρακαλούμε εισάγετε μικρό όνομα',
    'please_enter_a_last_name' => 'Παρακαλούμε εισάγετε επώνυμο',
    'please_agree_to_terms_and_privacy' => 'Παρακαλούμε συμφωνήστε με τους όρους χρήσης και την πολιτική απορρήτου για να δημιουργήσετε ένα λογαριασμό.',
    'i_agree_to_the' => 'Συμφωνώ με το',
    'terms_of_service_link' => 'όροι της υπηρεσίας',
    'privacy_policy_link' => 'πολιτική απορρήτου',
    'view_website' => 'Εμφάνιση Ιστοσελίδας',
    'create_account' => 'Δημιουργία Λογαριασμού',
    'email_login' => 'Είσοδος με Email',
    'late_fees' => 'Καθυστερούμενα Τέλη',
    'payment_number' => 'Αριθμός Πληρωμής',
    'before_due_date' => 'Πριν την ημερομηνία πληρωμής',
    'after_due_date' => 'Μετά την ημερομηνία πληρωμής',
    'after_invoice_date' => 'Μετά την ημερομηνία τιμολογίου',
    'filtered_by_user' => 'Φιλτράρισμα από το Χρήστη',
    'created_user' => 'Επιτυχής δημιουργία χρήστη',
    'primary_font' => 'Κύρια Γραμματοσειρά',
    'secondary_font' => 'Δευτερεύουσα Γραμματοσειρά',
    'number_padding' => 'Περιθώριο Αρίθμησης',
    'general' => 'Γενικός',
    'surcharge_field' => 'Πεδίο Επιβάρυνσης',
    'company_value' => 'Αξία Εταιρίας',
    'credit_field' => 'Πεδίο Πίστωσης',
    'payment_field' => 'Πεδίο Πληρωμής',
    'group_field' => 'Πεδίο Γκρουπ',
    'number_counter' => 'Μετρητής Αρίθμησης',
    'number_pattern' => 'Μοτίβο Αρίθμησης',
    'custom_javascript' => 'Προσαρμοσμένη JavaScript',
    'portal_mode' => 'Περιβάλλον Portal',
    'attach_pdf' => 'Επισύναψε PDF',
    'attach_documents' => 'Επισύναψη Εγγράφων',
    'attach_ubl' => 'Επισύναψη UBL',
    'email_style' => 'Στυλ Email',
    'processed' => 'Επεξεργάσθηκε',
    'fee_amount' => 'Ποσό Τέλους',
    'fee_percent' => 'Ποσοστό Τέλους',
    'fee_cap' => 'Ανώτατο Όριο Τέλους',
    'limits_and_fees' => 'Όρια/Τέλη',
    'credentials' => 'Στοιχεία εισόδου',
    'require_billing_address_help' => 'Απαίτηση από τον πελάτη να συμπληρώσει τη διεύθυνση τιμολόγησης',
    'require_shipping_address_help' => 'Απαίτηση από τον πελάτη να εισάγει την διεύθυνση αποστολής του',
    'deleted_tax_rate' => 'Επιτυχής διαγραφή ποσοστού φόρου',
    'restored_tax_rate' => 'Επιτυχής ανάκτηση ποσοστού φόρου',
    'provider' => 'Provider',
    'company_gateway' => 'Πύλη Πληρωμών (Gateway)',
    'company_gateways' => 'Πύλες Πληρωμών (Gateways)',
    'new_company_gateway' => 'Νέα Πύλη πληρωμής (Gateway)',
    'edit_company_gateway' => 'Επεξεργασία Πύλης Πληρωμών (Gateway)',
    'created_company_gateway' => 'Επιτυχής δημιουργία πύλης πληρωμών (Gateway)',
    'updated_company_gateway' => 'Επιτυχής ενημέρωση πύλης πληρωμών (Gateway)',
    'archived_company_gateway' => 'Επιτυχής αρχειοθέτηση πύλης πληρωμών (Gateway)',
    'deleted_company_gateway' => 'Επιτυχής διαγραφή πύλης πληρωμών (Gateway)',
    'restored_company_gateway' => 'Επιτυχής επαναφορά πύλης πληρωμών (Gateway)',
    'continue_editing' => 'Συνεχίστε την Επεξεργασία',
    'default_value' => 'Προεπιλεγμένη τιμή',
    'currency_format' => 'Μορφή Νομίσματος',
    'first_day_of_the_week' => 'Πρώτη Μέρα της Εβδομάδας',
    'first_month_of_the_year' => 'Πρώτος Μήνας του Έτους',
    'symbol' => 'Σύμβολο',
    'ocde' => 'Κωδικός',
    'date_format' => 'Μορφή Ημερομηνίας',
    'datetime_format' => 'Μορφή Ημερομηνίας/Ώρας',
    'send_reminders' => 'Αποστολή Υπενθυμίσεων',
    'timezone' => 'Ζώνη ώρας',
    'filtered_by_group' => 'Φιλτράρισμα ανά Γκρουπ',
    'filtered_by_invoice' => 'Φιλτράρισμα ανά Τιμολόγιο',
    'filtered_by_client' => 'Φιλτράρισμα ανά Πελάτη',
    'filtered_by_vendor' => 'Φιλτράρισμα ανά Προμηθευτή',
    'group_settings' => 'Ρυθμίσεις Γρουπ',
    'groups' => 'Γρουπ',
    'new_group' => 'Νέο Γκρουπ',
    'edit_group' => 'Επεξεργασία Γκρουπ',
    'created_group' => 'Επιτυχής δημιουργία γκρουπ',
    'updated_group' => 'Επιτυχής ενημέρωση γκρουπ',
    'archived_group' => 'Επιτυχής αρχειοθέτηση γκρουπ',
    'deleted_group' => 'Επιτυχής διαγραφή γκρουπ',
    'restored_group' => 'Επιτυχής ανάκτηση γκρουπ',
    'upload_logo' => 'Μεταφόρτωση Λογοτύπου',
    'uploaded_logo' => 'Επιτυχής μεταφόρτωση λογοτύπου',
    'saved_settings' => 'Επιτυχής αποθήκευση ρυθμίσεων',
    'device_settings' => 'Ρυθμίσεις Συσκευής',
    'credit_cards_and_banks' => 'Πιστωτικές Κάρτες & Τράπεζες',
    'price' => 'Τιμή',
    'email_sign_up' => 'Εγγραφή μέσω Email',
    'google_sign_up' => 'Εγγραφή μέσω Google',
    'sign_up_with_google' => 'Εγγραφή μέσω Google',
    'long_press_multiselect' => 'Πολλαπλή επιλογή με Παρατεταμένη πίεση',
    'migrate_to_next_version' => 'Μεταφερθείτε στην επόμενη έκδοση του Invoice Ninja',
    'migrate_intro_text' => 'Εργαζόμαστε για την επόμενη έκδοση του Invoice Ninja. Πατήστε το κουμπί παρακάτω για να ξεκινήσετε τη μεταφορά.',
    'start_the_migration' => 'Ξεκινήστε τη μεταφορά',
    'migration' => 'Μεταφορά',
    'welcome_to_the_new_version' => 'Καλωσήρθατε στην επόμενη έκδοση του Invoice Ninja ',
    'next_step_data_download' => 'Στο επόμενο βήμα θα σας προτρέψουμε να μεταφορτώσετε τα δεδομένα σας για τη μεταφορά.',
    'download_data' => 'Πατήστε το κουμπί παρακάτω για να μεταφορτώσετε τα δεδομένα.',
    'migration_import' => 'Τέλεια: Τώρα είσαστε έτοιμοι να εισάγετε τη μεταφορά σας. Πηγαίνετε στην καινούργια σας εγκατάσταση για να εισάγετε τα δεδομένα',
    'continue' => 'Συνεχίστε',
    'company1' => 'Προσαρμοσμένη εταιρεία 1',
    'company2' => 'Προσαρμοσμένη εταιρεία 2',
    'company3' => 'Προσαρμοσμένη εταιρεία 3',
    'company4' => 'Προσαρμοσμένη εταιρεία 4',
    'product1' => 'Προσαρμοσμένο Προιόν 1',
    'product2' => 'Προσαρμοσμένο Προιόν 2',
    'product3' => 'Προσαρμοσμένο Προιόν 3',
    'product4' => 'Προσαρμοσμένο Προιόν 4',
    'client1' => 'Προσαρμοσμένος Πελάτης 1',
    'client2' => 'Προσαρμοσμένος Πελάτης 2',
    'client3' => 'Προσαρμοσμένος Πελάτης 3',
    'client4' => 'Προσαρμοσμένος Πελάτης 4',
    'contact1' => 'Προσαρμοσμένη Επαφή 1',
    'contact2' => 'Προσαρμοσμένη Επαφή 2',
    'contact3' => 'Προσαρμοσμένη Επαφή 3',
    'contact4' => 'Προσαρμοσμένη Επαφή 4',
    'task1' => 'Προσαρμοσμένη Εργασία 1',
    'task2' => 'Προσαρμοσμένη Εργασία 2',
    'task3' => 'Προσαρμοσμένη Εργασία 3',
    'task4' => 'Προσαρμοσμένη Εργασία 4',
    'project1' => 'Προσαρμοσμένο Εργο 1',
    'project2' => 'Προσαρμοσμένο Εργο 2',
    'project3' => 'Προσαρμοσμένο Εργο 3',
    'project4' => 'Προσαρμοσμένο Εργο 4',
    'expense1' => 'Προσαρμοσμένες Δαπάνες 1',
    'expense2' => 'Προσαρμοσμένες Δαπάνες 2',
    'expense3' => 'Προσαρμοσμένες Δαπάνες 3',
    'expense4' => 'Προσαρμοσμένες Δαπάνες 4',
    'vendor1' => 'Προσαρμοσμένος Προμηθευτής 1',
    'vendor2' => 'Προσαρμοσμένος Προμηθευτής 2',
    'vendor3' => 'Προσαρμοσμένος Προμηθευτής 3',
    'vendor4' => 'Προσαρμοσμένος Προμηθευτής 4',
    'invoice1' => 'Προσαρμοσμένο Τιμολόγιο 1',
    'invoice2' => 'Προσαρμοσμένο Τιμολόγιο 2',
    'invoice3' => 'Προσαρμοσμένο Τιμολόγιο 3',
    'invoice4' => 'Προσαρμοσμένο Τιμολόγιο 4',
    'payment1' => 'Προσαρμοσμένη Πληρωμή 1',
    'payment2' => 'Προσαρμοσμένη Πληρωμή 2',
    'payment3' => 'Προσαρμοσμένη Πληρωμή 3',
    'payment4' => 'Προσαρμοσμένη Πληρωμή 4',
    'surcharge1' => 'Προσαρμοσμένη Προσαύξηση 1',
    'surcharge2' => 'Προσαρμοσμένη Προσαύξηση 2',
    'surcharge3' => 'Προσαρμοσμένη Προσαύξηση 3',
    'surcharge4' => 'Προσαρμοσμένη Προσαύξηση 4',
    'group1' => 'Προσαρμοσένη Ομάδα 1',
    'group2' => 'Προσαρμοσένη Ομάδα 2',
    'group3' => 'Προσαρμοσένη Ομάδα 3',
    'group4' => 'Προσαρμοσένη Ομάδα 4',
    'number' => 'Αριθμός',
    'count' => 'Μέτρηση',
    'is_active' => 'Είναι ενεργό',
    'contact_last_login' => 'Τελευταία είσοδος επαφής',
    'contact_full_name' => 'Πλήρες ονοματεπώνυμο επαφής',
    'contact_custom_value1' => 'Προσαρμοσμένη Τιμή Επαφής 1',
    'contact_custom_value2' => 'Προσαρμοσμένη Τιμή Επαφής 2',
    'contact_custom_value3' => 'Προσαρμοσμένη Τιμή Επαφής 3',
    'contact_custom_value4' => 'Προσαρμοσμένη Τιμή Επαφής 4',
    'assigned_to_id' => 'Ορίστηκε σε Id',
    'created_by_id' => 'Δημιουργήθηκε απο Id',
    'add_column' => 'Προσθήκη στήλης',
    'edit_columns' => 'Επεξεργασία στηλών',
    'to_learn_about_gogle_fonts' => 'για να μάθετε σχετικά με τις γραμματοσειρές της Google',
    'refund_date' => 'Ημερομηνία επιστροφής χρημάτων',
    'multiselect' => 'Πολλαπλή επιλογή',
    'verify_password' => 'Επαλήθευση Κωδικού',
    'applied' => 'Εγινε εφαρμογή',
    'include_recent_errors' => 'Συμπερίληψη πρόσφατων σφαλμάτων απο αρχεία καταγραφής',
    'your_message_has_been_received' => 'Εχουμε λάβει το μήνυμά σας και θα σας απαντήσουμε σύντομα.',
    'show_product_details' => 'Εμφάνιση Λεπτομερειών Προιόντος',
    'show_product_details_help' => 'Συμπερίληψη της περιγραφής και κόστους τιμής στη λίστα προιόντος',
    'pdf_min_requirements' => 'Ο κωδικοποιητής PDF απαιτεί :version',
    'adjust_fee_percent' => 'Προσαρμογή του ποσοστού του τέλους',
    'configure_settings' => 'Προσαρμογή Ρυθμίσεων',
    'about' => 'Περί',
    'credit_email' => 'Πιστωτικό μήνυμα ηλεκτρονικού ταχυδρομείου',
    'domain_url' => 'Σύνδεσμος URL',
    'password_is_too_easy' => 'Ο κωδικός πρόσβασης πρέπει να περιέχει ένα κεφαλαίο χαρακτήρα και έναν αριθμό',
    'client_portal_tasks' => 'Εργασίες πύλης πελάτη',
    'client_portal_dashboard' => 'Πίνακας ελέγχου πύλης πελατών',
    'please_enter_a_value' => 'Παρακαλούμε ορίστε μια τιμή',
    'deleted_logo' => 'Επιτυχής διαγραφή λογότυπου',
    'generate_number' => 'Δημιουργία Αριθμού',
    'when_saved' => 'Οταν αποθηκευτεί',
    'when_sent' => 'Οταν αποσταλλεί',
    'select_company' => 'Επιλέξτε Εταιρεία',
    'float' => 'Float',
    'collapse' => 'Συρρίκνωση',
    'show_or_hide' => 'Εμφάνιση/απόκρυψη',
    'menu_sidebar' => 'Πλευρικό Μενού',
    'history_sidebar' => 'Μενού Πλευρικού Ιστορικού',
    'tablet' => 'Τάμπλετ',
    'layout' => 'Εμφάνιση',
    'module' => 'Ενότητα',
    'first_custom' => 'Πρώτη Προσαρμογή',
    'second_custom' => 'Δεύτερη Προσαρμογή',
    'third_custom' => 'Τρίτη Προσαρμογή',
    'show_cost' => 'Εμφάνιση Κόστους',
    'show_cost_help' => 'Εμφάνιση του πεδίου κόστους προϊόντος για να είναι δυνατή η εύρεση του κέρδους',
    'show_product_quantity' => 'Εμφάνισε την Ποσότητα Προϊόντος',
    'show_product_quantity_help' => 'Εμφάνιση του πεδίου ποσότητας προϊόντος, αλλιώς ορισμός σε ένα',
    'show_invoice_quantity' => 'Εμφάνισε την Ποσότητα Τιμολογίου',
    'show_invoice_quantity_help' => 'Εμφάνιση του πεδίου ποσότητας γραμμής, αλλιώς ορισμός σε ένα',
    'default_quantity' => 'Προεπιλεγμένη Ποσότητα',
    'default_quantity_help' => 'Αυτόματος ορισμός της ποσότητας γραμμής σε ένα',
    'one_tax_rate' => 'Ένα Ποσοστό Φόρου',
    'two_tax_rates' => 'Δύο Ποσοστά Φόρων',
    'three_tax_rates' => 'Τρία Ποσοστά Φόρων',
    'default_tax_rate' => 'Προεπιλεγμένο Ποσοστό Φόρου',
    'invoice_tax' => 'Φόρος Τιμολογίου',
    'line_item_tax' => 'Ποσοστό Φόρου Γραμμής',
    'inclusive_taxes' => 'Συμπεριλαμβανόμενοι Φόροι',
    'invoice_tax_rates' => 'Φόροι Τιμολογίου',
    'item_tax_rates' => 'Ποσοστά Φόρων Προϊόντος',
    'configure_rates' => 'Προσαρμογή ποσοστών',
    'tax_settings_rates' => 'Ποσοστά Φόρων',
    'accent_color' => 'Χρώμα Τονισμού',
    'comma_sparated_list' => 'Λίστα διαχωριζόμενη με κόμματα',
    'single_line_text' => 'Κείμενο μονής γραμμής',
    'multi_line_text' => 'Κείμενο πολλαπλών γραμμών',
    'dropdown' => 'Πτυσώμενο',
    'field_type' => 'Τύπος Πεδίου',
    'recover_password_email_sent' => 'Ένα email ανάκτησης κωδικού έχει αποσταλεί',
    'removed_user' => 'Επιτυχής αφαίρεση χρήστη',
    'freq_three_years' => 'Τρία Χρόνια',
    'military_time_help' => '24ωρη εμφάνιση Ώρας',
    'click_here_capital' => 'Πατήστε εδώ',
    'marked_invoice_as_paid' => 'Επιτυχής ορισμός τιμολογίου ως απεσταλμένο',
    'marked_invoices_as_sent' => 'Επιτυχής ορισμός τιμολογίων ως απεσταλμένα',
    'marked_invoices_as_paid' => 'Επιτυχής ορισμός τιμολογίων ως απεσταλμένα',
    'activity_57' => 'Το σύστημα απέτυχε να στείλει με email το τιμολόγιο :invoice',
    'custom_value3' => 'Προσαρμοσμένη Τιμή 3',
    'custom_value4' => 'Προσαρμοσμένη Τιμή 4',
    'email_style_custom' => 'Προσαρμοσμένο Στυλ Email',
    'custom_message_dashboard' => 'Προσαρμοσμένο Μήνυμα Πίνακα Διαχείρισης',
    'custom_message_unpaid_invoice' => 'Προσαρμοσμένο Μήνυμα Ανεξόφλητου Τιμολογίου',
    'custom_message_paid_invoice' => 'Προσαρμοσμένο Μήνυμα Εξοφλημένου Τιμολογίου',
    'custom_message_unapproved_quote' => 'Προσαρμοσμένο Μήνυμα Μη Εγκεκριμένη Προσφοράς',
    'lock_sent_invoices' => 'Κλείδωμα Απεσταλένων Τιμολογίων',
    'translations' => 'Μεταφράσεις',
    'task_number_pattern' => 'Μοτίβο Αρίθμησης Εργασίας',
    'task_number_counter' => 'Μετρητής Αρίθμησης Εργασίας',
    'expense_number_pattern' => 'Μοτίβο Αρίθμησης Δαπάνης',
    'expense_number_counter' => 'Μετρητής Αρίθμησης Δαπάνης',
    'vendor_number_pattern' => 'Μοτίβο Αρίθμησης Προμηθευτή',
    'vendor_number_counter' => 'Μετρητής Αρίθμησης Προμηθευτή',
    'ticket_number_pattern' => 'Μοτίβο Αρίθμησης Αιτήματος Βοήθειας',
    'ticket_number_counter' => 'Μετρητής Αρίθμησης Αιτήματος Βοήθειας',
    'payment_number_pattern' => 'Μοτίβο Αρίθμησης Πληρωμής',
    'payment_number_counter' => 'Μετρητής Αρίθμησης Πληρωμής',
    'invoice_number_pattern' => 'Μοτίβο Αρίθμησης Τιμολογίου',
    'quote_number_pattern' => 'Μοτίβο Αρίθμησης Προσφοράς',
    'client_number_pattern' => 'Μοντέλο αριθμών πιστωτικού',
    'client_number_counter' => 'Μετρητής Αριθμών πιστωτικών',
    'credit_number_pattern' => 'Μοντέλο πιστωτικού αριθμού',
    'credit_number_counter' => 'Μετρητής Αριθμών πιστωτικών',
    'reset_counter_date' => 'Μηδενισμός Μετρητή Ημερομηνίας',
    'counter_padding' => 'Αντισταθμιστής',
    'shared_invoice_quote_counter' => 'Κοινόχρηστο παράθυρο παραγγελίας τιμολογίου',
    'default_tax_name_1' => 'Προεπιλεγμένη ονομασία φορολογικού συντελεστή 1',
    'default_tax_rate_1' => 'Προεπιλεγμένος φορολογικός συντελεστής 1',
    'default_tax_name_2' => 'Προεπιλεγμένη ονομασία φορολογικού συντελεστή 2',
    'default_tax_rate_2' => 'Προεπιλεγμένος φορολογικός συντελεστής 2',
    'default_tax_name_3' => 'Προεπιλεγμένη ονομασία φορολογικού συντελεστή 3',
    'default_tax_rate_3' => 'Προεπιλεγμένος φορολογικός συντελεστής 3',
    'email_subject_invoice' => 'Θέμα τιμολογίου με ηλεκτρονικό ταχυδρομείο',
    'email_subject_quote' => 'Θέμα ηλεκτρονικού ταχυδρομείου',
    'email_subject_payment' => 'Θέμα Πληρωμής με ηλεκτρονικό ταχυδρομείο',
    'switch_list_table' => 'Πίνακας Λίστας Αλλαγών',
    'client_city' => 'Πόλη Πελάτη',
    'client_state' => 'Κράτος Πελάτη',
    'client_country' => 'Χώρα Πελάτη',
    'client_is_active' => 'Ο Πελάτης είναι Ενεργός',
    'client_balance' => 'Ισοζύγιο Πελατών',
    'client_address1' => 'Οδός Πελάτη',
    'client_address2' => 'Διαμέρισμα Πελάτη',
    'client_shipping_address1' => 'Οδός Αποστολής Πελάτη',
    'client_shipping_address2' => 'Διαμέρισμα Αποστολής Πελάτη',
    'tax_rate1' => 'Φορολογικός Συντελεστής 1',
    'tax_rate2' => 'Φορολογικός Συντελεστής 2',
    'tax_rate3' => 'Φορολογικός Συντελεστής 3',
    'archived_at' => 'Αρχειοθετήθηκε στις',
    'has_expenses' => 'Εχει έξοδα',
    'custom_taxes1' => 'Προσαρμοσμένη Φορολόγηση 1',
    'custom_taxes2' => 'Προσαρμοσμένη Φορολόγηση 2',
    'custom_taxes3' => 'Προσαρμοσμένη Φορολόγηση 3',
    'custom_taxes4' => 'Προσαρμοσμένη Φορολόγηση 4',
    'custom_surcharge1' => 'Προσαρμοσμένη Προσαύξηση 1',
    'custom_surcharge2' => 'Προσαρμοσμένη Προσαύξηση 2',
    'custom_surcharge3' => 'Προσαρμοσμένη Προσαύξηση 3',
    'custom_surcharge4' => 'Προσαρμοσμένη Προσαύξηση 4',
    'is_deleted' => 'Εχει διαγραφεί',
    'vendor_city' => 'Πόλη Προμηθευτή',
    'vendor_state' => 'Κράτος Προμηθευτή',
    'vendor_country' => 'Χώρα Προμηθευτή',
    'credit_footer' => 'Υποσέλιδο Πίστωσης',
    'credit_terms' => 'Όροι Πίστωσης',
    'untitled_company' => 'Ανώνυμη Εταιρία',
    'added_company' => 'Επιτυχής προσθήκη επιχείρησης',
    'supported_events' => 'Υποστηριζόμενα Γεγονότα',
    'custom3' => 'Τρίτη Προσαρμογή',
    'custom4' => 'Τέταρτη Προσαρμογή',
    'optional' => 'Προαιρετικό',
    'license' => 'Άδεια Χρήσης',
    'invoice_balance' => 'Ισοζύγιο Τιμολογίων',
    'saved_design' => 'Επιτυχής αποθήκευση σχεδιασμού',
    'client_details' => 'Λεπτομέρειες Πελάτη',
    'company_address' => 'Διεύθυνση Εταιρείας',
    'quote_details' => 'Λεπτομέρειες Προσφοράς',
    'credit_details' => 'Λεπτομέρειες Πίστωσης',
    'product_columns' => 'Στήλες Προϊόντος',
    'task_columns' => 'Στήλες Εργασιών',
    'add_field' => 'Προσθήκη Πεδίου',
    'all_events' => 'Όλα τα Γεγονότα',
    'owned' => 'Κατέχεται',
    'payment_success' => 'Επιτυχία Πληρωμής',
    'payment_failure' => 'Αποτυχία Πληρωμής',
    'quote_sent' => 'Προσφορά στάλθηκε',
    'credit_sent' => 'Πίστωση στάλθηκε',
    'invoice_viewed' => 'Τιμολόγιο εμφανίστηκε',
    'quote_viewed' => 'Προσφορά εμφανίστηκε',
    'credit_viewed' => 'Πίστωση εμφανίστηκε',
    'quote_approved' => 'Προσφορά έγινε αποδεκτή',
    'receive_all_notifications' => 'Αποδοχή όλων των Ειδοποιήσεων',
    'purchase_license' => 'Προμήθεια Άδειας Χρήσης',
    'enable_modules' => 'Ενεργοποίηση Ενοτήτων',
    'converted_quote' => 'Επιτυχής μετατροπή προσφοράς',
    'credit_design' => 'Σχεδιασμός Πιστώσεων',
    'includes' => 'Περιλαμβανόμενα',
    'css_framework' => 'CSS Framework',
    'custom_designs' => 'Προσαρμοσμένοι Σχέδια',
    'designs' => 'Σχέδια',
    'new_design' => 'Νέο σχλεδιο',
    'edit_design' => 'Επεξεργασία Σχεδίου',
    'created_design' => 'Επιτυχής δημιουργία σχεδιασμού',
    'updated_design' => 'Επιτυχής ενημέρωση σχεδιασμού',
    'archived_design' => 'Επιτυχής αρχειοθέτηση σχεδιασμού',
    'deleted_design' => 'Επιτυχής διαγραφή σχεδιασμού',
    'removed_design' => 'Επιτυχής αφαίρεση σχεδιασμού',
    'restored_design' => 'Επιτυχής ανάκτηση σχεδιασμού',
    'recurring_tasks' => 'Επαναλαμβανόμενες Εργασίες',
    'removed_credit' => 'Επιτυχής αφίαρεση πίστωσης',
    'latest_version' => 'Τελευταία Έκδοση',
    'update_now' => 'Ενημέρωση Τώρα',
    'a_new_version_is_available' => 'Υπάρχει διαθέσιμη νεότερη έκδοση της εφαρμογής web',
    'update_available' => 'Διαθέσιμη ενημέρωση',
    'app_updated' => 'Η ενημέρωση οκοκληρώθηκε με επιτυχία',
    'integrations' => 'Ενσωματώσεις',
    'tracking_id' => 'Κωδικός παρακολούθησης',
    'slack_webhook_url' => 'Διεύθυνση URL του Webhook για το Slack',
    'partial_payment' => 'Μερική Πληρωμή',
    'partial_payment_email' => 'Email Μερικής Πληρωμής',
    'clone_to_credit' => 'Κλωνοποίηση σε Πίστωση',
    'emailed_credit' => 'Επιτυχής αποστολή πίστωσης με email',
    'marked_credit_as_sent' => 'Επιτυχής ορισμός πίστωσης ως απεσταλμένη',
    'email_subject_payment_partial' => 'Θέμα Email μερικής πληρωμής',
    'is_approved' => 'Είναι Αποδεκτή',
    'migration_went_wrong' => 'Ουπς, κάτι πήγε λάθος! Σιγουρευτείτε ότι εγκαταστήσατε σωστά μία έκδοση του Invoice Ninja v5, πριν ξεκινήσετε τη μεταφορά.',
    'cross_migration_message' => 'Cross account migration is not allowed. Please read more about it here: <a href="https://invoiceninja.github.io/docs/migration/#troubleshooting">https://invoiceninja.github.io/docs/migration/#troubleshooting</a>',
    'email_credit' => 'Αποστολή Πίστωσης με email',
    'client_email_not_set' => 'Ο πελάτης δεν έχει καταχωρημένη μία διεύθυνση email',
    'ledger' => 'Καθολικό',
    'view_pdf' => 'Προβολή PDF',
    'all_records' => 'Όλες οι εγγραφές',
    'owned_by_user' => 'Ιδιοκτησία του χρήστη',
    'credit_remaining' => 'Υπολειπόμενη Πίστωση',
    'use_default' => 'Χρήση προεπιλογής',
    'reminder_endless' => 'Συνεχής Υπενθύμιση',
    'number_of_days' => 'Αριθμός ημερών',
    'configure_payment_terms' => 'Προσαρμογή Όρων Πληρωμής',
    'payment_term' => 'Όρος Πληρωμής',
    'new_payment_term' => 'Νέος Όρος Πληρωμής',
    'deleted_payment_term' => 'Επιτυχής διαγραφή όρου πληρωμής',
    'removed_payment_term' => 'Επιτυχής αφαίρεση όρου πληρωμής',
    'restored_payment_term' => 'Επιτυχής ανάκτηση όρου πληρωμής',
    'full_width_editor' => 'Επεξεργαστής Πλήρους Πλάτους',
    'full_height_filter' => 'Φίλτρο Πλήρους Ύψους',
    'email_sign_in' => 'Είσοδος με email',
    'change' => 'Αλλαγή',
    'change_to_mobile_layout' => 'Αλλαγή σε εμφάνιση κινητής συσκευής;',
    'change_to_desktop_layout' => 'Αλλαγή σε εμφάνιση Desktop συσκευής;',
    'send_from_gmail' => 'Αποστολή μέσω Gmail',
    'reversed' => 'Αντιστράφηκε',
    'cancelled' => 'Ακυρωμένη',
    'quote_amount' => 'Ποσό Προσφοράς',
    'hosted' => 'Φιλοξενούμενη',
    'selfhosted' => 'Ιδίας Φιλοξενίας',
    'hide_menu' => 'Απόκρυψη Μενού',
    'show_menu' => 'Εμφάνιση Μενού',
    'partially_refunded' => 'Μερική Επιστροφή Χρημάτων',
    'search_documents' => 'ΑναζήτησηΕγγράφων',
    'search_designs' => 'Αναζήτηση Σχεδίων',
    'search_invoices' => 'Αναζήτηση Τιμολογίων',
    'search_clients' => 'Αναζήτηση Πελατών',
    'search_products' => 'Αναζήτηση Προϊόντων',
    'search_quotes' => 'Αναζήτηση Προσφορών',
    'search_credits' => 'Αναζήτηση Πιστώσεων',
    'search_vendors' => 'Αναζήτηση Προμηθευτών',
    'search_users' => 'Αναζήτηση Χρηστών',
    'search_tax_rates' => 'Αναζήτηση Ποσοστών Φόρου',
    'search_tasks' => 'Αναζήτηση Εργασιών',
    'search_settings' => 'Αναζήτηση Ρυθμίσεων',
    'search_projects' => 'Αναζήτηση Projects',
    'search_expenses' => 'Αναζήτηση Δαπανών',
    'search_payments' => 'Αναζήτηση Πληρωμών',
    'search_groups' => 'Αναζήτηση Γκρουπ',
    'search_company' => 'Αναζήτηση Εταιριών',
    'cancelled_invoice' => 'Επιτυχής ακύρωση τιμολογίου',
    'cancelled_invoices' => 'Επιτυχής ακύρωση τιμολογίων',
    'reversed_invoice' => 'Επιτυχής αντιστροφή τιμολογίου',
    'reversed_invoices' => 'Επιτυχής αντιστροφή τιμολογίων',
    'reverse' => 'Αντιστροφή',
    'filtered_by_project' => 'Φιλτράρισμα ανά Project',
    'google_sign_in' => 'Είσοδος μέσω Google',
    'activity_58' => 'Ο χρήστης :user αντίστρεψε το τιμολόγιο :invoice',
    'activity_59' => 'Ο χρήστης :user ακύρωσε το τιμολόγιο :invoice',
    'payment_reconciliation_failure' => 'Αποτυχία Συμβιβασμού',
    'payment_reconciliation_success' => 'Επιτυχία Συμβιβασμού',
    'gateway_success' => 'Επιτυχία Πύλης Πληρωμής',
    'gateway_failure' => 'Αποτυχία Πύλης Πληρωμής',
    'gateway_error' => 'Σφάλμα Πύλης Πληρωμής',
    'email_send' => 'Email απεστάλη',
    'email_retry_queue' => 'Ουρά Επαναποστολής Email',
    'failure' => 'Αποτυχία',
    'quota_exceeded' => 'Υπέρβαση Ορίου',
    'upstream_failure' => 'Αποτυχία Ροής',
    'system_logs' => 'Αρχείο Καταγραφής Συστήματος',
    'copy_link' => 'Αντιγραφή Συνδέσμου',
    'welcome_to_invoice_ninja' => 'Καλωσήρθατε στο Invoice Ninja ',
    'optin' => 'Συμμετοχή',
    'optout' => 'Μη Συμμετοχή',
    'auto_convert' => 'Αυτόματη Μετατροπή',
    'reminder1_sent' => 'Υπενθύμιση 1 Απεστάλη',
    'reminder2_sent' => 'Υπενθύμιση 2 Απεστάλη',
    'reminder3_sent' => 'Υπενθύμιση 3 Απεστάλη',
    'reminder_last_sent' => 'Τελευταία Υπενθύμιση Απεστάλη',
    'pdf_page_info' => 'Σελίδα :current από :total',
    'emailed_credits' => 'Επιτυχής αποστολή ΄πιστώσεων με email',
    'view_in_stripe' => 'Προβολή στο Stripe',
    'rows_per_page' => 'Γραμμές ανά Σελίδα',
    'apply_payment' => 'Πληρωμή',
    'unapplied' => 'Ανεφάρμοστο',
    'custom_labels' => 'Προσαρμοσμένες Ετικέτες',
    'record_type' => 'Τύπος Εγγραφής',
    'record_name' => 'Όνομασία Εγγραφής',
    'file_type' => 'Τύπος Αρχείου',
    'height' => 'Ύψος',
    'width' => 'Πλάτος',
    'health_check' => 'Έλεγχος Υγείας',
    'last_login_at' => 'Τελευταία Είσοδος στις',
    'company_key' => 'Κλειδί Εταιρείας',
    'storefront' => 'Βιτρίνα καταστήματος',
    'storefront_help' => 'Ενεργοποίηση εφαρμογών τρίτων για τη δημιουργία τιμολογίων',
    'count_records_selected' => ':count εγγραφές επιλέχθηκαν',
    'count_record_selected' => ':count εγγραφή επιλέχθηκε',
    'client_created' => 'Πελάτης Δημιουργήθηκε',
    'online_payment_email' => 'Email Online Πληρωμών',
    'manual_payment_email' => 'Email Χειροκίνητων Πληρωμών',
    'completed' => 'Ολοκληρώθηκε',
    'gross' => 'Μεικτό',
    'net_amount' => 'Καθαρό Ποσό',
    'net_balance' => 'Καθαρό Υπόλοιπο',
    'client_settings' => 'Ρυθμίσεις Πελάτη',
    'selected_invoices' => 'Επιλεγμένα Τιμολόγια',
    'selected_payments' => 'Επιλεγμένες Πληρωμές',
    'selected_quotes' => 'Επιλεγμένες Προσφορές',
    'selected_tasks' => 'Επιλεγμένες Εργασίες',
    'selected_expenses' => 'Επιλεγμένες Δαπάνες',
    'past_due_invoices' => 'Ληγμένα Τιμολόγια',
    'create_payment' => 'Δημιουργία Πληρωμής',
    'update_quote' => 'Ενημέρωση Προσφοράς',
    'update_invoice' => 'Ενημέρωση Τιμολογίου',
    'update_client' => 'Ενημέρωση Πελάτη',
    'update_vendor' => 'Ενημέρωση Προμηθευτή',
    'create_expense' => 'Δημιουργία Δαπάνης',
    'update_expense' => 'Ενημέρωση Δαπάνης',
    'update_task' => 'Ενημέρωση Εργασίας',
    'approve_quote' => 'Αποδοχή Προσφοράς',
    'when_paid' => 'Οταν Πληρωθεί',
    'expires_on' => 'Λήγει την ',
    'show_sidebar' => 'Εμφάνιση Πλευρικής Μπάρας',
    'hide_sidebar' => 'Απόκρυψη Πλευρικής Μπάρας',
    'event_type' => 'Τύπος Γεγονότος',
    'copy' => 'Αντιγραφή',
    'must_be_online' => 'Παρακαλούμε επανεκκινήστε την εφαρμογή μόλις συνδεθείτε στο internet',
    'crons_not_enabled' => 'Πρέπει να ενεργοποιήσετε τα crons',
    'api_webhooks' => 'API Webhooks',
    'search_webhooks' => 'Αναζήτηση :count Webhooks',
    'search_webhook' => 'Αναζήτηση 1 Webhook',
    'webhook' => 'Webhook',
    'webhooks' => 'Webhooks',
    'new_webhook' => 'Νέο Webhook',
    'edit_webhook' => 'Επεξεργασία Webhook',
    'created_webhook' => 'Επιτυχής δημιουργία webhook',
    'updated_webhook' => 'Επιτυχής ενημέρωση webhook',
    'archived_webhook' => 'Επιτυχής αρχειοθέτηση webhook',
    'deleted_webhook' => 'Επιτυχής διαγραφή webhook',
    'removed_webhook' => 'Επιτυχής αφαίρεση webhook',
    'restored_webhook' => 'Επιτυχής ανάκτηση webhook',
    'search_tokens' => 'Αναζήτηση :count Διακριτικών',
    'search_token' => 'Αναζήτηση 1 Διακριτικού',
    'new_token' => 'Νέο Διακριτικό',
    'removed_token' => 'Επιτυχής αφαίρεση διακριτικού',
    'restored_token' => 'Επιτυχής ανάκτηση διακριτικού',
    'client_registration' => 'Εγγραφή Πελάτη',
    'client_registration_help' => 'Ενεργοποίηση αυτοεγγραφής πελατών στο portal',
    'customize_and_preview' => 'Προσαρμογή & Προεπισκόπηση',
    'search_document' => 'Αναζήτηση 1 Εγγράφου',
    'search_design' => 'Αναζήτηση 1 Σχεδίου',
    'search_invoice' => 'Αναζήτηση 1 Τιμολογίου',
    'search_client' => 'Αναζήτηση 1 Πελάτη',
    'search_product' => 'Αναζήτηση 1 Προϊόντος',
    'search_quote' => 'Αναζήτηση 1 Προσφοράς',
    'search_credit' => 'Αναζήτηση 1 Πίστωσης',
    'search_vendor' => 'Αναζήτηση 1 Προμηθευτή',
    'search_user' => 'Αναζήτηση 1 Χρήστη',
    'search_tax_rate' => 'Αναζήτηση 1 Ποσοστού Φόρου',
    'search_task' => 'Αναζήτηση 1 Εργασίας',
    'search_project' => 'Αναζήτηση 1 Project',
    'search_expense' => 'Αναζήτηση 1 Δαπάνης',
    'search_payment' => 'Αναζήτηση 1 Πληρωμής',
    'search_group' => 'Αναζήτηση 1 Γκρουπ',
    'created_on' => 'Δημιουργήθηκε στις',
    'payment_status_-1' => 'Ανεφάρμοστο',
    'lock_invoices' => 'Κλείδωμα Τιμολογίων',
    'show_table' => 'Εμφάνιση Πίνακα',
    'show_list' => 'Εμφάνιση Λίστας',
    'view_changes' => 'Προβολή Αλλαγών',
    'force_update' => 'Εξαναγκασμένη Ενημέρωση',
    'force_update_help' => 'Εκτελείτε την τελευταία έκδοση αλλά μπορεί να υπάρχουν διορθώσεις σε αναμονή.',
    'mark_paid_help' => 'Εντοπισμός της δαπάνης που πληρώθηκε',
    'mark_invoiceable_help' => 'Ενεργοποίηση της δαπάνης που θα τιμολογηθεί',
    'add_documents_to_invoice_help' => 'Κάνε τα έγγραφα εμφανίσιμα',
    'convert_currency_help' => 'Ορισμός Ισοτιμίας Ανταλλαγής',
    'expense_settings' => 'Ρυθμίσεις Δαπάνης',
    'clone_to_recurring' => 'Κλωνοποίηση σε Επαναλαμβανόμενο',
    'crypto' => 'Κρύπτο',
    'user_field' => 'Πεδίο Χρήστη',
    'variables' => 'Μεταβλητές',
    'show_password' => 'Εμφάνιση Κωδικού Πρόσβασης',
    'hide_password' => 'Απόκρυψη Κωδικού Πρόσβασης',
    'copy_error' => 'Σφάλμα Αντιγραγής',
    'capture_card' => 'Κάρτα Σύλληψης',
    'auto_bill_enabled' => 'Αυτόματη Χρέωση Ενεργοποιήθηκε',
    'total_taxes' => 'Συνολικοί Φόροι',
    'line_taxes' => 'Φόροι Γραμμής',
    'total_fields' => 'Συνολικά Πεδία',
    'stopped_recurring_invoice' => 'Επιτυχής διακοπή επαναλαμβανόμενου τιμολογίου',
    'started_recurring_invoice' => 'Επιτυχής έναρξη επαναλαμβανόμενου τιμολογίου',
    'resumed_recurring_invoice' => 'Επιτυχής επανεκκίνηση επαναλαμβανόμενου τιμολογίου',
    'gateway_refund' => 'Επιστροφή Χρημάτων μέσω Πύλης Πληρωμής (Gateway)',
    'gateway_refund_help' => 'Εκτελέστε την επιστροφή νρημάτων μέσω Πύλης Πληρωμής (Gateway)',
    'due_date_days' => 'Ημερομηνία Ολοκλήρωσης',
    'paused' => 'Σε παύση',
    'day_count' => 'Ημέρα :count',
    'first_day_of_the_month' => 'Πρώτη Μέρα του Μήνα',
    'last_day_of_the_month' => 'Τελευταία Μέρα του Μήνα',
    'use_payment_terms' => 'Χρησιμοποίηση Όρων Πληρωμής',
    'endless' => 'Συνεχής',
    'next_send_date' => 'Επόμενη Ημερομηνία Αποστολής',
    'remaining_cycles' => 'Εναπομείναντες Κύκλοι',
    'created_recurring_invoice' => 'Επιτυχής δημιουργία επαναλαμβανόμενου τιμολογίου',
    'updated_recurring_invoice' => 'Επιτυχής ενημέρωση επαναλαμβανόμενου τιμολογίου',
    'removed_recurring_invoice' => 'Επιτυχής αφαίρεση επαναλαμβανόμενου τιμολογίου',
    'search_recurring_invoice' => 'Αναζήτηση 1 Επαναλαμβανόμενου Τιμολογίου',
    'search_recurring_invoices' => 'Αναζήτηση :count Επαναλαμβανόμενων Τιμολογίων',
    'send_date' => 'Ημερομηνία Αποστολής',
    'auto_bill_on' => 'Αυτόματη Χρέωση στις',
    'minimum_under_payment_amount' => 'Ελάχιστο Ποσό Υποπληρωμής',
    'allow_over_payment' => 'Επιτρέψτε Υπερπληρωμή',
    'allow_over_payment_help' => 'Υποστήριξη της επιπλεόν πληρωμής για να δέχεστε φιλοδορήματα',
    'allow_under_payment' => 'Επιτρέψτε Υποπληρωμή',
    'allow_under_payment_help' => 'Υποστήριξη εξόφλησης κατ\' ελάχιστο του μερικού ποσού',
    'test_mode' => 'Περιβάλλον Τεστ',
    'calculated_rate' => 'Υπολογιζόμενο Κόστος',
    'default_task_rate' => 'Προεπιλεγμένο Κόστος Εργασίας',
    'clear_cache' => 'Καθαρισμός Προσωρινής Μνήμης',
    'sort_order' => 'Σειρά Ταξινόμησης',
    'task_status' => 'Κατάσταση',
    'task_statuses' => 'Καταστάσεις Εργασίας',
    'new_task_status' => 'Κατάσταση Νέας Εργασίας',
    'edit_task_status' => 'Επεξεργασία Κατάστασης Εργασίας',
    'created_task_status' => 'Επιτυχής δημιουργία κατάστασης εργασίας',
    'archived_task_status' => 'Επιτυχής αρχειοθέτηση κατάστασης εργασίας',
    'deleted_task_status' => 'Επιτυχής διαγραφή κατάστασης εργασίας',
    'removed_task_status' => 'Επιτυχής αφαίρεση κατάστασης εργασίας',
    'restored_task_status' => 'Επιτυχής ανάκτηση κατάστασης εργασίας',
    'search_task_status' => 'Αναζήτηση 1 Κατάστασης Εργασίας',
    'search_task_statuses' => 'Αναζήτηση :count Καταστάσεων Εργασίας',
    'show_tasks_table' => 'Εμφάνιση Πίνακα Εργασιών',
    'show_tasks_table_help' => 'Πάντα να εμφανίζεται το τμήμα των εργασιών όταν δημιουργούνται τιμολόγια',
    'invoice_task_timelog' => 'Χρονολόγιο Τιμολόγησης Εργασίας',
    'invoice_task_timelog_help' => 'Προσθήκη λεπτομεριών χρόνου στις γραμμές των τιμολογίων',
    'auto_start_tasks_help' => 'Έναρξη εργασιών πριν την αποθήκευση',
    'configure_statuses' => 'Προσαρμογή Καταστάσεων',
    'task_settings' => 'Ρυθμίσεις Εργασίας',
    'configure_categories' => 'Προσαρμογή Κατηγοριών',
    'edit_expense_category' => 'Επεξεργασία Κατηγορίας Δαπάνης',
    'removed_expense_category' => 'Επιτυχής αφαίρεση κατηγορίας δαπάνης',
    'search_expense_category' => 'Αναζήτηση 1 Κατηγορίας Δαπάνης',
    'search_expense_categories' => 'Αναζήτηση :count Κατηγορίες Δαπανών',
    'use_available_credits' => 'Χρήση Διαθέσιμων Πιστώσεων',
    'show_option' => 'Εμφάνιση Επιλογής',
    'negative_payment_error' => 'Το ποσό πίστωσης δεν μπορεί να υπερβαίνει το ποσό πληρωμής',
    'should_be_invoiced_help' => 'Ενεργοποίηση της δαπάνης που θα τιμολογηθεί',
    'configure_gateways' => 'Παραμετροποίηση Πυλών Πληρωμών (Gateways)',
    'payment_partial' => 'Μερική Πληρωμή',
    'is_running' => 'Εκτελείται',
    'invoice_currency_id' => 'Κωδικός Νομίσματος Τιμολογίου',
    'tax_name1' => 'Ονομασία Φόρου 1',
    'tax_name2' => 'Ονομασία Φόρου 2',
    'transaction_id' => 'Κωδικός Συναλλαγής',
    'invoice_late' => 'Καθυστερημένο Ποσό Τιμολογίου',
    'quote_expired' => 'Ληγμένη Προσφορά',
    'recurring_invoice_total' => 'Σύνολο Τιμολογίου',
    'actions' => 'Ενέργειες',
    'expense_number' => 'Αριθμός Δαπάνης',
    'task_number' => 'Αριθμός Εργασίας',
    'project_number' => 'Αριθμός Project',
    'view_settings' => 'Ρυθμίσεις Εμφάνισης',
    'company_disabled_warning' => 'Προειδοποίηση: Αυτή η εταιρία δεν έχει ενεργοποιηθεί ακόμα',
    'late_invoice' => 'Καθυστερημένο Τιμολόγιο',
    'expired_quote' => 'Προσφορά που έληξε',
    'remind_invoice' => 'Υπενθύμιση Τιμολογίου',
    'client_phone' => 'Τηλέφωνο Πελάτη',
    'required_fields' => 'Απαιτούμενα Πεδία',
    'enabled_modules' => 'Ενεργοποιημένες Ενότητες',
    'activity_60' => 'Η επαφή :contact είδε την προσφορά :quote',
    'activity_61' => 'Ο χρήστης :user ενημέρωσε τον πελάτη :client',
    'activity_62' => 'Ο χρήστης :user ενημέρωσε τον προμηθευτή :vendor',
    'activity_63' => 'Ο χρήστης :user έστειλε με email πρώτη ειδοποίηση για το τιμολόγιο :invoice στην επαφή :contact',
    'activity_64' => 'Ο χρήστης :user έστειλε με email δεύτερη ειδοποίηση για το τιμολόγιο :invoice στην επαφή :contact',
    'activity_65' => 'Ο χρήστης :user έστειλε με email τρίτη ειδοποίηση για το τιμολόγιο :invoice στην επαφή :contact',
    'activity_66' => 'Ο χρήστης :user έστειλε με email ατέρμονη ειδοποίηση για το τιμολόγιο :invoice στην επαφή :contact',
    'expense_category_id' => 'Κωδικός Κατηγορίας Δαπάνης',
    'view_licenses' => 'Εμφάνιση Αδειών Χρήσης',
    'fullscreen_editor' => 'Επεξεργαστής Πλήρους Οθόνης',
    'sidebar_editor' => 'Επεξεργαστής Πλάγιας Μπάρας',
    'please_type_to_confirm' => 'Παρακαλούμε πληκρολογήστε ":value" για επιβεβαίωση',
    'purge' => 'Εκκαθάριση',
    'clone_to' => 'Κλωνοποίηση Σε',
    'clone_to_other' => 'Κλωνοποίηση σε Άλλο',
    'labels' => 'Ετικέτες',
    'add_custom' => 'Προσθήκη Προσαρμογής',
    'payment_tax' => 'Φόρος Πληρωμής',
    'white_label' => 'Λευκή Ετικέτα',
    'sent_invoices_are_locked' => 'Τα απεσταλμένα τιμολόγια είναι κλειδωμένα',
    'paid_invoices_are_locked' => 'Τα εξοφλημένα τιμολόγια είναι κλειδωμένα',
    'source_code' => 'Πηγαίος Κώδικας',
    'app_platforms' => 'Πλατφόρμες Εφαρμογής',
    'archived_task_statuses' => 'Επιτυχής αρχειοθέτηση :value καταστάσεων εργασίας',
    'deleted_task_statuses' => 'Επιτυχής διαγραφή :value καταστάσεων εργασίας',
    'restored_task_statuses' => 'Επιτυχής ανάκτηση :value καταστάσεων εργασίας',
    'deleted_expense_categories' => 'Επιτυχής διαγραφή δαπάνης :value κατηγοριών',
    'restored_expense_categories' => 'Επιτυχής επαναφορά δαπάνης :value κατηγοριών',
    'archived_recurring_invoices' => 'Επιτυχής αρχειοθέτηση :value επαναλαμβανόμενων τιμολογίων',
    'deleted_recurring_invoices' => 'Επιτυχής διαγραφή :value επαναλαμβανόμενων τιμολογίων',
    'restored_recurring_invoices' => 'Επιτυχής επαναφορά :value επαναλαμβανόμενων τιμολογίων',
    'archived_webhooks' => 'Επιτυχής αρχειοθέτηση :value webhooks',
    'deleted_webhooks' => 'Επιτυχής διαγραφή :value webhooks',
    'removed_webhooks' => 'Επιτυχής αφαίρεση :value webhooks',
    'restored_webhooks' => 'Επιτυχής ανάκτηση :value webhooks',
    'api_docs' => 'Κείμενα API',
    'archived_tokens' => 'Επιτυχής αρχειοθέτηση :value διακριτικών',
    'deleted_tokens' => 'Επιτυχής διαγραφή :value διακριτικών',
    'restored_tokens' => 'Επιτυχής ανάκτηση :value διακριτικών',
    'archived_payment_terms' => 'Επιτυχής αρχειοθέτηση :value όρων πληρωμής',
    'deleted_payment_terms' => 'Επιτυχής διαγραφή :value όρων πληρωμής',
    'restored_payment_terms' => 'Επιτυχής ανάκτηση :value όρων πληρωμής',
    'archived_designs' => 'Επιτυχής αρχειοθέτηση :value σχεδίων',
    'deleted_designs' => 'Επιτυχής διαγραφή :value σχεδίων',
    'restored_designs' => 'Επιτυχής ανάκτηση :value σχεδίων',
    'restored_credits' => 'Επιτυχής ανάκτηση :value πιστώσεων',
    'archived_users' => 'Επιτυχής αρχειοθέτηση :value χρηστών',
    'deleted_users' => 'Επιτυχής διαγραφή :value χρηστών',
    'removed_users' => 'Επιτυχής αφαίρεση :value χρηστών',
    'restored_users' => 'Επιτυχής ανάκτηση :value χρηστών',
    'archived_tax_rates' => 'Επιτυχής αρχειοθέτηση :value ποσοστών φόρου',
    'deleted_tax_rates' => 'Επιτυχής διαγραφή :value ποσοστών φόρου',
    'restored_tax_rates' => 'Επιτυχής ανάκτηση :value ποσοστών φόρου',
    'archived_company_gateways' => 'Επιτυχής αρχειοθέτηση :value πυλών πληρωμών (gateways)',
    'deleted_company_gateways' => 'Επιτυχής διαγραφή :value πυλών πληρωμών (gateways)',
    'restored_company_gateways' => 'Επιτυχής ανάκτηση :value πυλών πληρωμών (gateways)',
    'archived_groups' => 'Επιτυχής αρχειοθέτηση :value γκρουπς',
    'deleted_groups' => 'Επιτυχής διαγραφή :value γκρουπς',
    'restored_groups' => 'Επιτυχής ανάκτηση :value γκρουπς',
    'archived_documents' => 'Επιτυχής αρχειοθέτηση :value εγγράφων',
    'deleted_documents' => 'Επιτυχής διαγραφή :value εγγράφων',
    'restored_documents' => 'Επιτυχής ανάκτηση :value εγγράφων',
    'restored_vendors' => 'Επιτυχής ανάκτηση :value προμηθευτών',
    'restored_expenses' => 'Επιτυχής ανάκτηση :value δαπανών',
    'restored_tasks' => 'Επιτυχής ανάκτηση :value εργασιών',
    'restored_projects' => 'Επιτυχής ανάκτηση :value projects',
    'restored_products' => 'Επιτυχής ανάκτηση :value προϊόντων',
    'restored_clients' => 'Επιτυχής ανάκτηση :value πελατών',
    'restored_invoices' => 'Επιτυχής ανάκτηση :value τιμολογίων',
    'restored_payments' => 'Επιτυχής ανάκτηση :value πληρωμών',
    'restored_quotes' => 'Επιτυχής ανάκτηση :value προσφορών',
    'update_app' => 'Ενημέρωση Εφαρμογής',
    'started_import' => 'Επιτυχής έναρξη εισαγωγής',
    'duplicate_column_mapping' => 'Κλωνοποίηση αντιστοίχισης στηλών',
    'uses_inclusive_taxes' => 'Χρησιμοποιούνται Συμπεριλαμβανόμενοι Φόροι',
    'is_amount_discount' => 'Είναι Ποσό Έκπτωσης',
    'map_to' => 'Αντιστοίχιση Σε',
    'first_row_as_column_names' => 'Χρήση της πρώτης σειράς ως ονόματα στηλών',
    'no_file_selected' => 'Δεν Επιλέχθηκε Αρχείο',
    'import_type' => 'Τύπος Εισαγωγής',
    'draft_mode' => 'Περιβάλλον Πρόχειρου',
    'draft_mode_help' => 'Προεπισκόπιση αλλαγών πιο γρήγορα αλλά με μικρότερη ακρίβεια',
    'show_product_discount' => 'Εμφάνιση Έκπτωσης Προιόντος',
    'show_product_discount_help' => 'Εμφάνιση έκπτωσης του πεδίου γραμμής',
    'tax_name3' => 'Ονομασία Φόρου 2',
    'debug_mode_is_enabled' => 'Το περιβάλλον αποσφαλμάτωσης έχει ενεργοποιηθεί',
    'debug_mode_is_enabled_help' => 'Προειδοποίηση: προορίζεται για χρήση σε τοπικά μηχανήματα, μπορεί να οδηγήσει σε διαρροή κωδικών. Πατήστε για να μάθετε περισσότερα.',
    'running_tasks' => 'Εκτελούμενες εργασίες',
    'recent_tasks' => 'Πρόσφατες Εργασίες',
    'recent_expenses' => 'Πρόσφατες Δαπάνες',
    'upcoming_expenses' => 'Επερχόμενες Δαπάνες',
    'search_payment_term' => 'Αναζήτηση 1 Όρου Πληρωμής',
    'search_payment_terms' => 'Αναζήτηση :count Όρων Πληρωμής',
    'save_and_preview' => 'Αποθήκευση και Προεπισκόπηση',
    'save_and_email' => 'Αποθήκευση και Αποστολή Email',
    'converted_balance' => 'Υπόλοιπο από Μετατροπή',
    'is_sent' => 'Έχει Αποσταλεί',
    'document_upload' => 'Μεταφόρτωση Εγγράφου',
    'document_upload_help' => 'Ενεργοποίησε τη δυνατότητα οι πελάτες να μεταφορτώνουν έγγραφα',
    'expense_total' => 'Συνολική Δαπάνη',
    'enter_taxes' => 'Εισαγετε Φόρους',
    'by_rate' => 'Με Ποσοστό',
    'by_amount' => 'Με Ποσό',
    'enter_amount' => 'Εισάγετε Ποσό',
    'before_taxes' => 'Προ Φόρων',
    'after_taxes' => 'Μετά Φόρων',
    'color' => 'Χρώμα',
    'show' => 'Εμφάνισε',
    'empty_columns' => 'Άδιασε Στήλες',
    'project_name' => 'Όνομα Project',
    'counter_pattern_error' => 'To use :client_counter please add either :client_number or :client_id_number to prevent conflicts',
    'this_quarter' => 'Τρέχον Τετράμηνο',
    'to_update_run' => 'Για ενημέρωση εκτελέστε',
    'registration_url' => 'URL Εγγραφής',
    'show_product_cost' => 'Εμφάνιση Κόστους Προιόντος',
    'complete' => 'Ολοκληρωμένη',
     'next' => 'Επόμενο',
     'next_step' => 'Επόμενο βήμα',
     'notification_credit_sent_subject' => 'Η πίστωση :invoice απεστάλη στον πελάτη :client',
     'notification_credit_viewed_subject' => 'Η πίστωση :invoice προβλήθηκε στον πελάτη :client',
     'notification_credit_sent' => 'The following client :client was emailed Credit :invoice for :amount.',
     'notification_credit_viewed' => 'The following client :client viewed Credit :credit for :amount.',
     'reset_password_text' => 'Enter your email to reset your password.',
     'password_reset' => 'Επαναφορά Κωδικού Πρόσβασης',
     'account_login_text' => 'Welcome back! Glad to see you.',
     'request_cancellation' => 'Request cancellation',
     'delete_payment_method' => 'Διαγραφή Μεθόδου Πληρωμής',
     'about_to_delete_payment_method' => 'You are about to delete the payment method.',
     'action_cant_be_reversed' => 'Action can\'t be reversed',
     'profile_updated_successfully' => 'The profile has been updated successfully.',
     'currency_ethiopian_birr' => 'Μπιρ Αιθιοπίας',
     'client_information_text' => 'Use a permanent address where you can receive mail.',
     'status_id' => 'Κατάσταση Τιμολογίου',
     'email_already_register' => 'This email is already linked to an account',
     'locations' => 'Τοποθεσίες',
     'freq_indefinitely' => 'Indefinitely',
     'cycles_remaining' => 'Cycles remaining',
     'i_understand_delete' => 'I understand, delete',
     'download_files' => 'Κατέβασμα Αρχείων',
     'download_timeframe' => 'Use this link to download your files, the link will expire in 1 hour.',
     'new_signup' => 'Νέα Εγγραφή',
     'new_signup_text' => 'A new account has been created by :user - :email - from IP address: :ip',
     'notification_payment_paid_subject' => 'Payment was made by :client',
     'notification_partial_payment_paid_subject' => 'Partial payment was made by :client',
     'notification_payment_paid' => 'A payment of :amount was made by client :client towards :invoice',
     'notification_partial_payment_paid' => 'A partial payment of :amount was made by client :client towards :invoice',
     'notification_bot' => 'Notification Bot',
     'invoice_number_placeholder' => 'Τιμολόγιο # :invoice',
     'entity_number_placeholder' => ':entity # :entity_number',
     'email_link_not_working' => 'If the button above isn\'t working for you, please click on the link',
     'display_log' => 'Display Log',
     'send_fail_logs_to_our_server' => 'Report errors in realtime',
     'setup' => 'Καθορισμός',
     'quick_overview_statistics' => 'Quick overview & statistics',
     'update_your_personal_info' => 'Επικαιροποίησε τις προσωπικές σου πληροφορίες',
     'name_website_logo' => 'Name, website & logo',
     'make_sure_use_full_link' => 'Make sure you use full link to your site',
     'personal_address' => 'Personal address',
     'enter_your_personal_address' => 'Enter your personal address',
     'enter_your_shipping_address' => 'Εισαγωγή Διεύθυνσης Αποστολής',
     'list_of_invoices' => 'Λίστα Τιμολογίων',
     'with_selected' => 'Με τα επιλεγμένα',
     'invoice_still_unpaid' => 'This invoice is still not paid. Click the button to complete the payment',
     'list_of_recurring_invoices' => 'List of recurring invoices',
     'details_of_recurring_invoice' => 'Here are some details about recurring invoice',
     'cancellation' => 'Ακύρωση',
     'about_cancellation' => 'In case you want to stop the recurring invoice,\n please click the request the cancellation.',
     'cancellation_warning' => 'Warning! You are requesting a cancellation of this service.\n Your service may be cancelled with no further notification to you.',
     'cancellation_pending' => 'Cancellation pending, we\'ll be in touch!',
     'list_of_payments' => 'Λίστα Πληρωμών',
     'payment_details' => 'Details of the payment',
     'list_of_payment_invoices' => 'List of invoices affected by the payment',
     'list_of_payment_methods' => 'List of payment methods',
     'payment_method_details' => 'Details of payment method',
     'permanently_remove_payment_method' => 'Οριστική αφαίρεσηε αυτής της μεθόδου πληρωμής',
     'warning_action_cannot_be_reversed' => 'Warning! This action can not be reversed!',
     'confirmation' => 'Επιβεβαίωση',
     'list_of_quotes' => 'Προσφορές',
     'waiting_for_approval' => 'Waiting for approval',
     'quote_still_not_approved' => 'This quote is still not approved',
     'list_of_credits' => 'Πιστώσεις',
     'required_extensions' => 'Απαιτούμενες επεκτάσεις',
     'php_version' => 'Έκδοση PHP',
     'writable_env_file' => 'Writable .env file',
     'env_not_writable' => '.env file is not writable by the current user.',
     'minumum_php_version' => 'Minimum PHP version',
     'satisfy_requirements' => 'Make sure all requirements are satisfied.',
     'oops_issues' => 'Oops, something does not look right!',
     'open_in_new_tab' => 'Open in new tab',
     'complete_your_payment' => 'Complete payment',
     'authorize_for_future_use' => 'Authorize payment method for future use',
     'page' => 'Σελίδα',
     'per_page' => 'Ανά σελίδα',
     'of' => 'Από',
     'view_credit' => 'Εμφάνιση Πίστωσης',
     'to_view_entity_password' => 'To view the :entity you need to enter password.',
     'showing_x_of' => 'Showing :first to :last out of :total results',
     'no_results' => 'No results found.',
     'payment_failed_subject' => 'Payment failed for Client :client',
     'payment_failed_body' => 'A payment made by client :client failed with message :message',
     'register' => 'Register',
     'register_label' => 'Create your account in seconds',
     'password_confirmation' => 'Confirm your password',
     'verification' => 'Επαλήθευση',
     'complete_your_bank_account_verification' => 'Before using a bank account it must be verified.',
     'checkout_com' => 'Checkout.com',
     'footer_label' => 'Copyright © :year :company.',
     'credit_card_invalid' => 'Provided credit card number is not valid.',
     'month_invalid' => 'Provided month is not valid.',
     'year_invalid' => 'Provided year is not valid.',
     'https_required' => 'HTTPS is required, form will fail',
     'if_you_need_help' => 'If you need help you can post to our',
     'update_password_on_confirm' => 'After updating password, your account will be confirmed.',
     'bank_account_not_linked' => 'To pay with a bank account, first you have to add it as payment method.',
     'application_settings_label' => 'Let\'s store basic information about your Invoice Ninja!',
     'recommended_in_production' => 'Highly recommended in production',
     'enable_only_for_development' => 'Enable only for development',
     'test_pdf' => 'Δοκιμαστικό PDF',
     'checkout_authorize_label' => 'Checkout.com can be can saved as payment method for future use, once you complete your first transaction. Don\'t forget to check "Store credit card details" during payment process.',
     'sofort_authorize_label' => 'Bank account (SOFORT) can be can saved as payment method for future use, once you complete your first transaction. Don\'t forget to check "Store payment details" during payment process.',
     'node_status' => 'Node status',
     'npm_status' => 'NPM status',
     'node_status_not_found' => 'I could not find Node anywhere. Is it installed?',
     'npm_status_not_found' => 'I could not find NPM anywhere. Is it installed?',
     'locked_invoice' => 'This invoice is locked and unable to be modified',
     'downloads' => 'Downloads',
     'resource' => 'Resource',
     'document_details' => 'Details about the document',
     'hash' => 'Hash',
     'resources' => 'Resources',
     'allowed_file_types' => 'Allowed file types:',
     'common_codes' => 'Common codes and their meanings',
     'payment_error_code_20087' => '20087: Bad Track Data (invalid CVV and/or expiry date)',
     'download_selected' => 'Download selected',
     'to_pay_invoices' => 'To pay invoices, you have to',
     'add_payment_method_first' => 'add payment method',
     'no_items_selected' => 'No items selected.',
     'payment_due' => 'Payment due',
     'account_balance' => 'Account balance',
     'thanks' => 'Thanks',
     'minimum_required_payment' => 'Minimum required payment is :amount',
     'under_payments_disabled' => 'Company doesn\'t support under payments.',
     'over_payments_disabled' => 'Company doesn\'t support over payments.',
     'saved_at' => 'Saved at :time',
     'credit_payment' => 'Credit applied to Invoice :invoice_number',
     'credit_subject' => 'New credit :number from :account',
     'credit_message' => 'To view your credit for :amount, click the link below.',
     'payment_type_Crypto' => 'Cryptocurrency',
     'payment_type_Credit' => 'Credit',
     'store_for_future_use' => 'Store for future use',
     'pay_with_credit' => 'Pay with credit',
     'payment_method_saving_failed' => 'Payment method can\'t be saved for future use.',
     'pay_with' => 'Pay with',
     'n/a' => 'N/A',
     'by_clicking_next_you_accept_terms' => 'By clicking "Next step" you accept terms.',
     'not_specified' => 'Not specified',
     'before_proceeding_with_payment_warning' => 'Before proceeding with payment, you have to fill following fields',
     'after_completing_go_back_to_previous_page' => 'After completing, go back to previous page.',
     'pay' => 'Pay',
     'instructions' => 'Instructions',
     'notification_invoice_reminder1_sent_subject' => 'Reminder 1 for Invoice :invoice was sent to :client',
     'notification_invoice_reminder2_sent_subject' => 'Reminder 2 for Invoice :invoice was sent to :client',
     'notification_invoice_reminder3_sent_subject' => 'Reminder 3 for Invoice :invoice was sent to :client',
     'notification_invoice_reminder_endless_sent_subject' => 'Endless reminder for Invoice :invoice was sent to :client',
     'assigned_user' => 'Assigned User',
     'setup_steps_notice' => 'To proceed to next step, make sure you test each section.',
     'setup_phantomjs_note' => 'Note about Phantom JS. Read more.',
     'minimum_payment' => 'Minimum Payment',
     'no_action_provided' => 'No action provided. If you believe this is wrong, please contact the support.',
     'no_payable_invoices_selected' => 'No payable invoices selected. Make sure you are not trying to pay draft invoice or invoice with zero balance due.',
     'required_payment_information' => 'Required payment details',
     'required_payment_information_more' => 'To complete a payment we need more details about you.',
     'required_client_info_save_label' => 'We will save this, so you don\'t have to enter it next time.',
     'notification_credit_bounced' => 'We were unable to deliver Credit :invoice to :contact. \n :error',
     'notification_credit_bounced_subject' => 'Unable to deliver Credit :invoice',
     'save_payment_method_details' => 'Save payment method details',
     'new_card' => 'New card',
     'new_bank_account' => 'New bank account',
     'company_limit_reached' => 'Limit of 10 companies per account.',
     'credits_applied_validation' => 'Total credits applied cannot be MORE than total of invoices',
     'credit_number_taken' => 'Credit number already taken',
     'credit_not_found' => 'Credit not found',
     'invoices_dont_match_client' => 'Selected invoices are not from a single client',
     'duplicate_credits_submitted' => 'Duplicate credits submitted.',
     'duplicate_invoices_submitted' => 'Duplicate invoices submitted.',
     'credit_with_no_invoice' => 'You must have an invoice set when using a credit in a payment',
     'client_id_required' => 'Client id is required',
     'expense_number_taken' => 'Expense number already taken',
     'invoice_number_taken' => 'Invoice number already taken',
     'payment_id_required' => 'Payment `id` required.',
     'unable_to_retrieve_payment' => 'Unable to retrieve specified payment',
     'invoice_not_related_to_payment' => 'Invoice id :invoice is not related to this payment',
     'credit_not_related_to_payment' => 'Credit id :credit is not related to this payment',
     'max_refundable_invoice' => 'Attempting to refund more than allowed for invoice id :invoice, maximum refundable amount is :amount',
     'refund_without_invoices' => 'Attempting to refund a payment with invoices attached, please specify valid invoice/s to be refunded.',
     'refund_without_credits' => 'Attempting to refund a payment with credits attached, please specify valid credits/s to be refunded.',
     'max_refundable_credit' => 'Attempting to refund more than allowed for credit :credit, maximum refundable amount is :amount',
     'project_client_do_not_match' => 'Project client does not match entity client',
     'quote_number_taken' => 'Quote number already taken',
     'recurring_invoice_number_taken' => 'Recurring Invoice number :number already taken',
     'user_not_associated_with_account' => 'User not associated with this account',
     'amounts_do_not_balance' => 'Amounts do not balance correctly.',
     'insufficient_applied_amount_remaining' => 'Insufficient applied amount remaining to cover payment.',
     'insufficient_credit_balance' => 'Insufficient balance on credit.',
     'one_or_more_invoices_paid' => 'One or more of these invoices have been paid',
     'invoice_cannot_be_refunded' => 'Invoice id :number cannot be refunded',
     'attempted_refund_failed' => 'Attempting to refund :amount only :refundable_amount available for refund',
     'user_not_associated_with_this_account' => 'This user is unable to be attached to this company. Perhaps they have already registered a user on another account?',
     'migration_completed' => 'Migration completed',
     'migration_completed_description' => 'Your migration has completed, please review your data after logging in.',
     'api_404' => '404 | Nothing to see here!',
     'large_account_update_parameter' => 'Cannot load a large account without a updated_at parameter',
     'no_backup_exists' => 'No backup exists for this activity',
     'company_user_not_found' => 'Company User record not found',
     'no_credits_found' => 'No credits found.',
     'action_unavailable' => 'The requested action :action is not available.',
     'no_documents_found' => 'No Documents Found',
     'no_group_settings_found' => 'No group settings found',
     'access_denied' => 'Insufficient privileges to access/modify this resource',
     'invoice_cannot_be_marked_paid' => 'Invoice cannot be marked as paid',
     'invoice_license_or_environment' => 'Invalid license, or invalid environment :environment',
     'route_not_available' => 'Route not available',
     'invalid_design_object' => 'Invalid custom design object',
     'quote_not_found' => 'Quote/s not found',
     'quote_unapprovable' => 'Unable to approve this quote as it has expired.',
     'scheduler_has_run' => 'Scheduler has run',
     'scheduler_has_never_run' => 'Scheduler has never run',
     'self_update_not_available' => 'Self update not available on this system.',
     'user_detached' => 'User detached from company',
     'create_webhook_failure' => 'Failed to create Webhook',
     'payment_message_extended' => 'Thank you for your payment of :amount for :invoice',
     'online_payments_minimum_note' => 'Note: Online payments are supported only if amount is bigger than $1 or currency equivalent.',
     'payment_token_not_found' => 'Payment token not found, please try again. If an issue still persist, try with another payment method',
     'vendor_address1' => 'Vendor Street',
     'vendor_address2' => 'Vendor Apt/Suite',
     'partially_unapplied' => 'Partially Unapplied',
     'select_a_gmail_user' => 'Please select a user authenticated with Gmail',
     'list_long_press' => 'List Long Press',
     'show_actions' => 'Show Actions',
     'start_multiselect' => 'Start Multiselect',
     'email_sent_to_confirm_email' => 'An email has been sent to confirm the email address',
     'converted_paid_to_date' => 'Converted Paid to Date',
     'converted_credit_balance' => 'Converted Credit Balance',
     'converted_total' => 'Converted Total',
     'reply_to_name' => 'Reply-To Name',
     'payment_status_-2' => 'Partially Unapplied',
     'color_theme' => 'Color Theme',
     'start_migration' => 'Start Migration',
     'recurring_cancellation_request' => 'Request for recurring invoice cancellation from :contact',
     'recurring_cancellation_request_body' => ':contact from Client :client requested to cancel Recurring Invoice :invoice',
     'hello' => 'Hello',
     'group_documents' => 'Group documents',
     'quote_approval_confirmation_label' => 'Are you sure you want to approve this quote?',
     'migration_select_company_label' => 'Select companies to migrate',
     'force_migration' => 'Force migration',
     'require_password_with_social_login' => 'Require Password with Social Login',
     'stay_logged_in' => 'Stay Logged In',
     'session_about_to_expire' => 'Warning: Your session is about to expire',
     'count_hours' => ':count Hours',
     'count_day' => '1 Day',
     'count_days' => ':count Days',
     'web_session_timeout' => 'Web Session Timeout',
     'security_settings' => 'Security Settings',
     'resend_email' => 'Resend Email',
     'confirm_your_email_address' => 'Please confirm your email address',
     'freshbooks' => 'FreshBooks',
     'invoice2go' => 'Invoice2go',
     'invoicely' => 'Invoicely',
     'waveaccounting' => 'Wave Accounting',
     'zoho' => 'Zoho',
     'accounting' => 'Accounting',
     'required_files_missing' => 'Please provide all CSVs.',
     'migration_auth_label' => 'Let\'s continue by authenticating. (These credentials should be identical across systems)',
     'api_secret' => 'API secret',
     'migration_api_secret_notice' => 'You can find API_SECRET in the .env file or Invoice Ninja v5. If property is missing, leave field blank.',
     'billing_coupon_notice' => 'Your discount will be applied on the checkout.',
     'use_last_email' => 'Use last email',
     'activate_company' => 'Activate Company',
     'activate_company_help' => 'Enable emails, recurring invoices and notifications',
     'an_error_occurred_try_again' => 'An error occurred, please try again',
     'please_first_set_a_password' => 'Please first set a password',
     'changing_phone_disables_two_factor' => 'Warning: Changing your phone number will disable 2FA',
     'help_translate' => 'Help Translate',
     'please_select_a_country' => 'Please select a country',
     'disabled_two_factor' => 'Successfully disabled 2FA',
     'connected_google' => 'Successfully connected account',
     'disconnected_google' => 'Successfully disconnected account',
     'delivered' => 'Delivered',
     'spam' => 'Spam',
     'view_docs' => 'View Docs',
     'enter_phone_to_enable_two_factor' => 'Please provide a mobile phone number to enable two factor authentication',
     'send_sms' => 'Send SMS',
     'sms_code' => 'SMS Code',
     'connect_google' => 'Connect Google',
     'disconnect_google' => 'Disconnect Google',
     'disable_two_factor' => 'Disable Two Factor',
     'invoice_task_datelog' => 'Invoice Task Datelog',
     'invoice_task_datelog_help' => 'Add date details to the invoice line items',
     'promo_code' => 'Promo code',
     'recurring_invoice_issued_to' => 'Recurring invoice issued to',
     'amount_greater_than_balance_v5' => 'The amount is greater than the invoice balance. You cannot overpay an invoice.',
     'move_top' => 'Move Top',
     'move_up' => 'Move Up',
     'move_down' => 'Move Down',
     'move_bottom' => 'Move Bottom',
     'body_variable_missing' => 'Error: the custom email must include a :body variable',
     'add_body_variable_message' => 'Make sure to include a :body variable',
     'view_date_formats' => 'View Date Formats',
     'is_viewed' => 'Is Viewed',
     'letter' => 'Letter',
     'legal' => 'Legal',
     'page_layout' => 'Page Layout',
     'portrait' => 'Portrait',
     'landscape' => 'Landscape',
     'upgrade_to_paid_plan' => 'Upgrade to a paid plan to enable the advanded settings',
     'invoice_payment_terms' => 'Invoice Payment Terms',
     'quote_valid_until' => 'Quote Valid Until',
     'no_headers' => 'No Headers',
     'add_header' => 'Add Header',
     'remove_header' => 'Remove Header',
     'return_url' => 'Return URL',
     'rest_method' => 'REST Method',
     'header_key' => 'Header Key',
     'header_value' => 'Header Value',
     'recurring_products' => 'Recurring Products',
     'promo_discount' => 'Promo Discount',
     'allow_cancellation' => 'Allow Cancellation',
     'per_seat_enabled' => 'Per Seat Enabled',
     'max_seats_limit' => 'Max Seats Limit',
     'trial_enabled' => 'Trial Enabled',
     'trial_duration' => 'Trial Duration',
     'allow_query_overrides' => 'Allow Query Overrides',
     'allow_plan_changes' => 'Allow Plan Changes',
     'plan_map' => 'Plan Map',
     'refund_period' => 'Refund Period',
     'webhook_configuration' => 'Webhook Configuration',
     'purchase_page' => 'Purchase Page',
     'email_bounced' => 'Email Bounced',
     'email_spam_complaint' => 'Spam Complaint',
     'email_delivery' => 'Email Delivery',
     'webhook_response' => 'Webhook Response',
     'pdf_response' => 'PDF Response',
     'authentication_failure' => 'Authentication Failure',
     'pdf_failed' => 'PDF Failed',
     'pdf_success' => 'PDF Success',
     'modified' => 'Modified',
     'subscription' => 'Subscription',
     'new_subscription' => 'New Subscription',
     'deleted_subscription' => 'Successfully deleted subscription',
     'removed_subscription' => 'Successfully removed subscription',
     'restored_subscription' => 'Successfully restored subscription',
     'search_subscription' => 'Search 1 Subscription',
     'search_subscriptions' => 'Search :count Subscriptions',
     'subdomain_is_not_available' => 'Subdomain is not available',
     'connect_gmail' => 'Connect Gmail',
     'disconnect_gmail' => 'Disconnect Gmail',
     'connected_gmail' => 'Successfully connected Gmail',
     'disconnected_gmail' => 'Successfully disconnected Gmail',
     'update_fail_help' => 'Changes to the codebase may be blocking the update, you can run this command to discard the changes:',
     'client_id_number' => 'Client ID Number',
     'count_minutes' => ':count Minutes',
     'password_timeout' => 'Password Timeout',
     'shared_invoice_credit_counter' => 'Shared Invoice/Credit Counter',
    'activity_80' => ':user created subscription :subscription',
    'activity_81' => ':user updated subscription :subscription',
    'activity_82' => ':user archived subscription :subscription',
    'activity_83' => ':user deleted subscription :subscription',
    'activity_84' => ':user restored subscription :subscription',

    'amount_greater_than_balance_v5' => 'The amount is greater than the invoice balance. You cannot overpay an invoice.',
    'click_to_continue' => 'Click to continue',

    'notification_invoice_created_subject' => 'Invoice :invoice was created to :client',
    'notification_invoice_created_subject' => 'Invoice :invoice was created to :client',
    'notification_quote_created_subject' => 'Quote :invoice was created to :client',
    'notification_quote_created_subject' => 'Quote :invoice was created to :client',
    'notification_credit_created_subject' => 'Credit :invoice was created to :client',
    'notification_credit_created_subject' => 'Credit :invoice was created to :client',
    'migration_create_account_notice' => 'Please ensure you have created an account on the new platform first <a href="https://invoicing.co">here</a> , please ensure that the credentials are <b>identical</b> to your v4 credentials. Once the account has been created, you can start the migration process here.',
    'auth' => 'Authentication',
    'companies' => 'Select companies for migration',
    'activity_100' => ':user created recurring invoice :recurring_invoice',
    'activity_101' => ':user updated recurring invoice :recurring_invoice',
    'activity_102' => ':user archived recurring invoice :recurring_invoice',
    'activity_103' => ':user deleted recurring invoice :recurring_invoice',
    'activity_104' => ':user restored recurring invoice :recurring_invoice',

    'import_settings' => 'Import Settings',
    'json_file_missing' => 'Please provide the JSON file',
    'json_option_missing' => 'Please select to import the settings and/or data',
    'json' => 'JSON',
    'no_payment_types_enabled' => 'No payment types enabled',
    'wait_for_data' => 'Please wait for the data to finish loading',
    'net_total' => 'Net Total',
    'has_taxes' => 'Has Taxes',
    'import_customers' => 'Import Customers',
    'imported_customers' => 'Successfully started importing customers',
    'login_success' => 'Successful Login',
    'login_failure' => 'Failed Login',
    'exported_data' => 'Once the file is ready you"ll receive an email with a download link',
    'include_deleted_clients' => 'Include Deleted Clients',
    'include_deleted_clients_help' => 'Load records belonging to deleted clients',
    'step_1_sign_in' => 'Step 1: Sign In',
    'step_2_authorize' => 'Step 2: Authorize',
    'account_id' => 'Account ID',
    'migration_not_yet_completed' => 'The migration has not yet completed',
    'wizard_warning' => 'If you are migrating from the legacy version stop here and begin the migration. Once the migration completes click "Refesh" and use the dropdown in the top left corner to switch companies.',
    'show_task_end_date' => 'Show Task End Date',
    'show_task_end_date_help' => 'Enable specifying the task end date',
    'gateway_setup' => 'Gateway Setup',
    'preview_sidebar' => 'Preview Sidebar',
    'years_data_shown' => 'Years Data Shown',
    'ended_all_sessions' => 'Successfully ended all sessions',
    'end_all_sessions' => 'End All Sessions',
    'count_session' => '1 Session',
    'count_sessions' => ':count Sessions',
    'invoice_created' => 'Invoice Created',
    'quote_created' => 'Quote Created',
    'credit_created' => 'Credit Created',
    'enterprise' => 'Enterprise',
    'invoice_item' => 'Invoice Item',
    'quote_item' => 'Quote Item',
    'order' => 'Order',
    'search_kanban' => 'Search Kanban',
    'search_kanbans' => 'Search Kanban',
    'owner_upgrade_to_paid_plan' => 'The account owner can upgrade to a paid plan to enable the advanced advanced settings',
    'html_mode' => 'HTML Mode',
    'html_mode_help' => 'Preview updates faster but is less accurate',

);

return $LANG;

?>
