<?php

$LANG = array(
    'organization' => 'องค์กร',
    'name' => 'ชื่อ',
    'website' => 'เว็บไซต์',
    'work_phone' => 'โทรศัพท์',
    'address' => 'ที่อยู่',
    'address1' => 'ถนน',
    'address2' => 'อาคาร',
    'city' => 'อำเภอ',
    'state' => 'จังหวัด',
    'postal_code' => 'รหัสไปรษณีย์',
    'country_id' => 'ประเทศ',
    'contacts' => 'ผู้ติดต่อ',
    'first_name' => 'ชื่อ',
    'last_name' => 'นามสกุล',
    'phone' => 'โทร.',
    'email' => 'อีเมล',
    'additional_info' => 'ข้อมูลเพิ่มเติม',
    'payment_terms' => 'เงื่อนไขการชำระ',
    'currency_id' => 'สกุลเงิน',
    'size_id' => 'ขนาดบริษัท',
    'industry_id' => 'อุตสาหกรรม',
    'private_notes' => 'หมายเหตุภายใน',
    'invoice' => 'ใบแจ้งหนี้',
    'client' => 'ลูกค้า',
    'invoice_date' => 'วันที่แจ้งหนี้',
    'due_date' => 'วันถึงกำหนดชำระ',
    'invoice_number' => 'เลขที่ใบแจ้งหนี้',
    'invoice_number_short' => 'Invoice #',
    'po_number' => 'เลขที่ใบสั่งซื้อ',
    'po_number_short' => 'PO #',
    'frequency_id' => 'ความถี่',
    'discount' => 'ส่วนลด',
    'taxes' => 'ภาษี',
    'tax' => 'ภาษี',
    'item' => 'รายการ',
    'description' => 'รายละเอียด',
    'unit_cost' => 'ราคาต่อหน่วย',
    'quantity' => 'จำนวน',
    'line_total' => 'รวมเงิน',
    'subtotal' => 'รวมเงิน',
    'paid_to_date' => 'ยอดชำระแล้ว',
    'balance_due' => 'ยอดคงเหลือ',
    'invoice_design_id' => 'ออกแบบ',
    'terms' => 'เงื่อนไข',
    'your_invoice' => 'ใบแจ้งหนี้ของคุณ',
    'remove_contact' => 'ลบผู้ติดต่อ',
    'add_contact' => 'เพิ่มผู้ติดต่อ',
    'create_new_client' => 'สร้างลูกค้าใหม่',
    'edit_client_details' => 'แก้ไขรายละเอียดลูกค้า',
    'enable' => 'เปิดใช้งาน',
    'learn_more' => 'อ่านต่อ',
    'manage_rates' => 'จัดการอัตรา',
    'note_to_client' => 'หมายเหตุสำหรับลูกค้า',
    'invoice_terms' => 'ระยะเวลาใบแจ้งหนี้',
    'save_as_default_terms' => 'บันทึกเป็น Default Terms',
    'download_pdf' => 'ดาวน์โหลด PDF',
    'pay_now' => 'จ่ายเดี๋ยวนี้',
    'save_invoice' => 'บันทึกใบแจ้งหนี้',
    'clone_invoice' => 'ทำใบแจ้งหนี้ซ้ำ',
    'archive_invoice' => 'เก็บบันทึกใบแจ้งหนี้',
    'delete_invoice' => 'ลบใบแจ้งหนี้',
    'email_invoice' => 'ส่งอีเมล',
    'enter_payment' => 'เพิ่มรายการจ่ายเงิน',
    'tax_rates' => 'อัตราภาษี',
    'rate' => 'อัตรา',
    'settings' => 'การตั้งค่า',
    'enable_invoice_tax' => 'เปิดใช้งานการระบุ <b>ภาษีใบแจ้งหนี้</b>',
    'enable_line_item_tax' => 'เปิดใช้การระบุ<b>ภาษีสินค้า</b>',
    'dashboard' => 'แดชบอร์ด',
    'dashboard_totals_in_all_currencies_help' => 'Note: add a :link named ":name" to show the totals using a single base currency.',
    'clients' => 'ลูกค้า',
    'invoices' => 'ใบแจ้งหนี้',
    'payments' => 'การจ่ายเงิน',
    'credits' => 'เครดิต',
    'history' => 'ประวัติ',
    'search' => 'ค้นหา',
    'sign_up' => 'ลงทะเบียน',
    'guest' => 'ผู้มาเยือน',
    'company_details' => 'รายละเอียดบริษัท',
    'online_payments' => 'การจ่ายเงินออนไลน์',
    'notifications' => 'การแจ้งเตือน',
    'import_export' => 'นำเข้า | ส่งออก',
    'done' => 'เรียบร้อย',
    'save' => 'บันทึก',
    'create' => 'สร้าง',
    'upload' => 'อัพโหลด',
    'import' => 'นำเข้า',
    'download' => 'ดาวน์โหลด',
    'cancel' => 'ยกเลิก',
    'close' => 'ปิด',
    'provide_email' => 'กรุณาระบุอีเมลที่ถูกต้อง',
    'powered_by' => 'สนับสนุนโดย',
    'no_items' => 'ไม่มีรายการ',
    'recurring_invoices' => 'ทำใบแจ้งหนี้ซ้ำ',
    'recurring_help' => '<p>ส่งใบแจ้งหนี้ใบเดิมให้ทุกอาทิตย์,สองครั้งต่อเดือน,เดือนละครั้ง,ทุกสามเดือนหรือทุกปี</p>
<p>ใช้ :MONTH, :QUARTER  หรือ :YEAR สำหรับวันที่เปลี่ยนไป. ตรงตามเดือนยิ่งดี, ตัวอย่าง :MONTH-1.
<p>ตัวอย่างใบแจ้งหนี้ที่เปลี่ยนแปลงไป:</p>
<ul>
<li>"Gym สมาชิกสำหรับเดือน :MONTH" >> "Gym สมาชิกสำหรับเดือนกรกฎาคม"</li>
<li>":ปี+1 สมัครสมาชิกรายปี" >> "2015 เป็นสมัครสมาชิกรายปี"</li>
<li>"เงินประกันสำหรับ :QUARTER+1" >> " ดำเนินการชำระเงินในไตรมาศที่ 2"</li>
</ul>',
    'recurring_quotes' => 'Recurring Quotes',
    'in_total_revenue' => 'รายได้รวมทั้งหมด',
    'billed_client' => 'ลูกค้าที่เรียกเก็บเงิน',
    'billed_clients' => 'ลูกค้าที่เรียกเก็บเงิน',
    'active_client' => 'ลูกค้าที่ใช้งานอยู่',
    'active_clients' => 'ลูกค้าที่ใช้งานอยู่',
    'invoices_past_due' => 'ใบแจ้งหนี้ที่ครบกำหนดชำระแล้ว',
    'upcoming_invoices' => 'ใบแจ้งหนี้ที่จะเกิดขึ้น',
    'average_invoice' => 'ใบแจ้งหนี้เฉลี่ย',
    'archive' => 'เอกสารเก่า',
    'delete' => 'ลบ',
    'archive_client' => 'เอกสารเก่าลูกค้า',
    'delete_client' => 'ลบลูกค้า',
    'archive_payment' => 'เอกสารการจ่ายเงิน',
    'delete_payment' => 'ลบการจ่ายเงิน',
    'archive_credit' => 'เอกสารเครดิต',
    'delete_credit' => 'ลบเครดิต',
    'show_archived_deleted' => 'แสดงเอกสารที่เก็บถาวร / ลบแล้ว',
    'filter' => 'กรอง',
    'new_client' => 'เพิ่มลูกค้า',
    'new_invoice' => 'เพิ่มใบแจ้งหนี้',
    'new_payment' => 'ป้อนการชำระเงิน',
    'new_credit' => 'ป้อนเครดิต',
    'contact' => 'ผู้ติดต่อ',
    'date_created' => 'วันที่ทำรายการ',
    'last_login' => 'ล็อกอินล่าล่าสุด',
    'balance' => 'ยอดคงเหลือ',
    'action' => 'การกระทำ',
    'status' => 'สถานะ',
    'invoice_total' => 'ยอดรวมตามใบแจ้งหนี้',
    'frequency' => 'ความถี่',
    'range' => 'Range',
    'start_date' => 'วันที่เริ่ม',
    'end_date' => 'วันที่สิ้นสุด',
    'transaction_reference' => 'รายการอ้างอิง',
    'method' => 'วิธี',
    'payment_amount' => 'ยอดจ่าย',
    'payment_date' => 'กำหนดจ่าย',
    'credit_amount' => 'ยอดเครดิต',
    'credit_balance' => 'เครดิตคงเหลือ',
    'credit_date' => 'วันที่เครดิต',
    'empty_table' => 'ไม่มีข้อมูลในตารางฐานข้อมูล',
    'select' => 'เลือก',
    'edit_client' => 'แก้ไขลูกค้า',
    'edit_invoice' => 'แก้ไขใบแจ้งหนี้',
    'create_invoice' => 'สร้างใบแจ้งหนี้',
    'enter_credit' => 'เพิ่มเครดิต',
    'last_logged_in' => 'เข้าระบบล่าสุด',
    'details' => 'รายละเอียด',
    'standing' => 'ยอดคงค้าง',
    'credit' => 'เครดิต',
    'activity' => 'กิจกรรม',
    'date' => 'วันที่',
    'message' => 'ข้อความ',
    'adjustment' => 'ปรับปรุงรายการ',
    'are_you_sure' => 'แน่ใจหรือไม่?',
    'payment_type_id' => 'ประเภทการจ่ายเงิน',
    'amount' => 'ยอดเงิน',
    'work_email' => 'อีเมล',
    'language_id' => 'ภาษา',
    'timezone_id' => 'เขตเวลา',
    'date_format_id' => 'รูปแบบวันที่',
    'datetime_format_id' => 'รูปแบบวันที่/เวลา',
    'users' => 'ผู้ใช้งาน',
    'localization' => 'การปรับให้เข้ากับท้องถิ่น',
    'remove_logo' => 'ลบโลโก้',
    'logo_help' => 'รองรับ: JPEG, GIF และ PNG',
    'payment_gateway' => 'ช่องทางการชำระเงิน',
    'gateway_id' => 'ช่องทาง',
    'email_notifications' => 'การแจ้งเตือนทางอีเมล',
    'email_sent' => 'ส่งอีเมลถึงฉันเมื่อใบแจ้งหนี้ถูก <b>ส่ง</b>',
    'email_viewed' => 'ส่งอีเมลถึงฉันเมื่อใบแจ้งหนี้ถูก <b>อ่าน</b>',
    'email_paid' => 'ส่งอีเมลถึงฉันเมื่อใบแจ้งหนี้ได้รับการ <b>ชำระเงิน</b>',
    'site_updates' => 'การอัปเดตไซด์',
    'custom_messages' => 'กำหนดข้อความเอง',
    'default_email_footer' => 'ตั้งค่าเริ่มต้น<b>ลายเซ็นอีเมล</b>',
    'select_file' => 'กรุณาเลือกไฟล์',
    'first_row_headers' => 'ใช้แถวแรกเป็นส่วนหัว',
    'column' => 'คอลัมน์',
    'sample' => 'ตัวอย่าง',
    'import_to' => 'นำเข้า',
    'client_will_create' => 'ลูกค้ากำลังถูกสร้างขึ้น',
    'clients_will_create' => 'ลูกค้ากำลังถูกสร้างขึ้น',
    'email_settings' => 'ตั้งค่าอีเมล์',
    'client_view_styling' => 'การจัดรูปแบบมุมมองลูกค้า',
    'pdf_email_attachment' => 'แนบไฟล์ PDF',
    'custom_css' => 'ปรับแต่ง CSS',
    'import_clients' => 'นำเข้าข้อมูลลูกค้า',
    'csv_file' => 'ไฟล์ CSV',
    'export_clients' => 'ส่งออกข้อมูลลูกค้า',
    'created_client' => 'สร้างลูกค้าเรียบร้อยแล้ว',
    'created_clients' => 'สร้างสำเร็จ :count ลูกค้า(s)',
    'updated_settings' => 'อัปเดตการตั้งค่าเรียบร้อยแล้ว',
    'removed_logo' => 'ลบโลโก้เรียบร้อยแล้ว',
    'sent_message' => 'ส่งข้อความเรียบร้อยแล้ว',
    'invoice_error' => 'โปรดเลือกลูกค้าและแก้ไขข้อผิดพลาด',
    'limit_clients' => 'ขออภัย,เกินขีดจำกัดของ :count ลูกค้า',
    'payment_error' => 'มีข้อผิดพลาดในการประมวลผลการชำระเงินของคุณ กรุณาลองใหม่อีกครั้งในภายหลัง.',
    'registration_required' => 'โปรดลงทะเบียนเพื่อส่งใบแจ้งหนี้ทางอีเมล',
    'confirmation_required' => 'โปรดยืนยันที่อยู่อีเมลของคุณ คลิกที่นี่ เพื่อส่งอีเมลยืนยันอีกครั้ง',
    'updated_client' => 'อัปเดตลูกค้าเรียบร้อยแล้ว',
    'archived_client' => 'เก็บข้อมูลลูกค้าเรียบร้อยแล้ว',
    'archived_clients' => 'เก็บข้อมูลเรียบร้อยแล้ว: นับลูกค้า',
    'deleted_client' => 'ลบลูกค้าเรียบร้อยแล้ว',
    'deleted_clients' => 'ลบลูกค้าเรียบร้อยแล้ว :count ลูกค้า',
    'updated_invoice' => 'อัปเดตใบแจ้งหนี้สำเร็จแล้ว',
    'created_invoice' => 'สร้างใบแจ้งหนี้เรียบร้อยแล้ว',
    'cloned_invoice' => 'ทำสำเนาใบแจ้งหนี้เรียบร้อยแล้ว',
    'emailed_invoice' => 'ส่งใบแจ้งหนี้ทางอีเมลเรียบร้อยแล้ว',
    'and_created_client' => 'และสร้างลูกค้า',
    'archived_invoice' => 'เก็บบันทึกใบแจ้งหนี้เรียบร้อยแล้ว',
    'archived_invoices' => 'บันทึกเรียบร้อยแล้ว :count ใบแจ้งหนี้',
    'deleted_invoice' => 'ลบใบแจ้งหนี้เรียบร้อยแล้ว',
    'deleted_invoices' => 'ลบเรียบร้อยแล้ว :count ใบแจ้งหนี้',
    'created_payment' => 'สร้างการชำระเงินเรียบร้อยแล้ว',
    'created_payments' => 'สร้างสำเร็จ :count ชำระเงิน (s)',
    'archived_payment' => 'เก็บการชำระเงินเรียบร้อยแล้ว',
    'archived_payments' => 'เก็บข้อมูลเรียบร้อยแล้ว :count การชำระเงิน',
    'deleted_payment' => 'ลบการชำระเงินเรียบร้อยแล้ว',
    'deleted_payments' => 'ลบเรียบร้อยแล้ว :count การชำระเงิน',
    'applied_payment' => 'ใช้การชำระเงินเรียบร้อยแล้ว',
    'created_credit' => 'สร้างเครดิตเรียบร้อยแล้ว',
    'archived_credit' => 'เก็บเครดิตเรียบร้อยแล้ว',
    'archived_credits' => 'เก็บข้อมูลเรียบร้อยแล้ว :count เครดิต',
    'deleted_credit' => 'ลบเครดิตเรียบร้อยแล้ว',
    'deleted_credits' => 'ลบเรียบร้อยแล้ว :count เครดิต',
    'imported_file' => 'นำเข้าไฟล์เรียบร้อยแล้ว',
    'updated_vendor' => 'อัปเดตผู้ขายสำเร็จแล้ว',
    'created_vendor' => 'สร้างผู้ขายสำเร็จแล้ว',
    'archived_vendor' => 'การจัดเก็บผู้ขายประสบความสำเร็จ',
    'archived_vendors' => 'เก็บเข้าคลังเรียบร้อยแล้ว :count ผู้ขาย',
    'deleted_vendor' => 'ลบผู้ขายเรียบร้อยแล้ว',
    'deleted_vendors' => 'ลบเรียบร้อยแล้ว :count ผู้ขาย',
    'confirmation_subject' => 'การยืนยันบัญชีของ Ninja Invoice',
    'confirmation_header' => 'การยืนยันบัญชี',
    'confirmation_message' => 'โปรดเข้าถึงลิงก์ด้านล่างเพื่อยืนยันบัญชีของคุณ',
    'invoice_subject' => 'ใบแจ้งหนี้ใหม่: ใบแจ้งหนี้จาก: บัญชี',
    'invoice_message' => 'หากต้องการดูใบแจ้งหนี้ของคุณสำหรับ :amount, คลิกที่ลิงก์ด้านล่าง',
    'payment_subject' => 'การชำระเงินที่ได้รับ',
    'payment_message' => 'ขอขอบคุณสำหรับการชำระเงิน: จำนวนเงิน',
    'email_salutation' => 'เรียนคุณ :name,',
    'email_signature' => 'ด้วยความเคารพ',
    'email_from' => 'ทีม Ninja Invoice',
    'invoice_link_message' => 'หากต้องการดูใบแจ้งหนี้ให้คลิกลิงก์ด้านล่าง:',
    'notification_invoice_paid_subject' => 'ใบแจ้งหนี้ :invoice ได้รับการชำระแล้วโดย :client',
    'notification_invoice_sent_subject' => 'ใบแจ้งหนี้ :invoice ได้ถูกส่งให้ :client',
    'notification_invoice_viewed_subject' => 'ใบแจ้งหนี้ :invoice ถูกอ่านแล้วโดย :client',
    'notification_invoice_paid' => 'การชำระเงินของ :amount เงินที่ทำโดยลูกค้า: ลูกค้าที่มีต่อใบแจ้งหนี้ :invoice.',
    'notification_invoice_sent' => 'ลูกค้าต่อไปนี้ :client ได้ส่งอีเมลใบแจ้งหนี้ :invoice สำหรับ :amount.',
    'notification_invoice_viewed' => 'ลูกค้าต่อไปนี้ :client ได้ดูใบแจ้งหนี้ :invoice สำหรับ :amount.',
    'reset_password' => 'คุณสามารถรีเซ็ตรหัสผ่านบัญชีโดยคลิกที่ปุ่มต่อไปนี้:',
    'secure_payment' => 'การชำระเงินที่ปลอดภัย',
    'card_number' => 'หมายเลขบัตร',
    'expiration_month' => 'เดือนที่หมดอายุ',
    'expiration_year' => 'ปีที่หมดอายุ',
    'cvv' => 'CVV',
    'logout' => 'ออกจากระบบ',
    'sign_up_to_save' => 'ลงชื่อสมัครใช้เพื่อบันทึกงานของคุณ',
    'agree_to_terms' => 'ฉันยอมรับเงื่อนไข',
    'terms_of_service' => 'เงื่อนไขการให้บริการ',
    'email_taken' => 'ที่อยู่อีเมลได้รับการลงทะเบียนแล้ว',
    'working' => 'กำลังทำงาน',
    'success' => 'สำเร็จ',
    'success_message' => 'คุณได้ลงทะเบียนแล้ว! โปรดไปที่ลิงก์ในอีเมลยืนยันบัญชีเพื่อยืนยันที่อยู่อีเมลของคุณ.',
    'erase_data' => 'บัญชีของคุณไม่ได้ลงทะเบียนการดำเนินการนี้จะลบข้อมูลของคุณอย่างถาวร.',
    'password' => 'รหัสผ่าน',
    'pro_plan_product' => 'Pro Plan',
    'pro_plan_success' => 'ขอขอบคุณที่เลือกแผน Pro Pro ของ Invoice Ninja!<p/>&nbsp;<br/>
<b>ขั้นตอนถัดไป</b><p/>มีการส่งใบแจ้งหนี้ที่ต้องชำระไปที่อีเมลแล้ว
ที่อยู่ที่เชื่อมโยงกับบัญชีของคุณ เพื่อปลดล็อก
โปรดปฏิบัติตามคำแนะนำในใบแจ้งหนี้ที่จะชำระแล้ว
ใช้ได้เป็นเวลาหนึ่งปีสำหรับการชำระเงิน.<p/>
ไม่พบใบแจ้งหนี้ใช่หรือไม่? ต้องการความช่วยเหลือเพิ่มเติมหรือไม่? เรายินดีที่จะช่วยเหลือ
-- ส่งอีเมลมาที่ contact@invoiceninja.com',
    'unsaved_changes' => 'คุณยังไม่ได้บันทึกการเปลี่ยนแปลงที่เกิดขึ้น',
    'custom_fields' => 'ฟิลด์ที่กำหนดเอง',
    'company_fields' => 'เขตข้อมูลของ บริษัท',
    'client_fields' => 'เขตข้อมูลลูกค้า',
    'field_label' => 'ฟิลด์ลาเบล',
    'field_value' => 'ค่าฟิลด์',
    'edit' => 'แก้ไข',
    'set_name' => 'ตั้งชื่อ บริษัท ของคุณ',
    'view_as_recipient' => 'ดูในฐานะผู้รับ',
    'product_library' => 'สินค้า',
    'product' => 'สินค้า',
    'products' => 'ผลิตภัณฑ์',
    'fill_products' => 'เติมข้อมูลอัตโนมัติ',
    'fill_products_help' => 'การเลือกสินค้า <b>จะเติมคำอธิบายและค่าใช้จ่ายโดยอัตโนมัติ</b>',
    'update_products' => 'อัปเดตผลิตภัณฑ์โดยอัตโนมัติ',
    'update_products_help' => 'การอัปเดตใบแจ้งหนี้ <b>จะอัปเดตสินค้าโดยอัตโนมัติ</b>',
    'create_product' => 'เพิ่มสินค้า',
    'edit_product' => 'แก้ไขสินค้า',
    'archive_product' => 'เก็บเข้าคลังสินค้า',
    'updated_product' => 'อัปเดตสินค้าสำเร็จแล้ว',
    'created_product' => 'สร้างสินค้าสำเร็จแล้ว',
    'archived_product' => 'บันทึกสินค้าสำเร็จ',
    'pro_plan_custom_fields' => ':link เพื่อเปิดใช้งานฟิลด์ที่กำหนดเองโดยเข้าร่วม Pro Plan',
    'advanced_settings' => 'ตั้งค่าขั้นสูง',
    'pro_plan_advanced_settings' => ':link เพื่อเปิดใช้งานการตั้งค่าขั้นสูงโดยเข้าร่วม Pro Plan',
    'invoice_design' => 'ออกแบบใบแจ้งหนี้',
    'specify_colors' => 'ระบุสี',
    'specify_colors_label' => 'เลือกสีที่จะใช้กับใบแจ้งหนี้',
    'chart_builder' => 'เครื่องมือสร้างแผนภูมิ',
    'ninja_email_footer' => 'สร้าง. ส่ง. รับเงิน',
    'go_pro' => 'Go Pro',
    'quote' => 'ใบเสนอราคา',
    'quotes' => 'ใบเสนอราคา',
    'quote_number' => 'หมายเลขใบเสนอราคา',
    'quote_number_short' => 'Quote #',
    'quote_date' => 'วันที่อ้างอิง',
    'quote_total' => 'ยอดรวมทั้งหมด',
    'your_quote' => 'ใบเสนอราคาของคุณ',
    'total' => 'ทั้งหมด',
    'clone' => 'ทำซ้ำ',
    'new_quote' => 'ใบเสนอราคาใหม่',
    'create_quote' => 'สร้างใบเสนอราคา',
    'edit_quote' => 'แก้ไขใบเสนอราคา',
    'archive_quote' => 'เก็บบันทึกใบเสนอราคา',
    'delete_quote' => 'ลบใบเสนอราคา',
    'save_quote' => 'บันทึกใบเสนอราคา',
    'email_quote' => 'อีเมล์ใบเสนอราคา',
    'clone_quote' => 'ทำซ้ำใบเสนอราคา',
    'convert_to_invoice' => 'แปลงเป็นใบแจ้งหนี้',
    'view_invoice' => 'ดูใบแจ้งหนี้',
    'view_client' => 'ดูลูกค้า',
    'view_quote' => 'ดูใบเสนอราคา',
    'updated_quote' => 'อัปเดทใบเสนอราคาเรียบร้อย',
    'created_quote' => 'สร้างใบเสนอราคาเรียบร้อย',
    'cloned_quote' => 'ทำซ้ำใบเสนอราคาเรียบร้อย',
    'emailed_quote' => 'อีเมล์ใบเสนอราคาเรียบร้อย',
    'archived_quote' => 'เก็บบันทึกใบเสนอราคาเรียบร้อย',
    'archived_quotes' => 'เก็บบันทึกเรียบร้อย :count ใบเสนอราคา',
    'deleted_quote' => 'ลบใบเสนอราคาเรียบร้อย',
    'deleted_quotes' => 'ลบเรียบร้อย :count ใบเสนอราคา',
    'converted_to_invoice' => 'แปลงใบเสนอราคาเป็นใบแจ้งหนี้เรียบร้อย',
    'quote_subject' => 'New quote :number from :account',
    'quote_message' => 'ดูใบเสนอราคา :amount, คลิกที่ลิงค์ด้านล่าง',
    'quote_link_message' => 'หากต้องการดูใบเสนอราคาของลูกค้าคลิกที่ลิงก์ด้านล่าง:',
    'notification_quote_sent_subject' => 'ใบเสนอราคา :invoice ถูกส่งไปยัง :client',
    'notification_quote_viewed_subject' => 'ใบเสนอราคา :invoice เปิดอ่านโดย :client',
    'notification_quote_sent' => 'ลูกค้าต่อไปนี้ :client ได้ส่งใบเสนอราคา :invoice สำหรับ :amount.',
    'notification_quote_viewed' => 'ลูกค้าต่อไปนี้ :client ได้ดูใบเสนอราคา :invoice สำหรับ :amount.',
    'session_expired' => 'เซสชั่นของคุณหมดอายุ',
    'invoice_fields' => 'ฟิลด์ใบเสนอราคา',
    'invoice_options' => 'ตัวเลือกใบเสนอราคา',
    'hide_paid_to_date' => 'ซ่อนการจ่ายเงินไปยังวันที่',
    'hide_paid_to_date_help' => 'แสดงเฉพาะพื้นที่ "ชำระเงินถึงวันที่" ในใบแจ้งหนี้ของคุณเมื่อได้รับการชำระเงินแล้ว',
    'charge_taxes' => 'ภาษีค่าบริการ',
    'user_management' => 'การจัดการผู้ใช้',
    'add_user' => 'เพิ่มผู้ใช้',
    'send_invite' => 'ส่งคำเชิญชวน',
    'sent_invite' => 'ส่งคำเชิญเรียบร้อยแล้ว',
    'updated_user' => 'อัปเดตผู้ใช้เรียบร้อยแล้ว',
    'invitation_message' => 'คุณได้รับเชิญจาก :invitor.',
    'register_to_add_user' => 'โปรดลงทะเบียนเพื่อเพิ่มผู้ใช้',
    'user_state' => 'สถานะ',
    'edit_user' => 'แก้ไขผู้ใช้',
    'delete_user' => 'ลบผู้ใช้',
    'active' => 'ใช้งานอยู่',
    'pending' => 'รอดำเนินการ',
    'deleted_user' => 'ลบผู้ใช้เรียบร้อยแล้ว',
    'confirm_email_invoice' => 'คุณแน่ใจหรือไม่ว่าต้องการส่งอีเมลใบแจ้งหนี้นี้',
    'confirm_email_quote' => 'คุณแน่ใจหรือไม่ว่าต้องการส่งอีเมลใบเสนอราคานี้',
    'confirm_recurring_email_invoice' => 'คุณแน่ใจหรือไม่ว่าต้องการส่งใบแจ้งหนี้นี้ทางอีเมล',
    'confirm_recurring_email_invoice_not_sent' => 'Are you sure you want to start the recurrence?',
    'cancel_account' => 'ลบบัญชี',
    'cancel_account_message' => 'คำเตือน: การดำเนินการนี้จะลบบัญชีของคุณอย่างถาวรและไม่สามารถนำกลับมาได้',
    'go_back' => 'กลับ',
    'data_visualizations' => 'การแสดงภาพข้อมูล',
    'sample_data' => 'แสดงข้อมูลตัวอย่าง',
    'hide' => 'ซ่อน',
    'new_version_available' => 'เวอร์ชันใหม่ของ :releases_link สามารถใช้ได้. คุณกำลังใช้งาน v::user_version, เวอร์ชันล่าสุดคือ v:latest_version',
    'invoice_settings' => 'ตั้งค่าใบแจ้งหนี้',
    'invoice_number_prefix' => 'คำนำหน้าหมายเลข ใบแจ้งหนี้',
    'invoice_number_counter' => 'การนับจำนวนใบแจ้งหนี้',
    'quote_number_prefix' => 'คำนำหน้าหมายเลข ใบเสนอราคา',
    'quote_number_counter' => 'การนับจำนวนใบเสนอราคา',
    'share_invoice_counter' => 'แชร์ใบแจ้งหนี้',
    'invoice_issued_to' => 'ใบแจ้งหนี้ออกให้กับ',
    'invalid_counter' => 'เพื่อป้องกันความขัดแย้งที่เป็นไปได้โปรดตั้งค่านำหน้าหมายเลขใบแจ้งหนี้หรือหมายเลขอ้างอิง',
    'mark_sent' => 'ทำเครื่องหมายไว้',
    'gateway_help_1' => ':link ลงทะเบียน Authorize.net',
    'gateway_help_2' => ':link ลงทะเบียน Authorize.net',
    'gateway_help_17' => ':link เพื่อรับลายเซ็น PayPal API ',
    'gateway_help_27' => ':link ลงชื่อสมัครใช้ 2Checkout.com เพื่อให้แน่ใจว่ามีการตั้งค่าการติดตามการชำระเงิน :complete_link เป็น URL การเปลี่ยนเส้นทางใน Account> Site Management ในเว็บ 2Checkout',
    'gateway_help_60' => ':link to create a WePay account.',
    'more_designs' => 'ออกแบบเพิ่มเติม',
    'more_designs_title' => 'การออกแบบใบแจ้งหนี้เพิ่มเติม',
    'more_designs_cloud_header' => 'Go Pro สำหรับการออกแบบใบแจ้งหนี้เพิ่มเติม',
    'more_designs_cloud_text' => '',
    'more_designs_self_host_text' => '',
    'buy' => 'ซื้อ',
    'bought_designs' => 'เพิ่มการออกแบบใบแจ้งหนี้เพิ่มเติมแล้ว',
    'sent' => 'ส่ง',
    'vat_number' => 'หมายเลขภาษี',
    'timesheets' => ' การบันทึกการทำงานประจำวัน',
    'payment_title' => 'ป้อนข้อมูลการเรียกเก็บเงินและข้อมูลบัตรเครดิตของคุณ',
    'payment_cvv' => '*This is the 3-4 digit number on the back of your card',
    'payment_footer1' => ' ที่อยู่สำหรับการเรียกเก็บเงินต้องตรงกับที่อยู่ที่เกี่ยวข้องกับบัตรเครดิต',
    'payment_footer2' => '* โปรดคลิก "ชำระเงินทันที" เพียงครั้งเดียวเท่านั้น - อาจใช้เวลาดำเนินการประมาณ 1 นาที',
    'id_number' => 'หมายเลขประจำตัวประชาชน',
    'white_label_link' => 'White label',
    'white_label_header' => 'White Label',
    'bought_white_label' => 'เปิดใช้ใบอนุญาต white label  สำเร็จแล้ว',
    'white_labeled' => 'White labeled',
    'restore' => 'กู้คืน',
    'restore_invoice' => 'เรียกคืนใบแจ้งหนี้',
    'restore_quote' => 'เรียกคืนใบเสนอราคา',
    'restore_client' => 'กู้คืนลูกค้า',
    'restore_credit' => 'กู้คืนเครดิต',
    'restore_payment' => 'กู้คืนการจ่ายเงิน',
    'restored_invoice' => 'กู้คืนใบแจ้งหนี้เรียบร้อยแล้ว',
    'restored_quote' => 'กู้คืนใบเสนอราคาเรียบร้อยแล้ว',
    'restored_client' => 'กู้คืนลูกค้าเรียบร้อยแล้ว',
    'restored_payment' => 'กู้คืนการชำระเงินเรียบร้อยแล้ว',
    'restored_credit' => 'กู้คืนเครดิตเรียบร้อยแล้ว',
    'reason_for_canceling' => 'ช่วยเราในการปรับปรุงเว็บไซต์ของเราด้วยการบอกเหตุผลที่คุณออกจากเว็บไซด์',
    'discount_percent' => 'เปอร์เซ็นต์',
    'discount_amount' => 'ยอดรวม',
    'invoice_history' => 'ประวัติการแจ้งหนี้',
    'quote_history' => 'ประวัติการเสนอราคา',
    'current_version' => 'รุ่นปัจจุบัน',
    'select_version' => 'เลือกรุ่น',
    'view_history' => 'ดูประวัติย้อนหลัง',
    'edit_payment' => 'แก้ไขรายการจ่ายเงิน',
    'updated_payment' => 'การปรับปรุงรายการจ่ายเงินเสร็จสมบูรณ์',
    'deleted' => 'ลบแล้ว',
    'restore_user' => 'กู้คืนผู้ใช้',
    'restored_user' => 'กู้คืนผู้ใช้เรียบร้อยแล้ว',
    'show_deleted_users' => 'แสดงผู้ใช้ที่ถูกลบ',
    'email_templates' => 'เทมเพลตอีเมล์',
    'invoice_email' => 'อีเมลใบแจ้งหนี้',
    'payment_email' => 'อีเมลการชำระเงิน',
    'quote_email' => 'อีเมล์ใบเสนอราคา',
    'reset_all' => 'เริ่มต้นการตั้งค่าใหม่ทั้งหมด',
    'approve' => 'อนุมัติ',
    'token_billing_type_id' => 'Token Billing',
    'token_billing_help' => 'Store payment details with WePay, Stripe, Braintree or GoCardless.',
    'token_billing_1' => 'ปิดการใช้',
    'token_billing_2' => 'Opt-in ช่องทำเครื่องหมายจะปรากฏ แต่ไม่ได้เลือกไว้',
    'token_billing_3' => 'Opt-out - ช่องทำเครื่องหมายจะปรากฏและสามารถเลือกได้',
    'token_billing_4' => 'ตลอดเวลา',
    'token_billing_checkbox' => 'เก็บรายละเอียดบัตรเครดิต',
    'view_in_gateway' => 'ดูใน :gateway',
    'use_card_on_file' => 'Use Card on File',
    'edit_payment_details' => 'แก้ไขรายละเอียดการชำระเงิน',
    'token_billing' => 'บันทึกรายละเอียดบัตรเครดิต',
    'token_billing_secure' => 'ข้อมูลถูกเก็บไว้อย่างปลอดภัยโดย :link',
    'support' => 'สนับสนุน',
    'contact_information' => 'ข้อมูลติดต่อ',
    '256_encryption' => '256-Bit Encryption',
    'amount_due' => 'จำนวนคงเหลือที่ยังค้างอยู่',
    'billing_address' => 'ที่อยู่เรียกเก็บเงิน',
    'billing_method' => 'วิธีการเรียกเก็บเงิน',
    'order_overview' => 'ภาพรวมคำสั่งซื้อ',
    'match_address' => '* ที่อยู่ต้องตรงกับที่อยู่ที่เกี่ยวข้องกับบัตรเครดิต',
    'click_once' => '* โปรดคลิก "ชำระเงินทันที" เพียงครั้งเดียวเท่านั้น - อาจใช้เวลาดำเนินการประมาณ 1 นาที',
    'invoice_footer' => 'ส่วนท้ายของใบแจ้งหนี้',
    'save_as_default_footer' => 'บันทึกเป็นส่วนท้ายเริ่มต้น',
    'token_management' => 'การจัดการโทเค็น',
    'tokens' => 'Tokens',
    'add_token' => 'เพิ่ม Token',
    'show_deleted_tokens' => 'แสดง Token ที่ถูกลบ',
    'deleted_token' => 'ลบ Token เรียบร้อย',
    'created_token' => 'สร้าง Token เรียบร้อย',
    'updated_token' => 'อัปเดท Token เรียบร้อย',
    'edit_token' => 'แก้ไข Token',
    'delete_token' => 'ลบ Token',
    'token' => 'Token',
    'add_gateway' => 'เพิ่มช่องทางการชำระเงิน',
    'delete_gateway' => 'ลบช่องทางการชำระเงิน',
    'edit_gateway' => 'แก้ไขช่องทางการชำระเงิน',
    'updated_gateway' => 'อัปเดทช่องทางการชำระเงินเรียบร้อย',
    'created_gateway' => 'สร้างช่องทางการชำระเงินเรียบร้อย',
    'deleted_gateway' => 'ลบช่องทางกา่รชำระเงินเรียบร้อย',
    'pay_with_paypal' => 'PayPal',
    'pay_with_card' => 'บัตรเครดิต',
    'change_password' => 'เปลี่ยนรหัสผ่าน',
    'current_password' => 'รหัสผ่านปัจจุบัน',
    'new_password' => 'รหัสผ่านใหม่',
    'confirm_password' => 'ยืนยันรหัสผ่าน',
    'password_error_incorrect' => 'รหัสผ่านปัจจุบันไม่ถูกต้อง',
    'password_error_invalid' => 'รหัสผ่านใหม่ไม่ถูกต้อง.',
    'updated_password' => 'อัปเดตรหัสผ่านเรียบร้อย',
    'api_tokens' => 'API Tokens',
    'users_and_tokens' => 'Users & Tokens',
    'account_login' => 'ลงชื่อเข้าใช้',
    'recover_password' => 'กู้คืนรหัสผ่านของคุณ',
    'forgot_password' => 'ลืมรหัสผ่านหรือไม่?',
    'email_address' => 'ที่อยู่อีเมล',
    'lets_go' => 'ไปกันเลย',
    'password_recovery' => 'กู้คืนรหัสผ่าน',
    'send_email' => 'ส่งอีเมล',
    'set_password' => 'ตั้งรหัสผ่าน',
    'converted' => 'แปลง',
    'email_approved' => 'ส่งอีเมลฉันเมื่อมีใบเสนอราคา <b>ได้รับการอนุมัติ</b>',
    'notification_quote_approved_subject' => 'ใบเสนอราคา  :invoice ได้รับการอนุมัติโดย :client',
    'notification_quote_approved' => 'ลูกค้าต่อไปนี้ :client ได้อนุมัติใบเสนอราคา :invoice สำหรับ :amount.',
    'resend_confirmation' => 'ส่งอีเมลยืนยันอีกครั้ง',
    'confirmation_resent' => 'อีเมลยืนยันถูกส่งอีกครั้ง',
    'gateway_help_42' => ':link ลงชื่อสมัครใช้ BitPay.<br/>หมายเหตุ: ใช้คีย์ API แบบเดิมไม่ใช่ API Token.',
    'payment_type_credit_card' => 'บัตรเครดิต',
    'payment_type_paypal' => 'PayPal',
    'payment_type_bitcoin' => 'Bitcoin',
    'payment_type_gocardless' => 'GoCardless',
    'knowledge_base' => 'ฐานความรู้',
    'partial' => 'บางส่วน / เงินฝาก',
    'partial_remaining' => ':partial ของ :balance',
    'more_fields' => 'ฟิลด์เพิ่มเติม',
    'less_fields' => 'ฟิลด์น้อยลง',
    'client_name' => 'ชื่อลูกค้า',
    'pdf_settings' => 'การตั้งค่า PDF',
    'product_settings' => 'การตั้งค่าสินค้า',
    'auto_wrap' => 'ตัดคำอัตโนมัติ',
    'duplicate_post' => 'คำเตือน: หน้าก่อนหน้านี้ถูกส่งมาสองครั้ง การส่งครั้งที่สองไม่มีผล',
    'view_documentation' => 'ดูเอกสาร',
    'app_title' => 'การออกใบแจ้งหนี้ออนไลน์แบบโอเพนซอร์ส',
    'app_description' => 'Invoice Ninja เป็นโซลูชันโอเพนซอร์สฟรีสำหรับลูกค้าที่ออกใบแจ้งหนี้และเรียกเก็บเงิน ด้วย Invoice Ninja คุณสามารถสร้างและส่งใบแจ้งหนี้ที่สวยงามได้จากอุปกรณ์ใด ๆ ที่สามารถเข้าถึงเว็บได้ ลูกค้าของคุณสามารถพิมพ์ใบแจ้งหนี้ของคุณดาวน์โหลดเป็นไฟล์ PDF และคุณจ่ายเงินออนไลน์จากภายในระบบของเราได้เลย',
    'rows' => 'แถว',
    'www' => 'www',
    'logo' => 'www',
    'subdomain' => 'Subdomain',
    'provide_name_or_email' => 'โปรดระบุชื่อหรืออีเมล',
    'charts_and_reports' => 'แผนภูมิและรายงาน',
    'chart' => 'แผนภูมิ',
    'report' => 'รายงาน',
    'group_by' => 'จัดกลุ่มตาม',
    'paid' => 'จ่ายเงิน',
    'enable_report' => 'รายงาน',
    'enable_chart' => 'แผนภูมิ',
    'totals' => 'ทั้งหมด',
    'run' => 'ทำงาน',
    'export' => 'ส่งออก',
    'documentation' => 'เอกสาร',
    'zapier' => 'Zapier',
    'recurring' => 'ทำประจำ',
    'last_invoice_sent' => 'ส่งใบแจ้งหนี้ครั้งสุดท้ายแล้ว :date',
    'processed_updates' => 'อัปเดตเสร็จเรียบร้อยแล้ว',
    'tasks' => 'งาน',
    'new_task' => 'งานใหม่',
    'start_time' => 'เวลาเริ่มต้น',
    'created_task' => 'สร้างงานเรียบร้อยแล้ว',
    'updated_task' => 'อัปเดตงานสำเร็จแล้ว',
    'edit_task' => 'แก้ไขงาน',
    'clone_task' => 'Clone Task',
    'archive_task' => 'เก็บงาน',
    'restore_task' => 'เรียกคืนงาน',
    'delete_task' => 'ลบงาน',
    'stop_task' => 'หยุดงาน',
    'time' => 'เวลา',
    'start' => 'เริ่ม',
    'stop' => 'หยุด',
    'now' => 'ตอนนี้',
    'timer' => 'จับเวลา',
    'manual' => 'คู่มือ',
    'date_and_time' => 'วันเวลา',
    'second' => 'วินาที',
    'seconds' => 'วินาที',
    'minute' => 'นาที',
    'minutes' => 'นาที',
    'hour' => 'ชั่วโมง',
    'hours' => 'ชั่วโมง',
    'task_details' => 'รายละเอียดงาน',
    'duration' => 'ระยะเวลา',
    'time_log' => 'Time Log',
    'end_time' => 'เวลาสิ้นสุด',
    'end' => 'จบงาน',
    'invoiced' => 'ออกใบแจ้งหนี้',
    'logged' => 'บันทึกการเข้า',
    'running' => 'กำลังทำงาน',
    'task_error_multiple_clients' => 'งานไม่สามารถเป็นของลูกค้าที่อื่นได้',
    'task_error_running' => 'โปรดหยุดการทำงานก่อน',
    'task_error_invoiced' => 'งานได้รับใบแจ้งหนี้แล้ว',
    'restored_task' => 'กู้คืนงานเรียบร้อยแล้ว',
    'archived_task' => 'เก็บบันทึกงานเรียบร้อยแล้ว',
    'archived_tasks' => 'เก็บเรียบร้อยแล้ว :count งาน',
    'deleted_task' => 'ลบงานเรียบร้อย',
    'deleted_tasks' => 'ลบงานเรียบร้อย :count งาน',
    'create_task' => 'สร้างงาน',
    'stopped_task' => 'หยุดงานเรียบร้อย',
    'invoice_task' => 'งานใบแจ้งหนี้',
    'invoice_labels' => 'ป้ายใบแจ้งหนี้',
    'prefix' => 'คำนำหน้า',
    'counter' => 'ตัวนับ',
    'payment_type_dwolla' => 'Dwolla',
    'gateway_help_43' => ':link ลงทะเบียนสำหรับ Dwolla',
    'partial_value' => 'ต้องมากกว่าศูนย์และน้อยกว่ายอดรวม',
    'more_actions' => 'การดำเนินการมากขึ้น',
    'pro_plan_title' => 'NINJA PRO',
    'pro_plan_call_to_action' => 'อัพเกรดเดี๋ยวนี้!',
    'pro_plan_feature1' => 'สร้างลูกค้าไม่จำกัด',
    'pro_plan_feature2' => 'เข้าถึง 10 แบบฟอร์มใบแจ้งหนี้สวย ๆ',
    'pro_plan_feature3' => 'URL ที่กำหนดได้เอง - "YourBrand.InvoiceNinja.com"',
    'pro_plan_feature4' => 'เอา  "Created by Invoice Ninja" ออก',
    'pro_plan_feature5' => 'การเข้าถึงและการติดตามกิจกรรมของผู้ใช้พร้อมกันหลายคน',
    'pro_plan_feature6' => 'สร้างใบเสนอราคาและใบแจ้งหนี้ ',
    'pro_plan_feature7' => 'กำหนดเขตข้อมูลใบกำกับสินค้า & เลขที่',
    'pro_plan_feature8' => 'ตัวเลือกในการแนบไฟล์ PDF กับอีเมลไคลเอ็นต์',
    'resume' => 'ทำต่อไป',
    'break_duration' => 'หยุด',
    'edit_details' => 'แก้ไขรายละเอียด',
    'work' => 'งาน',
    'timezone_unset' => 'กรุณา :link ตั้งเขตเวลาของคุณ',
    'click_here' => 'คลิกที่นี่',
    'email_receipt' => 'ใบเสร็จการชำระเงินทางอีเมลให้กับลูกค้า',
    'created_payment_emailed_client' => 'สร้างการชำระเงินและส่งอีเมลเรียบร้อยแล้ว',
    'add_company' => 'เพิ่ม บริษัท',
    'untitled' => 'ไม่ได้ตั้งชื่อ',
    'new_company' => 'บริษัทใหม่',
    'associated_accounts' => 'เชื่อมโยงบัญชีเรียบร้อยแล้ว',
    'unlinked_account' => 'ยกเลิกการเชื่อมโยงบัญชีเรียบร้อยแล้ว',
    'login' => 'เข้าสู่ระบบ',
    'or' => 'หรือ',
    'email_error' => 'เกิดปัญหาในการส่งอีเมล',
    'confirm_recurring_timing' => 'หมายเหตุ: อีเมลจะถูกส่งในช่วงเริ่มต้นของชั่วโมง',
    'confirm_recurring_timing_not_sent' => 'Note: invoices are created at the start of the hour.',
    'payment_terms_help' => 'ตั้งค่าเริ่มต้น<b>วันครบกำหนดของใบแจ้งหนี้</b>',
    'unlink_account' => 'ยกเลิกการเชื่อมโยงบัญชี',
    'unlink' => 'ยกเลิกการเชื่อมโยง',
    'show_address' => 'แสดงที่อยู่',
    'show_address_help' => 'กำหนดให้ลูกค้าระบุที่อยู่สำหรับการเรียกเก็บเงิน',
    'update_address' => 'อัปเดตที่อยู่',
    'update_address_help' => 'อัปเดตที่อยู่ของลูกค้าโดยระบุรายละเอียดไว้',
    'times' => 'เวลา',
    'set_now' => 'ตั้งค่าเวลานี้',
    'dark_mode' => 'โหมดกลางคืน',
    'dark_mode_help' => 'ใช้พื้นหลังสีเข้มสำหรับแถบด้านข้าง',
    'add_to_invoice' => 'เพิ่มลงในใบแจ้งหนี้ :invoice',
    'create_new_invoice' => 'สร้างใบแจ้งหนี้ใหม่',
    'task_errors' => 'โปรดแก้ไขเวลาซ้อนทับกัน',
    'from' => 'จาก',
    'to' => 'ไปยัง',
    'font_size' => 'ขนาดตัวอักษร',
    'primary_color' => 'สีหลัก',
    'secondary_color' => 'สีรอง',
    'customize_design' => 'ปรับแต่งการออกแบบ',
    'content' => 'เนื้อหา',
    'styles' => 'รูปแบบ',
    'defaults' => 'ค่าเริ่มต้น',
    'margins' => 'ขอบ',
    'header' => 'ส่วนหัว',
    'footer' => 'ส่วนท้าย',
    'custom' => 'กำหนดเอง',
    'invoice_to' => 'Invoice to',
    'invoice_no' => 'Invoice No.',
    'quote_no' => 'Quote No.',
    'recent_payments' => 'การชำระเงินล่าสุด',
    'outstanding' => 'โดดเด่น',
    'manage_companies' => 'จัดการ บริษัท',
    'total_revenue' => 'รายได้รวม',
    'current_user' => 'ผู้ใช้ปัจจุบัน',
    'new_recurring_invoice' => 'ใบแจ้งหนี้ซ้ำใหม่',
    'recurring_invoice' => 'ทำใบแจ้งหนี้ซ้ำ',
    'new_recurring_quote' => 'New Recurring Quote',
    'recurring_quote' => 'Recurring Quote',
    'recurring_too_soon' => 'เร็วเกินไปที่จะสร้างใบแจ้งหนี้ที่เกิดซ้ำครั้งต่อไปซึ่งกำหนดไว้ :date',
    'created_by_invoice' => 'สร้างโดย   :invoice',
    'primary_user' => 'ผู้ใช้หลัก',
    'help' => 'ช่วยเหลือ',
    'customize_help' => '<p>We use :pdfmake_link to define the invoice designs declaratively. The pdfmake :playground_link provides a great way to see the library in action.</p>
                        <p>If you need help figuring something out post a question to our :forum_link with the design you\'re using.</p>',
    'playground' => 'playground',
    'support_forum' => 'support forum',
    'invoice_due_date' => 'วันครบกำหนด',
    'quote_due_date' => 'ใช้ได้ถึงวันที่',
    'valid_until' => 'ใช้ได้ถึงวันที่',
    'reset_terms' => 'รีเซ็ตข้อกำหนด',
    'reset_footer' => 'รีเซ็ตท้ายกระดาษ',
    'invoice_sent' => ':count ส่งใบแจ้งหนี้',
    'invoices_sent' => ':count ส่งใบแจ้งหนี้',
    'status_draft' => 'ร่าง',
    'status_sent' => 'ส่ง',
    'status_viewed' => 'มีผู้เข้าชม',
    'status_partial' => 'บางส่วน',
    'status_paid' => 'จ่ายเงิน',
    'status_unpaid' => 'Unpaid',
    'status_all' => 'ทั้งหมด',
    'show_line_item_tax' => 'แสดง <b>ภาษีสินค้า</b>',
    'iframe_url' => 'Website',
    'iframe_url_help1' => 'คัดลอกโค้ดต่อไปนี้ไปยังหน้าเว็บในไซต์ของคุณ',
    'iframe_url_help2' => 'คุณสามารถทดสอบคุณลักษณะโดยคลิก \'ดูเป็นผู้รับ\' สำหรับใบแจ้งหนี้',
    'auto_bill' => 'บิลอัตโนมัติ',
    'military_time' => '24 ชั่วโมง',
    'last_sent' => 'ส่งครั้งสุดท้าย',
    'reminder_emails' => 'อีเมลแจ้งเตือน',
    'quote_reminder_emails' => 'Quote Reminder Emails',
    'templates_and_reminders' => 'เทมเพลตและการแจ้งเตือน',
    'subject' => 'เรื่อง',
    'body' => 'เนื้อเรื่อง',
    'first_reminder' => 'คำเตือนครั้งแรก',
    'second_reminder' => 'คำเตือนครั้งที่สอง',
    'third_reminder' => 'Third Reminder',
    'num_days_reminder' => 'หลังวันครบกำหนด',
    'reminder_subject' => 'การแจ้งเตือน: ใบแจ้งหนี้ :invoice จาก :account',
    'reset' => 'รีเซ็ต',
    'invoice_not_found' => 'ไม่มีใบแจ้งหนี้ตามที่ร้องขอ',
    'referral_program' => 'Referral Program',
    'referral_code' => 'Referral URL',
    'last_sent_on' => 'ส่งล่าสุด :date',
    'page_expire' => 'หน้านี้จะหมดอายุเร็ว ๆ นี้, :click_here เพื่อดำเนินการต่อ',
    'upcoming_quotes' => 'ใบเสนอราคาที่จะเกิดขึ้น',
    'expired_quotes' => 'ใบเสนอราคาหมดอายุ',
    'sign_up_using' => 'ลงชื่อสมัครใช้โดยใช้',
    'invalid_credentials' => 'ข้อมูลรับรองเหล่านี้ไม่ตรงกับบันทึกของเรา',
    'show_all_options' => 'แสดงตัวเลือกทั้งหมด',
    'user_details' => 'รายละเอียดผู้ใช้',
    'oneclick_login' => 'เชื่อมต่อบัญชี',
    'disable' => 'ปิดการใช้',
    'invoice_quote_number' => 'หมายเลขใบแจ้งหนี้และใบเสนอราคา',
    'invoice_charges' => 'การเรียกเก็บเงินตามใบแจ้งหนี้',
    'notification_invoice_bounced' => 'เราไม่สามารถส่งใบแจ้งหนี้ :invoice ไปยัง :contact.',
    'notification_invoice_bounced_subject' => 'ไม่สามารถส่งใบแจ้งหนี้ :invoice',
    'notification_quote_bounced' => 'เราไม่สามารถส่งใบเสนอราคา :invoice ไปยัง :contact',
    'notification_quote_bounced_subject' => 'ไม่สามารถส่งใบเสนอราคา :invoice',
    'custom_invoice_link' => 'ลิงก์ใบแจ้งหนี้ที่กำหนดเอง',
    'total_invoiced' => 'ใบแจ้งหนี้ทั้งหมด',
    'open_balance' => 'ยอดคงเหลือ',
    'verify_email' => 'โปรดไปที่ลิงก์ในอีเมลเพื่อยืนยันที่อยู่อีเมลของคุณ',
    'basic_settings' => 'ตั้งค่าพื้นฐาน',
    'pro' => 'Pro',
    'gateways' => 'ช่องทางการชำระเงิน',
    'next_send_on' => 'ส่งครั้งต่อไป :date',
    'no_longer_running' => 'ไม่ได้กำหนดเวลาเรียกใช้งานใบแจ้งหนี้นี้',
    'general_settings' => 'การตั้งค่าทั่วไป',
    'customize' => 'ปรับแต่ง',
    'oneclick_login_help' => 'เชื่อมต่อบัญชีเพื่อเข้าสู่ระบบโดยไม่ใช้รหัสผ่าน',
    'referral_code_help' => 'สร้างรายได้ด้วยการแชร์แอปออนไลน์',
    'enable_with_stripe' => 'เปิดใช้งาน | ต้องใช้ Stripe',
    'tax_settings' => 'การตั้งค่าภาษี',
    'create_tax_rate' => 'เพิ่มอัตราภาษี',
    'updated_tax_rate' => 'อัปเดตอัตราภาษีเรียบร้อยแล้ว',
    'created_tax_rate' => 'อัปเดตอัตราภาษีเรียบร้อยแล้ว',
    'edit_tax_rate' => 'แก้ไขอัตราภาษี',
    'archive_tax_rate' => 'เก็บบันทึกอัตราภาษี',
    'archived_tax_rate' => 'เก็บบันทึกอัตราภาษีเรียบร้อยแล้ว',
    'default_tax_rate_id' => 'อัตราภาษีเริ่มต้น',
    'tax_rate' => 'อัตราภาษี',
    'recurring_hour' => 'ชั่วโมงที่เกิดขึ้นประจำ',
    'pattern' => 'แบบแผน',
    'pattern_help_title' => 'รูปแบบช่วยเหลือ',
    'pattern_help_1' => 'สร้างหมายเลขที่กำหนดเองโดยการระบุรูปแบบ',
    'pattern_help_2' => 'ตัวแปรที่สามารถใช้ได้:',
    'pattern_help_3' => 'ตัวอย่างเช่น :example จะถูกแปลงเป็น :value',
    'see_options' => 'ดูตัวเลือก',
    'invoice_counter' => 'จำนวนใบแจ้งหนี้',
    'quote_counter' => 'จำนวนใบเสนอราคา',
    'type' => 'ชนิด',
    'activity_1' => ':user ได้สร้างผู้ใช้ :client',
    'activity_2' => ':user เก็บบันทึก :client',
    'activity_3' => ':user ได้ลบผู้ใช้ :client',
    'activity_4' => ':user ได้สร้างใบแจ้งหนี้ :invoice',
    'activity_5' => ':user ได้อัปเดทแจ้งหนี้ :invoice',
    'activity_6' => ':user emailed invoice :invoice for :client to :contact',
    'activity_7' => ':contact viewed invoice :invoice for :client',
    'activity_8' => ':user บันทึกใบแจ้งหนี้ :invoice',
    'activity_9' => ':user ได้ลบใบแจ้งหนี้ :invoice',
    'activity_10' => ':contact entered payment :payment for :payment_amount on invoice :invoice for :client',
    'activity_11' => ':user  อัปเดตการชำระเงินที่แล้ว :payment',
    'activity_12' => ':user เก็บบันทึกการจ่ายเงิน  :payment',
    'activity_13' => ':user ลบการจ่ายเงิน :payment',
    'activity_14' => ':user ป้อน :credit เครดิต',
    'activity_15' => ':user อัปเดต :credit เครดิต',
    'activity_16' => ':user เก็บบันทึก :credit เครดิต',
    'activity_17' => ':user ลบแล้ว :credit เครดิต',
    'activity_18' => ':user สร้างใบเสนอราคา :quote',
    'activity_19' => ';user อัปเดตใบเสนอราคา :quote',
    'activity_20' => ':user emailed quote :quote for :client to :contact',
    'activity_21' => ':contact ดูใบเสนอราคา :quote',
    'activity_22' => ':user เก็บบันทึกใบเสนอราคา :quote',
    'activity_23' => ':user ลบใบเสนอราคา :quote',
    'activity_24' => ':user กู้คืนใบเสนอราคา :quote',
    'activity_25' => ':user กู้คืนใบแจ้งหนี้ :invoice',
    'activity_26' => ':user กู้คืน ลูกค้า :client',
    'activity_27' => ':user กู้คืนการชำระเงิน :payment',
    'activity_28' => ':user กู้คืน :credit เครดิต',
    'activity_29' => ':contact approved quote :quote for :client',
    'activity_30' => ':user สร้างผู้ขาย :vendor',
    'activity_31' => ':user เก็บบันทึกผู้ขาย :vendor',
    'activity_32' => ':user ได้ลบผู้ขาย :vendor',
    'activity_33' => ':user ได้กู้คืนผู้ขาย :vendor',
    'activity_34' => ':user ได้สร้างค่าใช้จ่าย :expense',
    'activity_35' => ':user ได้เก็บบันทึกค่าใช้จ่าย :expense',
    'activity_36' => ':user ได้ลบค่าใช้จ่าย :expense',
    'activity_37' => ':user ได้กู้คืนค่าใช้จ่าย :expense',
    'activity_42' => ':user ได้สร้างงาน :task',
    'activity_43' => ':user ได้อัปเดตงาน :task',
    'activity_44' => ':user ได้บันทึกงาน :task',
    'activity_45' => ':user ได้ลบงาน :task',
    'activity_46' => ':user ได้กู้คืนงาน :task',
    'activity_47' => ':user ได้อัปเดตค่าใช้จ่าย :expense',
    'activity_48' => ':user updated ticket :ticket',
    'activity_49' => ':user closed ticket :ticket',
    'activity_50' => ':user merged ticket :ticket',
    'activity_51' => ':user split ticket :ticket',
    'activity_52' => ':contact opened ticket :ticket',
    'activity_53' => ':contact reopened ticket :ticket',
    'activity_54' => ':user reopened ticket :ticket',
    'activity_55' => ':contact replied ticket :ticket',
    'activity_56' => ':user viewed ticket :ticket',

    'payment' => 'การจ่ายเงิน',
    'system' => 'ระบบ',
    'signature' => 'ลายเซนต์อีเมล',
    'default_messages' => 'ข้อความเริ่มต้น',
    'quote_terms' => 'ระยะเวลาใบเสนอราคา',
    'default_quote_terms' => 'ค่าเริ่มต้นระยะเวลาใบเสนอราคา',
    'default_invoice_terms' => 'ค่าเริ่มต้นระยะเวลาใบแจ้งหนี้',
    'default_invoice_footer' => 'ค่าเริ่มต้นส่วนท้ายใบแจ้งหนี้',
    'quote_footer' => 'สุดท้ายใบเสนอราคา',
    'free' => 'ฟรี',
    'quote_is_approved' => 'อนุมัติสำเร็จแล้ว',
    'apply_credit' => 'สมัครเครดิต',
    'system_settings' => 'ตั้งค่าระบบ',
    'archive_token' => 'เก็บบันทึก Token',
    'archived_token' => 'เก็บบันทึก Token แล้ว',
    'archive_user' => 'เก็บบันทึกผู้ใช้',
    'archived_user' => 'เก็บบันทึกผู้ใช้แล้ว',
    'archive_account_gateway' => 'Delete Gateway',
    'archived_account_gateway' => 'เก็บบันทึกช่องทางชำระเงินแล้ว',
    'archive_recurring_invoice' => 'เก็บบันทึกใบแจ้งหนี้ประจำแล้ว',
    'archived_recurring_invoice' => 'เก็บบันทึกใบแจ้งหนี้ประจำแล้ว',
    'delete_recurring_invoice' => 'ลบใบแจ้งหนี้ประจำ',
    'deleted_recurring_invoice' => 'ลบใบแจ้งหนี้ประจำแล้ว',
    'restore_recurring_invoice' => 'กู้คืนใบแจ้งหนี้',
    'restored_recurring_invoice' => 'กู้คืนใบแจ้งหนี้แล้ว',
    'archive_recurring_quote' => 'Archive Recurring Quote',
    'archived_recurring_quote' => 'Successfully archived recurring quote',
    'delete_recurring_quote' => 'Delete Recurring Quote',
    'deleted_recurring_quote' => 'Successfully deleted recurring quote',
    'restore_recurring_quote' => 'Restore Recurring Quote',
    'restored_recurring_quote' => 'Successfully restored recurring quote',
    'archived' => 'เก็บถาวร',
    'untitled_account' => 'ไม่มีชื่อบริษัท',
    'before' => 'ก่อน',
    'after' => 'หลัง',
    'reset_terms_help' => 'รีเซ็ตเป็นข้อกำหนดบัญชีเริ่มต้น',
    'reset_footer_help' => 'รีเซ็ตเป็นส่วนท้ายของบัญชีเริ่มต้น',
    'export_data' => 'ส่งออกข้อมูล',
    'user' => 'ผู้ใช้งาน',
    'country' => 'ประเทศ',
    'include' => 'รวม',
    'logo_too_large' => 'โลโก :size, เพื่อประสิทธิภาพของ PDF ขอแนะนำขนาดภาพไม่เกิน 200KB',
    'import_freshbooks' => 'นำเข้าจาก FreshBooks',
    'import_data' => 'นำเข้าข้อมูล',
    'source' => 'แหล่ง',
    'csv' => 'CSV',
    'client_file' => 'ไฟล์ลูกค้า',
    'invoice_file' => 'ไฟล์ใบแจ้งหนี้',
    'task_file' => 'ไฟล์งาน',
    'no_mapper' => 'การแม็พไฟล์ไม่ถูกต้อง
',
    'invalid_csv_header' => 'ส่วนหัว CSV ไม่ถูกต้อง',
    'client_portal' => 'Portal ลูกค้า',
    'admin' => 'แอดมิน',
    'disabled' => 'ปิดการใช้',
    'show_archived_users' => 'แสดงเอกสารที่บันทึกไว้ของลูกค้า',
    'notes' => 'บันทึก',
    'invoice_will_create' => 'invoice will be created',
    'invoices_will_create' => 'ใบแจ้งหนี้ถูกสร้าง',
    'failed_to_import' => 'ไม่สามารถนำเข้าระเบียนต่อไปนี้ได้ อาจจะมีอยู่แล้วหรือหายไปในฟิลด์ที่จำเป็น',
    'publishable_key' => 'Publishable Key',
    'secret_key' => 'Secret Key',
    'missing_publishable_key' => 'ตั้งค่าปุ่ม Stripe publishable ของคุณ สำหรับกระบวนการเช็คเอาต์ที่อนุมัติแล้ว',
    'email_design' => 'ออกแบบอีเมล์',
    'due_by' => 'วันครบกำหนด :date',
    'enable_email_markup' => 'เปิดใช้งาน Markup',
    'enable_email_markup_help' => 'ทำให้ลูกค้าของคุณสามารถจ่ายเงินให้คุณได้ง่ายขึ้นโดยการเพิ่มมาร์กอัป schema.org ลงในอีเมลของคุณ',
    'template_help_title' => 'เทมเพลตช่วยเหลือ',
    'template_help_1' => 'ตัวแปรที่สามารถใช้ได้:',
    'email_design_id' => 'รูปแบบอีเมล์',
    'email_design_help' => 'ทำให้อีเมล์ของคุณดูเป็มืออาชีพด้วย HTML เลย์เอ้าท์',
    'plain' => 'ธรรมดา',
    'light' => 'บาง',
    'dark' => 'มืด',
    'industry_help' => 'ใช้เพื่อเปรียบเทียบกับค่าเฉลี่ยของ บริษัท ขนาดและอุตสาหกรรมที่คล้ายคลึงกัน.',
    'subdomain_help' => 'ตั้งค่าโดเมนย่อยหรือแสดงใบแจ้งหนี้ในเว็บไซต์ของคุณเอง.',
    'website_help' => 'Display the invoice in an iFrame on your own website',
    'invoice_number_help' => 'ระบุคำนำหน้าหรือใช้รูปแบบที่กำหนดเองเพื่อตั้งค่าหมายเลขใบแจ้งหนี้แบบไดนามิก.',
    'quote_number_help' => 'ระบุคำนำหน้าหรือใช้รูปแบบที่กำหนดเองเพื่อตั้งค่าหมายเลขใบเสนอราคาแบบไดนามิก',
    'custom_client_fields_helps' => 'เพิ่มฟิลด์เมื่อสร้างลูกค้าและแสดงป้ายกำกับและค่าในรูปแบบ PDF',
    'custom_account_fields_helps' => 'เพิ่มป้ายกำกับและค่าลงในส่วนรายละเอียดบริษัท บน PDF',
    'custom_invoice_fields_helps' => 'เพิ่มฟิลด์เมื่อสร้างใบแจ้งหนี้และแสดงป้ายกำกับและค่าในรูปแบบ บน PDF',
    'custom_invoice_charges_helps' => 'เพิ่มฟิลด์เมื่อสร้างใบแจ้งหนี้และรวมค่าใช้จ่ายในยอดรวมย่อยของใบแจ้งหนี้',
    'token_expired' => 'การตรวจสอบ Token หมดเวลา. กรุณาลองใหม่.',
    'invoice_link' => 'ลิงค์ใบแจ้งหนี้',
    'button_confirmation_message' => 'คลิกเพื่อยืนยันอีเมล์ของคุณ',
    'confirm' => 'ยืนยัน',
    'email_preferences' => 'การตั้งค่าอีเมล์',
    'created_invoices' => 'สร้างใบแจ้งหนี้ :count ใบแจ้งหนี้(s)',
    'next_invoice_number' => 'ใบแจ้งหนี้หมายเลขถัดไปคือ :number.',
    'next_quote_number' => 'หมายเลขใบเสนอราคาถัดไปคือ :number',
    'days_before' => 'วันก่อนหน้า',
    'days_after' => 'วันหลังจากนี้',
    'field_due_date' => 'วันครบกำหนด',
    'field_invoice_date' => 'วันที่ในใบแจ้งหนี้',
    'schedule' => 'ตารางเวลา',
    'email_designs' => 'ออกแบบอีเมล์',
    'assigned_when_sent' => 'การกำหนดเมื่อส่ง',
    'white_label_purchase_link' => 'สั่งซื้อ Whit label license',
    'expense' => 'ค่าใช้จ่าย',
    'expenses' => 'ค่าใช้จ่าย',
    'new_expense' => 'ป้อนค่าใช้จ่าย',
    'enter_expense' => 'ป้อนค่าใช้จ่าย',
    'vendors' => 'ผู้ขาย',
    'new_vendor' => 'ผู้ขายใหม่',
    'payment_terms_net' => 'สุทธิ',
    'vendor' => 'ผู้ขาย',
    'edit_vendor' => 'แก้ไขผู้ขาย',
    'archive_vendor' => 'เก็บบันทึกผู้ขาย',
    'delete_vendor' => 'ลบผู้ขาย',
    'view_vendor' => 'แสดงผู้ขาย',
    'deleted_expense' => 'ลบค่าใช้จ่ายสำเร็จ',
    'archived_expense' => 'เก็บบันทึกค่าใช้จ่ายสำเร็จ',
    'deleted_expenses' => 'ลบค่าใช้จ่ายสำเร็จ',
    'archived_expenses' => 'เก็บบันทึกค่าใช้จ่ายสำเร็จ',
    'expense_amount' => 'จำนวนเงินค่าใช้จ่าย',
    'expense_balance' => 'ค่าใช้จ่ายคงเหลือ',
    'expense_date' => 'วันที่เบิกจ่าย',
    'expense_should_be_invoiced' => 'ค่าใช้จ่ายนี้อาจถูกเรียกเก็บเงิน?',
    'public_notes' => 'หมายเหตุแบบเปิด',
    'invoice_amount' => 'จำนวนใบแจ้งหนี้',
    'exchange_rate' => 'อัตราแลกเปลี่ยน',
    'yes' => 'ใช่',
    'no' => 'ไม่ใช่',
    'should_be_invoiced' => 'ควรได้รับใบแจ้งหนี้',
    'view_expense' => 'ดูค่าใช้จ่าย # :expense',
    'edit_expense' => 'แก้ไขค่าใช้จ่าย',
    'archive_expense' => 'เก็บบันทึกค่าใช้จ่าย',
    'delete_expense' => 'ลบค่าใช้จ่าย',
    'view_expense_num' => 'ค่าใช้จ่าย # :expense',
    'updated_expense' => 'อัปเดตค่าใช้จ่ายสำเร็จ',
    'created_expense' => 'สร้างค่าใช้จ่ายสำเร็จ',
    'enter_expense' => 'ป้อนค่าใช้จ่าย',
    'view' => 'ดู',
    'restore_expense' => 'กู้คืนค่าใช้จ่าย',
    'invoice_expense' => 'ค่าใช้จ่ายในใบแจ้งหนี้',
    'expense_error_multiple_clients' => 'ค่าใช้จ่ายไม่สามารถเป็นของลูกค้าอื่นได้',
    'expense_error_invoiced' => 'ค่าใช้จ่ายถูกเรียกเก็บเงินแล้ว',
    'convert_currency' => 'แปลงสกุลเงิน',
    'num_days' => 'จำนวนวัน',
    'create_payment_term' => 'สร้างเงื่อนไขการชำระเงิน',
    'edit_payment_terms' => 'แก้ไขข้อกำหนดในการชำระเงิน',
    'edit_payment_term' => 'แก้ไขข้อกำหนดในการชำระเงิน',
    'archive_payment_term' => 'เก็บบันทึกเงื่อนไขการชำระเงิน',
    'recurring_due_dates' => 'กำหนดวันที่ครบกำหนดของใบแจ้งหนี้',
    'recurring_due_date_help' => '<p>กำหนดวันที่ครบกำหนดสำหรับใบแจ้งหนี้โดยอัตโนมัติ</p>
<p>ใบแจ้งหนี้ในรอบรายเดือนหรือรายปีที่กำหนดให้ครบกำหนดในหรือก่อนวันที่สร้างขึ้นจะครบกำหนดในเดือนถัดไป ใบแจ้งหนี้ที่กำหนดให้ครบกำหนดในวันที่ 29 หรือ 30 ในเดือนที่ไม่มีวันนั้นจะครบกำหนดในวันสุดท้ายของเดือน</p>
<p>ะมีการเรียกเก็บเงินในรอบสัปดาห์ที่ครบกำหนดชำระในวันที่กำหนดไว้ในสัปดาห์ถัดไป</p>
<p>ตัวอย่างเช่น:</p>
<ul>
<li>วันนี้เป็นวันที่ 15 ครบกำหนดคือวันที่ 1 ของเดือน วันครบกำหนดน่าจะเป็นวันที่ 1 ของเดือนถัดไป</li>
<li>วันนี้เป็นวันที่ 15 ครบกำหนดคือวันสุดท้ายของเดือน วันครบกำหนดจะเป็นวันสุดท้ายของเดือนนี้
</li>
<li>วันนี้เป็นวันที่ 15 ครบกำหนดคือวันที่ 15 ของเดือน วันครบกำหนดจะเป็นวันที่ 15 ของวันที่<strong>ถัดไป</strong>เดือน.
</li>
<li>วันนี้เป็นวันศุกร์วันครบกำหนดคือวันศุกร์ที่ 1 หลังจาก วันครบกำหนดจะเป็นวันศุกร์ถัดไปไม่ใช่วันนี้
</li>
</ul>',
    'due' => 'ครบกำหนด',
    'next_due_on' => 'กำหนดถัดไป :date',
    'use_client_terms' => 'ใช้ข้อกำหนดของลูกค้า',
    'day_of_month' => ':ordinary วันของเดือน',
    'last_day_of_month' => 'วันสุดท้ายของเดือน',
    'day_of_week_after' => ':ordinary :day หลังจาก',
    'sunday' => 'วันอาทิตย์',
    'monday' => 'วันจันทร์',
    'tuesday' => 'วันอังคาร',
    'wednesday' => 'วันพุธ',
    'thursday' => 'วันพฤหัสบดี',
    'friday' => 'วันศุกร์',
    'saturday' => 'วันเสาร์',
    'header_font_id' => 'แบบอักษรส่วนหัว',
    'body_font_id' => 'ฟ้อนในเนื้อหา',
    'color_font_help' => 'หมายเหตุ: สีหลักและแบบอักษรยังใช้ในพอร์ทัลลูกค้าและการออกแบบอีเมลแบบกำหนดเอง',
    'live_preview' => 'ดูตัวอย่างสด',
    'invalid_mail_config' => 'ไม่สามารถส่งอีเมล. โปรดตรวจสอบว่าการตั้งค่าอีเมลให้ถูกต้อง',
    'invoice_message_button' => 'หากต้องการดูใบแจ้งหนี้ของคุณ :amount คลิกปุ่มด้านล่าง',
    'quote_message_button' => 'หากต้องการดูใบเสนอราคา :amount คลิกปุ่มด้านล่าง',
    'payment_message_button' => 'ขอบคุณที่จ่ายชำระเงินจำนวน :amount',
    'payment_type_direct_debit' => 'Direct Debit',
    'bank_accounts' => 'บัตรเครดิต & ธนาคาร',
    'add_bank_account' => 'เพิ่มธนาคารลูกค้า',
    'setup_account' => 'ตั้งค่าบัญชี',
    'import_expenses' => 'นำเข้าค่าใช้จ่าย',
    'bank_id' => 'ธนาคาร',
    'integration_type' => 'ประเภทการผสานรวม',
    'updated_bank_account' => 'อัปเดตบัญชีธนาคารสำเร็จ',
    'edit_bank_account' => 'แก้ไขบัญชีธนาคาร',
    'archive_bank_account' => 'เก็บข้อมูลบัญชีธนาคาร',
    'archived_bank_account' => 'การเก็บบันทึกบัญชีธนาคารสำเร็จ',
    'created_bank_account' => 'สร้างบัญชีธนาคารสำเร็จ',
    'validate_bank_account' => 'ตรวจสอบบัญชีธนาคาร',
    'bank_password_help' => 'หมายเหตุ: รหัสผ่านของคุณจะถูกส่งอย่างปลอดภัยและไม่ถูกเก็บไว้ในเซิร์ฟเวอร์ของเรา',
    'bank_password_warning' => 'หมายเหตุ: รหัสผ่านของคุณอาจถูกส่งผ่านด้วยข้อความธรรมดา โปรดเปิดใช้ HTTPS.',
    'username' => 'ชื่อผู้ใช้',
    'account_number' => 'หมายเลขบัญชี',
    'account_name' => 'ชื่อบัญชี',
    'bank_account_error' => 'Failed to retrieve account details, please check your credentials.',
    'status_approved' => 'อนุมัติ',
    'quote_settings' => 'การตั้งค่าใบเสนอราคา',
    'auto_convert_quote' => 'แปลงอัตโนมัติ',
    'auto_convert_quote_help' => '
แปลงใบเสนอราคาให้เป็นใบแจ้งหนี้โดยอัตโนมัติเมื่อได้รับอนุมัติจากลูกค้า',
    'validate' => 'ตรวจสอบ',
    'info' => 'ข้อมูล',
    'imported_expenses' => 'สร้าง :count_vendors ผู้ขาย(s) และ :count_enpenses ค่าใช้จ่าย(s)',
    'iframe_url_help3' => 'หมายเหตุ: หากคุณวางแผนที่จะรับบัตรเครดิตเราขอแนะนำให้เปิดใช้ HTTPS บนไซต์ของคุณ.',
    'expense_error_multiple_currencies' => 'ค่าใช้จ่ายไม่สามารถมีสกุลเงินต่างกัน',
    'expense_error_mismatch_currencies' => 'สกุลเงินของลูกค้าไม่ตรงกับสกุลเงินค่าใช้จ่าย',
    'trello_roadmap' => 'Trello Roadmap',
    'header_footer' => 'ส่วนหัว / ท้ายกระดาษ',
    'first_page' => 'หน้าแรก',
    'all_pages' => 'หน้าทั้งหมด',
    'last_page' => 'หน้าสุดท้าย',
    'all_pages_header' => 'แสดงหัวเรื่อง',
    'all_pages_footer' => 'แสดงส่วนท้าย',
    'invoice_currency' => 'สกุลเงินใบแจ้งหนี้',
    'enable_https' => 'เราขอแนะนำให้ใช้ HTTPS เพื่อรับรายละเอียดบัตรเครดิตทางออนไลน์',
    'quote_issued_to' => 'ใบเสนอราคาที่ออกให้กับ',
    'show_currency_code' => 'รหัสสกุลเงิน',
    'free_year_message' => 'Your account has been upgraded to the pro plan for one year at no cost.',
    'trial_message' => 'บัญชีของคุณจะได้รับการทดลองใช้ฟรีเป็นระยะเวลาสองสัปดาห์',
    'trial_footer' => 'การทดลองใช้ Pro Pro ฟรีของคุณมีจำกัด :count วันเพิ่มขึ้น :link เพื่ออัปเกรดทันที',
    'trial_footer_last_day' => 'นี่เป็นวันสุดท้ายของการทดลอง Pro Plan ของคุณ :link เพื่ออัปเกรดทันที',
    'trial_call_to_action' => 'เริ่มทดลองใช้ฟรี',
    'trial_success' => 'เปิดใช้งานการทดลองใช้ฟรี Pro Plan สองสัปดาห์แล้ว',
    'overdue' => 'เกินกำหนด',


    'white_label_text' => 'ชำระเงินสำหรับ white label ไลเซนต์ 1 ปี ราคา :price เพื่อเอา logo invoice ninja ออกจากใบแจ้งหนี้และพอร์ทัลของลูกค้า',
    'user_email_footer' => 'หากต้องการปรับการตั้งค่าการแจ้งเตือนทางอีเมลโปรดไปที่ :link',
    'reset_password_footer' => 'หากคุณไม่ได้ขอให้รีเซ็ตรหัสผ่านนี้โปรดส่งอีเมลถึงฝ่ายสนับสนุนของเรา: :email',
    'limit_users' => 'ขออภัย, เกินขีดจำกัดของ :limit ผู้ใช้',
    'more_designs_self_host_header' => 'เพิ่มการออกแบบใบแจ้งหนี้ 6 ใบในราคา :price',
    'old_browser' => 'Please use a :link',
    'newer_browser' => 'เปิดหน้าต่างใหม่',
    'white_label_custom_css' => ':link สำหรับ $:price เพื่อให้สามารถจัดแต่งแบบได้ตามต้องการและช่วยสนับสนุนโครงการของเรา',
    'bank_accounts_help' => 'Connect a bank account to automatically import expenses and create vendors. Supports American Express and :link.',
    'us_banks' => '400+ US banks',

    'pro_plan_remove_logo' => ':link ลบโลโก้ Invoice Ninja โดยการเข้าร่วม Pro Plan',
    'pro_plan_remove_logo_link' => 'คลิกที่นี่',
    'invitation_status_sent' => 'ส่ง',
    'invitation_status_opened' => 'Opened',
    'invitation_status_viewed' => 'มุมมอง',
    'email_error_inactive_client' => 'อีเมลไม่สามารถส่งไปยังลูกค้าที่ไม่ได้ใช้งานได้',
    'email_error_inactive_contact' => 'ไม่สามารถส่งอีเมลไปยังที่อยู่ติดต่อที่ไม่ใช้งานได้',
    'email_error_inactive_invoice' => 'ไม่สามารถส่งอีเมลไปยังใบแจ้งหนี้ที่ไม่ใช้งานได้',
    'email_error_inactive_proposal' => 'Emails can not be sent to inactive proposals',
    'email_error_user_unregistered' => 'โปรดลงทะเบียนบัญชีของคุณเพื่อส่งอีเมล',
    'email_error_user_unconfirmed' => 'โปรดยืนยันบัญชีของคุณเพื่อส่งอีเมล',
    'email_error_invalid_contact_email' => 'อีเมลติดต่อไม่ถูกต้อง',

    'navigation' => 'สำรวจ',
    'list_invoices' => 'รายการใบแจ้งหนี้',
    'list_clients' => 'รายการลูกค้า',
    'list_quotes' => 'รายการใบเสนอราคา',
    'list_tasks' => 'รายการงาน',
    'list_expenses' => 'รายการค่าใช้จ่าย',
    'list_recurring_invoices' => 'แสดงรายการใบแจ้งหนี้ที่เกิดซ้ำ',
    'list_payments' => 'รายการชำระเงิน',
    'list_credits' => 'รายการเครดิต',
    'tax_name' => 'ชื่อภาษี',
    'report_settings' => 'การตั้งค่ารายงาน',
    'search_hotkey' => 'ทางลัดคือ /',

    'new_user' => 'ผู้ใช้ใหม่',
    'new_product' => 'สินค้าใหม่',
    'new_tax_rate' => 'อัตราภาษีใหม่',
    'invoiced_amount' => 'จำนวนเงินในใบแจ้งหนี้',
    'invoice_item_fields' => 'ช่องรายการสินค้าใบแจ้งหนี้',
    'custom_invoice_item_fields_help' => 'เพิ่มฟิลด์เมื่อสร้างรายการใบแจ้งหนี้และแสดงป้ายกำกับ และค่าใน PDF',
    'recurring_invoice_number' => 'จำนวนที่เกิดขึ้นประจำ',
    'recurring_invoice_number_prefix_help' => 'Specify a prefix to be added to the invoice number for recurring invoices.',

    // Client Passwords
    'enable_portal_password' => 'รหัสผ่านป้องกันใบแจ้งหนี้',
    'enable_portal_password_help' => 'ช่วยให้คุณสามารถตั้งรหัสผ่านสำหรับแต่ละรายชื่อ หากมีการตั้งรหัสผ่านผู้ติดต่อจะต้องป้อนรหัสผ่านก่อนดูใบแจ้งหนี้',
    'send_portal_password' => 'Generate Automatically',
    'send_portal_password_help' => 'หากไม่มีการตั้งค่ารหัสผ่าน ระบบจะสร้างและส่งใบแจ้งหนี้ฉบับแรก',

    'expired' => 'หมดอายุ',
    'invalid_card_number' => 'เลขที่บัตรเครดิตไม่ถูกต้อง',
    'invalid_expiry' => 'วันที่หมดอายุไม่ถูกต้อง',
    'invalid_cvv' => 'รสัส CVV ไม่ถูกต้อง',
    'cost' => 'ค่าใช้จ่าย',
    'create_invoice_for_sample' => 'หมายเหตุ: สร้างใบแจ้งหนี้เพื่อดู Preview ได้ที่นี่',

    // User Permissions
    'owner' => 'เจ้าของ',
    'administrator' => 'ผู้ดูแลระบบ',
    'administrator_help' => 'อนุญาตให้ผู้ใช้ จัดการผู้ใช้อื่น เปลี่ยนแปลงการตั้งค่าและแก้ไขระเบียนทั้งหมด',
    'user_create_all' => 'สร้าง ลูกค้า, ใบแจ้งหนี้, อื่นๆ.',
    'user_view_all' => 'ดูลูกค้าใบแจ้งหนี้ และอื่นๆ',
    'user_edit_all' => 'แก้ไขลูกค้าใบแจ้งหนี้ และอื่นๆ',
    'gateway_help_20' => ':link ลงชื่อสมัครใช้ Sage Pay',
    'gateway_help_21' => ':link เพื่อลงชื่อสมัครใช้ Sage Pay',
    'partial_due' => 'ครบกำหนด',
    'restore_vendor' => 'คืนค่าผู้ขาย',
    'restored_vendor' => 'ผู้ขายที่ได้รับการคืนค่าเรียบร้อยแล้ว',
    'restored_expense' => 'กู้คืนค่าใช้จ่ายเรียบร้อยแล้ว',
    'permissions' => 'สิทธิ์',
    'create_all_help' => 'อนุญาตให้ผู้ใช้สร้างและแก้ไขรายการ',
    'view_all_help' => 'อนุญาตให้ผู้ใช้มองเห็นรายการที่ตนเองไม่ได้สร้าง',
    'edit_all_help' => 'อนุญาตให้ผู้ใช้แก้ไขรายการที่ไม่ได้สร้างขึ้นเอง',
    'view_payment' => 'ดูรายการจ่ายเงิน',

    'january' => 'มกราคม',
    'february' => 'กุมภาพันธ์',
    'march' => 'มีนาคม',
    'april' => 'เมษายน',
    'may' => 'พฤษภาคม',
    'june' => 'มิถุนายน',
    'july' => 'กรกฎาคม',
    'august' => 'สิงหาคม',
    'september' => 'กันยายน',
    'october' => 'ตุลาคม',
    'november' => 'พฤศจิกายน',
    'december' => 'ธันวาคม',

    // Documents
    'documents_header' => 'เอกสาร',
    'email_documents_header' => 'เอกสาร:',
    'email_documents_example_1' => 'Widgets Receipt.pdf',
    'email_documents_example_2' => 'Final Deliverable.zip',
    'quote_documents' => 'Quote Documents',
    'invoice_documents' => 'Invoice Documents',
    'expense_documents' => 'Expense Documents',
    'invoice_embed_documents' => 'ฝังเอกสาร',
    'invoice_embed_documents_help' => 'รวมภาพที่แนบมาในใบแจ้งหนี้',
    'document_email_attachment' => 'แนบเอกสาร',
    'ubl_email_attachment' => 'Attach UBL',
    'download_documents' => 'ดาวน์โหลดเอกสาร (:size)',
    'documents_from_expenses' => 'จากค่าใช้จ่าย:',
    'dropzone_default_message' => 'วางไฟล์หรือคลิกเพื่ออัปโหลด',
    'dropzone_default_message_disabled' => 'Uploads disabled',
    'dropzone_fallback_message' => 'เบราว์เซอร์ของคุณไม่สนับสนุนการอัปโหลดไฟแ์บบลากวาง',
    'dropzone_fallback_text' => 'โปรดใช้แบบฟอร์มสำรองทางด้านล่างเพื่ออัปโหลดไฟล์ของคุณ',
    'dropzone_file_too_big' => 'ไฟล์ใหญ่เกินไป ({{filesize}} MiB) ไฟล์สูงสุด: {{maxFilesize}} MiB',
    'dropzone_invalid_file_type' => 'คุณไม่สามารถอัปโหลดไฟล์ประเภทนี้ได้',
    'dropzone_response_error' => 'เซิร์ฟเวอร์ตอบกลับด้วยรหัส {{statusCode}} code.',
    'dropzone_cancel_upload' => 'ยกเลิกการอัปโหลด',
    'dropzone_cancel_upload_confirmation' => 'คุณแน่ใจหรือไม่ว่าต้องการยกเลิกการอัปโหลดนี้',
    'dropzone_remove_file' => 'ลบไฟล์',
    'documents' => 'เอกสาร:',
    'document_date' => 'วันที่เอกสาร',
    'document_size' => 'ขนาด',

    'enable_client_portal' => 'พอร์ทัลลูกค้า',
    'enable_client_portal_help' => 'แสดง / ซ่อนพอร์ทัลลูกค้า',
    'enable_client_portal_dashboard' => 'แดชบอร์ด',
    'enable_client_portal_dashboard_help' => 'แสดง / ซ่อนหน้าแดชบอร์ดในหน้าลูกค้า',

    // Plans
    'account_management' => 'การจัดการบัญชี',
    'plan_status' => 'สถานะ Plan',

    'plan_upgrade' => 'อัปเกรด',
    'plan_change' => 'เปลี่ยน Plan',
    'pending_change_to' => 'เปลี่ยนเป็น',
    'plan_changes_to' => ':plan ใน :date',
    'plan_term_changes_to' => ': plan (: term) วันที่: date',
    'cancel_plan_change' => 'ยกเลิกการเปลี่ยนแปลง',
    'plan' => 'Plan',
    'expires' => 'หมดอายุ',
    'renews' => 'ต่ออายุ',
    'plan_expired' => ':plan หมดอายุ',
    'trial_expired' => ':plan หมดเวลาทดลอง',
    'never' => 'ไม่เคย',
    'plan_free' => 'ฟรี',
    'plan_pro' => 'Pro',
    'plan_enterprise' => 'Enterprise',
    'plan_white_label' => 'Self Hosted (White labeled)',
    'plan_free_self_hosted' => 'Self Hosted (Free)',
    'plan_trial' => 'ทดลอง',
    'plan_term' => 'ระยะเวลา',
    'plan_term_monthly' => 'รายเดือน',
    'plan_term_yearly' => 'รายปี',
    'plan_term_month' => 'เดือน',
    'plan_term_year' => 'ปี',
    'plan_price_monthly' => '$:price/เดือน',
    'plan_price_yearly' => '$:price/ปี',
    'updated_plan' => 'อัปเดตการตั้งค่าแพลน',
    'plan_paid' => 'เริ่มต้นระยะเวลา',
    'plan_started' => 'เริ่มต้นแพลน',
    'plan_expires' => 'แพลนหมดอายุ',

    'white_label_button' => 'White Label',

    'pro_plan_year_description' => 'การลงทะเบียนหนึ่งปีสำหรับ   Invoice Ninja Pro Plan',
    'pro_plan_month_description' => 'ลงทะเบียนหนึ่งเดือนสำหรับ Invoice Ninja Pro Plan.',
    'enterprise_plan_product' => 'Enterprise Plan',
    'enterprise_plan_year_description' => 'ลงทะเบียนหนึ่งปีสำหรับ Invoice Ninja Enterprise Plan.',
    'enterprise_plan_month_description' => 'ลงทะเบียนหนึ่งเดือนสำหรับ Invoice Ninja Enterprise Plan.',
    'plan_credit_product' => 'เครดิต',
    'plan_credit_description' => 'เครดิตสำหรับเวลาที่ไม่ได้ใช้',
    'plan_pending_monthly' => 'จะเปลี่ยนเป็นรายเดือน :date',
    'plan_refunded' => 'มีการออกเอกสารการคืนเงินแล้ว',

    'live_preview' => 'ดูตัวอย่างสด',
    'page_size' => 'ขนาดหน้า',
    'live_preview_disabled' => 'การดูตัวอย่างแบบสดถูกปิดใช้งานเพื่อสนับสนุนแบบอักษรที่เลือก',
    'invoice_number_padding' => 'การขยาย',
    'preview' => 'ดูตัวอย่าง',
    'list_vendors' => 'รายชื่อผู้ขาย',
    'add_users_not_supported' => 'อัปเกรดเป็นแผน Enterprise เพื่อเพิ่มผู้ใช้เพิ่มเติมในบัญชีของคุณ',
    'enterprise_plan_features' => 'แผน Enterprise เพิ่มการสนับสนุนสำหรับผู้ใช้หลายคนและไฟล์แนบ :link  เพื่อดูรายการคุณสมบัติทั้งหมด',
    'return_to_app' => 'Return To App',


    // Payment updates
    'refund_payment' => 'การชำระเงินคืน',
    'refund_max' => 'สูงสุด:',
    'refund' => 'คืนเงิน',
    'are_you_sure_refund' => 'คืนเงินที่เลือก?',
    'status_pending' => 'Pending',
    'status_completed' => 'Completed',
    'status_failed' => 'Failed',
    'status_partially_refunded' => 'คืนเงินบางส่วน',
    'status_partially_refunded_amount' => ':amount  คืนเงิน',
    'status_refunded' => 'Refunded',
    'status_voided' => 'Cancelled',
    'refunded_payment' => 'การคืนเงิน',
    'activity_39' => ':user ยกเลิก :payment_amount  การชำระเงิน :payment',
    'activity_40' => ':usre คืนเงิน :adjustment ของ  :payment_amount การชำระเงิน :payment',
    'card_expiration' => 'Exp:&nbsp:expires',

    'card_creditcardother' => 'ไม่ทราบ',
    'card_americanexpress' => 'American Express',
    'card_carteblanche' => 'Carte Blanche',
    'card_unionpay' => 'UnionPay',
    'card_diners' => 'Diners Club',
    'card_discover' => 'Discover',
    'card_jcb' => 'JCB',
    'card_laser' => 'Laser',
    'card_maestro' => 'Maestro',
    'card_mastercard' => 'MasterCard',
    'card_solo' => 'Solo',
    'card_switch' => 'Switch',
    'card_visacard' => 'Visa',
    'card_ach' => 'ACH',

    'payment_type_stripe' => 'Stripe',
    'ach' => 'ACH',
    'enable_ach' => 'Accept US bank transfers',
    'stripe_ach_help' => 'ACH support must also be enabled in :link.',
    'ach_disabled' => 'มีการกำหนดค่าเกตเวย์อื่นสำหรับการตัดบัญชีโดยตรงแล้ว',

    'plaid' => 'Plaid',
    'client_id' => 'รหัสลูกค้า',
    'secret' => 'Secret',
    'public_key' => 'กุญแจสาธารณะ',
    'plaid_optional' => '(ตัวเลือกเพิ่มเติม)',
    'plaid_environment_help' => 'When a Stripe test key is given, Plaid\'s development environment (tartan) will be used.',
    'other_providers' => 'ผู้ให้บริการอื่น',
    'country_not_supported' => 'ประเทศนี้ไม่ได้รับการสนับสนุน',
    'invalid_routing_number' => 'หมายเลขเส้นทางไม่ถูกต้อง',
    'invalid_account_number' => 'หมายเลขบัญชีไม่ถูกต้อง',
    'account_number_mismatch' => 'หมายเลขบัญชีไม่ตรงกัน',
    'missing_account_holder_type' => 'โปรดเลือกบัญชีส่วนบุคคลหรือบัญชีบริษัท',
    'missing_account_holder_name' => 'โปรดใส่ชื่อผู้ถือบัตร',
    'routing_number' => 'หมายเลขเส้นทาง',
    'confirm_account_number' => 'ยืนยันบัญชีธนาคาร',
    'individual_account' => 'บัญชีส่วนบุคคล',
    'company_account' => 'บัญชีบริษัท',
    'account_holder_name' => 'ชื่อเจ้าของบัญขี',
    'add_account' => 'เพิ่มบัญชี',
    'payment_methods' => 'วิธีการชำระเงิน',
    'complete_verification' => 'การยื่นยันสมบูรณ์',
    'verification_amount1' => 'จำนวนเงิน 1',
    'verification_amount2' => 'จำนวนเงิน 2',
    'payment_method_verified' => 'การยืนยันเสร็จสมบูรณ์แล้ว',
    'verification_failed' => 'การยืนยันล้มเหลว',
    'remove_payment_method' => 'ลบวิธีการชำระเงิน',
    'confirm_remove_payment_method' => 'คุณแน่ใจหรือไม่ว่าต้องการนำวิธีการชำระเงินนี้ออก',
    'remove' => 'เอาออก',
    'payment_method_removed' => 'ลบวิธีการชำระเงินแล้ว',
    'bank_account_verification_help' => 'เราได้ทำการฝากเงินเข้าบัญชีของคุณไว้ 2 ใบพร้อมคำอธิบาย "VERIFICATION" เงินฝากเหล่านี้จะใช้เวลา 1-2 วันทำการในใบแจ้งยอดของคุณ โปรดป้อนจำนวนเงินด้านล่าง',
    'bank_account_verification_next_steps' => 'เราได้ทำการฝากเงินเข้าบัญชีของคุณไว้ 2 ใบพร้อมคำอธิบาย "VERIFICATION" เงินฝากเหล่านี้จะใช้เวลา 1-2 วันทำการจะปรากฎในใบแจ้งยอดของคุณ
       เมื่อคุณมีจำนวนแล้วให้กลับมาที่หน้าวิธีการชำระเงินนี้และคลิก "Complete Verification" ถัดจากบัญชี',
    'unknown_bank' => 'ธนาคารที่ไม่รู้จัก',
    'ach_verification_delay_help' => 'คุณจะสามารถใช้บัญชีหลังจากเสร็จสิ้นการยืนยัน การยืนยันจะใช้เวลาประมาณ 1-2 วันทำการ',
    'add_credit_card' => 'เพิ่มบัตรเครดิต',
    'payment_method_added' => 'เพิ่มวิธีการชำระเงิน',
    'use_for_auto_bill' => 'ใช้สำหรับ บิล อัตโนมัติ',
    'used_for_auto_bill' => 'วิธีการชำระเงินอัตโนมัติ',
    'payment_method_set_as_default' => 'ตั้งค่าการชำระเงินอัตโนมัติ',
    'activity_41' => ':payment_amount จ่ายชำระเงิน (:payment) ล้มเหลว',
    'webhook_url' => 'Webhook URL',
    'stripe_webhook_help' => 'คุณต้อง :link.',
    'stripe_webhook_help_link_text' => 'เพิ่ม URL นี้เป็นปลายทางที่ Stripe',
    'gocardless_webhook_help_link_text' => 'add this URL as an endpoint in GoCardless',
    'payment_method_error' => 'มีข้อผิดพลาดในการเพิ่มวิธีการชำระเงินของคุณ กรุณาลองใหม่อีกครั้งในภายหลัง.',
    'notification_invoice_payment_failed_subject' => 'การชำระเงินล้มเหลวสำหรับใบแจ้งหนี้',
    'notification_invoice_payment_failed' => 'การชำระเงินโดยลูกค้า:client   ต่อ Invoice :invoice ล้มเหลว การชำระเงินถูกทำเครื่องหมายว่าไม่ผ่านและ :amount ถูกเพิ่มลงในยอดเงินของลูกค้า',
    'link_with_plaid' => 'เชื่อมโยงบัญชีทันทีกับ Plaid',
    'link_manually' => 'ลิงค์เอง',
    'secured_by_plaid' => 'รับประกันโดย Plaid',
    'plaid_linked_status' => 'บัญชีธนาคารของคุณที่ :bank',
    'add_payment_method' => 'เพิ่มวิธีการชำระเงิน',
    'account_holder_type' => 'ประเภทเจ้าของบัญชี',
    'ach_authorization' => 'ฉันอนุญาต :company เพื่อใช้บัญชีธนาคารของฉันสำหรับการชำระเงินในอนาคตและหากจำเป็นให้เครดิตบัญชีของฉันทางอิเล็กทรอนิกส์เพื่อแก้ไขการตัดบัญชีที่ผิดพลาด. ฉันเข้าใจว่าฉันสามารถยกเลิกการให้สิทธิ์นี้เมื่อใดก็ได้โดยการลบวิธีการชำระเงินหรือโดยการติดต่อ :email',
    'ach_authorization_required' => 'คุณต้องยอมรับการทำธุรกรรมของ ACH',
    'off' => 'ปิด',
    'opt_in' => 'Opt-in',
    'opt_out' => 'Opt-out',
    'always' => 'ตลอดเวลา',
    'opted_out' => 'Opted out',
    'opted_in' => 'Opted in',
    'manage_auto_bill' => 'จัดการการเรียกเก็บเงินอัตโนมัติ',
    'enabled' => 'เปิด',
    'paypal' => 'PayPal',
    'braintree_enable_paypal' => 'เปิดใช้งานการชำระ PayPal ผ่าน BrainTree',
    'braintree_paypal_disabled_help' => 'เกตเวย์ของ PayPal กำลังประมวลผลการชำระเงินผ่าน PayPal',
    'braintree_paypal_help' => 'คุณต้อง :link.',
    'braintree_paypal_help_link_text' => 'เชื่อมโยง PayPal กับบัญชี BrainTree ของคุณ',
    'token_billing_braintree_paypal' => 'บันทึกรายละเอียดการชำระเงิน',
    'add_paypal_account' => 'เพิ่มบัญชี PayPal',


    'no_payment_method_specified' => 'ไม่ระบุวิธีการชำระเงิน',
    'chart_type' => 'ประเภทแผนภูมิ',
    'format' => 'รูปแบบ',
    'import_ofx' => 'นำเข้า OFX',
    'ofx_file' => 'OFX File',
    'ofx_parse_failed' => 'ไม่สามารถวิเคราะห์ไฟล์ OFX ได้',

    // WePay
    'wepay' => 'WePay',
    'sign_up_with_wepay' => 'ลงชื่อสมัครใช้ WePay',
    'use_another_provider' => 'ใช้ผู้ให้บริการรายอื่น',
    'company_name' => 'ชื่อบริษัท',
    'wepay_company_name_help' => 'ข้อความนี้จะปรากฏในใบแจ้งยอดบัตรเครดิตของลูกค้า',
    'wepay_description_help' => 'วัตถุประสงค์ของบัญชีนี้',
    'wepay_tos_agree' => 'ข้าพเจ้าเห็นด้วยตาม :link',
    'wepay_tos_link_text' => 'เงื่อนไขของ WePay',
    'resend_confirmation_email' => 'ส่งอีเมลเพื่อยืนยันใหม่',
    'manage_account' => 'จัดการบัญชี',
    'action_required' => 'ต้องการการดำเนินการ',
    'finish_setup' => 'การติดตั้งเสร็จสมบูรณ์',
    'created_wepay_confirmation_required' => 'โปรดตรวจสอบอีเมลของคุณและยืนยันที่อยู่อีเมลของคุณกับ WePay',
    'switch_to_wepay' => 'สลับไปยัง Wepay',
    'switch' => 'สลับ',
    'restore_account_gateway' => 'เกตเวย์ที่ได้รับการคืนค่าแล้ว',
    'restored_account_gateway' => 'เรียกคืนเกตเวย์เรียบร้อยแล้ว',
    'united_states' => 'สหรัฐอเมริกา',
    'canada' => 'แคนาดา',
    'accept_debit_cards' => 'ยอมรับบัตรเดบิต',
    'debit_cards' => 'บัตรเดบิต',

    'warn_start_date_changed' => 'ใบแจ้งหนี้ถัดไปจะถูกส่งในวันเริ่มต้นใหม่',
    'warn_start_date_changed_not_sent' => 'The next invoice will be created on the new start date.',
    'original_start_date' => 'วันที่เริ่มต้นเดิม',
    'new_start_date' => 'วันที่เริ่มต้นใหม่',
    'security' => 'ความปลอดภัย',
    'see_whats_new' => 'ดูว่ามีอะไรใหม่ในเวอร์ชัน  :version',
    'wait_for_upload' => 'โปรดรอให้เอกสารอัปโหลดเสร็จสมบูรณ์',
    'upgrade_for_permissions' => 'อัปเกรดเป็นแผน Enterprise เพื่อเปิดใช้สิทธิ์',
    'enable_second_tax_rate' => 'ปิดใช้งาน <b>การระบุอัตราภาษี</b>',
    'payment_file' => 'ไฟล์การชำระเงิน',
    'expense_file' => 'ไฟล์ค่าใช้จ่าย',
    'product_file' => 'ไฟล์สินค้า',
    'import_products' => 'นำเข้าสินค้า',
    'products_will_create' => 'สินค้ากำลังถูกสร้างขึ้น',
    'product_key' => 'สินค้า',
    'created_products' => 'สร้าง / อัปเดตเรียบร้อยแล้ว :count สินค้า(s)',
    'export_help' => 'ใช้ JSON ถ้าคุณวางแผนที่จะนำเข้าข้อมูลลงใน Invoice Ninja. <br/> ไฟล์ประกอบด้วยลูกค้า, สินค้า, ใบแจ้งหนี้, ใบเสนอราคา และการชำระเงิน.',
    'selfhost_export_help' => '<br/>We recommend using mysqldump to create a full backup.',
    'JSON_file' => 'JSON File',

    'view_dashboard' => 'มุมมองแดชบอร์ด',
    'client_session_expired' => 'เซสชั่นหมดอายุ',
    'client_session_expired_message' => 'เซสชันของคุณหมดอายุแล้ว โปรดคลิกลิงก์ในอีเมลของคุณอีกครั้ง',

    'auto_bill_notification' => 'ใบแจ้งหนี้นี้จะถูกเรียกเก็บเงินจากคุณโดยอัตโนมัติ :payment_method  ในไฟล์ :due_date',
    'auto_bill_payment_method_bank_transfer' => 'บัญชีธนาคาร',
    'auto_bill_payment_method_credit_card' => 'บัตรเครดิต',
    'auto_bill_payment_method_paypal' => 'บัญชี PayPal',
    'auto_bill_notification_placeholder' => 'ใบแจ้งหนี้นี้จะถูกเรียกเก็บเงินจากบัตรเครดิตของคุณโดยอัตโนมัติในวันครบกำหนด',
    'payment_settings' => 'การตั้งค่าการชำระเงิน',

    'on_send_date' => 'ในวันที่ส่ง',
    'on_due_date' => 'ในวันครบกำหนด',
    'auto_bill_ach_date_help' => 'ACH จะเรียกเก็บเงินอัตโนมัติในวันครบกำหนด',
    'warn_change_auto_bill' => 'เนื่องจากกฎของ NACHA การเปลี่ยนแปลงในใบแจ้งหนี้นี้อาจป้องกันการเรียกเก็บเงินอัตโนมัติของ ACH',

    'bank_account' => 'บัญชีธนาคาร',
    'payment_processed_through_wepay' => 'ACH การชำระเงินจะดำเนินการโดยใช้ WePay',
    'wepay_payment_tos_agree' => 'ฉันยอมรับ WePay :terms และ :privacy_policy',
    'privacy_policy' => 'นโยบายความเป็นส่วนตัว',
    'wepay_payment_tos_agree_required' => 'คุณต้องยอมรับข้อกำหนดในการให้บริการและนโยบายส่วนบุคคลของ WePay',
    'ach_email_prompt' => 'กรุณากรอกอีเมลของคุณ:',
    'verification_pending' => 'กำลังตรวจสอบรอดำเนินการ',

    'update_font_cache' => 'โปรดบังคับให้รีเฟรชหน้าเว็บเพื่อปรับปรุงแคชแบบอักษร',
    'more_options' => 'ตัวเลือกเพิ่มเติม',
    'credit_card' => 'บัตรเครดิต',
    'bank_transfer' => 'โอนเงินผ่านธนาคาร',
    'no_transaction_reference' => 'เราไม่ได้รับการอ้างอิงธุรกรรมการชำระเงินจากเกตเวย์',
    'use_bank_on_file' => 'ใช้ธนาคารจากไฟล์',
    'auto_bill_email_message' => 'ใบแจ้งหนี้นี้จะถูกเรียกเก็บเงินโดยอัตโนมัติตามวิธีการชำระเงินที่ระบุในวันที่ครบกำหนด',
    'bitcoin' => 'Bitcoin',
    'gocardless' => 'GoCardless',
    'added_on' => 'เพิ่ม :date',
    'failed_remove_payment_method' => 'ไม่สามารถลบวิธีการชำระเงินได้',
    'gateway_exists' => 'เกตเวย์นี้มีอยู่แล้ว',
    'manual_entry' => 'ป้อนค่าด้วยตนเอง',
    'start_of_week' => 'วันแรกของสัปดาห์',

    // Frequencies
    'freq_inactive' => 'ไม่ทำงาน',
    'freq_daily' => 'Daily',
    'freq_weekly' => 'รายสัปดาห์',
    'freq_biweekly' => 'Biweekly',
    'freq_two_weeks' => 'สองสัปดาห์',
    'freq_four_weeks' => 'สี่สับดาห์',
    'freq_monthly' => 'รายเดือน',
    'freq_three_months' => 'สามเดือน',
    'freq_four_months' => 'Four months',
    'freq_six_months' => 'หกเดือน',
    'freq_annually' => 'รายปี',
    'freq_two_years' => 'Two years',

    // Payment types
    'payment_type_Apply Credit' => 'สมัครเครดิต',
    'payment_type_Bank Transfer' => 'โอนเงินผ่านธนาคาร',
    'payment_type_Cash' => 'เงินสด',
    'payment_type_Debit' => 'เดบิต',
    'payment_type_ACH' => 'ACH',
    'payment_type_Visa Card' => 'บัตรวีซ่า',
    'payment_type_MasterCard' => 'บัตรมาสเตอร์การ์ด',
    'payment_type_American Express' => 'อเมริกันเอ็กเพรส',
    'payment_type_Discover Card' => 'Discover Card',
    'payment_type_Diners Card' => 'Diners Card',
    'payment_type_EuroCard' => 'EuroCard',
    'payment_type_Nova' => 'Nova',
    'payment_type_Credit Card Other' => 'บัตรเครดิตอื่น ๆ',
    'payment_type_PayPal' => 'PayPal',
    'payment_type_Google Wallet' => 'Google Wallet',
    'payment_type_Check' => 'เช็ค',
    'payment_type_Carte Blanche' => 'Carte Blanche',
    'payment_type_UnionPay' => 'UnionPay',
    'payment_type_JCB' => 'JCB',
    'payment_type_Laser' => 'Laser',
    'payment_type_Maestro' => 'Maestro',
    'payment_type_Solo' => 'Solo',
    'payment_type_Switch' => 'Switch',
    'payment_type_iZettle' => 'iZettle',
    'payment_type_Swish' => 'Swish',
    'payment_type_Alipay' => 'Alipay',
    'payment_type_Sofort' => 'Sofort',
    'payment_type_SEPA' => 'SEPA Direct Debit',
    'payment_type_Bitcoin' => 'Bitcoin',
    'payment_type_GoCardless' => 'GoCardless',
    'payment_type_Zelle' => 'Zelle',

    // Industries
    'industry_Accounting & Legal' => 'การบัญชีและกฎหมาย',
    'industry_Advertising' => 'การโฆษณา',
    'industry_Aerospace' => 'การบินและอวกาศ',
    'industry_Agriculture' => 'การเกษตร',
    'industry_Automotive' => 'ยานยนต์',
    'industry_Banking & Finance' => 'การเงินและการธนาคาร',
    'industry_Biotechnology' => 'เทคโนโลยีชีวภาพ',
    'industry_Broadcasting' => 'วิทยุและการกระจายเสียง',
    'industry_Business Services' => 'บริการทางธุรกิจ',
    'industry_Commodities & Chemicals' => 'สินค้าโภคภัณฑ์และเคมีภัณฑ์',
    'industry_Communications' => 'คมนาคม',
    'industry_Computers & Hightech' => 'คอมพิวเตอร์และเทคโนโลยี',
    'industry_Defense' => 'การป้องกันทางทหาร',
    'industry_Energy' => 'พลังงาน',
    'industry_Entertainment' => 'บันเทิง',
    'industry_Government' => 'ราชการ',
    'industry_Healthcare & Life Sciences' => 'สุขภาพและวิทยาศาสตร์เพื่อชีวิต',
    'industry_Insurance' => 'ประกันภัย',
    'industry_Manufacturing' => 'การผลิต',
    'industry_Marketing' => 'การตลาด',
    'industry_Media' => 'สื่อ',
    'industry_Nonprofit & Higher Ed' => 'องค์กรที่ไม่แสวงหากำไรและอุดมศึกษา',
    'industry_Pharmaceuticals' => 'ยาและเวชภัณฑ์',
    'industry_Professional Services & Consulting' => 'บริการและที่ปรึกษาทางวิชาชีพ',
    'industry_Real Estate' => 'อสังหาริมทรัพย์',
    'industry_Restaurant & Catering' => 'ร้านอาหารและการจัดเลี้ยง',
    'industry_Retail & Wholesale' => 'ค้าปลีกค้าส่ง',
    'industry_Sports' => 'กีฬา',
    'industry_Transportation' => 'การขนส่ง',
    'industry_Travel & Luxury' => 'การท่องเที่ยวและความบันเทิง',
    'industry_Other' => 'อื่นๆ',
    'industry_Photography' => 'ภาพถ่าย',

    // Countries
    'country_Afghanistan' => 'อัฟกานิสถาน',
    'country_Albania' => 'อัลบาเนีย',
    'country_Antarctica' => 'แอนตาร์กติการ์',
    'country_Algeria' => 'อัลจีเรีย',
    'country_American Samoa' => 'อเมริกัน ซามาว',
    'country_Andorra' => 'แอนโดรา',
    'country_Angola' => 'แองโกลา',
    'country_Antigua and Barbuda' => 'แอนติกัวและบาร์บัวดา',
    'country_Azerbaijan' => 'อาเซอร์ไบจัน',
    'country_Argentina' => 'อาร์เจนตินาร์',
    'country_Australia' => 'ออสเตรเลีย',
    'country_Austria' => 'ออสเตรีย',
    'country_Bahamas' => 'บาฮามาส',
    'country_Bahrain' => 'บาร์เรน',
    'country_Bangladesh' => 'บังกลาเทศ',
    'country_Armenia' => 'อาร์มาเนีย',
    'country_Barbados' => 'บาร์เบดอส',
    'country_Belgium' => 'เบลเยี่ยม',
    'country_Bermuda' => 'เบอร์มิวดา',
    'country_Bhutan' => 'ภูฐาน',
    'country_Bolivia, Plurinational State of' => 'โบลิเวียร์',
    'country_Bosnia and Herzegovina' => 'บอสเนีย',
    'country_Botswana' => 'บอสวาร์นา',
    'country_Bouvet Island' => 'เกาะบัวร์เวต',
    'country_Brazil' => 'บราซิล',
    'country_Belize' => 'เบลิซ',
    'country_British Indian Ocean Territory' => 'ดินแดนบริติชอินเดียนโอเชี่ยน',
    'country_Solomon Islands' => 'หมู่เกาะโซโลมอน',
    'country_Virgin Islands, British' => 'หมู่เกาะเวอร์จินไอร์แลนด์',
    'country_Brunei Darussalam' => 'บรูไน',
    'country_Bulgaria' => 'บัลแกเรีย',
    'country_Myanmar' => 'เมียนมาร์',
    'country_Burundi' => 'บูรันดี',
    'country_Belarus' => 'เบลารุส',
    'country_Cambodia' => 'โคลัมเบีย',
    'country_Cameroon' => 'แคเมอรูน',
    'country_Canada' => 'แคนาดา',
    'country_Cape Verde' => 'เคปเวิร์ด',
    'country_Cayman Islands' => 'หมู่เกาะเคย์แมน',
    'country_Central African Republic' => 'สาธารณรัฐแอฟริกากลาง',
    'country_Sri Lanka' => 'ศรีลังกา',
    'country_Chad' => 'ชาด',
    'country_Chile' => 'ชิลี',
    'country_China' => 'จีน',
    'country_Taiwan, Province of China' => 'ไต้หวัน',
    'country_Christmas Island' => 'เกาะคริสต์มาส',
    'country_Cocos (Keeling) Islands' => 'เกาะโคโคส (คีลิง)',
    'country_Colombia' => 'โคลอมเบีย',
    'country_Comoros' => 'คอโมโรส',
    'country_Mayotte' => 'มายอต',
    'country_Congo' => 'คองโก',
    'country_Congo, the Democratic Republic of the' => 'สาธารณรัฐประชาธิปไตยคองโก',
    'country_Cook Islands' => 'หมู่เกาะคุก',
    'country_Costa Rica' => 'คอสตาริกา',
    'country_Croatia' => 'โครเอเชีย',
    'country_Cuba' => 'คิวบา',
    'country_Cyprus' => 'ไซปรัส',
    'country_Czech Republic' => 'สาธารณรัฐเช็ก',
    'country_Benin' => 'ประเทศเบนิน',
    'country_Denmark' => 'เดนมาร์ก',
    'country_Dominica' => 'โดมินิกา',
    'country_Dominican Republic' => 'สาธารณรัฐโดมินิกัน',
    'country_Ecuador' => 'เอกวาดอร์',
    'country_El Salvador' => 'เอลซัลวาดอร์',
    'country_Equatorial Guinea' => 'อิเควทอเรียลกินี',
    'country_Ethiopia' => 'สาธารณรัฐเอธิโอเปีย',
    'country_Eritrea' => 'เอริเทรี',
    'country_Estonia' => 'เอสโตเนีย',
    'country_Faroe Islands' => 'หมู่เกาะแฟโร',
    'country_Falkland Islands (Malvinas)' => 'หมู่เกาะฟอล์กแลนด์ (Malvinas)',
    'country_South Georgia and the South Sandwich Islands' => 'เกาะเซาท์จอร์เจียและหมู่เกาะเซาท์แซนด์วิช',
    'country_Fiji' => 'ฟิจิ',
    'country_Finland' => 'ฟินแลนด์',
    'country_Åland Islands' => 'หมู่เกาะโอลัน',
    'country_France' => 'ฝรั่งเศส',
    'country_French Guiana' => 'เฟรนช์เกีย',
    'country_French Polynesia' => 'เฟรนช์โปลินีเซีย',
    'country_French Southern Territories' => 'ดินแดนทางตอนใต้ของฝรั่งเศส',
    'country_Djibouti' => 'จิบูตี',
    'country_Gabon' => 'ประเทศกาบอง',
    'country_Georgia' => 'จอร์เจีย',
    'country_Gambia' => 'แกมเบีย',
    'country_Palestinian Territory, Occupied' => 'ดินแดนปาเลสไตน์',
    'country_Germany' => 'ประเทศเยอรมัน',
    'country_Ghana' => 'ประเทศกานา',
    'country_Gibraltar' => 'ยิบรอลตา',
    'country_Kiribati' => 'ประเทศคิริบาส',
    'country_Greece' => 'กรีซ',
    'country_Greenland' => 'เกาะกรีนแลนด์',
    'country_Grenada' => 'เกรเนดา',
    'country_Guadeloupe' => 'ลุป',
    'country_Guam' => 'กวม',
    'country_Guatemala' => 'กัวเตมาลา',
    'country_Guinea' => 'ประเทศกินี',
    'country_Guyana' => 'กายอานา',
    'country_Haiti' => 'ไฮติ',
    'country_Heard Island and McDonald Islands' => 'เกาะเฮิร์ดและหมู่เกาะแมคโดนัลด์',
    'country_Holy See (Vatican City State)' => 'Holy See  (นครรัฐวาติกัน)',
    'country_Honduras' => 'ฮอนดูรัส',
    'country_Hong Kong' => 'ฮ่องกง',
    'country_Hungary' => 'ฮังการี่',
    'country_Iceland' => 'ไอซ์แลนด์',
    'country_India' => 'อินเดีย',
    'country_Indonesia' => 'อินโดนีเซีย',
    'country_Iran, Islamic Republic of' => 'อิหร่าน',
    'country_Iraq' => 'อิรัค',
    'country_Ireland' => 'ไอร์แลนด์',
    'country_Israel' => 'อิสราเอล',
    'country_Italy' => 'อิตาลี',
    'country_Côte d\'Ivoire' => 'โกตดิวัวร์',
    'country_Jamaica' => 'เกาะจาเมกา',
    'country_Japan' => 'ประเทศญี่ปุ่น',
    'country_Kazakhstan' => 'คาซัคสถาน',
    'country_Jordan' => 'จอร์แดน',
    'country_Kenya' => 'ประเทศเคนย่า',
    'country_Korea, Democratic People\'s Republic of' => 'เกาหลีใต้',
    'country_Korea, Republic of' => 'เกาหลีเหนือ',
    'country_Kuwait' => 'คูเวต',
    'country_Kyrgyzstan' => 'คีร์กีสถาน',
    'country_Lao People\'s Democratic Republic' => 'ลาว',
    'country_Lebanon' => 'เลบานอน',
    'country_Lesotho' => 'เลโซโท',
    'country_Latvia' => 'ลัตเวีย',
    'country_Liberia' => 'ไลบีเรีย',
    'country_Libya' => 'ลิบยา',
    'country_Liechtenstein' => 'ลิกเตนสไตน์',
    'country_Lithuania' => 'ลิธัวเนีย',
    'country_Luxembourg' => 'ลักเซมเบิร์ก',
    'country_Macao' => 'มาเก๊า',
    'country_Madagascar' => 'มาดากัสการ์',
    'country_Malawi' => 'มาลาวี',
    'country_Malaysia' => 'มาเลเซีย',
    'country_Maldives' => 'มัลดีฟส์',
    'country_Mali' => 'มาลี',
    'country_Malta' => 'มอลตา',
    'country_Martinique' => 'มาร์ตินีก',
    'country_Mauritania' => 'มอริเตเนีย',
    'country_Mauritius' => 'มอริเชียส',
    'country_Mexico' => 'เม็กซิโก',
    'country_Monaco' => 'โมนาโก',
    'country_Mongolia' => 'มองโกเลีย',
    'country_Moldova, Republic of' => 'มอลโดวา',
    'country_Montenegro' => 'มอนเตเนโก',
    'country_Montserrat' => 'มอนต์เซอร์รัต',
    'country_Morocco' => 'Morocco',
    'country_Mozambique' => 'โมซัมบิก',
    'country_Oman' => 'โอมาน',
    'country_Namibia' => 'นามิเบีย',
    'country_Nauru' => 'นาอูรู',
    'country_Nepal' => 'เนปาล',
    'country_Netherlands' => 'เนเธอร์แลนด์',
    'country_Curaçao' => 'คูราเซา',
    'country_Aruba' => 'อารูบา',
    'country_Sint Maarten (Dutch part)' => 'Sint Maarten (ส่วนชาวดัตช์)',
    'country_Bonaire, Sint Eustatius and Saba' => 'Bonaire, Sint Eustatius และ Saba',
    'country_New Caledonia' => 'สกอตแลนด์',
    'country_Vanuatu' => 'วานูอาตู',
    'country_New Zealand' => 'นิวซีแลนด์',
    'country_Nicaragua' => 'นิการากัว',
    'country_Niger' => 'ไนเธอร์',
    'country_Nigeria' => 'ไนจีเรีย',
    'country_Niue' => 'Niue',
    'country_Norfolk Island' => 'นอร์ฟอล์ก',
    'country_Norway' => 'นอร์เวย์',
    'country_Northern Mariana Islands' => 'หมู่เกาะนอร์เทิร์นมาเรียนา',
    'country_United States Minor Outlying Islands' => 'หมู่เกาะห่างไกลของสหรัฐอเมริกา',
    'country_Micronesia, Federated States of' => 'ไมโครนีเซีย',
    'country_Marshall Islands' => 'หมู่เกาะมาร์แชลล์',
    'country_Palau' => 'ปาเลา',
    'country_Pakistan' => 'ปากีสถาน',
    'country_Panama' => 'ปานามา',
    'country_Papua New Guinea' => 'ปาปัวนิวกินี',
    'country_Paraguay' => 'ปารากวัย',
    'country_Peru' => 'เปรู',
    'country_Philippines' => 'ฟิลิปปินส์',
    'country_Pitcairn' => 'พิตแคร์น',
    'country_Poland' => 'โปแลนด์',
    'country_Portugal' => 'โปรตุเกส',
    'country_Guinea-Bissau' => 'กินีบิสเซา',
    'country_Timor-Leste' => 'ติมอร์เลสเต',
    'country_Puerto Rico' => 'เปอร์โตริโก้',
    'country_Qatar' => 'กาตาร์',
    'country_Réunion' => 'เรอูนียง',
    'country_Romania' => 'โรมาเนีย',
    'country_Russian Federation' => 'สหพันธรัฐรัสเซีย',
    'country_Rwanda' => 'รวันดา',
    'country_Saint Barthélemy' => 'Saint Barthélemy',
    'country_Saint Helena, Ascension and Tristan da Cunha' => 'Saint Helena, Ascension and Tristan da Cunha',
    'country_Saint Kitts and Nevis' => 'เซนต์คิตส์และเนวิส',
    'country_Anguilla' => 'แองกวิลลา',
    'country_Saint Lucia' => 'เซนต์ลูเซีย',
    'country_Saint Martin (French part)' => 'เซนต์มาร์ติน (ฝรั่งเศส)',
    'country_Saint Pierre and Miquelon' => 'เซนต์ปิแอร์และมีเกอลง',
    'country_Saint Vincent and the Grenadines' => 'เซนต์วินเซนต์และเกรนาดีนส์',
    'country_San Marino' => 'ซานมารีโน',
    'country_Sao Tome and Principe' => 'เซาตูเมและปรินซิเป',
    'country_Saudi Arabia' => 'ซาอุดิอาราเบีย',
    'country_Senegal' => 'ประเทศเซเนกัล',
    'country_Serbia' => 'เซอร์เบีย',
    'country_Seychelles' => 'เซเชลส์',
    'country_Sierra Leone' => 'เซียร์ราลีโอน',
    'country_Singapore' => 'สิงคโปร์',
    'country_Slovakia' => 'สโลวะเกีย',
    'country_Viet Nam' => 'เวียดนาม',
    'country_Slovenia' => 'สโลวีเนีย',
    'country_Somalia' => 'โซมาเลีย',
    'country_South Africa' => 'แอฟริกาใต้',
    'country_Zimbabwe' => 'ซิมบับเว',
    'country_Spain' => 'สเปน',
    'country_South Sudan' => 'ซูดานใต้',
    'country_Sudan' => 'ซูดาน',
    'country_Western Sahara' => 'ซาฮาร่าตะวันตก',
    'country_Suriname' => 'ซูรินาเม',
    'country_Svalbard and Jan Mayen' => 'สฟาลบาร์และ Jan Mayen',
    'country_Swaziland' => 'สวาซิแลนด์',
    'country_Sweden' => 'สวีเดน',
    'country_Switzerland' => 'สวิตเซอร์แลนด์',
    'country_Syrian Arab Republic' => 'อาหรับซีเรีย',
    'country_Tajikistan' => 'ทาจิกิสถาน',
    'country_Thailand' => 'ไทย',
    'country_Togo' => 'โตโก',
    'country_Tokelau' => 'โตเกเลา',
    'country_Tonga' => 'ตองกา',
    'country_Trinidad and Tobago' => 'ตรินิแดดและโตเบโก',
    'country_United Arab Emirates' => 'สหรัฐอาหรับเอมิเรตส์',
    'country_Tunisia' => 'ตูนิเซีย',
    'country_Turkey' => 'ตุรกี',
    'country_Turkmenistan' => 'เติร์กเมนิสถาน',
    'country_Turks and Caicos Islands' => 'หมู่เกาะเติกส์และหมู่เกาะเคคอส',
    'country_Tuvalu' => 'ตูวาลู',
    'country_Uganda' => 'ยูกันดา',
    'country_Ukraine' => 'ยูเครน',
    'country_Macedonia, the former Yugoslav Republic of' => 'มาซิโดเนียอดีตสาธารณรัฐยูโกสลาเวีย',
    'country_Egypt' => 'อียิปต์',
    'country_United Kingdom' => 'อังกฤษ',
    'country_Guernsey' => 'เกิร์นซีย์',
    'country_Jersey' => 'เจอร์ซีย์',
    'country_Isle of Man' => 'เกาะแมน',
    'country_Tanzania, United Republic of' => 'แทนซาเนีย',
    'country_United States' => 'สหรัฐอเมริกา',
    'country_Virgin Islands, U.S.' => 'หมู่เกาะเวอร์จิน',
    'country_Burkina Faso' => 'บูร์กินาฟาโซ',
    'country_Uruguay' => 'อุรุกวัย',
    'country_Uzbekistan' => 'อุซเบกิ',
    'country_Venezuela, Bolivarian Republic of' => 'เวเนซุเอลา',
    'country_Wallis and Futuna' => 'วาลลิสและฟุตูนา',
    'country_Samoa' => 'ซามัว',
    'country_Yemen' => 'เยเมน',
    'country_Zambia' => 'แซมเบีย',

    // Languages
    'lang_Brazilian Portuguese' => 'โปรตุเกส',
    'lang_Croatian' => 'โครเอเชีย',
    'lang_Czech' => 'สาธารณรัฐเช็ก',
    'lang_Danish' => 'เดนิส',
    'lang_Dutch' => 'ดัตช์',
    'lang_English' => 'อังกฤษ',
    'lang_French' => 'ฝรั่งเศส',
    'lang_French - Canada' => 'ฝรั่งเศส - แคนาดา',
    'lang_German' => 'เยอรมัน',
    'lang_Italian' => 'อิตาลี',
    'lang_Japanese' => 'ญี่ปุ่น',
    'lang_Lithuanian' => 'ลิธัวเนีย',
    'lang_Norwegian' => 'นอร์เวย์',
    'lang_Polish' => 'โปแลนด์',
    'lang_Spanish' => 'สเปน',
    'lang_Spanish - Spain' => 'สเปน - สเปน',
    'lang_Swedish' => 'สวีเดน',
    'lang_Albanian' => 'แอลเบเนีย',
    'lang_Greek' => 'กรีก',
    'lang_English - United Kingdom' => 'อังกฤษ - สหราชอาณาจักร',
    'lang_English - Australia' => 'English - Australia',
    'lang_Slovenian' => 'สโลเวเนีย',
    'lang_Finnish' => 'ฟินแลนด์',
    'lang_Romanian' => 'โรมาเนีย',
    'lang_Turkish - Turkey' => 'ตุรกี - ตุรกี',
    'lang_Portuguese - Brazilian' => 'โปรตุเกส - บราซิล',
    'lang_Portuguese - Portugal' => 'โปรตุเกส - โปรตุเกส',
    'lang_Thai' => 'Thai',
    'lang_Macedonian' => 'Macedonian',
    'lang_Chinese - Taiwan' => 'Chinese - Taiwan',
    'lang_Serbian' => 'Serbian',
    'lang_Bulgarian' => 'Bulgarian',
    'lang_Russian' => 'Russian',

    // Industries
    'industry_Accounting & Legal' => 'การบัญชีและกฎหมาย',
    'industry_Advertising' => 'การโฆษณา',
    'industry_Aerospace' => 'การบินและอวกาศ',
    'industry_Agriculture' => 'การเกษตร',
    'industry_Automotive' => 'ยานยนต์',
    'industry_Banking & Finance' => 'การเงินและการธนาคาร',
    'industry_Biotechnology' => 'เทคโนโลยีชีวภาพ',
    'industry_Broadcasting' => 'วิทยุและการกระจายเสียง',
    'industry_Business Services' => 'บริการทางธุรกิจ',
    'industry_Commodities & Chemicals' => 'สินค้าโภคภัณฑ์และเคมีภัณฑ์',
    'industry_Communications' => 'คมนาคม',
    'industry_Computers & Hightech' => 'คอมพิวเตอร์และเทคโนโลยี',
    'industry_Defense' => 'การป้องกันทางทหาร',
    'industry_Energy' => 'พลังงาน',
    'industry_Entertainment' => 'บันเทิง',
    'industry_Government' => 'ราชการ',
    'industry_Healthcare & Life Sciences' => 'สุขภาพและวิทยาศาสตร์เพื่อชีวิต',
    'industry_Insurance' => 'ประกันภัย',
    'industry_Manufacturing' => 'การผลิต',
    'industry_Marketing' => 'การตลาด',
    'industry_Media' => 'สื่อ',
    'industry_Nonprofit & Higher Ed' => 'องค์กรที่ไม่แสวงหากำไรและอุดมศึกษา',
    'industry_Pharmaceuticals' => 'ยาและเวชภัณฑ์',
    'industry_Professional Services & Consulting' => 'บริการและที่ปรึกษาทางวิชาชีพ',
    'industry_Real Estate' => 'อสังหาริมทรัพย์',
    'industry_Retail & Wholesale' => 'ค้าปลีกค้าส่ง',
    'industry_Sports' => 'กีฬา',
    'industry_Transportation' => 'การขนส่ง',
    'industry_Travel & Luxury' => 'การท่องเที่ยวและความบันเทิง',
    'industry_Other' => 'อื่นๆ',
    'industry_Photography' => 'ภาพถ่าย',

    'view_client_portal' => 'ดูพอร์ทัลลูกค้า',
    'view_portal' => 'ดูพอร์ทัล',
    'vendor_contacts' => 'รายชื่อผู้ขาย',
    'all' => 'ทั้งหมด',
    'selected' => 'เลือกแล้ว',
    'category' => 'แคตตาล็อก',
    'categories' => 'หมวดหมู่',
    'new_expense_category' => 'หมวดค่าใช้จ่ายใหม่',
    'edit_category' => 'แก้ไขหมวดหมู่',
    'archive_expense_category' => 'จัดเก็บหมวดหมู่',
    'expense_categories' => 'หมวดค่าใช้จ่าย',
    'list_expense_categories' => 'รายการหมวดค่าใช้จ่าย',
    'updated_expense_category' => 'อัปเดตหมวดค่าใช้จ่ายเรียบร้อยแล้ว',
    'created_expense_category' => 'สร้างหมวดหมู่ค่าใช้จ่ายเรียบร้อยแล้ว',
    'archived_expense_category' => 'หมวดหมู่ค่าใช้จ่ายที่เก็บสำเร็จแล้ว',
    'archived_expense_categories' => 'จัดเก็บเรียบร้อยแล้ว :count หมวดค่าใช้จ่าย',
    'restore_expense_category' => 'คืนค่าหมวดหมู่ค่าใช้จ่าย',
    'restored_expense_category' => 'กู้คืนหมวดหมู่ค่าใช้จ่ายเรียบร้อยแล้ว',
    'apply_taxes' => 'ใช้ภาษี',
    'min_to_max_users' => ':min ไป :max ผู้ใช้',
    'max_users_reached' => 'มีผู้ใช้ถึงจำนวนสูงสุดแล้ว',
    'buy_now_buttons' => 'ปุ่มซื้อเดี๋ยวนี้',
    'landing_page' => 'หน้า Landing Page',
    'payment_type' => 'ประเภทการชำระเงิน',
    'form' => 'ฟอร์ม',
    'link' => 'ลิงค์',
    'fields' => 'ฟิลด์',
    'dwolla' => 'Dwolla',
    'buy_now_buttons_warning' => 'หมายเหตุ: ลูกค้าและใบแจ้งหนี้จะถูกสร้างขึ้นแม้ว่าการทำธุรกรรมจะยังไม่สมบูรณ์ก็ตาม',
    'buy_now_buttons_disabled' => 'คุณลักษณะนี้ต้องการให้สร้างผลิตภัณฑ์และมีการกำหนดค่าเกตเวย์การชำระเงิน',
    'enable_buy_now_buttons_help' => 'เปิดใช้การสนับสนุนสำหรับปุ่มซื้อเดี๋ยวนี้',
    'changes_take_effect_immediately' => 'หมายเหตุ: การเปลี่ยนแปลงมีผลทันที',
    'wepay_account_description' => 'เกตเวย์การชำระเงินสำหรับ Invoice Ninja',
    'payment_error_code' => 'เกิดข้อผิดพลาดในการประมวลผลการชำระเงินของคุณ [: code] กรุณาลองใหม่อีกครั้งในภายหลัง.',
    'standard_fees_apply' => 'ค่าธรรมเนียม: 2.9% / 1.2% [Credit Card / Bank Transfer] + $ 0.30 ต่อครั้งสำหรับการเรียกเก็บเงินที่ประสบความสำเร็จ',
    'limit_import_rows' => 'ต้องนำเข้าข้อมูลเป็นชุด :count หรือน้อยกว่า',
    'error_title' => 'บางอย่างผิดพลาด',
    'error_contact_text' => 'หากคุณต้องการความช่วยเหลือโปรดส่งอีเมลถึงเราที่ :mailaddress',
    'no_undo' => 'คำเตือน: ไม่สามารถยกเลิกได้',
    'no_contact_selected' => 'โปรดเลือกผู้ติดต่อ',
    'no_client_selected' => 'โปรดเลือกลูกค้า',

    'gateway_config_error' => 'อาจช่วยในการตั้งรหัสผ่านใหม่หรือสร้างคีย์ API ใหม่',
    'payment_type_on_file' => ':type ในไฟล์',
    'invoice_for_client' => 'ใบแจ้งหนี้ :invoice สำหรับ :client',
    'intent_not_found' => 'ขออภัยฉันไม่แน่ใจว่าคุณต้องการอะไร',
    'intent_not_supported' => 'ขออภัยฉันไม่สามารถทำเช่นนั้นได้',
    'client_not_found' => 'ฉันไม่สามารถหาลูกค้าได้',
    'not_allowed' => 'ขออภัยคุณไม่มีสิทธิ์',
    'bot_emailed_invoice' => 'ส่งใบแจ้งหนี้ของคุณแล้ว',
    'bot_emailed_notify_viewed' => 'ฉันจะส่งอีเมลถึงคุณเมื่อมีการดู',
    'bot_emailed_notify_paid' => 'ฉันจะส่งอีเมลถึงคุณเมื่อมีการชำระเงิน',
    'add_product_to_invoice' => 'Add1 :product',
    'not_authorized' => 'คุณไม่ได้รับอนุญาต',
    'bot_get_email' => 'Hi! (wave)<br/>Thanks for trying the Invoice Ninja Bot.<br/>You need to create a free account to use this bot.<br/>Send me your account email address to get started.',
    'bot_get_code' => 'ขอบคุณ! ฉันส่งอีเมลพร้อมรหัสรักษาความปลอดภัยของคุณมาให้',
    'bot_welcome' => 'บัญชีของคุณได้รับการยืนยันแล้ว.<br/>',
    'email_not_found' => 'ฉันไม่พบบัญชีที่พร้อมใช้งานสำหรับ :email',
    'invalid_code' => 'รหัสไม่ถูกต้อง',
    'security_code_email_subject' => 'รหัสรักษาความปลอดภัยสำหรับ  Invoice Ninja Bot',
    'security_code_email_line1' => 'นี่เป็นรหัสรักษาความปลอดภัยของ Bot Invoice  Ninja  ของคุณ',
    'security_code_email_line2' => 'หมายเหตุ: จะหมดอายุภายใน 10 นาที',
    'bot_help_message' => 'ฉันสนับสนุน:<br/>.สร้าง \ อัปเดท\ อีเมล์ ใบแจ้งหนี้<br/>.แสดงสินค้า<br/>ตัวอย่างเช่น:<br/><i>ใบแจ้งหนี้ 2 ใบกำหนดวันครบกำหนดถึงวันพฤหัสบดีถัดไปและส่วนลด 10%</i>',
    'list_products' => 'แสดงสินค้า',

    'include_item_taxes_inline' => 'รวมถึง <b>รายการภาษีในบรรทัดรวม</b>',
    'created_quotes' => 'สร้างเรียบร้อย :count ใบเสนอราคา(s)',
    'limited_gateways' => 'หมายเหตุ: เราสนับสนุนเกตเวย์บัตรเครดิตหนึ่งใบต่อ บริษัท',

    'warning' => 'คำเตือน',
    'self-update' => 'ปรับปรุง',
    'update_invoiceninja_title' => 'อัปเดท Invoice Ninja',
    'update_invoiceninja_warning' => 'ก่อนที่จะเริ่มต้นการอัพเกรด Invoice Ninja กรุณาสำรองฐานข้อมูลและไฟล์ของคุณ!',
    'update_invoiceninja_available' => 'มีเวอร์ชันใหม่ของ Invoice Ninja ให้ใช้งาน',
    'update_invoiceninja_unavailable' => 'ไม่มีเวอร์ชันใหม่ของ Invoice Ninja available.',
    'update_invoiceninja_instructions' => 'โปรดติดตั้งเวอร์ชันใหม่ <strong>:version</strong>โดยการคลิกที่ <em>Update now</em>ด้านล่าง หลังจากนั้นคุณจะถูกเปลี่ยนเส้นทางไปยังแดชบอร์ด.',
    'update_invoiceninja_update_start' => 'Update now',
    'update_invoiceninja_download_start' => 'ดาวน์โหลด :version',
    'create_new' => 'สร้างใหม่',

    'toggle_navigation' => 'สลับการนำทาง',
    'toggle_history' => 'สลับประวัติ',
    'unassigned' => 'ยังไม่ได้มอบหมาย',
    'task' => 'งาน',
    'contact_name' => 'ชื่อผู้ติดต่อ',
    'city_state_postal' => 'เมือง / รัฐ / ไปรษณีย์',
    'custom_field' => 'ฟิลด์ที่กำหนดเอง',
    'account_fields' => 'ฟิลด์บริษัท',
    'facebook_and_twitter' => 'Facebook และ Twitter',
    'facebook_and_twitter_help' => 'ติดตามฟีดของเราเพื่อช่วยสนับสนุนโครงการของเรา',
    'reseller_text' => 'หมายเหตุ: ใบอนุญาต white-label มีไว้สำหรับการใช้งานส่วนบุคคลโปรดส่งอีเมลถึงเราที่ :email หากต้องการขายโปรแกรมนี้',
    'unnamed_client' => 'ลูกค้าไม่มีชื่อ',

    'day' => 'วัน',
    'week' => 'สัปดาห์',
    'month' => 'เดือน',
    'inactive_logout' => 'คุณได้ออกจากระบบเนื่องจากไม่มีการใช้งาน',
    'reports' => 'รายงาน',
    'total_profit' => 'ผลกำไรทั้งหมด',
    'total_expenses' => 'ค่าใช้จ่ายรวมทั้งหมด',
    'quote_to' => 'ใบเสนอราคาไปยัง',

    // Limits
    'limit' => 'จำกัด',
    'min_limit' => 'ต่ำสุด :min',
    'max_limit' => 'สูงสุด :max',
    'no_limit' => 'ไม่จำกัด',
    'set_limits' => 'Set : gateway_type จำกัด',
    'enable_min' => 'เปิดใช้ค่าต่ำสุด',
    'enable_max' => 'เปิดใช้ค่าสูงสุด',
    'min' => 'น้อย',
    'max' => 'มาก',
    'limits_not_met' => 'ใบแจ้งหนี้นี้ไม่ตรงกับประเภทการชำระเงิน',

    'date_range' => 'ช่วงวันที่',
    'raw' => 'ข้อมูลดิบ',
    'raw_html' => 'Raw HTML',
    'update' => 'อัปเดต',
    'invoice_fields_help' => 'ลากและวางฟิลด์เพื่อเปลี่ยนลำดับและตำแหน่ง',
    'new_category' => 'หมวดหมู่ใหม่',
    'restore_product' => 'กู้คืนสินค้า',
    'blank' => 'ว่าง',
    'invoice_save_error' => 'มีข้อผิดพลาดในการบันทึกใบแจ้งหนี้ของคุณ',
    'enable_recurring' => 'เปิดใช้งานประจำ',
    'disable_recurring' => 'ปิดการใช้งานประจำ',
    'text' => 'ตัวอักษร',
    'expense_will_create' => 'ค่าใช้จ่ายถูกสร้างขึ้น',
    'expenses_will_create' => 'ค่าใช้จ่ายถูกสร้างขึ้น',
    'created_expenses' => 'สร้างเรียบร้อย :count  ใบแจ้งหนี้(s)',

    'translate_app' => 'ช่วยปรับปรุงการแปลของเราด้วย :link',
    'expense_category' => 'หมวดค่าใช้จ่าย',

    'go_ninja_pro' => 'Go Ninja Pro!',
    'go_enterprise' => 'Go Enterprise!',
    'upgrade_for_features' => 'อัพเกรดเพื่อเพิ่มคุณสมบัติเพิ่มเติม',
    'pay_annually_discount' => 'จ่ายรายปีเป็นเวลา 10 เดือน + ฟรี 2 เดือน',
    'pro_upgrade_title' => 'Ninja Pro',
    'pro_upgrade_feature1' => 'YourBrand.InvoiceNinja.com',
    'pro_upgrade_feature2' => 'ปรับแต่งทุกด้านในใบแจ้งหนี้ของคุณ!',
    'enterprise_upgrade_feature1' => 'ตั้งค่าสิทธิ์สำหรับผู้ใช้หลายคน',
    'enterprise_upgrade_feature2' => 'แนบไฟล์ 3rd Party เข้ากับใบแจ้งหนี้และค่าใช้จ่าย',
    'much_more' => 'และอื่น ๆ มากมาย',
    'all_pro_fetaures' => 'Plus all pro features!',

    'currency_symbol' => 'สัญลักษณ์',
    'currency_code' => 'Code',

    'buy_license' => 'ซื้อไลเซนต์',
    'apply_license' => 'สมัครไลเซนต์',
    'submit' => 'ยอมรับ',
    'white_label_license_key' => 'License Key',
    'invalid_white_label_license' => 'ใบอนุญาต White label ไม่ถูกต้อง',
    'created_by' => 'สร้างโดย :name',
    'modules' => 'โมดูล',
    'financial_year_start' => 'เดือนแรกของปี',
    'authentication' => 'การรับรอง',
    'checkbox' => 'ช่องทำเครื่องหมาย',
    'invoice_signature' => 'ลายเซ็น',
    'show_accept_invoice_terms' => 'Checkbox เงื่อนไขในใบแจ้งหนี้',
    'show_accept_invoice_terms_help' => 'กำหนดให้ลูกค้ายืนยันว่ายอมรับข้อกำหนดในใบแจ้งหนี้',
    'show_accept_quote_terms' => 'Checkbox เงื่อนไขใบเสนอราคา',
    'show_accept_quote_terms_help' => 'กำหนดให้ลูกค้ายืนยันว่ายอมรับเงื่อนไขการเสนอราคา',
    'require_invoice_signature' => 'ลายเซ็นของใบแจ้งหนี้',
    'require_invoice_signature_help' => 'กำหนดให้ลูกค้าจัดหาลายเซ็น',
    'require_quote_signature' => 'ลายมือชื่อใบเสนอราคา',
    'require_quote_signature_help' => 'กำหนดให้ลูกค้าจัดหาลายเซ็น',
    'i_agree' => 'ฉันยอมรับข้อเงื่อนไขข้อกำหนด',
    'sign_here' => 'โปรดเซ็นชื่อที่นี่:',
    'authorization' => 'การอนุญาต',
    'signed' => 'ลงนาม',

    // BlueVine
    'bluevine_promo' => 'เพิ่มความคล่องตัวในการทำธุรกิจเครดิตและแฟ็กทีฟแฟคตอริ่งโดยใช้ BlueVine',
    'bluevine_modal_label' => 'ลงทะเบียนกับ BlueVine',
    'bluevine_modal_text' => '<h3>การระดมทุนอย่างรวดเร็วสำหรับธุรกิจของคุณ ไม่ต้องมีเอกสาร</h3>
<ul><li>สายธุรกิจที่ยืดหยุ่นของสินเชื่อและแฟ็กเรียลแฟกเตอริ่ง</li></ul>',
    'bluevine_create_account' => 'สร้างบัญชี',
    'quote_types' => 'รับใบเสนอราคาสำหรับ',
    'invoice_factoring' => 'Invoice factoring',
    'line_of_credit' => 'วงเงิน',
    'fico_score' => 'คะแนน FICO ของคุณ',
    'business_inception' => 'วันที่จดทะเบียนกองทุน',
    'average_bank_balance' => 'ยอดคงเหลือในบัญชีธนาคารโดยเฉลี่ย',
    'annual_revenue' => 'รายได้ประจำปี',
    'desired_credit_limit_factoring' => 'วงเงินแฟคเตอริ่งที่ต้องการ',
    'desired_credit_limit_loc' => 'วงเงินเครดิตสูงสุดที่ต้องการ',
    'desired_credit_limit' => 'วงเงินเครดิตที่ต้องการ',
    'bluevine_credit_line_type_required' => 'คุณต้องเลือกอย่างน้อยหนึ่งอย่าง',
    'bluevine_field_required' => 'ต้องระบุข้อมูลนี้',
    'bluevine_unexpected_error' => 'เกิดความผิดพลาดอย่างไม่ได้คาดคิด.',
    'bluevine_no_conditional_offer' => 'ต้องการข้อมูลเพิ่มเติมก่อนรับใบเสนอราคา คลิกดำเนินการต่อด้านล่าง.',
    'bluevine_invoice_factoring' => 'Invoice Factoring',
    'bluevine_conditional_offer' => 'ข้อเสนอที่มีเงื่อนไข',
    'bluevine_credit_line_amount' => 'วงเงิน',
    'bluevine_advance_rate' => 'อัตราค่าบริการล่วงหน้า',
    'bluevine_weekly_discount_rate' => 'อัตราส่วนลดรายสัปดาห์',
    'bluevine_minimum_fee_rate' => 'ค่าธรรมเนียมขั้นต่ำ',
    'bluevine_line_of_credit' => 'วงเงินสูงสุด',
    'bluevine_interest_rate' => 'อัตราดอกเบี้ย',
    'bluevine_weekly_draw_rate' => 'Weekly Draw Rate',
    'bluevine_continue' => 'ไปที่ BlueVine',
    'bluevine_completed' => 'สมัคร BlueVine เรียบร้อยแล้ว',

    'vendor_name' => 'ผู้ขาย',
    'entity_state' => 'สถานะ',
    'client_created_at' => 'วันที่สร้าง',
    'postmark_error' => 'เกิดปัญหาในการส่งอีเมลผ่าน Postmark: :link',
    'project' => 'โครงการ',
    'projects' => 'โครงการ',
    'new_project' => 'โครงการใหม่',
    'edit_project' => 'แก้ไขโครงการ',
    'archive_project' => 'เก็บบันทึกโครงการ',
    'list_projects' => 'แสดงรายการโครงการ',
    'updated_project' => 'อัปเดตโครงการสำเร็จ',
    'created_project' => 'สร้างโครงการสำเร็จ',
    'archived_project' => 'เก็บบันทึกโครงการสำเร็จ',
    'archived_projects' => 'เก็บบันทึก :count โครงการ',
    'restore_project' => 'Restore Project',
    'restored_project' => 'กู้คืนโครงการสำเร็จ',
    'delete_project' => 'Delete Project',
    'deleted_project' => 'ลบโครงการสำเร็จ',
    'deleted_projects' => 'ลบโครงการ :count โครงการ',
    'delete_expense_category' => 'ลบหมวดหมู่',
    'deleted_expense_category' => 'นำออกหมวดหมู่เรียบร้อยแล้ว',
    'delete_product' => 'Delete Product',
    'deleted_product' => 'ลบสินค้าแล้ว',
    'deleted_products' => 'ลบสินค้า :count สินค้า',
    'restored_product' => 'กู้คืนสินค้าแล้ว',
    'update_credit' => 'อัปเดตเครดิต',
    'updated_credit' => 'อัปเดตเครดิตแล้ว',
    'edit_credit' => 'แก้ไขเครดิต',
    'realtime_preview' => 'Realtime Preview',
    'realtime_preview_help' => 'Realtime refresh PDF preview on the invoice page when editing invoice.<br/>Disable this to improve performance when editing invoices.',
    'live_preview_help' => 'Display a live PDF preview on the invoice page.',
    'force_pdfjs_help' => 'แทนที่โปรแกรมอ่าน PDF ในตัวใน :chrome_link และ :firefox_link.<br/>เปิดใช้งานหากเบราว์เซอร์ของคุณดาวน์โหลดไฟล์ PDF โดยอัตโนมัติ',
    'force_pdfjs' => 'ป้องการการดาวน์โหลด',
    'redirect_url' => 'เปลี่ยนเส้นทาง URL',
    'redirect_url_help' => 'ระบุ URL ที่จะเปลี่ยนเส้นทางไปยังหลังจากที่ป้อนการชำระเงิน',
    'save_draft' => 'บันทึกร่าง',
    'refunded_credit_payment' => 'การชำระคืนเงินคืน',
    'keyboard_shortcuts' => 'แป้นพิมพ์ลัด',
    'toggle_menu' => 'สลับเมนู',
    'new_...' => 'ใหม่...',
    'list_...' => 'รายละเอียด ...',
    'created_at' => 'Date Created',
    'contact_us' => 'ติดต่อเรา',
    'user_guide' => 'คู่มือผู้ใช้',
    'promo_message' => 'อัปเกรดก่อน :expire และรับ :amount ปีแรกของแพ็คเกจ Pro หรือ  Enterprise',
    'discount_message' => ':amount หมดอายุ :expires',
    'mark_paid' => 'ทำเครื่องว่าจ่ายเงินแล้ว',
    'marked_sent_invoice' => 'ทำเครื่องหมายใบแจ้งหนี้ที่ส่งเรียบร้อยแล้ว',
    'marked_sent_invoices' => 'ทำเครื่องหมายใบแจ้งหนี้ที่ส่งเรียบร้อยแล้ว',
    'invoice_name' => 'ใบแจ้งหนี้',
    'product_will_create' => 'สินค้าถูกสร้างขึ้น',
    'contact_us_response' => 'ขอบคุณสำหรับข้อความ! เราจะพยายามตอบกลับโดยเร็วที่สุด',
    'last_7_days' => '7 วันล่าสุด',
    'last_30_days' => '30 วันล่าสุด',
    'this_month' => 'เดือนนี้',
    'last_month' => 'เดือนล่าสุด',
    'current_quarter' => 'Current Quarter',
    'last_quarter' => 'Last Quarter',
    'last_year' => 'ปีล่าสุด',
    'custom_range' => 'ระบุช่วง',
    'url' => 'URL',
    'debug' => 'Debug',
    'https' => 'HTTPS',
    'require' => 'ต้องการ',
    'license_expiring' => 'หมายเหตุ: ใบอนุญาตของคุณจะหมดอายุลงใน :count วัน, :link เพื่อต่ออายุ',
    'security_confirmation' => 'ที่อยู่อีเมลของคุณได้รับการยืนยัน',
    'white_label_expired' => 'ใบอนุญาต White label ของคุณหมดอายุแล้วโปรดพิจารณาต่ออายุใบอนุญาตเพื่อช่วยสนับสนุนโครงการของเรา',
    'renew_license' => 'ต่ออายุไลเซน',
    'iphone_app_message' => 'ลองดาวน์โหลดเรา :link',
    'iphone_app' => 'ไอโฟน app',
    'android_app' => 'แอนดรอย app',
    'logged_in' => 'เข้าสู่ระบบ',
    'switch_to_primary' => 'เปลี่ยนไปใช้บริษัทหลักของคุณ (:name) เพื่อจัดการแผนของคุณ',
    'inclusive' => 'รวมทั้ง',
    'exclusive' => 'พิเศษ',
    'postal_city_state' => 'ไปรษณีย์ / เมือง / รัฐ',
    'phantomjs_help' => 'ในบางกรณีแอปจะใช้: link_phantom เพื่อสร้างไฟล์ PDF ติดตั้ง: link_docs เพื่อสร้างไฟล์ในเครื่อง',
    'phantomjs_local' => 'ใช้โปรแกรม PhantomJS ในเครื่อง',
    'client_number' => 'หมายเลขลูกค้า',
    'client_number_help' => 'ระบุคำนำหน้าหรือใช้รูปแบบที่กำหนดเองเพื่อตั้งค่าหมายเลขลูกค้าแบบไดนามิก',
    'next_client_number' => 'หมายเลขลูกค้ารายถัดไปคือ :number',
    'generated_numbers' => 'ตัวเลขที่สร้างขึ้น',
    'notes_reminder1' => 'คำเตือนครั้งแรก',
    'notes_reminder2' => 'คำเตือนครั้งที่สอง',
    'notes_reminder3' => 'คำเตือนที่สาม',
    'notes_reminder4' => 'Reminder',
    'bcc_email' => 'BCC Email',
    'tax_quote' => 'ใบเสนอราคาภาษี',
    'tax_invoice' => 'ใบแจ้งหนี้ภาษี',
    'emailed_invoices' => 'ส่งอีเมลใบแจ้งหนี้เรียบร้อยแล้ว',
    'emailed_quotes' => 'ส่งอีเมลใบเสนอราคาเรียบร้อยแล้ว',
    'website_url' => 'เว็บไซด์ URL',
    'domain' => 'โดเมน',
    'domain_help' => 'ใช้ในพอร์ทัลลูกค้าและเมื่อส่งอีเมล',
    'domain_help_website' => 'ใช้เมื่อส่งอีเมล',
    'import_invoices' => 'นำเข้าใบแจ้งหนี้',
    'new_report' => 'รายงานใหม่',
    'edit_report' => 'แก้ไขรายงาน',
    'columns' => 'คอลัม',
    'filters' => 'ฟิลเตอร์',
    'sort_by' => 'เรียงตาม',
    'draft' => 'ดราฟ',
    'unpaid' => 'ยังไม่จ่าย',
    'aging' => 'อายุลูกหนี้',
    'age' => 'อายุ',
    'days' => 'วัน',
    'age_group_0' => '0 - 30 วัน',
    'age_group_30' => '30 - 60 วัน',
    'age_group_60' => '60 - 90 วัน',
    'age_group_90' => '90 - 120 วัน',
    'age_group_120' => '120+ วัน',
    'invoice_details' => 'รายละเอียดใบแจ้งหนี้',
    'qty' => 'จำนวน',
    'profit_and_loss' => 'กำไรและขาดทุน',
    'revenue' => 'รายได้',
    'profit' => 'กำไร',
    'group_when_sorted' => 'Group Sort',
    'group_dates_by' => 'จัดกลุ่มตามวันที่',
    'year' => 'ปี',
    'view_statement' => 'ดูรายงาน',
    'statement' => 'รายงาน',
    'statement_date' => 'วัน รายงาน',
    'mark_active' => 'ทำเครื่องหมายว่าใช้งานอยู่',
    'send_automatically' => 'ส่งโดยอัตโนมัติ',
    'initial_email' => 'อีเมลเริ่มต้น',
    'invoice_not_emailed' => 'ยังไม่ได้ส่งใบแจ้งหนี้นี้ทางอีเมล',
    'quote_not_emailed' => 'ใบเสนอราคานี้ยังไม่ได้ส่งทางอีเมล',
    'sent_by' => 'ส่งโดย :user',
    'recipients' => 'ผู้รับ',
    'save_as_default' => 'บันทึกเป็นค่าเริ่มต้น',
    'start_of_week_help' => 'ใช้โดย <b>วันที่</b>ถูกเลือก',
    'financial_year_start_help' => 'ใช้โดย <b>ช่วงวันที่</b>ถูกเลือก',
    'reports_help' => 'Shift + Click to sort by multiple columns, Ctrl + Click to clear the grouping.',
    'this_year' => 'ปีนี้',

    // Updated login screen
    'ninja_tagline' => 'สร้าง. ส่ง. รับเงิน',
    'login_or_existing' => 'Or login with a connected account.',
    'sign_up_now' => 'สมัครตอนนี้เลย',
    'not_a_member_yet' => 'ยังไม่เป็นสมาชิก',
    'login_create_an_account' => 'สร้างบัญชี!',

    // New Client Portal styling
    'invoice_from' => 'ใบแจ้งหนี้จาก:',
    'email_alias_message' => 'เราต้องการให้ บริษัท แต่ละแห่งมีที่อยู่อีเมลที่ไม่ซ้ำกัน.<br/>พิจารณาใช้นามแฝง เช่น email+label@example.com',
    'full_name' => 'ชื่อเต็ม',
    'month_year' => 'เดือน/ปี',
    'valid_thru' => 'Valid\nthru',

    'product_fields' => 'ข้อมูลสินค้า',
    'custom_product_fields_help' => 'เพิ่มฟิลด์เมื่อสร้างใบเสนอราคาหรือใบแจ้งหนี้และแสดงฉลากและมูลค่าใน PDF',
    'freq_two_months' => '2 เดือน',
    'freq_yearly' => 'ประจำปี',
    'profile' => 'ข้อมูลส่วนตัว',
    'payment_type_help' => 'ตั้งค่าเริ่มต้น <b>ประเภทการชำระเงินด้วยตนเอง</b>.',
    'industry_Construction' => 'การสร้าง',
    'your_statement' => 'Statement ของคุณ',
    'statement_issued_to' => 'Statement ออกให้',
    'statement_to' => 'Statement ไปยัง',
    'customize_options' => 'กำหนดค่าตัวเลือก',
    'created_payment_term' => 'สร้างเงื่อนไขการชำระเงินเรียบร้อยแล้ว',
    'updated_payment_term' => 'อัปเดตเงื่อนไขการชำระเงินเรียบร้อยแล้ว',
    'archived_payment_term' => 'เก็บบันทึกระยะเวลาการชำระเงินเรียบร้อยแล้ว',
    'resend_invite' => 'ส่งคำเชิญอีกครั้ง',
    'credit_created_by' => 'เครดิตที่สร้างโดยการชำระเงิน :transaction_reference',
    'created_payment_and_credit' => 'สร้างการชำระเงินและเครดิตเรียบร้อยแล้ว',
    'created_payment_and_credit_emailed_client' => 'สร้างการชำระเงินและเครดิตและส่งอีเมลเรียบร้อยแล้ว',
    'create_project' => 'สร้างโครงการ',
    'create_vendor' => 'สร้างผู้ขาย',
    'create_expense_category' => 'สร้างหมวดหมู่',
    'pro_plan_reports' => ':link เพื่อเปิดใช้รายงานโดยเข้าร่วม Pro Plan',
    'mark_ready' => 'ทำเครื่องหมายเรียบร้อย',

    'limits' => 'จำกัด',
    'fees' => 'ค่าธรรมเนียม',
    'fee' => 'ค่าธรรมเนียม',
    'set_limits_fees' => 'Set :gateway_type จำกัด / ค่าธรรมเนียม',
    'fees_tax_help' => 'เปิดใช้รายการภาษีเพื่อกำหนดอัตราภาษีค่าธรรมเนียม',
    'fees_sample' => 'ค่าธรรมเนียมสำหรับ :amount  ใบแจ้งหนี้จะเป็น :total.',
    'discount_sample' => 'ส่วนลดสำหรับ :amount ใบแจ้งหนี้จะเป็น :total.',
    'no_fees' => 'ไม่มีค่าธรรมเนียม',
    'gateway_fees_disclaimer' => 'คำเตือน: ไม่ใช่ทุกรัฐ / เกตเวย์การชำระเงินอนุญาตให้มีการเพิ่มค่าธรรมเนียมโปรดทบทวนกฎหมายท้องถิ่น / ข้อกำหนดในการให้บริการ',
    'percent' => 'เปอร์เซนต์',
    'location' => 'ตำแหน่ง',
    'line_item' => 'รายการ',
    'surcharge' => 'คิดค่าใช้จ่าย',
    'location_first_surcharge' => 'เปิดใช้งาน - คิดค่าบริการครั้งแรก',
    'location_second_surcharge' => 'เปิดใช้งาน - คิดค่าธรรมเนียมครั้งที่สอง',
    'location_line_item' => 'เปิดใช้งาน - รายการ',
    'online_payment_surcharge' => 'ชำระเงินออนไลน์',
    'gateway_fees' => 'ค่าธรรมเนียมการชำระเงิน',
    'fees_disabled' => 'ปิดใช้ค่าธรรมเนียม',
    'gateway_fees_help' => 'เพิ่มส่วนลด / ส่วนลดการชำระเงินออนไลน์โดยอัตโนมัติ',
    'gateway' => 'เกตเวย์',
    'gateway_fee_change_warning' => 'หากมีใบแจ้งหนี้ค้างชำระพร้อมค่าธรรมเนียมพวกเขาจะต้องได้รับการอัปเดตด้วยตนเอง',
    'fees_surcharge_help' => 'กำหนดค่าบริการเพิ่มเติม :link.',
    'label_and_taxes' => 'ฉลากและภาษี',
    'billable' => 'ที่เรียกเก็บเงิน',
    'logo_warning_too_large' => 'ไฟล์รูปภาพมีขนาดใหญ่เกินไป',
    'logo_warning_fileinfo' => 'คำเตือน: ในการสนับสนุน gifs จำเป็นต้องเปิดใช้ส่วนขยายของไฟล์ info PHP',
    'logo_warning_invalid' => 'เกิดปัญหาในการอ่านไฟล์รูปภาพกรุณาลองใช้รูปแบบอื่น',

    'error_refresh_page' => 'เกิดข้อผิดพลาดขึ้นโปรดรีเฟรชหน้าเว็บและลองอีกครั้ง',
    'data' => 'ข้อมูล',
    'imported_settings' => 'การตั้งค่าการนำเข้าสำเร็จ',
    'reset_counter' => 'รีเซ็ตตัวนับ',
    'next_reset' => 'รีเซ็ตครั้งต่อไป',
    'reset_counter_help' => 'รีเซ็ตเคาน์เตอร์ใบแจ้งหนี้และใบเสนอราคาโดยอัตโนมัติ',
    'auto_bill_failed' => 'การเรียกเก็บเงินอัตโนมัติสำหรับใบแจ้งหนี้ :invoice_number ล้มเหลว',
    'online_payment_discount' => 'ส่วนลดการชำระเงินออนไลน์',
    'created_new_company' => 'สร้างบริษัทใหม่เรียบร้อยแล้ว',
    'fees_disabled_for_gateway' => 'ค่าธรรมเนียมถูกปิดใช้งานสำหรับเกตเวย์นี้.',
    'logout_and_delete' => 'ออกจากระบบ / ลบบัญชี',
    'tax_rate_type_help' => 'Inclusive tax rates adjust the line item cost when selected.<br/>Only exclusive tax rates can be used as a default.',
    'invoice_footer_help' => 'ใช้ $pageNumber และ $pageCount เพื่อแสดงข้อมูล',
    'credit_note' => 'ใบลดหนี้',
    'credit_issued_to' => 'เครดิตที่ออกให้',
    'credit_to' => 'เครดิตไปที่',
    'your_credit' => 'เครดิตของคุณ',
    'credit_number' => 'หมายเลขเครดิต',
    'create_credit_note' => 'สร้างใบลดหนี้',
    'menu' => 'เมนู',
    'error_incorrect_gateway_ids' => 'ข้อผิดพลาด: ตารางเกตเวย์มีรหัสไม่ถูกต้อง',
    'purge_data' => 'ล้างข้อมูล',
    'delete_data' => 'ลบข้อมูล',
    'purge_data_help' => 'Permanently delete all data but keep the account and settings.',
    'cancel_account_help' => 'ลบบัญชีทั้งหมดพร้อมกับข้อมูลและการตั้งค่าทั้งหมด',
    'purge_successful' => 'Successfully purged company data',
    'forbidden' => 'หวงห้าม',
    'purge_data_message' => 'คำเตือน: การดำเนินการนี้จะลบข้อมูลของคุณอย่างถาวรและไม่สามารถนำคืนกลับมาได้',
    'contact_phone' => 'โทรศัพท์ติดต่อ',
    'contact_email' => 'ติดต่ออีเมล์',
    'reply_to_email' => 'ตอบกลับอีเมล',
    'reply_to_email_help' => 'ระบุที่อยู่ตอบกลับสำหรับอีเมลลูกค้า',
    'bcc_email_help' => 'ใส่ที่อยู่นี้ด้วยอีเมลลูกค้า',
    'import_complete' => 'การนำเข้าของคุณเสร็จสมบูรณ์แล้ว',
    'confirm_account_to_import' => 'โปรดยืนยันบัญชีของคุณเพื่อนำเข้าข้อมูล',
    'import_started' => 'การนำเข้าของคุณได้เริ่มขึ้นแล้วเราจะส่งอีเมลถึงคุณเมื่อเสร็จสิ้น',
    'listening' => 'กำลังฟัง',
    'microphone_help' => 'พูดว่า "new invoice for [client]"  หรือ "show me [client]\'s archived payments"',
    'voice_commands' => 'คำสั่งเสียง',
    'sample_commands' => 'คำสั่งตัวอย่าง',
    'voice_commands_feedback' => 'เรากำลังทำงานอย่างเต็มที่เพื่อปรับปรุงคุณลักษณะนี้ถ้ามีคำสั่งที่คุณต้องการให้เราสนับสนุนเพิ่มเติมโปรดส่งอีเมลถึงเราที่ :email.',
    'payment_type_Venmo' => 'Venmo',
    'payment_type_Money Order' => 'Money Order',
    'archived_products' => 'เก็บบันทึก :count สินค้า',
    'recommend_on' => 'เราแนะนำ <b>เปิดการใช้งาน</b>การตั้งค่านี้',
    'recommend_off' => 'เราแนะนำ <b>ปิดการใช้งาน</b>การตั้งค่านี้',
    'notes_auto_billed' => 'Auto-billed',
    'surcharge_label' => 'ป้ายค่าบริการ',
    'contact_fields' => 'ฟิลด์ติดต่อ',
    'custom_contact_fields_help' => 'เพิ่มช่องเมื่อสร้างผู้ติดต่อและเลือกแสดงป้ายกำกับและค่าใน PDF.',
    'datatable_info' => 'กำลังแสดง :start ถึง :end ของ :total รายการ',
    'credit_total' => 'เครดิตทั้งหมด',
    'mark_billable' => 'Mark billable ',
    'billed' => 'การเรียกเก็บเงิน',
    'company_variables' => 'ตัวแปรบริษัท',
    'client_variables' => 'ตัวแปรผู้ใช้',
    'invoice_variables' => 'ตัวแปรใบแจ้งหนี้',
    'navigation_variables' => 'ตัวแปนการนำทาง',
    'custom_variables' => 'ตัวแปรการปรับแต่ง',
    'invalid_file' => 'ชนิดไฟล์ไม่ถูกต้อง',
    'add_documents_to_invoice' => 'เพิ่มเอกสารลงในใบแจ้งหนี้',
    'mark_expense_paid' => 'ทำเครื่องหมายว่าจ่ายแล้ว',
    'white_label_license_error' => 'ไม่สามารถตรวจสอบความถูกต้องของใบอนุญาตตรวจสอบพื้นที่จัดเก็บ / logs / laravel-error.log สำหรับรายละเอียดเพิ่มเติม',
    'plan_price' => 'ราคา Plan',
    'wrong_confirmation' => 'รหัสยืนยันไม่ถูกต้อง',
    'oauth_taken' => 'มีการลงทะเบียนบัญชีแล้ว',
    'emailed_payment' => 'ส่งอีเมลเรียบร้อยแล้ว',
    'email_payment' => 'การชำระเงินทางอีเมล',
    'invoiceplane_import' => 'ใช้ :link เพื่อย้ายข้อมูลของคุณจาก InvoicePlane',
    'duplicate_expense_warning' => 'คำเตือน:  :link นี้อาจซ้ำซ้อน',
    'expense_link' => 'ค่าใช้จ่าย',
    'resume_task' => 'ทำงานต่อ',
    'resumed_task' => 'ทำงานต่อสำเร็จ',
    'quote_design' => 'ออกแบบใบเสนอราคา',
    'default_design' => 'การออกแบบมาตรฐาน',
    'custom_design1' => 'ปรับแต่งการออกแบบ 1',
    'custom_design2' => 'ปรับแต่งการออกแบบ 2',
    'custom_design3' => 'ปรับแต่งการออกแบบ 3',
    'empty' => 'ว่าง',
    'load_design' => 'โหลดการออกแบบ',
    'accepted_card_logos' => 'ยอมรับโลโก้ของบัตร',
    'phantomjs_local_and_cloud' => 'ใช้ PhantomJS ใน localhost กลับไปที่ phantomjscloud.com',
    'google_analytics' => 'Google Analytics',
    'analytics_key' => 'Analytics Key',
    'analytics_key_help' => 'ติดตามการชำระเงินโดยใช้ :link',
    'start_date_required' => 'ต้องระบุวันที่เริ่มต้น',
    'application_settings' => 'การตั้งค่าโปรแกรม',
    'database_connection' => 'การเชื่อมต่อดาต้าเบส',
    'driver' => 'Driver',
    'host' => 'Host',
    'database' => 'Database',
    'test_connection' => 'ทดสอบการเชื่อมต่อ',
    'from_name' => 'จากชื่อ',
    'from_address' => 'จากที่อยู่',
    'port' => 'Port',
    'encryption' => 'การเข้ารหัส',
    'mailgun_domain' => 'Mailgun Domain',
    'mailgun_private_key' => 'Mailgun Private Key',
    'send_test_email' => 'ส่งอีเมล์ทดสอบ',
    'select_label' => 'เลือกป้ายกำกับ',
    'label' => 'ป้ายกำกับ',
    'service' => 'การบริการ',
    'update_payment_details' => 'อัปเดตรายละเอียดการชำระเงิน',
    'updated_payment_details' => 'อัปเดตรายละเอียดการชำระเงินสำเร็จแล้ว',
    'update_credit_card' => 'อัปเดตบัตรเครดิต',
    'recurring_expenses' => 'ค่าใช้จ่ายที่เกิดขึ้นประจำ',
    'recurring_expense' => 'Recurring Expense',
    'new_recurring_expense' => 'ค่าใช้จ่ายที่เกิดซ้ำใหม่',
    'edit_recurring_expense' => 'แก้ไขค่าใช้จ่ายที่เกิดประจำ',
    'archive_recurring_expense' => 'เก็บข้อมูลค่าใช้จ่ายที่เกิดขึ้นประจำ',
    'list_recurring_expense' => 'เรียกรายการค่าใช้จ่ายที่เกิดขึ้นประจำ',
    'updated_recurring_expense' => 'อัปเดตค่าใช้จ่ายที่เกิดขึ้นประจำแล้ว',
    'created_recurring_expense' => 'สร้างค่าใช้จ่ายที่เกิดขึ้นประจำแล้ว',
    'archived_recurring_expense' => 'เก็บข้อมูลค่าใช้จ่ายที่เกิดขึ้นประจำ',
    'restore_recurring_expense' => 'เรียกคืนค่าใช้จ่ายที่เกิดประจำ',
    'restored_recurring_expense' => 'กู้คืนค่าใช้จ่ายที่เกิดขึ้นแล้ว',
    'delete_recurring_expense' => 'ลบค่าใช้จ่ายที่เกิดประจำ',
    'deleted_recurring_expense' => 'ลบโครงการเรียบร้อยแล้ว',
    'view_recurring_expense' => 'ดูค่าใช้จ่ายที่เกิดขึ้นประจำ',
    'taxes_and_fees' => 'ภาษีและค่าธรรมเนียม',
    'import_failed' => 'การนำเข้าล้มเหลว',
    'recurring_prefix' => 'คำนำหน้า ที่เกิดขึ้นประจำ',
    'options' => 'ตัวเลือก',
    'credit_number_help' => 'ระบุคำนำหน้าหรือใช้รูปแบบที่กำหนดเองเพื่อตั้งค่าหมายเลขเครดิตสำหรับใบแจ้งหนี้เชิงลบ',
    'next_credit_number' => 'หมายเลขเครดิตถัดไปคือ :number',
    'padding_help' => 'จำนวนเลขศูนย์ใส่ในหมายเลขบัตร',
    'import_warning_invalid_date' => 'คำเตือน: รูปแบบวันที่ดูเหมือนจะไม่ถูกต้อง',
    'product_notes' => 'หมายเหตุผลิตภัณฑ์',
    'app_version' => 'เวอร์ชัน app ',
    'ofx_version' => 'เวอร์ชัน OFX',
    'gateway_help_23' => ':link เพื่อรับคีย์ API Stripe ของคุณ',
    'error_app_key_set_to_default' => 'ข้อผิดพลาด: APP_KEY ถูกตั้งค่าเป็นค่าดีฟอลต์เพื่ออัพเดตข้อมูลสำรองฐานข้อมูลของคุณและเรียกใช้ <code>php artisan ninja:update-key</code>',
    'charge_late_fee' => 'ค่าปรับล่าช้า',
    'late_fee_amount' => 'ค่าปรับล่าช้าจำนวน',
    'late_fee_percent' => 'ค่าปรับล่าช้าเป็นเปอร์เซนต์',
    'late_fee_added' => 'ค่าปรับล่าช้าเพิ่ม :วัน',
    'download_invoice' => 'ดาวน์โหลดใบแจ้งหนี้',
    'download_quote' => 'ดาวน์โหลดใบเสนอราคา',
    'invoices_are_attached' => 'ใบแจ้งหนี้ไฟล์ PDF ได้ถูกเพิ่ม',
    'downloaded_invoice' => 'อีเมล์จะถูกส่งไปพร้อมกับไฟล์ PDF ใบแจ้งหนี้',
    'downloaded_quote' => 'อีเมล์จะถูกส่งไปพร้อมกับไฟล์ PDF ใบเสนอราคา',
    'downloaded_invoices' => 'อีเมล์จะถูกส่งไปพร้อมกับไฟล์ PDF ใบแจ้งหนี้',
    'downloaded_quotes' => 'อีเมล์จะถูกส่งไปพร้อมกับไฟล์ PDF ใบเสนอราคา',
    'clone_expense' => 'ลอกแบบค่าใช้จ่าย',
    'default_documents' => 'เอกสารเริ่มต้น',
    'send_email_to_client' => 'ส่งอีเมล์ให้ลูกค้า',
    'refund_subject' => 'กระบวนการขอคืนเงิน',
    'refund_body' => 'คุณได้รับการดำเนินการคืนเงิน: จำนวนเงินสำหรับใบแจ้งหนี้: หมายเลขใบแจ้งหนี้.',

    'currency_us_dollar' => 'ดอลลาร์',
    'currency_british_pound' => 'ปอนด์อังกฤษ',
    'currency_euro' => 'ยูโร',
    'currency_south_african_rand' => 'แอฟริกาใต้ แรน',
    'currency_danish_krone' => 'เดนิส โครน',
    'currency_israeli_shekel' => 'อิสราเอล ชีเกล',
    'currency_swedish_krona' => 'สวีเดน โครนา',
    'currency_kenyan_shilling' => 'เคนยา ชิลลิ่ง',
    'currency_canadian_dollar' => 'แคนนาดา ดอลลาร์',
    'currency_philippine_peso' => 'ฟิลิปปินส์ เปโซ',
    'currency_indian_rupee' => 'อินเดีย รูปี',
    'currency_australian_dollar' => 'ออสเตรเลีย ดอลลาร์',
    'currency_singapore_dollar' => 'สิงคโปร์ ดอลลาห์',
    'currency_norske_kroner' => 'นอร์เวย์ โครเนอร์',
    'currency_new_zealand_dollar' => 'นิวซีแลนด์ ดอลลาห์',
    'currency_vietnamese_dong' => 'เวียดนาม ดอง',
    'currency_swiss_franc' => 'สวิช ฟรังค์',
    'currency_guatemalan_quetzal' => 'กัวเตมาลา เควตซัล',
    'currency_malaysian_ringgit' => 'มาเลเซีย ริงกิต',
    'currency_brazilian_real' => 'บราซิล รีล',
    'currency_thai_baht' => 'ไทย บาท',
    'currency_nigerian_naira' => 'ไนจีเรีย ไนรา',
    'currency_argentine_peso' => 'อาร์เจตินา เปโซ',
    'currency_bangladeshi_taka' => 'บังกลาเทศ ทากา',
    'currency_united_arab_emirates_dirham' => 'อาหรับเอมีเรต เดอร์แฮม',
    'currency_hong_kong_dollar' => 'ฮ่องกง ดอลลาห์',
    'currency_indonesian_rupiah' => 'อินโดนีเซีย รูเปียะ',
    'currency_mexican_peso' => 'แมกซิกัน เปโซ',
    'currency_egyptian_pound' => 'อียิปต์ ปอนด์',
    'currency_colombian_peso' => 'โคลัมเบีย เปโซ',
    'currency_west_african_franc' => 'แอฟริกาตะวันออก ฟรังค์',
    'currency_chinese_renminbi' => 'จีน หยวน',
    'currency_rwandan_franc' => 'รวันดา ฟรังค์',
    'currency_tanzanian_shilling' => 'แทนซาเนีย ชิลลิ่ง',
    'currency_netherlands_antillean_guilder' => 'เนเธอร์แลนด์ กิลเดอร์',
    'currency_trinidad_and_tobago_dollar' => 'ตรินิแดด และ โทบาโก ดอลลาห์',
    'currency_east_caribbean_dollar' => 'คาริเบียนตะวันตก ดอลลาร์',
    'currency_ghanaian_cedi' => 'กานาร์ เซดิ',
    'currency_bulgarian_lev' => 'บัลกาเรีย เลฟ',
    'currency_aruban_florin' => 'อารูบา ฟลอริน',
    'currency_turkish_lira' => 'ตุรกี ลีรา',
    'currency_romanian_new_leu' => 'โรมาเนีย ลิว',
    'currency_croatian_kuna' => 'โครเอเชีย กูนา',
    'currency_saudi_riyal' => 'ซาอุ รียัล',
    'currency_japanese_yen' => 'ญี่ปุ่น เยน',
    'currency_maldivian_rufiyaa' => 'มัลดีฟ รูฟียา',
    'currency_costa_rican_colon' => 'Costa Rican Colón',
    'currency_pakistani_rupee' => 'ปากีสถาน รูปี',
    'currency_polish_zloty' => 'โปแลนด์ สลอตตี้',
    'currency_sri_lankan_rupee' => 'ศรีลังกา รูปี',
    'currency_czech_koruna' => 'เชค โครูนา',
    'currency_uruguayan_peso' => 'อุรุกวัย เปโซ',
    'currency_namibian_dollar' => 'นามิเบีย ดอลลาห์',
    'currency_tunisian_dinar' => 'ตูนีเซีย ดีนา',
    'currency_russian_ruble' => 'รัสเซีย รูเบิล',
    'currency_mozambican_metical' => 'โมซัมบิก เมติคัล',
    'currency_omani_rial' => 'โอมาน เรียลโอมาน',
    'currency_ukrainian_hryvnia' => 'ยูเครน ฮรีฟเนียยูเครน',
    'currency_macanese_pataca' => 'มาเก๊า ปาตากา',
    'currency_taiwan_new_dollar' => 'ไต้หวัน ดอลลาร์ใหม่ไต้หวัน',
    'currency_dominican_peso' => 'โดมินิกัน เปโซโดมินิกัน',
    'currency_chilean_peso' => 'ชิลี เปโซชิลี',
    'currency_icelandic_krona' => 'Icelandic Króna',
    'currency_papua_new_guinean_kina' => 'ปาปัวนิวกีนี  กีนา',
    'currency_jordanian_dinar' => 'จอร์แดน ดีนาร์จอร์แดน',
    'currency_myanmar_kyat' => 'พม่า จัตพม่า',
    'currency_peruvian_sol' => 'เปรู นูโวซอล',
    'currency_botswana_pula' => 'Botswana Pula',
    'currency_hungarian_forint' => 'Hungarian Forint',
    'currency_ugandan_shilling' => 'Ugandan Shilling',
    'currency_barbadian_dollar' => 'Barbadian Dollar',
    'currency_brunei_dollar' => 'Brunei Dollar',
    'currency_georgian_lari' => 'Georgian Lari',
    'currency_qatari_riyal' => 'Qatari Riyal',
    'currency_honduran_lempira' => 'Honduran Lempira',
    'currency_surinamese_dollar' => 'Surinamese Dollar',
    'currency_bahraini_dinar' => 'Bahraini Dinar',
    'currency_venezuelan_bolivars' => 'Venezuelan Bolivars',
    'currency_south_korean_won' => 'South Korean Won',
    'currency_moroccan_dirham' => 'Moroccan Dirham',
    'currency_jamaican_dollar' => 'Jamaican Dollar',
    'currency_angolan_kwanza' => 'Angolan Kwanza',
    'currency_haitian_gourde' => 'Haitian Gourde',
    'currency_zambian_kwacha' => 'Zambian Kwacha',
    'currency_nepalese_rupee' => 'Nepalese Rupee',
    'currency_cfp_franc' => 'CFP Franc',
    'currency_mauritian_rupee' => 'Mauritian Rupee',
    'currency_cape_verdean_escudo' => 'Cape Verdean Escudo',
    'currency_kuwaiti_dinar' => 'Kuwaiti Dinar',
    'currency_algerian_dinar' => 'Algerian Dinar',
    'currency_macedonian_denar' => 'Macedonian Denar',
    'currency_fijian_dollar' => 'Fijian Dollar',
    'currency_bolivian_boliviano' => 'Bolivian Boliviano',
    'currency_albanian_lek' => 'Albanian Lek',
    'currency_serbian_dinar' => 'Serbian Dinar',
    'currency_lebanese_pound' => 'Lebanese Pound',
    'currency_armenian_dram' => 'Armenian Dram',
    'currency_azerbaijan_manat' => 'Azerbaijan Manat',
    'currency_bosnia_and_herzegovina_convertible_mark' => 'Bosnia and Herzegovina Convertible Mark',
    'currency_belarusian_ruble' => 'Belarusian Ruble',
    'currency_moldovan_leu' => 'Moldovan Leu',
    'currency_kazakhstani_tenge' => 'Kazakhstani Tenge',
    'currency_gibraltar_pound' => 'Gibraltar Pound',

    'review_app_help' => 'We hope you\'re enjoying using the app.<br/>If you\'d consider :link we\'d greatly appreciate it!',
    'writing_a_review' => 'writing a review',

    'use_english_version' => 'คุณแน่ใจว่าใช้ไฟล์นี้ด้วยภาษาอังกฤษ.<br/>เราใช้คอลัมนี้เพื่อให้ตรงกับช่องที่กำหนด',
    'tax1' => 'ภาษีส่วนที่หนึ่ง',
    'tax2' => 'ภาษีส่วนที่สอง',
    'fee_help' => 'ค่าใช้จ่ายที่เกิดขึ้นขึ้นอยู่กับสถาบันการเงินที่ใช้ชำระ',
    'format_export' => 'ไฟล์ที่ส่งออก',
    'custom1' => 'กำหนดเองครั้งแรก',
    'custom2' => 'กำหนดเองครั้งที่สอง',
    'contact_first_name' => 'ชื่อที่ติดต่อ',
    'contact_last_name' => 'นามสกุลที่ติดต่อ',
    'contact_custom1' => 'ติดต่อกำหนดเองแบบที่หนึ่ง',
    'contact_custom2' => 'ติดต่อกำหนดเองแบบที่สอง',
    'currency' => 'สกุลเงิน',
    'ofx_help' => 'To troubleshoot check for comments on :ofxhome_link and test with :ofxget_link.',
    'comments' => 'comments',

    'item_product' => 'Item Product',
    'item_notes' => 'Item Notes',
    'item_cost' => 'Item Cost',
    'item_quantity' => 'Item Quantity',
    'item_tax_rate' => 'Item Tax Rate',
    'item_tax_name' => 'Item Tax Name',
    'item_tax1' => 'Item Tax1',
    'item_tax2' => 'Item Tax2',

    'delete_company' => 'Delete Company',
    'delete_company_help' => 'Permanently delete the company along with all data and setting.',
    'delete_company_message' => 'Warning: This will permanently delete your company, there is no undo.',

    'applied_discount' => 'The coupon has been applied, the plan price has been reduced by :discount%.',
    'applied_free_year' => 'The coupon has been applied, your account has been upgraded to pro for one year.',

    'contact_us_help' => 'If you\'re reporting an error please include any relevant logs from storage/logs/laravel-error.log',
    'include_errors' => 'Include Errors',
    'include_errors_help' => 'Include :link from storage/logs/laravel-error.log',
    'recent_errors' => 'recent errors',
    'customer' => 'Customer',
    'customers' => 'Customers',
    'created_customer' => 'Successfully created customer',
    'created_customers' => 'Successfully created :count customers',

    'purge_details' => 'The data in your company (:account) has been successfully purged.',
    'deleted_company' => 'Successfully deleted company',
    'deleted_account' => 'Successfully canceled account',
    'deleted_company_details' => 'Your company (:account) has been successfully deleted.',
    'deleted_account_details' => 'Your account (:account) has been successfully deleted.',

    'alipay' => 'Alipay',
    'sofort' => 'Sofort',
    'sepa' => 'SEPA Direct Debit',
    'enable_alipay' => 'Accept Alipay',
    'enable_sofort' => 'Accept EU bank transfers',
    'stripe_alipay_help' => 'These gateways also need to be activated in :link.',
    'calendar' => 'Calendar',
    'pro_plan_calendar' => ':link to enable the calendar by joining the Pro Plan',

    'what_are_you_working_on' => 'What are you working on?',
    'time_tracker' => 'Time Tracker',
    'refresh' => 'Refresh',
    'filter_sort' => 'Filter/Sort',
    'no_description' => 'No Description',
    'time_tracker_login' => 'Time Tracker Login',
    'save_or_discard' => 'Save or discard your changes',
    'discard_changes' => 'Discard Changes',
    'tasks_not_enabled' => 'Tasks are not enabled.',
    'started_task' => 'Successfully started task',
    'create_client' => 'Create Client',

    'download_desktop_app' => 'Download the desktop app',
    'download_iphone_app' => 'Download the iPhone app',
    'download_android_app' => 'Download the Android app',
    'time_tracker_mobile_help' => 'Double tap a task to select it',
    'stopped' => 'Stopped',
    'ascending' => 'Ascending',
    'descending' => 'Descending',
    'sort_field' => 'Sort By',
    'sort_direction' => 'Direction',
    'discard' => 'Discard',
    'time_am' => 'AM',
    'time_pm' => 'PM',
    'time_mins' => 'mins',
    'time_hr' => 'hr',
    'time_hrs' => 'hrs',
    'clear' => 'Clear',
    'warn_payment_gateway' => 'Note: accepting online payments requires a payment gateway, :link to add one.',
    'task_rate' => 'Task Rate',
    'task_rate_help' => 'Set the default rate for invoiced tasks.',
    'past_due' => 'Past Due',
    'document' => 'Document',
    'invoice_or_expense' => 'Invoice/Expense',
    'invoice_pdfs' => 'Invoice PDFs',
    'enable_sepa' => 'Accept SEPA',
    'enable_bitcoin' => 'Accept Bitcoin',
    'iban' => 'IBAN',
    'sepa_authorization' => 'By providing your IBAN and confirming this payment, you are authorizing :company and Stripe, our payment service provider, to send instructions to your bank to debit your account and your bank to debit your account in accordance with those instructions. You are entitled to a refund from your bank under the terms and conditions of your agreement with your bank. A refund must be claimed within 8 weeks starting from the date on which your account was debited.',
    'recover_license' => 'Recover License',
    'purchase' => 'Purchase',
    'recover' => 'Recover',
    'apply' => 'Apply',
    'recover_white_label_header' => 'Recover White Label License',
    'apply_white_label_header' => 'Apply White Label License',
    'videos' => 'Videos',
    'video' => 'Video',
    'return_to_invoice' => 'Return to Invoice',
    'gateway_help_13' => 'To use ITN leave the PDT Key field blank.',
    'partial_due_date' => 'Partial Due Date',
    'task_fields' => 'Task Fields',
    'product_fields_help' => 'Drag and drop fields to change their order',
    'custom_value1' => 'Custom Value',
    'custom_value2' => 'Custom Value',
    'enable_two_factor' => 'Two-Factor Authentication',
    'enable_two_factor_help' => 'Use your phone to confirm your identity when logging in',
    'two_factor_setup' => 'Two-Factor Setup',
    'two_factor_setup_help' => 'Scan the bar code with a :link compatible app.',
    'one_time_password' => 'One Time Password',
    'set_phone_for_two_factor' => 'Set your mobile phone number as a backup to enable.',
    'enabled_two_factor' => 'Successfully enabled Two-Factor Authentication',
    'add_product' => 'Add Product',
    'email_will_be_sent_on' => 'Note: the email will be sent on :date.',
    'invoice_product' => 'Invoice Product',
    'self_host_login' => 'Self-Host Login',
    'set_self_hoat_url' => 'Self-Host URL',
    'local_storage_required' => 'Error: local storage is not available.',
    'your_password_reset_link' => 'Your Password Reset Link',
    'subdomain_taken' => 'The subdomain is already in use',
    'client_login' => 'เข้าสู่ระบบลูกค้า',
    'converted_amount' => 'Converted Amount',
    'default' => 'Default',
    'shipping_address' => 'Shipping Address',
    'bllling_address' => 'Billing Address',
    'billing_address1' => 'Billing Street',
    'billing_address2' => 'Billing Apt/Suite',
    'billing_city' => 'Billing City',
    'billing_state' => 'Billing State/Province',
    'billing_postal_code' => 'Billing Postal Code',
    'billing_country' => 'Billing Country',
    'shipping_address1' => 'Shipping Street',
    'shipping_address2' => 'Shipping Apt/Suite',
    'shipping_city' => 'Shipping City',
    'shipping_state' => 'Shipping State/Province',
    'shipping_postal_code' => 'Shipping Postal Code',
    'shipping_country' => 'Shipping Country',
    'classify' => 'Classify',
    'show_shipping_address_help' => 'Require client to provide their shipping address',
    'ship_to_billing_address' => 'Ship to billing address',
    'delivery_note' => 'Delivery Note',
    'show_tasks_in_portal' => 'Show tasks in the client portal',
    'cancel_schedule' => 'Cancel Schedule',
    'scheduled_report' => 'Scheduled Report',
    'scheduled_report_help' => 'Email the :report report as :format to :email',
    'created_scheduled_report' => 'Successfully scheduled report',
    'deleted_scheduled_report' => 'Successfully canceled scheduled report',
    'scheduled_report_attached' => 'Your scheduled :type report is attached.',
    'scheduled_report_error' => 'Failed to create schedule report',
    'invalid_one_time_password' => 'Invalid one time password',
    'apple_pay' => 'Apple/Google Pay',
    'enable_apple_pay' => 'Accept Apple Pay and Pay with Google',
    'requires_subdomain' => 'This payment type requires that a :link.',
    'subdomain_is_set' => 'subdomain is set',
    'verification_file' => 'Verification File',
    'verification_file_missing' => 'The verification file is needed to accept payments.',
    'apple_pay_domain' => 'Use <code>:domain</code> as the domain in :link.',
    'apple_pay_not_supported' => 'Sorry, Apple/Google Pay isn\'t supported by your browser',
    'optional_payment_methods' => 'Optional Payment Methods',
    'add_subscription' => 'Add Subscription',
    'target_url' => 'Target',
    'target_url_help' => 'When the selected event occurs the app will post the entity to the target URL.',
    'event' => 'Event',
    'subscription_event_1' => 'Created Client',
    'subscription_event_2' => 'Created Invoice',
    'subscription_event_3' => 'Created Quote',
    'subscription_event_4' => 'Created Payment',
    'subscription_event_5' => 'Created Vendor',
    'subscription_event_6' => 'Updated Quote',
    'subscription_event_7' => 'Deleted Quote',
    'subscription_event_8' => 'Updated Invoice',
    'subscription_event_9' => 'Deleted Invoice',
    'subscription_event_10' => 'Updated Client',
    'subscription_event_11' => 'Deleted Client',
    'subscription_event_12' => 'Deleted Payment',
    'subscription_event_13' => 'Updated Vendor',
    'subscription_event_14' => 'Deleted Vendor',
    'subscription_event_15' => 'Created Expense',
    'subscription_event_16' => 'Updated Expense',
    'subscription_event_17' => 'Deleted Expense',
    'subscription_event_18' => 'Created Task',
    'subscription_event_19' => 'Updated Task',
    'subscription_event_20' => 'Deleted Task',
    'subscription_event_21' => 'Approved Quote',
    'subscriptions' => 'Subscriptions',
    'updated_subscription' => 'Successfully updated subscription',
    'created_subscription' => 'Successfully created subscription',
    'edit_subscription' => 'Edit Subscription',
    'archive_subscription' => 'Archive Subscription',
    'archived_subscription' => 'Successfully archived subscription',
    'project_error_multiple_clients' => 'The projects can\'t belong to different clients',
    'invoice_project' => 'Invoice Project',
    'module_recurring_invoice' => 'Recurring Invoices',
    'module_credit' => 'Credits',
    'module_quote' => 'Quotes & Proposals',
    'module_task' => 'Tasks & Projects',
    'module_expense' => 'Expenses & Vendors',
    'module_ticket' => 'Tickets',
    'reminders' => 'Reminders',
    'send_client_reminders' => 'Send email reminders',
    'can_view_tasks' => 'Tasks are visible in the portal',
    'is_not_sent_reminders' => 'Reminders are not sent',
    'promotion_footer' => 'Your promotion will expire soon, :link to upgrade now.',
    'unable_to_delete_primary' => 'Note: to delete this company first delete all linked companies.',
    'please_register' => 'Please register your account',
    'processing_request' => 'Processing request',
    'mcrypt_warning' => 'Warning: Mcrypt is deprecated, run :command to update your cipher.',
    'edit_times' => 'Edit Times',
    'inclusive_taxes_help' => 'Include <b>taxes in the cost</b>',
    'inclusive_taxes_notice' => 'This setting can not be changed once an invoice has been created.',
    'inclusive_taxes_warning' => 'Warning: existing invoices will need to be resaved',
    'copy_shipping' => 'Copy Shipping',
    'copy_billing' => 'Copy Billing',
    'quote_has_expired' => 'The quote has expired, please contact the merchant.',
    'empty_table_footer' => 'Showing 0 to 0 of 0 entries',
    'do_not_trust' => 'Do not remember this device',
    'trust_for_30_days' => 'Trust for 30 days',
    'trust_forever' => 'Trust forever',
    'kanban' => 'Kanban',
    'backlog' => 'Backlog',
    'ready_to_do' => 'Ready to do',
    'in_progress' => 'In progress',
    'add_status' => 'Add status',
    'archive_status' => 'Archive Status',
    'new_status' => 'New Status',
    'convert_products' => 'Convert Products',
    'convert_products_help' => 'Automatically convert product prices to the client\'s currency',
    'improve_client_portal_link' => 'Set a subdomain to shorten the client portal link.',
    'budgeted_hours' => 'Budgeted Hours',
    'progress' => 'Progress',
    'view_project' => 'View Project',
    'summary' => 'Summary',
    'endless_reminder' => 'Endless Reminder',
    'signature_on_invoice_help' => 'Add the following code to show your client\'s signature on the PDF.',
    'signature_on_pdf' => 'Show on PDF',
    'signature_on_pdf_help' => 'Show the client signature on the invoice/quote PDF.',
    'expired_white_label' => 'The white label license has expired',
    'return_to_login' => 'Return to Login',
    'convert_products_tip' => 'Note: add a :link named ":name" to see the exchange rate.',
    'amount_greater_than_balance' => 'The amount is greater than the invoice balance, a credit will be created with the remaining amount.',
    'custom_fields_tip' => 'Use <code>Label|Option1,Option2</code> to show a select box.',
    'client_information' => 'Client Information',
    'updated_client_details' => 'Successfully updated client details',
    'auto' => 'Auto',
    'tax_amount' => 'Tax Amount',
    'tax_paid' => 'Tax Paid',
    'none' => 'None',
    'proposal_message_button' => 'To view your proposal for :amount, click the button below.',
    'proposal' => 'Proposal',
    'proposals' => 'Proposals',
    'list_proposals' => 'List Proposals',
    'new_proposal' => 'New Proposal',
    'edit_proposal' => 'Edit Proposal',
    'archive_proposal' => 'Archive Proposal',
    'delete_proposal' => 'Delete Proposal',
    'created_proposal' => 'Successfully created proposal',
    'updated_proposal' => 'Successfully updated proposal',
    'archived_proposal' => 'Successfully archived proposal',
    'deleted_proposal' => 'Successfully archived proposal',
    'archived_proposals' => 'Successfully archived :count proposals',
    'deleted_proposals' => 'Successfully archived :count proposals',
    'restored_proposal' => 'Successfully restored proposal',
    'restore_proposal' => 'Restore Proposal',
    'snippet' => 'Snippet',
    'snippets' => 'Snippets',
    'proposal_snippet' => 'Snippet',
    'proposal_snippets' => 'Snippets',
    'new_proposal_snippet' => 'New Snippet',
    'edit_proposal_snippet' => 'Edit Snippet',
    'archive_proposal_snippet' => 'Archive Snippet',
    'delete_proposal_snippet' => 'Delete Snippet',
    'created_proposal_snippet' => 'Successfully created snippet',
    'updated_proposal_snippet' => 'Successfully updated snippet',
    'archived_proposal_snippet' => 'Successfully archived snippet',
    'deleted_proposal_snippet' => 'Successfully archived snippet',
    'archived_proposal_snippets' => 'Successfully archived :count snippets',
    'deleted_proposal_snippets' => 'Successfully archived :count snippets',
    'restored_proposal_snippet' => 'Successfully restored snippet',
    'restore_proposal_snippet' => 'Restore Snippet',
    'template' => 'แบบ',
    'templates' => 'Templates',
    'proposal_template' => 'Template',
    'proposal_templates' => 'Templates',
    'new_proposal_template' => 'New Template',
    'edit_proposal_template' => 'Edit Template',
    'archive_proposal_template' => 'Archive Template',
    'delete_proposal_template' => 'Delete Template',
    'created_proposal_template' => 'Successfully created template',
    'updated_proposal_template' => 'Successfully updated template',
    'archived_proposal_template' => 'Successfully archived template',
    'deleted_proposal_template' => 'Successfully archived template',
    'archived_proposal_templates' => 'Successfully archived :count templates',
    'deleted_proposal_templates' => 'Successfully archived :count templates',
    'restored_proposal_template' => 'Successfully restored template',
    'restore_proposal_template' => 'Restore Template',
    'proposal_category' => 'Category',
    'proposal_categories' => 'Categories',
    'new_proposal_category' => 'New Category',
    'edit_proposal_category' => 'Edit Category',
    'archive_proposal_category' => 'Archive Category',
    'delete_proposal_category' => 'Delete Category',
    'created_proposal_category' => 'Successfully created category',
    'updated_proposal_category' => 'Successfully updated category',
    'archived_proposal_category' => 'Successfully archived category',
    'deleted_proposal_category' => 'Successfully archived category',
    'archived_proposal_categories' => 'Successfully archived :count categories',
    'deleted_proposal_categories' => 'Successfully archived :count categories',
    'restored_proposal_category' => 'Successfully restored category',
    'restore_proposal_category' => 'Restore Category',
    'delete_status' => 'Delete Status',
    'standard' => 'Standard',
    'icon' => 'Icon',
    'proposal_not_found' => 'The requested proposal is not available',
    'create_proposal_category' => 'Create category',
    'clone_proposal_template' => 'Clone Template',
    'proposal_email' => 'Proposal Email',
    'proposal_subject' => 'New proposal :number from :account',
    'proposal_message' => 'To view your proposal for :amount, click the link below.',
    'emailed_proposal' => 'Successfully emailed proposal',
    'load_template' => 'Load Template',
    'no_assets' => 'No images, drag to upload',
    'add_image' => 'Add Image',
    'select_image' => 'Select Image',
    'upgrade_to_upload_images' => 'Upgrade to the enterprise plan to upload images',
    'delete_image' => 'Delete Image',
    'delete_image_help' => 'Warning: deleting the image will remove it from all proposals.',
    'amount_variable_help' => 'Note: the invoice $amount field will use the partial/deposit field if set otherwise it will use the invoice balance.',
    'taxes_are_included_help' => 'Note: Inclusive taxes have been enabled.',
    'taxes_are_not_included_help' => 'Note: Inclusive taxes are not enabled.',
    'change_requires_purge' => 'Changing this setting requires :link the account data.',
    'purging' => 'purging',
    'warning_local_refund' => 'The refund will be recorded in the app but will NOT be processed by the payment gateway.',
    'email_address_changed' => 'Email address has been changed',
    'email_address_changed_message' => 'The email address for your account has been changed from :old_email to :new_email.',
    'test' => 'Test',
    'beta' => 'Beta',
    'gmp_required' => 'Exporting to ZIP requires the GMP extension',
    'email_history' => 'Email History',
    'loading' => 'Loading',
    'no_messages_found' => 'No messages found',
    'processing' => 'Processing',
    'reactivate' => 'Reactivate',
    'reactivated_email' => 'The email address has been reactivated',
    'emails' => 'Emails',
    'opened' => 'Opened',
    'bounced' => 'Bounced',
    'total_sent' => 'Total Sent',
    'total_opened' => 'Total Opened',
    'total_bounced' => 'Total Bounced',
    'total_spam' => 'Total Spam',
    'platforms' => 'Platforms',
    'email_clients' => 'Email Clients',
    'mobile' => 'Mobile',
    'desktop' => 'Desktop',
    'webmail' => 'Webmail',
    'group' => 'Group',
    'subgroup' => 'Subgroup',
    'unset' => 'Unset',
    'received_new_payment' => 'You\'ve received a new payment!',
    'slack_webhook_help' => 'Receive payment notifications using :link.',
    'slack_incoming_webhooks' => 'Slack incoming webhooks',
    'accept' => 'Accept',
    'accepted_terms' => 'Successfully accepted the latest terms of service',
    'invalid_url' => 'Invalid URL',
    'workflow_settings' => 'Workflow Settings',
    'auto_email_invoice' => 'Auto Email',
    'auto_email_invoice_help' => 'Automatically email recurring invoices when they are created.',
    'auto_archive_invoice' => 'Auto Archive',
    'auto_archive_invoice_help' => 'Automatically archive invoices when they are paid.',
    'auto_archive_quote' => 'Auto Archive',
    'auto_archive_quote_help' => 'Automatically archive quotes when they are converted.',
    'require_approve_quote' => 'Require approve quote',
    'require_approve_quote_help' => 'Require clients to approve quotes.',
    'allow_approve_expired_quote' => 'Allow approve expired quote',
    'allow_approve_expired_quote_help' => 'Allow clients to approve expired quotes.',
    'invoice_workflow' => 'Invoice Workflow',
    'quote_workflow' => 'Quote Workflow',
    'client_must_be_active' => 'Error: the client must be active',
    'purge_client' => 'Purge Client',
    'purged_client' => 'Successfully purged client',
    'purge_client_warning' => 'All related records (invoices, tasks, expenses, documents, etc) will also be deleted.',
    'clone_product' => 'Clone Product',
    'item_details' => 'Item Details',
    'send_item_details_help' => 'Send line item details to the payment gateway.',
    'view_proposal' => 'View Proposal',
    'view_in_portal' => 'View in Portal',
    'cookie_message' => 'This website uses cookies to ensure you get the best experience on our website.',
    'got_it' => 'Got it!',
    'vendor_will_create' => 'vendor will be created',
    'vendors_will_create' => 'vendors will be created',
    'created_vendors' => 'Successfully created :count vendor(s)',
    'import_vendors' => 'Import Vendors',
    'company' => 'Company',
    'client_field' => 'Client Field',
    'contact_field' => 'Contact Field',
    'product_field' => 'Product Field',
    'task_field' => 'Task Field',
    'project_field' => 'Project Field',
    'expense_field' => 'Expense Field',
    'vendor_field' => 'Vendor Field',
    'company_field' => 'Company Field',
    'invoice_field' => 'Invoice Field',
    'invoice_surcharge' => 'Invoice Surcharge',
    'custom_task_fields_help' => 'Add a field when creating a task.',
    'custom_project_fields_help' => 'Add a field when creating a project.',
    'custom_expense_fields_help' => 'Add a field when creating an expense.',
    'custom_vendor_fields_help' => 'Add a field when creating a vendor.',
    'messages' => 'Messages',
    'unpaid_invoice' => 'Unpaid Invoice',
    'paid_invoice' => 'Paid Invoice',
    'unapproved_quote' => 'Unapproved Quote',
    'unapproved_proposal' => 'Unapproved Proposal',
    'autofills_city_state' => 'Auto-fills city/state',
    'no_match_found' => 'No match found',
    'password_strength' => 'Password Strength',
    'strength_weak' => 'Weak',
    'strength_good' => 'Good',
    'strength_strong' => 'Strong',
    'mark' => 'Mark',
    'updated_task_status' => 'Successfully update task status',
    'background_image' => 'Background Image',
    'background_image_help' => 'Use the :link to manage your images, we recommend using a small file.',
    'proposal_editor' => 'proposal editor',
    'background' => 'Background',
    'guide' => 'Guide',
    'gateway_fee_item' => 'Gateway Fee Item',
    'gateway_fee_description' => 'Gateway Fee Surcharge',
    'gateway_fee_discount_description' => 'Gateway Fee Discount',
    'show_payments' => 'Show Payments',
    'show_aging' => 'Show Aging',
    'reference' => 'Reference',
    'amount_paid' => 'Amount Paid',
    'send_notifications_for' => 'Send Notifications For',
    'all_invoices' => 'All Invoices',
    'my_invoices' => 'My Invoices',
    'payment_reference' => 'Payment Reference',
    'maximum' => 'Maximum',
    'sort' => 'Sort',
    'refresh_complete' => 'Refresh Complete',
    'please_enter_your_email' => 'Please enter your email',
    'please_enter_your_password' => 'Please enter your password',
    'please_enter_your_url' => 'Please enter your URL',
    'please_enter_a_product_key' => 'Please enter a product key',
    'an_error_occurred' => 'An error occurred',
    'overview' => 'Overview',
    'copied_to_clipboard' => 'Copied :value to the clipboard',
    'error' => 'Error',
    'could_not_launch' => 'Could not launch',
    'additional' => 'Additional',
    'ok' => 'Ok',
    'email_is_invalid' => 'Email is invalid',
    'items' => 'Items',
    'partial_deposit' => 'Partial/Deposit',
    'add_item' => 'Add Item',
    'total_amount' => 'Total Amount',
    'pdf' => 'PDF',
    'invoice_status_id' => 'Invoice Status',
    'click_plus_to_add_item' => 'Click + to add an item',
    'count_selected' => ':count selected',
    'dismiss' => 'Dismiss',
    'please_select_a_date' => 'Please select a date',
    'please_select_a_client' => 'Please select a client',
    'language' => 'Language',
    'updated_at' => 'Updated',
    'please_enter_an_invoice_number' => 'Please enter an invoice number',
    'please_enter_a_quote_number' => 'Please enter a quote number',
    'clients_invoices' => ':client\'s invoices',
    'viewed' => 'Viewed',
    'approved' => 'Approved',
    'invoice_status_1' => 'Draft',
    'invoice_status_2' => 'Sent',
    'invoice_status_3' => 'Viewed',
    'invoice_status_4' => 'Approved',
    'invoice_status_5' => 'Partial',
    'invoice_status_6' => 'Paid',
    'marked_invoice_as_sent' => 'Successfully marked invoice as sent',
    'please_enter_a_client_or_contact_name' => 'Please enter a client or contact name',
    'restart_app_to_apply_change' => 'Restart the app to apply the change',
    'refresh_data' => 'Refresh Data',
    'blank_contact' => 'Blank Contact',
    'no_records_found' => 'No records found',
    'industry' => 'Industry',
    'size' => 'Size',
    'net' => 'Net',
    'show_tasks' => 'Show tasks',
    'email_reminders' => 'Email Reminders',
    'reminder1' => 'First Reminder',
    'reminder2' => 'Second Reminder',
    'reminder3' => 'Third Reminder',
    'send' => 'Send',
    'auto_billing' => 'Auto billing',
    'button' => 'Button',
    'more' => 'More',
    'edit_recurring_invoice' => 'Edit Recurring Invoice',
    'edit_recurring_quote' => 'Edit Recurring Quote',
    'quote_status' => 'Quote Status',
    'please_select_an_invoice' => 'Please select an invoice',
    'filtered_by' => 'Filtered by',
    'payment_status' => 'Payment Status',
    'payment_status_1' => 'Pending',
    'payment_status_2' => 'Voided',
    'payment_status_3' => 'Failed',
    'payment_status_4' => 'Completed',
    'payment_status_5' => 'Partially Refunded',
    'payment_status_6' => 'Refunded',
    'send_receipt_to_client' => 'Send receipt to the client',
    'refunded' => 'Refunded',
    'marked_quote_as_sent' => 'Successfully marked quote as sent',
    'custom_module_settings' => 'Custom Module Settings',
    'ticket' => 'Ticket',
    'tickets' => 'Tickets',
    'ticket_number' => 'Ticket #',
    'new_ticket' => 'New Ticket',
    'edit_ticket' => 'Edit Ticket',
    'view_ticket' => 'View Ticket',
    'archive_ticket' => 'Archive Ticket',
    'restore_ticket' => 'Restore Ticket',
    'delete_ticket' => 'Delete Ticket',
    'archived_ticket' => 'Successfully archived ticket',
    'archived_tickets' => 'Successfully archived tickets',
    'restored_ticket' => 'Successfully restored ticket',
    'deleted_ticket' => 'Successfully deleted ticket',
    'open' => 'Open',
    'new' => 'New',
    'closed' => 'Closed',
    'reopened' => 'Reopened',
    'priority' => 'Priority',
    'last_updated' => 'Last Updated',
    'comment' => 'Comments',
    'tags' => 'Tags',
    'linked_objects' => 'Linked Objects',
    'low' => 'Low',
    'medium' => 'Medium',
    'high' => 'High',
    'no_due_date' => 'No due date set',
    'assigned_to' => 'Assigned to',
    'reply' => 'Reply',
    'awaiting_reply' => 'Awaiting reply',
    'ticket_close' => 'Close Ticket',
    'ticket_reopen' => 'Reopen Ticket',
    'ticket_open' => 'Open Ticket',
    'ticket_split' => 'Split Ticket',
    'ticket_merge' => 'Merge Ticket',
    'ticket_update' => 'Update Ticket',
    'ticket_settings' => 'Ticket Settings',
    'updated_ticket' => 'Ticket Updated',
    'mark_spam' => 'Mark as Spam',
    'local_part' => 'Local Part',
    'local_part_unavailable' => 'Name taken',
    'local_part_available' => 'Name available',
    'local_part_invalid' => 'Invalid name (alpha numeric only, no spaces',
    'local_part_help' => 'Customize the local part of your inbound support email, ie. YOUR_NAME@support.invoiceninja.com',
    'from_name_help' => 'From name is the recognizable sender which is displayed instead of the email address, ie Support Center',
    'local_part_placeholder' => 'YOUR_NAME',
    'from_name_placeholder' => 'Support Center',
    'attachments' => 'Attachments',
    'client_upload' => 'Client uploads',
    'enable_client_upload_help' => 'Allow clients to upload documents/attachments',
    'max_file_size_help' => 'Maximum file size (KB) is limited by your post_max_size and upload_max_filesize variables as set in your PHP.INI',
    'max_file_size' => 'Maximum file size',
    'mime_types' => 'Mime types',
    'mime_types_placeholder' => '.pdf , .docx, .jpg',
    'mime_types_help' => 'Comma separated list of allowed mime types, leave blank for all',
    'ticket_number_start_help' => 'Ticket number must be greater than the current ticket number',
    'new_ticket_template_id' => 'New ticket',
    'new_ticket_autoresponder_help' => 'Selecting a template will send an auto response to a client/contact when a new ticket is created',
    'update_ticket_template_id' => 'Updated ticket',
    'update_ticket_autoresponder_help' => 'Selecting a template will send an auto response to a client/contact when a ticket is updated',
    'close_ticket_template_id' => 'Closed ticket',
    'close_ticket_autoresponder_help' => 'Selecting a template will send an auto response to a client/contact when a ticket is closed',
    'default_priority' => 'Default priority',
    'alert_new_comment_id' => 'New comment',
    'alert_comment_ticket_help' => 'Selecting a template will send a notification (to agent) when a comment is made.',
    'alert_comment_ticket_email_help' => 'Comma separated emails to bcc on new comment.',
    'new_ticket_notification_list' => 'Additional new ticket notifications',
    'update_ticket_notification_list' => 'Additional new comment notifications',
    'comma_separated_values' => 'admin@example.com, supervisor@example.com',
    'alert_ticket_assign_agent_id' => 'Ticket assignment',
    'alert_ticket_assign_agent_id_hel' => 'Selecting a template will send a notification (to agent) when a ticket is assigned.',
    'alert_ticket_assign_agent_id_notifications' => 'Additional ticket assigned notifications',
    'alert_ticket_assign_agent_id_help' => 'Comma separated emails to bcc on ticket assignment.',
    'alert_ticket_transfer_email_help' => 'Comma separated emails to bcc on ticket transfer.',
    'alert_ticket_overdue_agent_id' => 'Ticket overdue',
    'alert_ticket_overdue_email' => 'Additional overdue ticket notifications',
    'alert_ticket_overdue_email_help' => 'Comma separated emails to bcc on ticket overdue.',
    'alert_ticket_overdue_agent_id_help' => 'Selecting a template will send a notification (to agent) when a ticket becomes overdue.',
    'ticket_master' => 'Ticket Master',
    'ticket_master_help' => 'Has the ability to assign and transfer tickets. Assigned as the default agent for all tickets.',
    'default_agent' => 'Default Agent',
    'default_agent_help' => 'If selected will automatically be assigned to all inbound tickets',
    'show_agent_details' => 'Show agent details on responses',
    'avatar' => 'Avatar',
    'remove_avatar' => 'Remove avatar',
    'ticket_not_found' => 'Ticket not found',
    'add_template' => 'Add Template',
    'ticket_template' => 'Ticket Template',
    'ticket_templates' => 'Ticket Templates',
    'updated_ticket_template' => 'Updated Ticket Template',
    'created_ticket_template' => 'Created Ticket Template',
    'archive_ticket_template' => 'Archive Template',
    'restore_ticket_template' => 'Restore Template',
    'archived_ticket_template' => 'Successfully archived template',
    'restored_ticket_template' => 'Successfully restored template',
    'close_reason' => 'Let us know why you are closing this ticket',
    'reopen_reason' => 'Let us know why you are reopening this ticket',
    'enter_ticket_message' => 'Please enter a message to update the ticket',
    'show_hide_all' => 'Show / Hide all',
    'subject_required' => 'Subject required',
    'mobile_refresh_warning' => 'If you\'re using the mobile app you may need to do a full refresh.',
    'enable_proposals_for_background' => 'To upload a background image :link to enable the proposals module.',
    'ticket_assignment' => 'Ticket :ticket_number has been assigned to :agent',
    'ticket_contact_reply' => 'Ticket :ticket_number has been updated by client :contact',
    'ticket_new_template_subject' => 'Ticket :ticket_number has been created.',
    'ticket_updated_template_subject' => 'Ticket :ticket_number has been updated.',
    'ticket_closed_template_subject' => 'Ticket :ticket_number has been closed.',
    'ticket_overdue_template_subject' => 'Ticket :ticket_number is now overdue',
    'merge' => 'Merge',
    'merged' => 'Merged',
    'agent' => 'Agent',
    'parent_ticket' => 'Parent Ticket',
    'linked_tickets' => 'Linked Tickets',
    'merge_prompt' => 'Enter ticket number to merge into',
    'merge_from_to' => 'Ticket #:old_ticket merged into Ticket #:new_ticket',
    'merge_closed_ticket_text' => 'Ticket #:old_ticket was closed and merged into Ticket#:new_ticket - :subject',
    'merge_updated_ticket_text' => 'Ticket #:old_ticket was closed and merged into this ticket',
    'merge_placeholder' => 'Merge ticket #:ticket into the following ticket',
    'select_ticket' => 'Select Ticket',
    'new_internal_ticket' => 'New internal ticket',
    'internal_ticket' => 'Internal ticket',
    'create_ticket' => 'Create ticket',
    'allow_inbound_email_tickets_external' => 'New Tickets by email (Client)',
    'allow_inbound_email_tickets_external_help' => 'Allow clients to create new tickets by email',
    'include_in_filter' => 'Include in filter',
    'custom_client1' => ':VALUE',
    'custom_client2' => ':VALUE',
    'compare' => 'Compare',
    'hosted_login' => 'Hosted Login',
    'selfhost_login' => 'Selfhost Login',
    'google_login' => 'Google Login',
    'thanks_for_patience' => 'Thank for your patience while we work to implement these features.\n\nWe hope to have them completed in the next few months.\n\nUntil then we\'ll continue to support the',
    'legacy_mobile_app' => 'legacy mobile app',
    'today' => 'Today',
    'current' => 'Current',
    'previous' => 'Previous',
    'current_period' => 'Current Period',
    'comparison_period' => 'Comparison Period',
    'previous_period' => 'Previous Period',
    'previous_year' => 'Previous Year',
    'compare_to' => 'Compare to',
    'last_week' => 'Last Week',
    'clone_to_invoice' => 'Clone to Invoice',
    'clone_to_quote' => 'Clone to Quote',
    'convert' => 'Convert',
    'last7_days' => 'Last 7 Days',
    'last30_days' => 'Last 30 Days',
    'custom_js' => 'Custom JS',
    'adjust_fee_percent_help' => 'Adjust percent to account for fee',
    'show_product_notes' => 'Show product details',
    'show_product_notes_help' => 'Include the <b>description and cost</b> in the product dropdown',
    'important' => 'Important',
    'thank_you_for_using_our_app' => 'Thank you for using our app!',
    'if_you_like_it' => 'If you like it please',
    'to_rate_it' => 'to rate it.',
    'average' => 'ค่าเฉลี่ย',
    'unapproved' => 'ไม่อนุมัติ',
    'authenticate_to_change_setting' => 'Please authenticate to change this setting',
    'locked' => 'Locked',
    'authenticate' => 'Authenticate',
    'please_authenticate' => 'Please authenticate',
    'biometric_authentication' => 'Biometric Authentication',
    'auto_start_tasks' => 'Auto Start Tasks',
    'budgeted' => 'Budgeted',
    'please_enter_a_name' => 'โปรดระบุชื่อ',
    'click_plus_to_add_time' => 'คลิ๊กปุ่ม + เพื่อเพิ่มรายการ',
    'design' => 'ออกแบบ',
    'password_is_too_short' => 'รหัสผ่านสั้นเกินไป',
    'failed_to_find_record' => 'Failed to find record',
    'valid_until_days' => 'Valid Until',
    'valid_until_days_help' => 'Automatically sets the <b>Valid Until</b> value on quotes to this many days in the future.  Leave blank to disable.',
    'usually_pays_in_days' => 'Days',
    'requires_an_enterprise_plan' => 'Requires an enterprise plan',
    'take_picture' => 'Take Picture',
    'upload_file' => 'Upload File',
    'new_document' => 'New Document',
    'edit_document' => 'Edit Document',
    'uploaded_document' => 'Successfully uploaded document',
    'updated_document' => 'Successfully updated document',
    'archived_document' => 'Successfully archived document',
    'deleted_document' => 'Successfully deleted document',
    'restored_document' => 'Successfully restored document',
    'no_history' => 'No History',
    'expense_status_1' => 'Logged',
    'expense_status_2' => 'Pending',
    'expense_status_3' => 'Invoiced',
    'no_record_selected' => 'No record selected',
    'error_unsaved_changes' => 'Please save or cancel your changes',
    'thank_you_for_your_purchase' => 'Thank you for your purchase!',
    'redeem' => 'Redeem',
    'back' => 'Back',
    'past_purchases' => 'Past Purchases',
    'annual_subscription' => 'Annual Subscription',
    'pro_plan' => 'Pro Plan',
    'enterprise_plan' => 'Enterprise Plan',
    'count_users' => ':count users',
    'upgrade' => 'Upgrade',
    'please_enter_a_first_name' => 'Please enter a first name',
    'please_enter_a_last_name' => 'Please enter a last name',
    'please_agree_to_terms_and_privacy' => 'Please agree to the terms of service and privacy policy to create an account.',
    'i_agree_to_the' => 'I agree to the',
    'terms_of_service_link' => 'terms of service',
    'privacy_policy_link' => 'privacy policy',
    'view_website' => 'View Website',
    'create_account' => 'Create Account',
    'email_login' => 'Email Login',
    'late_fees' => 'Late Fees',
    'payment_number' => 'Payment Number',
    'before_due_date' => 'Before the due date',
    'after_due_date' => 'After the due date',
    'after_invoice_date' => 'After the invoice date',
    'filtered_by_user' => 'Filtered by User',
    'created_user' => 'Successfully created user',
    'primary_font' => 'Primary Font',
    'secondary_font' => 'Secondary Font',
    'number_padding' => 'Number Padding',
    'general' => 'General',
    'surcharge_field' => 'Surcharge Field',
    'company_value' => 'Company Value',
    'credit_field' => 'Credit Field',
    'payment_field' => 'Payment Field',
    'group_field' => 'Group Field',
    'number_counter' => 'Number Counter',
    'number_pattern' => 'Number Pattern',
    'custom_javascript' => 'Custom JavaScript',
    'portal_mode' => 'Portal Mode',
    'attach_pdf' => 'Attach PDF',
    'attach_documents' => 'Attach Documents',
    'attach_ubl' => 'Attach UBL',
    'email_style' => 'Email Style',
    'processed' => 'Processed',
    'fee_amount' => 'Fee Amount',
    'fee_percent' => 'Fee Percent',
    'fee_cap' => 'Fee Cap',
    'limits_and_fees' => 'Limits/Fees',
    'credentials' => 'Credentials',
    'require_billing_address_help' => 'Require client to provide their billing address',
    'require_shipping_address_help' => 'Require client to provide their shipping address',
    'deleted_tax_rate' => 'Successfully deleted tax rate',
    'restored_tax_rate' => 'Successfully restored tax rate',
    'provider' => 'Provider',
    'company_gateway' => 'Payment Gateway',
    'company_gateways' => 'Payment Gateways',
    'new_company_gateway' => 'New Gateway',
    'edit_company_gateway' => 'Edit Gateway',
    'created_company_gateway' => 'Successfully created gateway',
    'updated_company_gateway' => 'Successfully updated gateway',
    'archived_company_gateway' => 'Successfully archived gateway',
    'deleted_company_gateway' => 'Successfully deleted gateway',
    'restored_company_gateway' => 'Successfully restored gateway',
    'continue_editing' => 'Continue Editing',
    'default_value' => 'Default value',
    'currency_format' => 'Currency Format',
    'first_day_of_the_week' => 'First Day of the Week',
    'first_month_of_the_year' => 'First Month of the Year',
    'symbol' => 'Symbol',
    'ocde' => 'Code',
    'date_format' => 'Date Format',
    'datetime_format' => 'Datetime Format',
    'send_reminders' => 'Send Reminders',
    'timezone' => 'Timezone',
    'filtered_by_group' => 'Filtered by Group',
    'filtered_by_invoice' => 'Filtered by Invoice',
    'filtered_by_client' => 'Filtered by Client',
    'filtered_by_vendor' => 'Filtered by Vendor',
    'group_settings' => 'Group Settings',
    'groups' => 'Groups',
    'new_group' => 'New Group',
    'edit_group' => 'Edit Group',
    'created_group' => 'Successfully created group',
    'updated_group' => 'Successfully updated group',
    'archived_group' => 'Successfully archived group',
    'deleted_group' => 'Successfully deleted group',
    'restored_group' => 'Successfully restored group',
    'upload_logo' => 'Upload Logo',
    'uploaded_logo' => 'Successfully uploaded logo',
    'saved_settings' => 'Successfully saved settings',
    'device_settings' => 'Device Settings',
    'credit_cards_and_banks' => 'Credit Cards & Banks',
    'price' => 'Price',
    'email_sign_up' => 'Email Sign Up',
    'google_sign_up' => 'Google Sign Up',
    'sign_up_with_google' => 'Sign Up With Google',
    'long_press_multiselect' => 'Long-press Multiselect',
    'migrate_to_next_version' => 'Migrate to the next version of Invoice Ninja',
    'migrate_intro_text' => 'We\'ve been working on next version of Invoice Ninja. Click the button bellow to start the migration.',
    'start_the_migration' => 'Start the migration',
    'migration' => 'Migration',
    'welcome_to_the_new_version' => 'Welcome to the new version of Invoice Ninja',
    'next_step_data_download' => 'At the next step, we\'ll let you download your data for the migration.',
    'download_data' => 'Press button below to download the data.',
    'migration_import' => 'Awesome! Now you are ready to import your migration. Go to your new installation to import your data',
    'continue' => 'Continue',
    'company1' => 'Custom Company 1',
    'company2' => 'Custom Company 2',
    'company3' => 'Custom Company 3',
    'company4' => 'Custom Company 4',
    'product1' => 'Custom Product 1',
    'product2' => 'Custom Product 2',
    'product3' => 'Custom Product 3',
    'product4' => 'Custom Product 4',
    'client1' => 'Custom Client 1',
    'client2' => 'Custom Client 2',
    'client3' => 'Custom Client 3',
    'client4' => 'Custom Client 4',
    'contact1' => 'Custom Contact 1',
    'contact2' => 'Custom Contact 2',
    'contact3' => 'Custom Contact 3',
    'contact4' => 'Custom Contact 4',
    'task1' => 'Custom Task 1',
    'task2' => 'Custom Task 2',
    'task3' => 'Custom Task 3',
    'task4' => 'Custom Task 4',
    'project1' => 'Custom Project 1',
    'project2' => 'Custom Project 2',
    'project3' => 'Custom Project 3',
    'project4' => 'Custom Project 4',
    'expense1' => 'Custom Expense 1',
    'expense2' => 'Custom Expense 2',
    'expense3' => 'Custom Expense 3',
    'expense4' => 'Custom Expense 4',
    'vendor1' => 'Custom Vendor 1',
    'vendor2' => 'Custom Vendor 2',
    'vendor3' => 'Custom Vendor 3',
    'vendor4' => 'Custom Vendor 4',
    'invoice1' => 'Custom Invoice 1',
    'invoice2' => 'Custom Invoice 2',
    'invoice3' => 'Custom Invoice 3',
    'invoice4' => 'Custom Invoice 4',
    'payment1' => 'Custom Payment 1',
    'payment2' => 'Custom Payment 2',
    'payment3' => 'Custom Payment 3',
    'payment4' => 'Custom Payment 4',
    'surcharge1' => 'Custom Surcharge 1',
    'surcharge2' => 'Custom Surcharge 2',
    'surcharge3' => 'Custom Surcharge 3',
    'surcharge4' => 'Custom Surcharge 4',
    'group1' => 'Custom Group 1',
    'group2' => 'Custom Group 2',
    'group3' => 'Custom Group 3',
    'group4' => 'Custom Group 4',
    'number' => 'Number',
    'count' => 'Count',
    'is_active' => 'Is Active',
    'contact_last_login' => 'Contact Last Login',
    'contact_full_name' => 'Contact Full Name',
    'contact_custom_value1' => 'Contact Custom Value 1',
    'contact_custom_value2' => 'Contact Custom Value 2',
    'contact_custom_value3' => 'Contact Custom Value 3',
    'contact_custom_value4' => 'Contact Custom Value 4',
    'assigned_to_id' => 'Assigned To Id',
    'created_by_id' => 'Created By Id',
    'add_column' => 'Add Column',
    'edit_columns' => 'Edit Columns',
    'to_learn_about_gogle_fonts' => 'to learn about Google Fonts',
    'refund_date' => 'Refund Date',
    'multiselect' => 'Multiselect',
    'verify_password' => 'Verify Password',
    'applied' => 'Applied',
    'include_recent_errors' => 'Include recent errors from the logs',
    'your_message_has_been_received' => 'We have received your message and will try to respond promptly.',
    'show_product_details' => 'Show Product Details',
    'show_product_details_help' => 'Include the description and cost in the product dropdown',
    'pdf_min_requirements' => 'The PDF renderer requires :version',
    'adjust_fee_percent' => 'Adjust Fee Percent',
    'configure_settings' => 'Configure Settings',
    'about' => 'About',
    'credit_email' => 'Credit Email',
    'domain_url' => 'Domain URL',
    'password_is_too_easy' => 'Password must contain an upper case character and a number',
    'client_portal_tasks' => 'Client Portal Tasks',
    'client_portal_dashboard' => 'Client Portal Dashboard',
    'please_enter_a_value' => 'Please enter a value',
    'deleted_logo' => 'Successfully deleted logo',
    'generate_number' => 'Generate Number',
    'when_saved' => 'When Saved',
    'when_sent' => 'When Sent',
    'select_company' => 'Select Company',
    'float' => 'Float',
    'collapse' => 'Collapse',
    'show_or_hide' => 'Show/hide',
    'menu_sidebar' => 'Menu Sidebar',
    'history_sidebar' => 'History Sidebar',
    'tablet' => 'Tablet',
    'layout' => 'Layout',
    'module' => 'Module',
    'first_custom' => 'First Custom',
    'second_custom' => 'Second Custom',
    'third_custom' => 'Third Custom',
    'show_cost' => 'Show Cost',
    'show_cost_help' => 'Display a product cost field to track the markup/profit',
    'show_product_quantity' => 'Show Product Quantity',
    'show_product_quantity_help' => 'Display a product quantity field, otherwise default to one',
    'show_invoice_quantity' => 'Show Invoice Quantity',
    'show_invoice_quantity_help' => 'Display a line item quantity field, otherwise default to one',
    'default_quantity' => 'Default Quantity',
    'default_quantity_help' => 'Automatically set the line item quantity to one',
    'one_tax_rate' => 'One Tax Rate',
    'two_tax_rates' => 'Two Tax Rates',
    'three_tax_rates' => 'Three Tax Rates',
    'default_tax_rate' => 'Default Tax Rate',
    'invoice_tax' => 'Invoice Tax',
    'line_item_tax' => 'Line Item Tax',
    'inclusive_taxes' => 'Inclusive Taxes',
    'invoice_tax_rates' => 'Invoice Tax Rates',
    'item_tax_rates' => 'Item Tax Rates',
    'configure_rates' => 'Configure rates',
    'tax_settings_rates' => 'Tax Rates',
    'accent_color' => 'Accent Color',
    'comma_sparated_list' => 'Comma separated list',
    'single_line_text' => 'Single-line text',
    'multi_line_text' => 'Multi-line text',
    'dropdown' => 'Dropdown',
    'field_type' => 'Field Type',
    'recover_password_email_sent' => 'A password recovery email has been sent',
    'removed_user' => 'Successfully removed user',
    'freq_three_years' => 'Three Years',
    'military_time_help' => '24 Hour Display',
    'click_here_capital' => 'Click here',
    'marked_invoice_as_paid' => 'Successfully marked invoice as sent',
    'marked_invoices_as_sent' => 'Successfully marked invoices as sent',
    'marked_invoices_as_paid' => 'Successfully marked invoices as sent',
    'activity_57' => 'System failed to email invoice :invoice',
    'custom_value3' => 'Custom Value 3',
    'custom_value4' => 'Custom Value 4',
    'email_style_custom' => 'Custom Email Style',
    'custom_message_dashboard' => 'Custom Dashboard Message',
    'custom_message_unpaid_invoice' => 'Custom Unpaid Invoice Message',
    'custom_message_paid_invoice' => 'Custom Paid Invoice Message',
    'custom_message_unapproved_quote' => 'Custom Unapproved Quote Message',
    'lock_sent_invoices' => 'Lock Sent Invoices',
    'translations' => 'Translations',
    'task_number_pattern' => 'Task Number Pattern',
    'task_number_counter' => 'Task Number Counter',
    'expense_number_pattern' => 'Expense Number Pattern',
    'expense_number_counter' => 'Expense Number Counter',
    'vendor_number_pattern' => 'Vendor Number Pattern',
    'vendor_number_counter' => 'Vendor Number Counter',
    'ticket_number_pattern' => 'Ticket Number Pattern',
    'ticket_number_counter' => 'Ticket Number Counter',
    'payment_number_pattern' => 'Payment Number Pattern',
    'payment_number_counter' => 'Payment Number Counter',
    'invoice_number_pattern' => 'Invoice Number Pattern',
    'quote_number_pattern' => 'Quote Number Pattern',
    'client_number_pattern' => 'Credit Number Pattern',
    'client_number_counter' => 'Credit Number Counter',
    'credit_number_pattern' => 'Credit Number Pattern',
    'credit_number_counter' => 'Credit Number Counter',
    'reset_counter_date' => 'Reset Counter Date',
    'counter_padding' => 'Counter Padding',
    'shared_invoice_quote_counter' => 'Shared Invoice Quote Counter',
    'default_tax_name_1' => 'Default Tax Name 1',
    'default_tax_rate_1' => 'Default Tax Rate 1',
    'default_tax_name_2' => 'Default Tax Name 2',
    'default_tax_rate_2' => 'Default Tax Rate 2',
    'default_tax_name_3' => 'Default Tax Name 3',
    'default_tax_rate_3' => 'Default Tax Rate 3',
    'email_subject_invoice' => 'Email Invoice Subject',
    'email_subject_quote' => 'Email Quote Subject',
    'email_subject_payment' => 'Email Payment Subject',
    'switch_list_table' => 'Switch List Table',
    'client_city' => 'Client City',
    'client_state' => 'Client State',
    'client_country' => 'Client Country',
    'client_is_active' => 'Client is Active',
    'client_balance' => 'Client Balance',
    'client_address1' => 'Client Street',
    'client_address2' => 'Client Apt/Suite',
    'client_shipping_address1' => 'Client Shipping Street',
    'client_shipping_address2' => 'Client Shipping Apt/Suite',
    'tax_rate1' => 'Tax Rate 1',
    'tax_rate2' => 'Tax Rate 2',
    'tax_rate3' => 'Tax Rate 3',
    'archived_at' => 'Archived At',
    'has_expenses' => 'Has Expenses',
    'custom_taxes1' => 'Custom Taxes 1',
    'custom_taxes2' => 'Custom Taxes 2',
    'custom_taxes3' => 'Custom Taxes 3',
    'custom_taxes4' => 'Custom Taxes 4',
    'custom_surcharge1' => 'Custom Surcharge 1',
    'custom_surcharge2' => 'Custom Surcharge 2',
    'custom_surcharge3' => 'Custom Surcharge 3',
    'custom_surcharge4' => 'Custom Surcharge 4',
    'is_deleted' => 'Is Deleted',
    'vendor_city' => 'Vendor City',
    'vendor_state' => 'Vendor State',
    'vendor_country' => 'Vendor Country',
    'credit_footer' => 'Credit Footer',
    'credit_terms' => 'Credit Terms',
    'untitled_company' => 'Untitled Company',
    'added_company' => 'Successfully added company',
    'supported_events' => 'Supported Events',
    'custom3' => 'Third Custom',
    'custom4' => 'Fourth Custom',
    'optional' => 'Optional',
    'license' => 'License',
    'invoice_balance' => 'Invoice Balance',
    'saved_design' => 'Successfully saved design',
    'client_details' => 'Client Details',
    'company_address' => 'Company Address',
    'quote_details' => 'Quote Details',
    'credit_details' => 'Credit Details',
    'product_columns' => 'Product Columns',
    'task_columns' => 'Task Columns',
    'add_field' => 'Add Field',
    'all_events' => 'All Events',
    'owned' => 'Owned',
    'payment_success' => 'Payment Success',
    'payment_failure' => 'Payment Failure',
    'quote_sent' => 'Quote Sent',
    'credit_sent' => 'Credit Sent',
    'invoice_viewed' => 'Invoice Viewed',
    'quote_viewed' => 'Quote Viewed',
    'credit_viewed' => 'Credit Viewed',
    'quote_approved' => 'Quote Approved',
    'receive_all_notifications' => 'Receive All Notifications',
    'purchase_license' => 'Purchase License',
    'enable_modules' => 'Enable Modules',
    'converted_quote' => 'Successfully converted quote',
    'credit_design' => 'Credit Design',
    'includes' => 'Includes',
    'css_framework' => 'CSS Framework',
    'custom_designs' => 'Custom Designs',
    'designs' => 'Designs',
    'new_design' => 'New Design',
    'edit_design' => 'Edit Design',
    'created_design' => 'Successfully created design',
    'updated_design' => 'Successfully updated design',
    'archived_design' => 'Successfully archived design',
    'deleted_design' => 'Successfully deleted design',
    'removed_design' => 'Successfully removed design',
    'restored_design' => 'Successfully restored design',
    'recurring_tasks' => 'Recurring Tasks',
    'removed_credit' => 'Successfully removed credit',
    'latest_version' => 'Latest Version',
    'update_now' => 'Update Now',
    'a_new_version_is_available' => 'A new version of the web app is available',
    'update_available' => 'Update Available',
    'app_updated' => 'Update successfully completed',
    'integrations' => 'Integrations',
    'tracking_id' => 'Tracking Id',
    'slack_webhook_url' => 'Slack Webhook URL',
    'partial_payment' => 'Partial Payment',
    'partial_payment_email' => 'Partial Payment Email',
    'clone_to_credit' => 'Clone to Credit',
    'emailed_credit' => 'Successfully emailed credit',
    'marked_credit_as_sent' => 'Successfully marked credit as sent',
    'email_subject_payment_partial' => 'Email Partial Payment Subject',
    'is_approved' => 'Is Approved',
    'migration_went_wrong' => 'Oops, something went wrong! Please make sure you have setup an Invoice Ninja v5 instance before starting the migration.',
    'cross_migration_message' => 'Cross account migration is not allowed. Please read more about it here: <a href="https://invoiceninja.github.io/docs/migration/#troubleshooting">https://invoiceninja.github.io/docs/migration/#troubleshooting</a>',
    'email_credit' => 'Email Credit',
    'client_email_not_set' => 'Client does not have an email address set',
    'ledger' => 'Ledger',
    'view_pdf' => 'View PDF',
    'all_records' => 'All records',
    'owned_by_user' => 'Owned by user',
    'credit_remaining' => 'Credit Remaining',
    'use_default' => 'Use default',
    'reminder_endless' => 'Endless Reminders',
    'number_of_days' => 'Number of days',
    'configure_payment_terms' => 'Configure Payment Terms',
    'payment_term' => 'Payment Term',
    'new_payment_term' => 'New Payment Term',
    'deleted_payment_term' => 'Successfully deleted payment term',
    'removed_payment_term' => 'Successfully removed payment term',
    'restored_payment_term' => 'Successfully restored payment term',
    'full_width_editor' => 'Full Width Editor',
    'full_height_filter' => 'Full Height Filter',
    'email_sign_in' => 'Sign in with email',
    'change' => 'Change',
    'change_to_mobile_layout' => 'Change to the mobile layout?',
    'change_to_desktop_layout' => 'Change to the desktop layout?',
    'send_from_gmail' => 'Send from Gmail',
    'reversed' => 'Reversed',
    'cancelled' => 'Cancelled',
    'quote_amount' => 'Quote Amount',
    'hosted' => 'Hosted',
    'selfhosted' => 'Self-Hosted',
    'hide_menu' => 'Hide Menu',
    'show_menu' => 'Show Menu',
    'partially_refunded' => 'Partially Refunded',
    'search_documents' => 'Search Documents',
    'search_designs' => 'Search Designs',
    'search_invoices' => 'Search Invoices',
    'search_clients' => 'Search Clients',
    'search_products' => 'Search Products',
    'search_quotes' => 'Search Quotes',
    'search_credits' => 'Search Credits',
    'search_vendors' => 'Search Vendors',
    'search_users' => 'Search Users',
    'search_tax_rates' => 'Search Tax Rates',
    'search_tasks' => 'Search Tasks',
    'search_settings' => 'Search Settings',
    'search_projects' => 'Search Projects',
    'search_expenses' => 'Search Expenses',
    'search_payments' => 'Search Payments',
    'search_groups' => 'Search Groups',
    'search_company' => 'Search Company',
    'cancelled_invoice' => 'Successfully cancelled invoice',
    'cancelled_invoices' => 'Successfully cancelled invoices',
    'reversed_invoice' => 'Successfully reversed invoice',
    'reversed_invoices' => 'Successfully reversed invoices',
    'reverse' => 'Reverse',
    'filtered_by_project' => 'Filtered by Project',
    'google_sign_in' => 'Sign in with Google',
    'activity_58' => ':user reversed invoice :invoice',
    'activity_59' => ':user cancelled invoice :invoice',
    'payment_reconciliation_failure' => 'Reconciliation Failure',
    'payment_reconciliation_success' => 'Reconciliation Success',
    'gateway_success' => 'Gateway Success',
    'gateway_failure' => 'Gateway Failure',
    'gateway_error' => 'Gateway Error',
    'email_send' => 'Email Send',
    'email_retry_queue' => 'Email Retry Queue',
    'failure' => 'Failure',
    'quota_exceeded' => 'Quota Exceeded',
    'upstream_failure' => 'Upstream Failure',
    'system_logs' => 'System Logs',
    'copy_link' => 'Copy Link',
    'welcome_to_invoice_ninja' => 'Welcome to Invoice Ninja',
    'optin' => 'Opt-In',
    'optout' => 'Opt-Out',
    'auto_convert' => 'Auto Convert',
    'reminder1_sent' => 'Reminder 1 Sent',
    'reminder2_sent' => 'Reminder 2 Sent',
    'reminder3_sent' => 'Reminder 3 Sent',
    'reminder_last_sent' => 'Reminder Last Sent',
    'pdf_page_info' => 'Page :current of :total',
    'emailed_credits' => 'Successfully emailed credits',
    'view_in_stripe' => 'View in Stripe',
    'rows_per_page' => 'Rows Per Page',
    'apply_payment' => 'Apply Payment',
    'unapplied' => 'Unapplied',
    'custom_labels' => 'Custom Labels',
    'record_type' => 'Record Type',
    'record_name' => 'Record Name',
    'file_type' => 'File Type',
    'height' => 'Height',
    'width' => 'Width',
    'health_check' => 'Health Check',
    'last_login_at' => 'Last Login At',
    'company_key' => 'Company Key',
    'storefront' => 'Storefront',
    'storefront_help' => 'Enable third-party apps to create invoices',
    'count_records_selected' => ':count records selected',
    'count_record_selected' => ':count record selected',
    'client_created' => 'Client Created',
    'online_payment_email' => 'Online Payment Email',
    'manual_payment_email' => 'Manual Payment Email',
    'completed' => 'Completed',
    'gross' => 'Gross',
    'net_amount' => 'Net Amount',
    'net_balance' => 'Net Balance',
    'client_settings' => 'Client Settings',
    'selected_invoices' => 'Selected Invoices',
    'selected_payments' => 'Selected Payments',
    'selected_quotes' => 'Selected Quotes',
    'selected_tasks' => 'Selected Tasks',
    'selected_expenses' => 'Selected Expenses',
    'past_due_invoices' => 'Past Due Invoices',
    'create_payment' => 'Create Payment',
    'update_quote' => 'Update Quote',
    'update_invoice' => 'Update Invoice',
    'update_client' => 'Update Client',
    'update_vendor' => 'Update Vendor',
    'create_expense' => 'Create Expense',
    'update_expense' => 'Update Expense',
    'update_task' => 'Update Task',
    'approve_quote' => 'Approve Quote',
    'when_paid' => 'When Paid',
    'expires_on' => 'Expires On',
    'show_sidebar' => 'Show Sidebar',
    'hide_sidebar' => 'Hide Sidebar',
    'event_type' => 'Event Type',
    'copy' => 'Copy',
    'must_be_online' => 'Please restart the app once connected to the internet',
    'crons_not_enabled' => 'The crons need to be enabled',
    'api_webhooks' => 'API Webhooks',
    'search_webhooks' => 'Search :count Webhooks',
    'search_webhook' => 'Search 1 Webhook',
    'webhook' => 'Webhook',
    'webhooks' => 'Webhooks',
    'new_webhook' => 'New Webhook',
    'edit_webhook' => 'Edit Webhook',
    'created_webhook' => 'Successfully created webhook',
    'updated_webhook' => 'Successfully updated webhook',
    'archived_webhook' => 'Successfully archived webhook',
    'deleted_webhook' => 'Successfully deleted webhook',
    'removed_webhook' => 'Successfully removed webhook',
    'restored_webhook' => 'Successfully restored webhook',
    'search_tokens' => 'Search :count Tokens',
    'search_token' => 'Search 1 Token',
    'new_token' => 'New Token',
    'removed_token' => 'Successfully removed token',
    'restored_token' => 'Successfully restored token',
    'client_registration' => 'Client Registration',
    'client_registration_help' => 'Enable clients to self register in the portal',
    'customize_and_preview' => 'Customize & Preview',
    'search_document' => 'Search 1 Document',
    'search_design' => 'Search 1 Design',
    'search_invoice' => 'Search 1 Invoice',
    'search_client' => 'Search 1 Client',
    'search_product' => 'Search 1 Product',
    'search_quote' => 'Search 1 Quote',
    'search_credit' => 'Search 1 Credit',
    'search_vendor' => 'Search 1 Vendor',
    'search_user' => 'Search 1 User',
    'search_tax_rate' => 'Search 1 Tax Rate',
    'search_task' => 'Search 1 Tasks',
    'search_project' => 'Search 1 Project',
    'search_expense' => 'Search 1 Expense',
    'search_payment' => 'Search 1 Payment',
    'search_group' => 'Search 1 Group',
    'created_on' => 'Created On',
    'payment_status_-1' => 'Unapplied',
    'lock_invoices' => 'Lock Invoices',
    'show_table' => 'Show Table',
    'show_list' => 'Show List',
    'view_changes' => 'View Changes',
    'force_update' => 'Force Update',
    'force_update_help' => 'You are running the latest version but there may be pending fixes available.',
    'mark_paid_help' => 'Track the expense has been paid',
    'mark_invoiceable_help' => 'Enable the expense to be invoiced',
    'add_documents_to_invoice_help' => 'Make the documents visible',
    'convert_currency_help' => 'Set an exchange rate',
    'expense_settings' => 'Expense Settings',
    'clone_to_recurring' => 'Clone to Recurring',
    'crypto' => 'Crypto',
    'user_field' => 'User Field',
    'variables' => 'Variables',
    'show_password' => 'Show Password',
    'hide_password' => 'Hide Password',
    'copy_error' => 'Copy Error',
    'capture_card' => 'Capture Card',
    'auto_bill_enabled' => 'Auto Bill Enabled',
    'total_taxes' => 'Total Taxes',
    'line_taxes' => 'Line Taxes',
    'total_fields' => 'Total Fields',
    'stopped_recurring_invoice' => 'Successfully stopped recurring invoice',
    'started_recurring_invoice' => 'Successfully started recurring invoice',
    'resumed_recurring_invoice' => 'Successfully resumed recurring invoice',
    'gateway_refund' => 'Gateway Refund',
    'gateway_refund_help' => 'Process the refund with the payment gateway',
    'due_date_days' => 'Due Date',
    'paused' => 'Paused',
    'day_count' => 'Day :count',
    'first_day_of_the_month' => 'First Day of the Month',
    'last_day_of_the_month' => 'Last Day of the Month',
    'use_payment_terms' => 'Use Payment Terms',
    'endless' => 'Endless',
    'next_send_date' => 'Next Send Date',
    'remaining_cycles' => 'Remaining Cycles',
    'created_recurring_invoice' => 'Successfully created recurring invoice',
    'updated_recurring_invoice' => 'Successfully updated recurring invoice',
    'removed_recurring_invoice' => 'Successfully removed recurring invoice',
    'search_recurring_invoice' => 'Search 1 Recurring Invoice',
    'search_recurring_invoices' => 'Search :count Recurring Invoices',
    'send_date' => 'Send Date',
    'auto_bill_on' => 'Auto Bill On',
    'minimum_under_payment_amount' => 'Minimum Under Payment Amount',
    'allow_over_payment' => 'Allow Over Payment',
    'allow_over_payment_help' => 'Support paying extra to accept tips',
    'allow_under_payment' => 'Allow Under Payment',
    'allow_under_payment_help' => 'Support paying at minimum the partial/deposit amount',
    'test_mode' => 'Test Mode',
    'calculated_rate' => 'Calculated Rate',
    'default_task_rate' => 'Default Task Rate',
    'clear_cache' => 'Clear Cache',
    'sort_order' => 'Sort Order',
    'task_status' => 'Status',
    'task_statuses' => 'Task Statuses',
    'new_task_status' => 'New Task Status',
    'edit_task_status' => 'Edit Task Status',
    'created_task_status' => 'Successfully created task status',
    'archived_task_status' => 'Successfully archived task status',
    'deleted_task_status' => 'Successfully deleted task status',
    'removed_task_status' => 'Successfully removed task status',
    'restored_task_status' => 'Successfully restored task status',
    'search_task_status' => 'Search 1 Task Status',
    'search_task_statuses' => 'Search :count Task Statuses',
    'show_tasks_table' => 'Show Tasks Table',
    'show_tasks_table_help' => 'Always show the tasks section when creating invoices',
    'invoice_task_timelog' => 'Invoice Task Timelog',
    'invoice_task_timelog_help' => 'Add time details to the invoice line items',
    'auto_start_tasks_help' => 'Start tasks before saving',
    'configure_statuses' => 'Configure Statuses',
    'task_settings' => 'Task Settings',
    'configure_categories' => 'Configure Categories',
    'edit_expense_category' => 'Edit Expense Category',
    'removed_expense_category' => 'Successfully removed expense category',
    'search_expense_category' => 'Search 1 Expense Category',
    'search_expense_categories' => 'Search :count Expense Categories',
    'use_available_credits' => 'Use Available Credits',
    'show_option' => 'Show Option',
    'negative_payment_error' => 'The credit amount cannot exceed the payment amount',
    'should_be_invoiced_help' => 'Enable the expense to be invoiced',
    'configure_gateways' => 'Configure Gateways',
    'payment_partial' => 'Partial Payment',
    'is_running' => 'Is Running',
    'invoice_currency_id' => 'Invoice Currency ID',
    'tax_name1' => 'Tax Name 1',
    'tax_name2' => 'Tax Name 2',
    'transaction_id' => 'Transaction ID',
    'invoice_late' => 'Invoice Late',
    'quote_expired' => 'Quote Expired',
    'recurring_invoice_total' => 'Invoice Total',
    'actions' => 'Actions',
    'expense_number' => 'Expense Number',
    'task_number' => 'Task Number',
    'project_number' => 'Project Number',
    'view_settings' => 'View Settings',
    'company_disabled_warning' => 'Warning: this company has not yet been activated',
    'late_invoice' => 'Late Invoice',
    'expired_quote' => 'Expired Quote',
    'remind_invoice' => 'Remind Invoice',
    'client_phone' => 'Client Phone',
    'required_fields' => 'Required Fields',
    'enabled_modules' => 'Enabled Modules',
    'activity_60' => ':contact viewed quote :quote',
    'activity_61' => ':user updated client :client',
    'activity_62' => ':user updated vendor :vendor',
    'activity_63' => ':user emailed first reminder for invoice :invoice to :contact',
    'activity_64' => ':user emailed second reminder for invoice :invoice to :contact',
    'activity_65' => ':user emailed third reminder for invoice :invoice to :contact',
    'activity_66' => ':user emailed endless reminder for invoice :invoice to :contact',
    'expense_category_id' => 'Expense Category ID',
    'view_licenses' => 'View Licenses',
    'fullscreen_editor' => 'Fullscreen Editor',
    'sidebar_editor' => 'Sidebar Editor',
    'please_type_to_confirm' => 'Please type ":value" to confirm',
    'purge' => 'Purge',
    'clone_to' => 'Clone To',
    'clone_to_other' => 'Clone to Other',
    'labels' => 'Labels',
    'add_custom' => 'Add Custom',
    'payment_tax' => 'Payment Tax',
    'white_label' => 'White Label',
    'sent_invoices_are_locked' => 'Sent invoices are locked',
    'paid_invoices_are_locked' => 'Paid invoices are locked',
    'source_code' => 'Source Code',
    'app_platforms' => 'App Platforms',
    'archived_task_statuses' => 'Successfully archived :value task statuses',
    'deleted_task_statuses' => 'Successfully deleted :value task statuses',
    'restored_task_statuses' => 'Successfully restored :value task statuses',
    'deleted_expense_categories' => 'Successfully deleted expense :value categories',
    'restored_expense_categories' => 'Successfully restored expense :value categories',
    'archived_recurring_invoices' => 'Successfully archived recurring :value invoices',
    'deleted_recurring_invoices' => 'Successfully deleted recurring :value invoices',
    'restored_recurring_invoices' => 'Successfully restored recurring :value invoices',
    'archived_webhooks' => 'Successfully archived :value webhooks',
    'deleted_webhooks' => 'Successfully deleted :value webhooks',
    'removed_webhooks' => 'Successfully removed :value webhooks',
    'restored_webhooks' => 'Successfully restored :value webhooks',
    'api_docs' => 'API Docs',
    'archived_tokens' => 'Successfully archived :value tokens',
    'deleted_tokens' => 'Successfully deleted :value tokens',
    'restored_tokens' => 'Successfully restored :value tokens',
    'archived_payment_terms' => 'Successfully archived :value payment terms',
    'deleted_payment_terms' => 'Successfully deleted :value payment terms',
    'restored_payment_terms' => 'Successfully restored :value payment terms',
    'archived_designs' => 'Successfully archived :value designs',
    'deleted_designs' => 'Successfully deleted :value designs',
    'restored_designs' => 'Successfully restored :value designs',
    'restored_credits' => 'Successfully restored :value credits',
    'archived_users' => 'Successfully archived :value users',
    'deleted_users' => 'Successfully deleted :value users',
    'removed_users' => 'Successfully removed :value users',
    'restored_users' => 'Successfully restored :value users',
    'archived_tax_rates' => 'Successfully archived :value tax rates',
    'deleted_tax_rates' => 'Successfully deleted :value tax rates',
    'restored_tax_rates' => 'Successfully restored :value tax rates',
    'archived_company_gateways' => 'Successfully archived :value gateways',
    'deleted_company_gateways' => 'Successfully deleted :value gateways',
    'restored_company_gateways' => 'Successfully restored :value gateways',
    'archived_groups' => 'Successfully archived :value groups',
    'deleted_groups' => 'Successfully deleted :value groups',
    'restored_groups' => 'Successfully restored :value groups',
    'archived_documents' => 'Successfully archived :value documents',
    'deleted_documents' => 'Successfully deleted :value documents',
    'restored_documents' => 'Successfully restored :value documents',
    'restored_vendors' => 'Successfully restored :value vendors',
    'restored_expenses' => 'Successfully restored :value expenses',
    'restored_tasks' => 'Successfully restored :value tasks',
    'restored_projects' => 'Successfully restored :value projects',
    'restored_products' => 'Successfully restored :value products',
    'restored_clients' => 'Successfully restored :value clients',
    'restored_invoices' => 'Successfully restored :value invoices',
    'restored_payments' => 'Successfully restored :value payments',
    'restored_quotes' => 'Successfully restored :value quotes',
    'update_app' => 'Update App',
    'started_import' => 'Successfully started import',
    'duplicate_column_mapping' => 'Duplicate column mapping',
    'uses_inclusive_taxes' => 'Uses Inclusive Taxes',
    'is_amount_discount' => 'Is Amount Discount',
    'map_to' => 'Map To',
    'first_row_as_column_names' => 'Use first row as column names',
    'no_file_selected' => 'No File Selected',
    'import_type' => 'Import Type',
    'draft_mode' => 'Draft Mode',
    'draft_mode_help' => 'Preview updates faster but is less accurate',
    'show_product_discount' => 'Show Product Discount',
    'show_product_discount_help' => 'Display a line item discount field',
    'tax_name3' => 'Tax Name 3',
    'debug_mode_is_enabled' => 'Debug mode is enabled',
    'debug_mode_is_enabled_help' => 'Warning: it is intended for use on local machines, it can leak credentials. Click to learn more.',
    'running_tasks' => 'Running Tasks',
    'recent_tasks' => 'Recent Tasks',
    'recent_expenses' => 'Recent Expenses',
    'upcoming_expenses' => 'Upcoming Expenses',
    'search_payment_term' => 'Search 1 Payment Term',
    'search_payment_terms' => 'Search :count Payment Terms',
    'save_and_preview' => 'Save and Preview',
    'save_and_email' => 'Save and Email',
    'converted_balance' => 'Converted Balance',
    'is_sent' => 'Is Sent',
    'document_upload' => 'Document Upload',
    'document_upload_help' => 'Enable clients to upload documents',
    'expense_total' => 'Expense Total',
    'enter_taxes' => 'Enter Taxes',
    'by_rate' => 'By Rate',
    'by_amount' => 'By Amount',
    'enter_amount' => 'Enter Amount',
    'before_taxes' => 'Before Taxes',
    'after_taxes' => 'After Taxes',
    'color' => 'Color',
    'show' => 'Show',
    'empty_columns' => 'Empty Columns',
    'project_name' => 'Project Name',
    'counter_pattern_error' => 'To use :client_counter please add either :client_number or :client_id_number to prevent conflicts',
    'this_quarter' => 'This Quarter',
    'to_update_run' => 'To update run',
    'registration_url' => 'Registration URL',
    'show_product_cost' => 'Show Product Cost',
    'complete' => 'Complete',
     'next' => 'Next',
     'next_step' => 'Next step',
     'notification_credit_sent_subject' => 'Credit :invoice was sent to :client',
     'notification_credit_viewed_subject' => 'Credit :invoice was viewed by :client',
     'notification_credit_sent' => 'The following client :client was emailed Credit :invoice for :amount.',
     'notification_credit_viewed' => 'The following client :client viewed Credit :credit for :amount.',
     'reset_password_text' => 'Enter your email to reset your password.',
     'password_reset' => 'Password reset',
     'account_login_text' => 'Welcome back! Glad to see you.',
     'request_cancellation' => 'Request cancellation',
     'delete_payment_method' => 'Delete Payment Method',
     'about_to_delete_payment_method' => 'You are about to delete the payment method.',
     'action_cant_be_reversed' => 'Action can\'t be reversed',
     'profile_updated_successfully' => 'The profile has been updated successfully.',
     'currency_ethiopian_birr' => 'Ethiopian Birr',
     'client_information_text' => 'Use a permanent address where you can receive mail.',
     'status_id' => 'Invoice Status',
     'email_already_register' => 'This email is already linked to an account',
     'locations' => 'Locations',
     'freq_indefinitely' => 'Indefinitely',
     'cycles_remaining' => 'Cycles remaining',
     'i_understand_delete' => 'I understand, delete',
     'download_files' => 'Download Files',
     'download_timeframe' => 'Use this link to download your files, the link will expire in 1 hour.',
     'new_signup' => 'New Signup',
     'new_signup_text' => 'A new account has been created by :user - :email - from IP address: :ip',
     'notification_payment_paid_subject' => 'Payment was made by :client',
     'notification_partial_payment_paid_subject' => 'Partial payment was made by :client',
     'notification_payment_paid' => 'A payment of :amount was made by client :client towards :invoice',
     'notification_partial_payment_paid' => 'A partial payment of :amount was made by client :client towards :invoice',
     'notification_bot' => 'Notification Bot',
     'invoice_number_placeholder' => 'Invoice # :invoice',
     'entity_number_placeholder' => ':entity # :entity_number',
     'email_link_not_working' => 'If the button above isn\'t working for you, please click on the link',
     'display_log' => 'Display Log',
     'send_fail_logs_to_our_server' => 'Report errors in realtime',
     'setup' => 'Setup',
     'quick_overview_statistics' => 'Quick overview & statistics',
     'update_your_personal_info' => 'Update your personal information',
     'name_website_logo' => 'Name, website & logo',
     'make_sure_use_full_link' => 'Make sure you use full link to your site',
     'personal_address' => 'Personal address',
     'enter_your_personal_address' => 'Enter your personal address',
     'enter_your_shipping_address' => 'Enter your shipping address',
     'list_of_invoices' => 'List of invoices',
     'with_selected' => 'With selected',
     'invoice_still_unpaid' => 'This invoice is still not paid. Click the button to complete the payment',
     'list_of_recurring_invoices' => 'List of recurring invoices',
     'details_of_recurring_invoice' => 'Here are some details about recurring invoice',
     'cancellation' => 'Cancellation',
     'about_cancellation' => 'In case you want to stop the recurring invoice,\n please click the request the cancellation.',
     'cancellation_warning' => 'Warning! You are requesting a cancellation of this service.\n Your service may be cancelled with no further notification to you.',
     'cancellation_pending' => 'Cancellation pending, we\'ll be in touch!',
     'list_of_payments' => 'List of payments',
     'payment_details' => 'Details of the payment',
     'list_of_payment_invoices' => 'List of invoices affected by the payment',
     'list_of_payment_methods' => 'List of payment methods',
     'payment_method_details' => 'Details of payment method',
     'permanently_remove_payment_method' => 'Permanently remove this payment method.',
     'warning_action_cannot_be_reversed' => 'Warning! This action can not be reversed!',
     'confirmation' => 'Confirmation',
     'list_of_quotes' => 'Quotes',
     'waiting_for_approval' => 'Waiting for approval',
     'quote_still_not_approved' => 'This quote is still not approved',
     'list_of_credits' => 'Credits',
     'required_extensions' => 'Required extensions',
     'php_version' => 'PHP version',
     'writable_env_file' => 'Writable .env file',
     'env_not_writable' => '.env file is not writable by the current user.',
     'minumum_php_version' => 'Minimum PHP version',
     'satisfy_requirements' => 'Make sure all requirements are satisfied.',
     'oops_issues' => 'Oops, something does not look right!',
     'open_in_new_tab' => 'Open in new tab',
     'complete_your_payment' => 'Complete payment',
     'authorize_for_future_use' => 'Authorize payment method for future use',
     'page' => 'Page',
     'per_page' => 'Per page',
     'of' => 'Of',
     'view_credit' => 'View Credit',
     'to_view_entity_password' => 'To view the :entity you need to enter password.',
     'showing_x_of' => 'Showing :first to :last out of :total results',
     'no_results' => 'No results found.',
     'payment_failed_subject' => 'Payment failed for Client :client',
     'payment_failed_body' => 'A payment made by client :client failed with message :message',
     'register' => 'Register',
     'register_label' => 'Create your account in seconds',
     'password_confirmation' => 'Confirm your password',
     'verification' => 'Verification',
     'complete_your_bank_account_verification' => 'Before using a bank account it must be verified.',
     'checkout_com' => 'Checkout.com',
     'footer_label' => 'Copyright © :year :company.',
     'credit_card_invalid' => 'Provided credit card number is not valid.',
     'month_invalid' => 'Provided month is not valid.',
     'year_invalid' => 'Provided year is not valid.',
     'https_required' => 'HTTPS is required, form will fail',
     'if_you_need_help' => 'If you need help you can post to our',
     'update_password_on_confirm' => 'After updating password, your account will be confirmed.',
     'bank_account_not_linked' => 'To pay with a bank account, first you have to add it as payment method.',
     'application_settings_label' => 'Let\'s store basic information about your Invoice Ninja!',
     'recommended_in_production' => 'Highly recommended in production',
     'enable_only_for_development' => 'Enable only for development',
     'test_pdf' => 'Test PDF',
     'checkout_authorize_label' => 'Checkout.com can be can saved as payment method for future use, once you complete your first transaction. Don\'t forget to check "Store credit card details" during payment process.',
     'sofort_authorize_label' => 'Bank account (SOFORT) can be can saved as payment method for future use, once you complete your first transaction. Don\'t forget to check "Store payment details" during payment process.',
     'node_status' => 'Node status',
     'npm_status' => 'NPM status',
     'node_status_not_found' => 'I could not find Node anywhere. Is it installed?',
     'npm_status_not_found' => 'I could not find NPM anywhere. Is it installed?',
     'locked_invoice' => 'This invoice is locked and unable to be modified',
     'downloads' => 'Downloads',
     'resource' => 'Resource',
     'document_details' => 'Details about the document',
     'hash' => 'Hash',
     'resources' => 'Resources',
     'allowed_file_types' => 'Allowed file types:',
     'common_codes' => 'Common codes and their meanings',
     'payment_error_code_20087' => '20087: Bad Track Data (invalid CVV and/or expiry date)',
     'download_selected' => 'Download selected',
     'to_pay_invoices' => 'To pay invoices, you have to',
     'add_payment_method_first' => 'add payment method',
     'no_items_selected' => 'No items selected.',
     'payment_due' => 'Payment due',
     'account_balance' => 'Account balance',
     'thanks' => 'Thanks',
     'minimum_required_payment' => 'Minimum required payment is :amount',
     'under_payments_disabled' => 'Company doesn\'t support under payments.',
     'over_payments_disabled' => 'Company doesn\'t support over payments.',
     'saved_at' => 'Saved at :time',
     'credit_payment' => 'Credit applied to Invoice :invoice_number',
     'credit_subject' => 'New credit :number from :account',
     'credit_message' => 'To view your credit for :amount, click the link below.',
     'payment_type_Crypto' => 'Cryptocurrency',
     'payment_type_Credit' => 'Credit',
     'store_for_future_use' => 'Store for future use',
     'pay_with_credit' => 'Pay with credit',
     'payment_method_saving_failed' => 'Payment method can\'t be saved for future use.',
     'pay_with' => 'Pay with',
     'n/a' => 'N/A',
     'by_clicking_next_you_accept_terms' => 'By clicking "Next step" you accept terms.',
     'not_specified' => 'Not specified',
     'before_proceeding_with_payment_warning' => 'Before proceeding with payment, you have to fill following fields',
     'after_completing_go_back_to_previous_page' => 'After completing, go back to previous page.',
     'pay' => 'Pay',
     'instructions' => 'Instructions',
     'notification_invoice_reminder1_sent_subject' => 'Reminder 1 for Invoice :invoice was sent to :client',
     'notification_invoice_reminder2_sent_subject' => 'Reminder 2 for Invoice :invoice was sent to :client',
     'notification_invoice_reminder3_sent_subject' => 'Reminder 3 for Invoice :invoice was sent to :client',
     'notification_invoice_reminder_endless_sent_subject' => 'Endless reminder for Invoice :invoice was sent to :client',
     'assigned_user' => 'Assigned User',
     'setup_steps_notice' => 'To proceed to next step, make sure you test each section.',
     'setup_phantomjs_note' => 'Note about Phantom JS. Read more.',
     'minimum_payment' => 'Minimum Payment',
     'no_action_provided' => 'No action provided. If you believe this is wrong, please contact the support.',
     'no_payable_invoices_selected' => 'No payable invoices selected. Make sure you are not trying to pay draft invoice or invoice with zero balance due.',
     'required_payment_information' => 'Required payment details',
     'required_payment_information_more' => 'To complete a payment we need more details about you.',
     'required_client_info_save_label' => 'We will save this, so you don\'t have to enter it next time.',
     'notification_credit_bounced' => 'We were unable to deliver Credit :invoice to :contact. \n :error',
     'notification_credit_bounced_subject' => 'Unable to deliver Credit :invoice',
     'save_payment_method_details' => 'Save payment method details',
     'new_card' => 'New card',
     'new_bank_account' => 'New bank account',
     'company_limit_reached' => 'Limit of 10 companies per account.',
     'credits_applied_validation' => 'Total credits applied cannot be MORE than total of invoices',
     'credit_number_taken' => 'Credit number already taken',
     'credit_not_found' => 'Credit not found',
     'invoices_dont_match_client' => 'Selected invoices are not from a single client',
     'duplicate_credits_submitted' => 'Duplicate credits submitted.',
     'duplicate_invoices_submitted' => 'Duplicate invoices submitted.',
     'credit_with_no_invoice' => 'You must have an invoice set when using a credit in a payment',
     'client_id_required' => 'Client id is required',
     'expense_number_taken' => 'Expense number already taken',
     'invoice_number_taken' => 'Invoice number already taken',
     'payment_id_required' => 'Payment `id` required.',
     'unable_to_retrieve_payment' => 'Unable to retrieve specified payment',
     'invoice_not_related_to_payment' => 'Invoice id :invoice is not related to this payment',
     'credit_not_related_to_payment' => 'Credit id :credit is not related to this payment',
     'max_refundable_invoice' => 'Attempting to refund more than allowed for invoice id :invoice, maximum refundable amount is :amount',
     'refund_without_invoices' => 'Attempting to refund a payment with invoices attached, please specify valid invoice/s to be refunded.',
     'refund_without_credits' => 'Attempting to refund a payment with credits attached, please specify valid credits/s to be refunded.',
     'max_refundable_credit' => 'Attempting to refund more than allowed for credit :credit, maximum refundable amount is :amount',
     'project_client_do_not_match' => 'Project client does not match entity client',
     'quote_number_taken' => 'Quote number already taken',
     'recurring_invoice_number_taken' => 'Recurring Invoice number :number already taken',
     'user_not_associated_with_account' => 'User not associated with this account',
     'amounts_do_not_balance' => 'Amounts do not balance correctly.',
     'insufficient_applied_amount_remaining' => 'Insufficient applied amount remaining to cover payment.',
     'insufficient_credit_balance' => 'Insufficient balance on credit.',
     'one_or_more_invoices_paid' => 'One or more of these invoices have been paid',
     'invoice_cannot_be_refunded' => 'Invoice id :number cannot be refunded',
     'attempted_refund_failed' => 'Attempting to refund :amount only :refundable_amount available for refund',
     'user_not_associated_with_this_account' => 'This user is unable to be attached to this company. Perhaps they have already registered a user on another account?',
     'migration_completed' => 'Migration completed',
     'migration_completed_description' => 'Your migration has completed, please review your data after logging in.',
     'api_404' => '404 | Nothing to see here!',
     'large_account_update_parameter' => 'Cannot load a large account without a updated_at parameter',
     'no_backup_exists' => 'No backup exists for this activity',
     'company_user_not_found' => 'Company User record not found',
     'no_credits_found' => 'No credits found.',
     'action_unavailable' => 'The requested action :action is not available.',
     'no_documents_found' => 'No Documents Found',
     'no_group_settings_found' => 'No group settings found',
     'access_denied' => 'Insufficient privileges to access/modify this resource',
     'invoice_cannot_be_marked_paid' => 'Invoice cannot be marked as paid',
     'invoice_license_or_environment' => 'Invalid license, or invalid environment :environment',
     'route_not_available' => 'Route not available',
     'invalid_design_object' => 'Invalid custom design object',
     'quote_not_found' => 'Quote/s not found',
     'quote_unapprovable' => 'Unable to approve this quote as it has expired.',
     'scheduler_has_run' => 'Scheduler has run',
     'scheduler_has_never_run' => 'Scheduler has never run',
     'self_update_not_available' => 'Self update not available on this system.',
     'user_detached' => 'User detached from company',
     'create_webhook_failure' => 'Failed to create Webhook',
     'payment_message_extended' => 'Thank you for your payment of :amount for :invoice',
     'online_payments_minimum_note' => 'Note: Online payments are supported only if amount is bigger than $1 or currency equivalent.',
     'payment_token_not_found' => 'Payment token not found, please try again. If an issue still persist, try with another payment method',
     'vendor_address1' => 'Vendor Street',
     'vendor_address2' => 'Vendor Apt/Suite',
     'partially_unapplied' => 'Partially Unapplied',
     'select_a_gmail_user' => 'Please select a user authenticated with Gmail',
     'list_long_press' => 'List Long Press',
     'show_actions' => 'Show Actions',
     'start_multiselect' => 'Start Multiselect',
     'email_sent_to_confirm_email' => 'An email has been sent to confirm the email address',
     'converted_paid_to_date' => 'Converted Paid to Date',
     'converted_credit_balance' => 'Converted Credit Balance',
     'converted_total' => 'Converted Total',
     'reply_to_name' => 'Reply-To Name',
     'payment_status_-2' => 'Partially Unapplied',
     'color_theme' => 'Color Theme',
     'start_migration' => 'Start Migration',
     'recurring_cancellation_request' => 'Request for recurring invoice cancellation from :contact',
     'recurring_cancellation_request_body' => ':contact from Client :client requested to cancel Recurring Invoice :invoice',
     'hello' => 'Hello',
     'group_documents' => 'Group documents',
     'quote_approval_confirmation_label' => 'Are you sure you want to approve this quote?',
     'migration_select_company_label' => 'Select companies to migrate',
     'force_migration' => 'Force migration',
     'require_password_with_social_login' => 'Require Password with Social Login',
     'stay_logged_in' => 'Stay Logged In',
     'session_about_to_expire' => 'Warning: Your session is about to expire',
     'count_hours' => ':count Hours',
     'count_day' => '1 Day',
     'count_days' => ':count Days',
     'web_session_timeout' => 'Web Session Timeout',
     'security_settings' => 'Security Settings',
     'resend_email' => 'Resend Email',
     'confirm_your_email_address' => 'Please confirm your email address',
     'freshbooks' => 'FreshBooks',
     'invoice2go' => 'Invoice2go',
     'invoicely' => 'Invoicely',
     'waveaccounting' => 'Wave Accounting',
     'zoho' => 'Zoho',
     'accounting' => 'Accounting',
     'required_files_missing' => 'Please provide all CSVs.',
     'migration_auth_label' => 'Let\'s continue by authenticating. (These credentials should be identical across systems)',
     'api_secret' => 'API secret',
     'migration_api_secret_notice' => 'You can find API_SECRET in the .env file or Invoice Ninja v5. If property is missing, leave field blank.',
     'billing_coupon_notice' => 'Your discount will be applied on the checkout.',
     'use_last_email' => 'Use last email',
     'activate_company' => 'Activate Company',
     'activate_company_help' => 'Enable emails, recurring invoices and notifications',
     'an_error_occurred_try_again' => 'An error occurred, please try again',
     'please_first_set_a_password' => 'Please first set a password',
     'changing_phone_disables_two_factor' => 'Warning: Changing your phone number will disable 2FA',
     'help_translate' => 'Help Translate',
     'please_select_a_country' => 'Please select a country',
     'disabled_two_factor' => 'Successfully disabled 2FA',
     'connected_google' => 'Successfully connected account',
     'disconnected_google' => 'Successfully disconnected account',
     'delivered' => 'Delivered',
     'spam' => 'Spam',
     'view_docs' => 'View Docs',
     'enter_phone_to_enable_two_factor' => 'Please provide a mobile phone number to enable two factor authentication',
     'send_sms' => 'Send SMS',
     'sms_code' => 'SMS Code',
     'connect_google' => 'Connect Google',
     'disconnect_google' => 'Disconnect Google',
     'disable_two_factor' => 'Disable Two Factor',
     'invoice_task_datelog' => 'Invoice Task Datelog',
     'invoice_task_datelog_help' => 'Add date details to the invoice line items',
     'promo_code' => 'Promo code',
     'recurring_invoice_issued_to' => 'Recurring invoice issued to',
     'amount_greater_than_balance_v5' => 'The amount is greater than the invoice balance. You cannot overpay an invoice.',
     'move_top' => 'Move Top',
     'move_up' => 'Move Up',
     'move_down' => 'Move Down',
     'move_bottom' => 'Move Bottom',
     'body_variable_missing' => 'Error: the custom email must include a :body variable',
     'add_body_variable_message' => 'Make sure to include a :body variable',
     'view_date_formats' => 'View Date Formats',
     'is_viewed' => 'Is Viewed',
     'letter' => 'Letter',
     'legal' => 'Legal',
     'page_layout' => 'Page Layout',
     'portrait' => 'Portrait',
     'landscape' => 'Landscape',
     'upgrade_to_paid_plan' => 'Upgrade to a paid plan to enable the advanded settings',
     'invoice_payment_terms' => 'Invoice Payment Terms',
     'quote_valid_until' => 'Quote Valid Until',
     'no_headers' => 'No Headers',
     'add_header' => 'Add Header',
     'remove_header' => 'Remove Header',
     'return_url' => 'Return URL',
     'rest_method' => 'REST Method',
     'header_key' => 'Header Key',
     'header_value' => 'Header Value',
     'recurring_products' => 'Recurring Products',
     'promo_discount' => 'Promo Discount',
     'allow_cancellation' => 'Allow Cancellation',
     'per_seat_enabled' => 'Per Seat Enabled',
     'max_seats_limit' => 'Max Seats Limit',
     'trial_enabled' => 'Trial Enabled',
     'trial_duration' => 'Trial Duration',
     'allow_query_overrides' => 'Allow Query Overrides',
     'allow_plan_changes' => 'Allow Plan Changes',
     'plan_map' => 'Plan Map',
     'refund_period' => 'Refund Period',
     'webhook_configuration' => 'Webhook Configuration',
     'purchase_page' => 'Purchase Page',
     'email_bounced' => 'Email Bounced',
     'email_spam_complaint' => 'Spam Complaint',
     'email_delivery' => 'Email Delivery',
     'webhook_response' => 'Webhook Response',
     'pdf_response' => 'PDF Response',
     'authentication_failure' => 'Authentication Failure',
     'pdf_failed' => 'PDF Failed',
     'pdf_success' => 'PDF Success',
     'modified' => 'Modified',
     'subscription' => 'Subscription',
     'new_subscription' => 'New Subscription',
     'deleted_subscription' => 'Successfully deleted subscription',
     'removed_subscription' => 'Successfully removed subscription',
     'restored_subscription' => 'Successfully restored subscription',
     'search_subscription' => 'Search 1 Subscription',
     'search_subscriptions' => 'Search :count Subscriptions',
     'subdomain_is_not_available' => 'Subdomain is not available',
     'connect_gmail' => 'Connect Gmail',
     'disconnect_gmail' => 'Disconnect Gmail',
     'connected_gmail' => 'Successfully connected Gmail',
     'disconnected_gmail' => 'Successfully disconnected Gmail',
     'update_fail_help' => 'Changes to the codebase may be blocking the update, you can run this command to discard the changes:',
     'client_id_number' => 'Client ID Number',
     'count_minutes' => ':count Minutes',
     'password_timeout' => 'Password Timeout',
     'shared_invoice_credit_counter' => 'Shared Invoice/Credit Counter',
    'activity_80' => ':user created subscription :subscription',
    'activity_81' => ':user updated subscription :subscription',
    'activity_82' => ':user archived subscription :subscription',
    'activity_83' => ':user deleted subscription :subscription',
    'activity_84' => ':user restored subscription :subscription',

    'amount_greater_than_balance_v5' => 'The amount is greater than the invoice balance. You cannot overpay an invoice.',
    'click_to_continue' => 'Click to continue',

    'notification_invoice_created_subject' => 'Invoice :invoice was created to :client',
    'notification_invoice_created_subject' => 'Invoice :invoice was created to :client',
    'notification_quote_created_subject' => 'Quote :invoice was created to :client',
    'notification_quote_created_subject' => 'Quote :invoice was created to :client',
    'notification_credit_created_subject' => 'Credit :invoice was created to :client',
    'notification_credit_created_subject' => 'Credit :invoice was created to :client',
    'migration_create_account_notice' => 'Please ensure you have created an account on the new platform first <a href="https://invoicing.co">here</a> , please ensure that the credentials are <b>identical</b> to your v4 credentials. Once the account has been created, you can start the migration process here.',
    'auth' => 'Authentication',
    'companies' => 'Select companies for migration',
    'activity_100' => ':user created recurring invoice :recurring_invoice',
    'activity_101' => ':user updated recurring invoice :recurring_invoice',
    'activity_102' => ':user archived recurring invoice :recurring_invoice',
    'activity_103' => ':user deleted recurring invoice :recurring_invoice',
    'activity_104' => ':user restored recurring invoice :recurring_invoice',

    'import_settings' => 'Import Settings',
    'json_file_missing' => 'Please provide the JSON file',
    'json_option_missing' => 'Please select to import the settings and/or data',
    'json' => 'JSON',
    'no_payment_types_enabled' => 'No payment types enabled',
    'wait_for_data' => 'Please wait for the data to finish loading',
    'net_total' => 'Net Total',
    'has_taxes' => 'Has Taxes',
    'import_customers' => 'Import Customers',
    'imported_customers' => 'Successfully started importing customers',
    'login_success' => 'Successful Login',
    'login_failure' => 'Failed Login',
    'exported_data' => 'Once the file is ready you"ll receive an email with a download link',
    'include_deleted_clients' => 'Include Deleted Clients',
    'include_deleted_clients_help' => 'Load records belonging to deleted clients',
    'step_1_sign_in' => 'Step 1: Sign In',
    'step_2_authorize' => 'Step 2: Authorize',
    'account_id' => 'Account ID',
    'migration_not_yet_completed' => 'The migration has not yet completed',
    'wizard_warning' => 'If you are migrating from the legacy version stop here and begin the migration. Once the migration completes click "Refesh" and use the dropdown in the top left corner to switch companies.',
    'show_task_end_date' => 'Show Task End Date',
    'show_task_end_date_help' => 'Enable specifying the task end date',
    'gateway_setup' => 'Gateway Setup',
    'preview_sidebar' => 'Preview Sidebar',
    'years_data_shown' => 'Years Data Shown',
    'ended_all_sessions' => 'Successfully ended all sessions',
    'end_all_sessions' => 'End All Sessions',
    'count_session' => '1 Session',
    'count_sessions' => ':count Sessions',
    'invoice_created' => 'Invoice Created',
    'quote_created' => 'Quote Created',
    'credit_created' => 'Credit Created',
    'enterprise' => 'Enterprise',
    'invoice_item' => 'Invoice Item',
    'quote_item' => 'Quote Item',
    'order' => 'Order',
    'search_kanban' => 'Search Kanban',
    'search_kanbans' => 'Search Kanban',
    'owner_upgrade_to_paid_plan' => 'The account owner can upgrade to a paid plan to enable the advanced advanced settings',
    'html_mode' => 'HTML Mode',
    'html_mode_help' => 'Preview updates faster but is less accurate',

);

return $LANG;

?>
